(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    280566,       5079]
NotebookOptionsPosition[    276887,       5016]
NotebookOutlinePosition[    277337,       5034]
CellTagsIndexPosition[    277294,       5031]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Goldbeter & Dupont, Allosteric regulation, cooperativity and biochemical \
oscillations, Biophysical Chemistry, 37, 341, 1990\n\nSection ",
 StyleBox["Allosteric model for glycolytic oscillations",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.8013020323003674`*^9, 3.8013020326085157`*^9}, {
  3.801302321748168*^9, 
  3.801302363434722*^9}},ExpressionUUID->"7c230cf9-21f3-4e48-9c7e-\
7eca40ed24ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Plot", ",", "LogPlot", ",", "LogLinearPlot"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
       RowBox[{"FontColor", "\[Rule]", "Black"}]}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "18", ",", 
       RowBox[{"Thickness", "\[Rule]", "0.0025"}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Marketing\>\""}]}], "]"}]}], 
    "\[IndentingNewLine]", ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"ColorData", "[", 
      RowBox[{"68", ",", "\"\<ColorList\>\""}], "]"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Prolog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          RowBox[{
           GraphicsBox[{
             {GrayLevel[0], RectangleBox[{0, 0}]}, 
             {GrayLevel[0], RectangleBox[{1, -1}]}, 
             {RGBColor[
               Rational[223, 255], 
               Rational[72, 85], 
               Rational[40, 51]], RectangleBox[{0, -1}, {2, 1}]}},
            AspectRatio->1,
            Frame->True,
            
            FrameStyle->RGBColor[
             0.5830065359477125, 0.5647058823529412, 0.5228758169934641],
            FrameTicks->None,
            
            ImageSize->
             Dynamic[{
              Automatic, 
               1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                Magnification])}],
            PlotRangePadding->None], "\[InvisibleSpace]"}],
          "RGBColor[{223/255, 72/85, 40/51}]"],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
               Rational[223, 255], 
               Rational[72, 85], 
               Rational[40, 51]]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[{
          Rational[223, 255], 
          Rational[72, 85], 
          Rational[40, 51]}],
        Editable->False,
        Selectable->False], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"Scaled", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
         RowBox[{"Scaled", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "]"}]}], "}"}]}]}], "]"}],
   ";"}]], "Input",
 CellChangeTimes->{3.895114192833994*^9},
 CellLabel->
  "In[201]:=",ExpressionUUID->"24404dde-2eae-4a6f-a8e8-6e5d3419ca58"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Odes", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}], "==", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "M"], "*", "\[CapitalPhi]"}], "-", 
       RowBox[{
        SubscriptBox["k", "s"], "*", 
        RowBox[{"\[Gamma]", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Alpha]", "'"}], "[", "t", "]"}], "\[Equal]", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], "-", 
       RowBox[{
        SubscriptBox["\[Sigma]", "M"], "*", "\[CapitalPhi]"}]}]}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fcs", "=", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"\[CapitalPhi]", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Alpha]", "[", "t", "]"}], "*", "e", "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"\[Alpha]", "[", "t", "]"}], "*", "e"}]}], ")"}], "*", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Gamma]", "[", "t", "]"}]}], ")"}], "2"]}], "+", 
         RowBox[{"L", "*", "\[CapitalTheta]", "*", 
          RowBox[{"\[Alpha]", "[", "t", "]"}], "*", "c", "*", "es", "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"\[Alpha]", "[", "t", "]"}], "*", "c", "*", "es"}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"L", "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"\[Alpha]", "[", "t", "]"}], "*", "c", "*", "es"}]}], 
           ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Gamma]", "[", "t", "]"}]}], ")"}], "2"], "*", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"\[Alpha]", "[", "t", "]"}], "*", "e"}]}], ")"}], 
           "2"]}]}], ")"}]}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"e", "\[Rule]", 
       FractionBox["1", 
        RowBox[{"1", "+", "\[Epsilon]"}]]}], ",", 
      RowBox[{"es", "\[Rule]", 
       FractionBox["1", 
        RowBox[{"1", "+", "\[Epsilon]s"}]]}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Parm", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Epsilon]", "\[Rule]", "0.1"}], ",", 
     RowBox[{"\[Epsilon]s", "\[Rule]", "0.1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"L", "\[Rule]", 
      SuperscriptBox["10", "6"]}], ",", 
     RowBox[{"c", "\[Rule]", 
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], "\[Rule]", "0.7"}], ",", 
     RowBox[{
      SubscriptBox["k", "s"], "\[Rule]", "0.1"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["\[Sigma]", "M"], "\[Rule]", "4"}], ",", 
     RowBox[{"\[CapitalTheta]", "\[Rule]", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Init", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Alpha]", "[", "0", "]"}], "\[Equal]", "40"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "[", "0", "]"}], "\[Equal]", "8"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.6066437942850513`*^9, 3.6066437982595453`*^9}},
 CellLabel->
  "In[202]:=",ExpressionUUID->"296f46ce-02f4-4cd4-867d-3d01cffcaee2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sol", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Odes", "/.", "Fcs"}], "/.", "Parm"}], ",", "Init"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\[Alpha]", ",", "\[Gamma]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1000"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[206]:=",ExpressionUUID->"77662464-de02-4001-a7f2-526dae05c13e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]", "[", "t", "]"}], ",", 
        RowBox[{"\[Gamma]", "[", "t", "]"}]}], "}"}], "/.", "Sol"}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "1000"}], "}"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<time [-]\>\"", ",", "\"\<concentrations [-]\>\""}], 
      "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
       RowBox[{"FontWeight", "\[Rule]", "\"\<Plain\>\""}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", 
         RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "->", "0.7"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/goldbeterglycosc.pdf\>\"", ",", "%"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.425623935126266*^9, 3.425624017348428*^9}, {
  3.425624065732197*^9, 3.425624074727695*^9}, {3.425624107564961*^9, 
  3.425624145074726*^9}, {3.606641229067478*^9, 3.6066412442010517`*^9}, {
  3.895114200425192*^9, 3.8951142352821302`*^9}},
 CellLabel->
  "In[210]:=",ExpressionUUID->"4c84379a-cc8c-4d9a-87ea-b40f161a8e53"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], Thickness[0.005], Opacity[1.], 
      LineBox[CompressedData["
1:eJwVmXc81d8fx4nKKGRUdkhpUFlR0evae4d7r70pZV+Vca+4115ZiWiIilJG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       "]]},
     Annotation[#, "Charting`Private`Tag$75623#1"]& ], 
    TagBox[
     {RGBColor[0, 0, 1], Thickness[0.005], Opacity[1.], 
      LineBox[CompressedData["
1:eJwUV3c81e8Xt8neJCMklL3vRc8hZc/I3ntfe3MvGUlIKBmRFpWWSkJDIZX0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       "]]},
     Annotation[#, "Charting`Private`Tag$75623#1"]& ]}, {}},
  AspectRatio->0.7,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 14, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"concentrations [-]\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"time [-]\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Directive[
    GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->600,
  LabelStyle->{FontSize -> 14, FontWeight -> "Plain"},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1000}, {0., 110.78728065452033`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{
    RGBColor[
     NCache[{
       Rational[223, 255], 
       Rational[72, 85], 
       Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
      0.7843137254901961}]], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.425623889775853*^9, 3.425623894284762*^9}, {
   3.4256239440567923`*^9, 3.425624017756219*^9}, 3.425624075558614*^9, {
   3.425624114430488*^9, 3.425624145665379*^9}, 3.6066410014501343`*^9, {
   3.606641232549489*^9, 3.606641244753502*^9}, 3.606643800087153*^9, 
   3.606645533427806*^9, 3.737296871526931*^9, 3.738998188581867*^9, 
   3.738998223505272*^9, {3.895114195636713*^9, 3.8951142060222483`*^9}, 
   3.895114237453291*^9},
 CellLabel->
  "Out[210]=",ExpressionUUID->"cb9b583f-b6ee-4057-9e2a-1cb6f6d90936"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/goldbeterglycosc.pdf\"\>"], "Output",
 CellChangeTimes->{{3.425623889775853*^9, 3.425623894284762*^9}, {
   3.4256239440567923`*^9, 3.425624017756219*^9}, 3.425624075558614*^9, {
   3.425624114430488*^9, 3.425624145665379*^9}, 3.6066410014501343`*^9, {
   3.606641232549489*^9, 3.606641244753502*^9}, 3.606643800087153*^9, 
   3.606645533427806*^9, 3.737296871526931*^9, 3.738998188581867*^9, 
   3.738998223505272*^9, {3.895114195636713*^9, 3.8951142060222483`*^9}, 
   3.89511423764438*^9},
 CellLabel->
  "Out[211]=",ExpressionUUID->"af33bfb9-7532-4d98-b83e-a0b6080968c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Nullcline1", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"0", "==", 
       RowBox[{
        RowBox[{"Odes", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "/.", "Fcs"}], ",", 
     RowBox[{"{", " ", 
      RowBox[{"\[Alpha]", "[", "t", "]"}], "}"}]}], "]"}], "/.", 
   "Parm"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t", "]"}], "\[Rule]", "10"}]}]}], "Input",
 CellChangeTimes->{{3.6066422132400627`*^9, 3.606642215200252*^9}, {
  3.6066438106353893`*^9, 3.606643810774336*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"ee989146-4196-49f4-ba9a-8837bbd65160"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"3.993484`", "\[VeryThinSpace]", "+", 
          RowBox[{"7.986000000000001`", " ", 
           RowBox[{"\[Gamma]", "[", "t", "]"}]}], "+", 
          RowBox[{"3.9930000000000003`", " ", 
           SuperscriptBox[
            RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "47.383599999999994`"}], "-", 
        RowBox[{"6.9212`", " ", 
         RowBox[{"\[Gamma]", "[", "t", "]"}]}], "-", 
        RowBox[{"3.4606`", " ", 
         SuperscriptBox[
          RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"47.383599999999994`", "\[VeryThinSpace]", "+", 
             RowBox[{"6.921200000000001`", " ", 
              RowBox[{"\[Gamma]", "[", "t", "]"}]}], "+", 
             RowBox[{"3.4606000000000003`", " ", 
              SuperscriptBox[
               RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}]}], ")"}], "2"], 
          "-", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1.0248710248699998`*^6"}], "-", 
             RowBox[{"2.04974`", " ", 
              RowBox[{"\[Gamma]", "[", "t", "]"}]}], "-", 
             RowBox[{"1.02487`", " ", 
              SuperscriptBox[
               RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"3.993484`", "\[VeryThinSpace]", "+", 
             RowBox[{"7.986000000000001`", " ", 
              RowBox[{"\[Gamma]", "[", "t", "]"}]}], "+", 
             RowBox[{"3.9930000000000003`", " ", 
              SuperscriptBox[
               RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}]}], ")"}]}]}]]}], 
       ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"3.993484`", "\[VeryThinSpace]", "+", 
          RowBox[{"7.986000000000001`", " ", 
           RowBox[{"\[Gamma]", "[", "t", "]"}]}], "+", 
          RowBox[{"3.9930000000000003`", " ", 
           SuperscriptBox[
            RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "47.383599999999994`"}], "-", 
        RowBox[{"6.9212`", " ", 
         RowBox[{"\[Gamma]", "[", "t", "]"}]}], "-", 
        RowBox[{"3.4606`", " ", 
         SuperscriptBox[
          RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"47.383599999999994`", "\[VeryThinSpace]", "+", 
             RowBox[{"6.921200000000001`", " ", 
              RowBox[{"\[Gamma]", "[", "t", "]"}]}], "+", 
             RowBox[{"3.4606000000000003`", " ", 
              SuperscriptBox[
               RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}]}], ")"}], "2"], 
          "-", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1.0248710248699998`*^6"}], "-", 
             RowBox[{"2.04974`", " ", 
              RowBox[{"\[Gamma]", "[", "t", "]"}]}], "-", 
             RowBox[{"1.02487`", " ", 
              SuperscriptBox[
               RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"3.993484`", "\[VeryThinSpace]", "+", 
             RowBox[{"7.986000000000001`", " ", 
              RowBox[{"\[Gamma]", "[", "t", "]"}]}], "+", 
             RowBox[{"3.9930000000000003`", " ", 
              SuperscriptBox[
               RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}]}], ")"}]}]}]]}], 
       ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4256238965452957`*^9, {3.606642206383216*^9, 3.606642215989211*^9}, {
   3.606643800968053*^9, 3.6066438144839687`*^9}, 3.606645533679771*^9, 
   3.737296871921947*^9, 3.738998189775832*^9, 3.738998223825046*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"24aa40d0-75ab-4bb2-8bf8-dcaa39aae356"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"-", "46.5406577483626`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", "45.583082950040335`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4256238965452957`*^9, {3.606642206383216*^9, 3.606642215989211*^9}, {
   3.606643800968053*^9, 3.6066438144839687`*^9}, 3.606645533679771*^9, 
   3.737296871921947*^9, 3.738998189775832*^9, 3.738998223842474*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"c3fb94e3-58b6-4a56-9e30-c05233df91cd"]
}, Open  ]],

Cell["\[LineSeparator]Second solution is positive", "Text",
 CellChangeTimes->{
  3.60664380176511*^9},ExpressionUUID->"71f09bf2-f3a6-4f59-a126-1df6e80f1b8b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Nullcline2", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"0", "==", 
       RowBox[{
        RowBox[{"Odes", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "/.", "Fcs"}], ",", 
     RowBox[{"{", " ", 
      RowBox[{"\[Alpha]", "[", "t", "]"}], "}"}]}], "]"}], "/.", 
   "Parm"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t", "]"}], "\[Rule]", "10"}]}]}], "Input",
 CellChangeTimes->{{3.606642221386063*^9, 3.606642223967849*^9}, {
  3.606643812654201*^9, 3.606643812757514*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"29949b17-efc7-44e8-b706-06b106990a97"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"58.56399999999999`", "\[VeryThinSpace]", "+", 
        RowBox[{"9.0508`", " ", 
         RowBox[{"\[Gamma]", "[", "t", "]"}]}], "+", 
        RowBox[{"4.7916`", " ", 
         SuperscriptBox[
          RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "-", 
        RowBox[{"0.2662`", " ", 
         SuperscriptBox[
          RowBox[{"\[Gamma]", "[", "t", "]"}], "3"]}], "-", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4.840484`"}], "-", 
              RowBox[{"9.559000000000001`", " ", 
               RowBox[{"\[Gamma]", "[", "t", "]"}]}], "-", 
              RowBox[{"4.598`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "+", 
              RowBox[{"0.12100000000000001`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "3"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"146410.14641000002`", " ", 
               RowBox[{"\[Gamma]", "[", "t", "]"}]}], "+", 
              RowBox[{"0.29282`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "+", 
              RowBox[{"0.14641`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "3"]}]}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "58.56399999999999`"}], "-", 
              RowBox[{"9.050800000000004`", " ", 
               RowBox[{"\[Gamma]", "[", "t", "]"}]}], "-", 
              RowBox[{"4.7916`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "+", 
              RowBox[{"0.2662`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "3"]}]}], ")"}], "2"]}], 
          ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4.840484`"}], "-", 
          RowBox[{"9.559000000000001`", " ", 
           RowBox[{"\[Gamma]", "[", "t", "]"}]}], "-", 
          RowBox[{"4.598`", " ", 
           SuperscriptBox[
            RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "+", 
          RowBox[{"0.12100000000000001`", " ", 
           SuperscriptBox[
            RowBox[{"\[Gamma]", "[", "t", "]"}], "3"]}]}], ")"}]}], ")"}]}]}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"58.56399999999999`", "\[VeryThinSpace]", "+", 
        RowBox[{"9.0508`", " ", 
         RowBox[{"\[Gamma]", "[", "t", "]"}]}], "+", 
        RowBox[{"4.7916`", " ", 
         SuperscriptBox[
          RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "-", 
        RowBox[{"0.2662`", " ", 
         SuperscriptBox[
          RowBox[{"\[Gamma]", "[", "t", "]"}], "3"]}], "+", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4.840484`"}], "-", 
              RowBox[{"9.559000000000001`", " ", 
               RowBox[{"\[Gamma]", "[", "t", "]"}]}], "-", 
              RowBox[{"4.598`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "+", 
              RowBox[{"0.12100000000000001`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "3"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"146410.14641000002`", " ", 
               RowBox[{"\[Gamma]", "[", "t", "]"}]}], "+", 
              RowBox[{"0.29282`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "+", 
              RowBox[{"0.14641`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "3"]}]}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "58.56399999999999`"}], "-", 
              RowBox[{"9.050800000000004`", " ", 
               RowBox[{"\[Gamma]", "[", "t", "]"}]}], "-", 
              RowBox[{"4.7916`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "+", 
              RowBox[{"0.2662`", " ", 
               SuperscriptBox[
                RowBox[{"\[Gamma]", "[", "t", "]"}], "3"]}]}], ")"}], "2"]}], 
          ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4.840484`"}], "-", 
          RowBox[{"9.559000000000001`", " ", 
           RowBox[{"\[Gamma]", "[", "t", "]"}]}], "-", 
          RowBox[{"4.598`", " ", 
           SuperscriptBox[
            RowBox[{"\[Gamma]", "[", "t", "]"}], "2"]}], "+", 
          RowBox[{"0.12100000000000001`", " ", 
           SuperscriptBox[
            RowBox[{"\[Gamma]", "[", "t", "]"}], "3"]}]}], ")"}]}], ")"}]}]}],
     "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.425623898546011*^9, {3.60664221895793*^9, 3.6066422248877897`*^9}, {
   3.606643803657732*^9, 3.60664381662811*^9}, 3.606645533906851*^9, 
   3.73729687224135*^9, 3.738998191753953*^9, 3.738998224025983*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"f1037ca5-26aa-4b84-872a-87b0adf790ed"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", "57.32783799373094`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"-", "58.15207950971825`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.425623898546011*^9, {3.60664221895793*^9, 3.6066422248877897`*^9}, {
   3.606643803657732*^9, 3.60664381662811*^9}, 3.606645533906851*^9, 
   3.73729687224135*^9, 3.738998191753953*^9, 3.738998224040292*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"dfb7fcc7-a066-426e-9919-0f1a22235348"]
}, Open  ]],

Cell["First solution is positive", "Text",ExpressionUUID->"0b64dc8d-58d8-4883-a6a2-8fcee904b42f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PlA", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
          "Nullcline1", "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
         "\[RightDoubleBracket]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
          "Nullcline2", "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
         "\[RightDoubleBracket]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Gamma]", "[", "t", "]"}], ",", "0", ",", "39"}], "}"}], 
      ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\[Gamma]", ",", "\[Alpha]"}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"FontSize", "\[Rule]", "14"}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"Thickness", "[", "0.01`", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Blue", ",", 
           RowBox[{"Thickness", "[", "0.01`", "]"}]}], "}"}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.606643280210577*^9, 3.606643281546494*^9}, {
   3.606643425745529*^9, 3.606643425934503*^9}, 3.606644229140684*^9},
 CellLabel->"In[11]:=",ExpressionUUID->"34c67952-6840-4058-92cf-15011cb23e1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlB", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Gamma]", "[", "t", "]"}], ",", 
         RowBox[{"\[Alpha]", "[", "t", "]"}]}], "}"}], "/.", 
       "\[InvisibleSpace]", "Sol"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1000"}], "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]", ",", "\[Alpha]"}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FontSize", "\[Rule]", "14"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"LightBlue", ",", 
         RowBox[{"Thickness", "[", "0.01`", "]"}]}], "}"}], "}"}]}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6066432882755337`*^9, 3.606643290468162*^9}, {
   3.606643429704658*^9, 3.606643429830105*^9}, 3.606644231490101*^9},
 CellLabel->"In[12]:=",ExpressionUUID->"3f7a5434-4483-4652-b33f-76d4dd9ada96"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlC", "=", 
   RowBox[{"StreamPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Odes", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}], "/.", "Fcs"}], "/.", 
      "Parm"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Gamma]", "[", "t", "]"}], ",", "0", ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "[", "t", "]"}], ",", "0", ",", "200"}], "}"}], 
     ",", 
     RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
     RowBox[{"StreamStyle", "\[Rule]", "Gray"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]", "[", "t", "]"}], ",", 
        RowBox[{"\[Gamma]", "[", "t", "]"}]}], "}"}]}], ",", 
     RowBox[{"StreamScale", "\[Rule]", "0.1"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.606642834374886*^9, 3.6066429223784122`*^9}, {
   3.606642953153635*^9, 3.606642994360067*^9}, {3.606643242569089*^9, 
   3.606643264219741*^9}, {3.606643349305791*^9, 3.606643349446566*^9}, {
   3.606643476400402*^9, 3.606643514725144*^9}, {3.6066435638606653`*^9, 
   3.60664365687492*^9}, {3.606643691298108*^9, 3.606643700361596*^9}, {
   3.6066437405723047`*^9, 3.606643770449963*^9}, {3.6066438643664627`*^9, 
   3.6066438647513514`*^9}, {3.6066439573671293`*^9, 3.606644162978647*^9}, 
   3.6066442332834597`*^9},
 CellLabel->"In[13]:=",ExpressionUUID->"019eb0ae-cfe4-4e50-aac3-1700013d7b6a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"PlA", ",", "PlB", ",", "PlC", ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.606642858046023*^9, 3.606642867209697*^9}, {
  3.606643445844398*^9, 3.6066434549476967`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"3c7accf7-e2f4-4c1b-a3b4-8e8dec9ddee1"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], Thickness[0.01], Opacity[1.], 
       LineBox[CompressedData["
1:eJwVzXk81IkDxvFxNGNyX1OYyeTI1z2MCFmPvtVg5D6Sswkl2jBSuTYShVJ+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        "]]},
      Annotation[#, "Charting`Private`Tag$2633#1"]& ], 
     TagBox[
      {RGBColor[0, 0, 1], Thickness[0.01], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV13c8VX8YB3BkpEWRlTJS9rj32tL53KuUa49rZa80NaWsIjStEE2RsiqJ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        "]]},
      Annotation[#, "Charting`Private`Tag$2633#2"]& ]}, {}, {}}, {{}, {}, 
    TagBox[
     {RGBColor[0.87, 0.94, 1], Thickness[0.01], Opacity[1.], FaceForm[Opacity[
      0.3]], LineBox[CompressedData["
1:eJw0W3c41W/YNyKhzJAtySgZmSd5PsfenHPMcyRCCg1NSklCUVISKqVUitLQ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       "]]},
     Annotation[#, "Charting`Private`Tag$2681#1"]& ]}, {{}, {
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999977`, 1.}}], 
       ArrowBox[{{3.071747612188803, 122.25048283727504`}, {3.678941520949639,
         122.15109013518104`}, {4.64749390305172, 121.65961019859053`}, {
        5.824460466995765, 120.75454312853314`}, {6.866549184180312, 
        119.75865830031802`}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{7.089582170978519, 119.54551409859982`}, {7.311274985512327,
         119.33365064889755`}, {9.088545132484473, 117.37022021361136`}, {
        10.15261286151854, 116.07980171155029`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{10.345602062480635`, 115.83916476596299`}, {
        11.494657080006233`, 114.35261054980919`}, {12.755869584444444`, 
        112.61574674881749`}, {13.094968387579428`, 112.118098909155}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{13.268687306638798`, 111.86315597223172`}, {
        14.023723415846561`, 110.75509517950506`}, {15.600616544201873`, 
        108.26582041014349`}, {15.771659250243658`, 107.97198789517137`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{15.926861508758817`, 107.70536752296022`}, {
        17.124251774691515`, 105.64838303420805`}, {17.999992328292706`, 
        104.03764528070032`}, {18.189633570151926`, 103.66960713960181`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{18.330941588881476`, 103.39536963711728`}, {
        18.84495904719523, 102.3978122071232}, {19.929353567058932`, 
        100.15297990521223`}, {19.96486744328993, 100.07661468253518`}, {
        20.000307586602542`, 100.00021098378828`}, {20.33679874119913, 
        99.22632405259765}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{20.459812694665818`, 98.94340757874235}, {
        20.813511579043343`, 98.12994505392612}, {21.582479409281003`, 
        96.24507973697052}, {22.206041672420646`, 94.65838379486645}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{22.31888064779679, 94.37125746454775}, {22.474217149390466`,
         93.9759933324652}, {23.301509497204798`, 91.6982889639204}, {
        23.864747641419807`, 90.01021255702753}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{23.962390074011893`, 89.71756922584822}, {24.06435645272401,
         89.41196663133623}, {24.762758015948094`, 87.1170263347126}, {
        25.272351268164964`, 85.2798679202842}}]}, 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{25.354810782807746`, 84.98258927596024}, {25.39930004448052,
         84.8221989625519}, {25.976568395924748`, 82.53621540335638}, {
        26.443112856115814`, 80.48525429066662}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{26.509736013377594`, 80.18404807973779}, {
        26.953284067548626`, 77.99077972386102}, {27.3557910343199, 
        75.73863712257405}, {27.371594653514844`, 75.63781861482987}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{27.419370091813263`, 75.3330372646432}, {
        27.705143617186234`, 73.50995737227805}, {28.001341816147626`, 
        71.30474047297304}, {28.063029661804023`, 70.75098144412733}}]}, 
      {Arrowheads[{{0.02500000000000004, 1.}}], 
       ArrowBox[{{28.09718512602608, 70.44437490768365}, {28.24438563120407, 
        69.122986424659}, {28.42005597463323, 67.15171139879982}, {
        28.509396483252303`, 65.83584339329606}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{28.53029410893424, 65.52804889502315}, {28.55206373491455, 
        65.20741098102366}, {28.64149317276531, 63.29379234500375}, {
        28.689428548902747`, 61.4145626644133}, {28.691515684122077`, 
        60.903944591163764`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{28.692776670257025`, 60.595444066301674`}, {
        28.69695412404415, 59.5734291129256}, {28.665154158906763`, 
        57.774098864213855`}, {28.595112914207856`, 56.02027909195128}, {
        28.591931178100808`, 55.96968504368126}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{28.572568422180392`, 55.66179017914243}, {28.48791465066469,
         54.315676969811136`}, {28.342768992377273`, 52.662416451953874`}, {
        28.158308752178776`, 51.06213434807449}, {28.157123046288195`, 
        51.05394347100992}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{28.112925032960696`, 50.74862282063704}, {
        27.934752973886198`, 49.517807115148}, {27.67232070131652, 
        48.03241121014946}, {27.251471781200053`, 46.204737491386936`}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{27.182245916633974`, 45.904101592663416`}, {
        27.031702848613847`, 45.25031921183629}, {26.238207544606713`, 
        42.73967000893524}, {25.728367959934214`, 41.51820598708458}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{25.60953495014787, 41.23350811264338}, {25.306445912204484`,
         40.50737313529949}, {24.258376944244215`, 38.55067976938389}, {
        23.338813403329265`, 37.215761436816976`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{23.163804027074058`, 36.961702620498826`}, {
        23.106774796153363`, 36.87891403389123}, {21.864413623359376`, 
        35.50140005152425}, {19.848496716429274`, 33.93038171551122}, {
        19.743769667286454`, 33.87994374980866}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{19.46582220670432, 33.74608048717786}, {17.78456272290284, 
        32.93636314218299}, {15.750047278524853`, 32.450518974388615`}, {
        15.080692455572635`, 32.42781776383679}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{14.772366625673316`, 32.417360874092964`}, {
        13.809906070967356`, 32.38471896437483}, {12.009690507969097`, 
        32.667514737519355`}, {10.36930774329916, 33.23448734702978}, {
        10.275587284226212`, 33.2853620250329}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{10.004455675382637`, 33.43254155693905}, {8.902306436136492,
         34.03082594663024}, {7.603054624085061, 35.01484250447638}, {
        6.466667398681671, 36.14893137286394}, {6.381324282976753, 
        36.2576102483923}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{6.190789895668938, 36.50024332771054}, {5.479416594608477, 
        37.406130695444524`}, {4.629267942660546, 38.761289209862156`}, {
        3.901459441318529, 40.19638814343123}, {3.799569904373123, 
        40.443045322091066`}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{3.681786431971833, 40.728179005747194`}, {
        3.2825796944198524`, 41.69459038162114}, {2.7592040450014994`, 
        43.24380671289156}, {2.2772225587256125`, 45.129889913909835`}}]}, 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{2.200840336491165, 45.42878775607793}, {2.020675019935405, 
        46.133808149262606`}, {1.488282055683482, 49.10978302444616}, {
        1.3721589807760686`, 49.97870631476107}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{1.3312938715172231`, 50.28449089051904}, {1.215639059753147,
         51.1499102712831}, {1.0010634329557844`, 53.20870799033989}, {
        0.8652755912391743, 54.887709905219054`}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{0.8404068631021216, 55.19520902763579}, {0.8334640592057868,
         55.281056043754546`}, {0.7036513876217589, 57.36271151876746}, {
        0.6036542190465783, 59.45017741549053}, {0.5903679511659297, 
        59.81579655019907}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{0.5791646228563587, 60.124096159931234`}, {
        0.527670488649498, 61.54114125945835}, {0.4706485927300826, 
        63.633465813279365`}, {0.44847805821811226`, 64.74971036078915}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{0.4423518648149389, 65.05815263039662}, {
        0.42909392129147256`, 65.72566505150094}, {0.39606349565708227`, 
        68.13259231821772}, {0.3832375830342354, 69.68528790868665}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{0.38068930578999954`, 69.99378048592199}, {
        0.3762132610477469, 70.53564718487777}, {0.3675464845685478, 
        72.93337895408833}, {0.3677520396735525, 74.6212928530036}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{0.3677896093547374, 74.92979595268775}, {
        0.36783761295143846`, 75.32397705593854}, {0.37599620781279325`, 
        77.70580794990278}, {0.38748869198895514`, 79.55729283881126}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{0.3894035867522398, 79.86578999780023}, {
        0.39071298959854556`, 80.07674000184353}, {0.41149714245377444`, 
        82.43478100580995}, {0.43511626051136143`, 84.49310535857106}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{0.4387232011216587, 84.80158728599396}, {
        0.47168856639896406`, 87.10398721829769}, {0.5119123069268132, 
        89.40984401222573}, {0.512322086491266, 89.42854253377281}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{0.51908133319847, 89.73697157992471}, {0.5800748481464346, 
        92.52014734665654}, {0.6324259587610072, 94.36310645780581}}]}, 
      {Arrowheads[{{0.02500000000000004, 1.}}], 
       ArrowBox[{{0.6411857667989628, 94.67148516927818}, {0.6668140392294625,
         95.57369827659014}, {0.779132236289728, 98.55241120650743}, {
        0.8174793841974488, 99.29556222428377}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{0.833377223798589, 99.60365542872398}, {0.9276711754182291, 
        101.43103112521428`}, {1.0532946773404872`, 103.2581567813669}, {
        1.140448872089729, 104.22051883936214`}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{1.1682739021566533`, 104.5277645580109}, {
        1.2116316362558264`, 105.00652336402986`}, {1.5692365461595197`, 
        107.5597473643783}, {1.9660783062258889`, 109.07740439317132`}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{2.0670190054452022`, 109.36668778378235`}, {
        2.600991490714892, 110.32753858333564`}, {3.535503513791577, 
        110.7645518834677}, {5.107322841050665, 110.14036090305113`}, {
        5.737403894908079, 109.6386575785888}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{5.978744950848913, 109.44648927047433`}, {6.246485719298506,
         109.23330013742088`}, {7.6721050565619295`, 107.81682285807697`}, {
        8.809885971962782, 106.53419004113891`}, {9.164042020822594, 
        106.09902284488022`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{9.358774731618569, 105.85974615301019`}, {10.05780075205092,
         105.00082197423997`}, {11.390199367193944`, 103.23096062061705`}, {
        12.137026988876132`, 102.1610414957861}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{12.31360600723934, 101.90807111372506`}, {
        12.770120635669592`, 101.25405977624607`}, {14.165387794616127`, 
        99.09789078420107}, {14.813338002278234`, 98.01524547693526}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{14.971767135985239`, 97.75052983040287}, {
        15.542952923987395`, 96.79614845102388}, {16.876922196582488`, 
        94.37734587511585}, {17.217201276786863`, 93.70557483789187}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{17.356606136116213`, 93.43036501044818}, {
        18.148120299453524`, 91.86777617847173}, {18.964909153275443`, 
        90.1297846666256}, {19.351336780553726`, 89.25583397917951}}]}, 
      {Arrowheads[{{0.025000000000000026`, 1.}}], 
       ArrowBox[{{19.47609371646632, 88.97368176694661}, {19.74515002446332, 
        88.36517986714236}, {20.485024550078332`, 86.58041897407229}, {
        21.18071436718159, 84.7819591814659}, {21.2152200643316, 
        84.68613547273205}}]}, 
      {Arrowheads[{{0.025000000000000036`, 1.}}], 
       ArrowBox[{{21.319740639017002`, 84.39587763322784}, {21.83183328243964,
         82.97377576712883}, {22.43995634229352, 81.15842577101265}, {
        22.79608764799791, 80.01086278773599}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{22.887525633711807`, 79.7162218898708}, {23.00420704346608, 
        79.34023903038671}, {23.523708882680243`, 77.52354538252017}, {
        23.99892717841994, 75.71139170389891}, {24.108565229737586`, 
        75.25339826941693}}]}, 
      {Arrowheads[{{0.02500000000000004, 1.}}], 
       ArrowBox[{{24.180387831545637`, 74.9533721408952}, {
        24.431094004461144`, 73.90609175056116}, {24.82048299046479, 
        72.1108756791046}, {25.147946599669385`, 70.42873765528066}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{25.202570799854936`, 70.12512465036153}, {25.47231712232157,
         68.56311390673481}, {25.736068513744158`, 66.8157379151811}, {
        25.89952180115122, 65.55101049214996}}]}, 
      {Arrowheads[{{0.0008465548937621196, 1.}}], 
       ArrowBox[{{25.939063854283297`, 65.24505201463982}, {
        25.959148565436312`, 65.0896456267853}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{2.1052435725958096`, 160.07717173753798`}, {
        2.700265001352796, 159.9822815067056}, {3.4982106147166054`, 
        159.6098111271194}, {4.903334041138486, 158.59433777203105`}, {
        5.950048183845587, 157.64849516430553`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{6.178943091711273, 157.44165879158695`}, {
        6.4971682308127585`, 157.1541009158205}, {8.394128305987103, 
        155.20363287936124`}, {9.382913686650003, 154.10531055928962`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{9.58485479460665, 153.872103917969}, {10.484899784099216`, 
        152.82280061173662`}, {11.834715617230678`, 151.16372302362086`}, {
        12.508271017843093`, 150.2861037336631}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{12.696099401787606`, 150.04136987390723`}, {
        13.186219105147314`, 149.40276092553304`}, {14.497085593604217`, 
        147.59385037416982`}, {15.393128597774338`, 146.28208749775007`}}]}, 
      {Arrowheads[{{0.025000000000000064`, 1.}}], 
       ArrowBox[{{15.567139655293714`, 146.0273438701807}, {15.76793507216811,
         145.73338925819752`}, {16.998767540839, 143.82137757761623`}, {
        18.034638435711507`, 142.113306889526}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{18.194408033788356`, 141.8494014084502}, {
        19.154943645131652`, 140.17441355913473`}, {20.081309329668905`, 
        138.47183011849737`}, {20.425249585604437`, 137.79589903326234`}}]}, 
      {Arrowheads[{{0.02500000000000006, 1.}}], 
       ArrowBox[{{20.565157252203022`, 137.52094447564752`}, {
        21.41565233186376, 135.8495028451282}, {21.459084991469716`, 
        135.7605307965274}, {21.502412324466768`, 135.67152686973012`}, {
        22.405822213577334`, 133.695200700354}, {22.5564134012491, 
        133.3450638632884}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{22.67830278407589, 133.0616610716996}, {23.260441505243815`,
         131.70814089754825`}, {24.37324864489447, 129.01926562682297`}, {
        24.46026960050361, 128.79120550336748`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{24.570250764817633`, 128.50297242507432`}, {
        25.40319830198314, 126.32002560694072`}, {26.159156006413404`, 
        124.1572513213863}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{26.260948574554735`, 123.86602557218576`}, {
        26.35029047650983, 123.61042083790156`}, {27.214525168474534`, 
        120.89045131970539`}, {27.63289896169899, 119.44705286500772`}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{27.718784519349764`, 119.15074587063663`}, {
        28.004318195039097`, 118.16564863718489`}, {28.72808537336534, 
        115.44154437517261`}, {28.911973730431242`, 114.68014684257282`}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{28.984399301243283`, 114.3802656984194}, {
        29.385826703453283`, 112.71813853366861`}, {29.977542185302905`, 
        109.9954311126728}, {30.002825897617203`, 109.86651930811209`}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{30.062201932124246`, 109.56378402696296`}, {
        30.510672560836085`, 107.27720690881449`}, {30.91296975212847, 
        105.01529942891918`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{30.966991548981305`, 104.7115630145876}, {
        30.992658571974665`, 104.56725071872289`}, {31.423500218718658`, 
        101.86556254239798`}, {31.66710816777509, 100.13750550262105`}}]}, 
      {Arrowheads[{{0.024999999999999977`, 1.}}], 
       ArrowBox[{{31.710172710229752`, 99.8320229186504}, {
        31.803197501068052`, 99.17214237983981}, {32.08210596162685, 
        96.92552295184738}, {32.26720894801791, 95.2383713072991}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{32.300853956628735`, 94.93170833705034}, {
        32.327652965869255`, 94.68744435517763}, {32.5420729482203, 
        92.45934393903084}, {32.720843565970235`, 90.32338915591586}}]}, 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{32.74395718802725, 90.01575711763833}, {32.88646958494844, 
        88.0388270451071}, {33.02091510817559, 85.84928526573063}, {
        33.04421618515342, 85.39806569439513}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{33.060126153029394`, 85.08997311602232}, {
        33.133171347211494`, 83.67547106367809}, {33.22547273648118, 
        81.51882178814972}, {33.26025642424868, 80.46686055717439}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{33.270451680369675`, 80.15852596508513}, {33.29616419269405,
         79.38090381366126}, {33.34239385787775, 77.26332321482549}, {
        33.360739404119784`, 75.53200618150468}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{33.36400821052757, 75.22352039766548}, {33.36460100443472, 
        75.16757689098824}, {33.36322490476738, 73.0951617414954}, {
        33.338704831278164`, 71.0475746656928}, {33.32816002045895, 
        70.59624744325647}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{33.32095411939304, 70.28782850914891}, {33.291480056369494`,
         69.02631256292631}, {33.22198985244379, 67.03287233254174}, {
        33.158316163161295`, 65.66331644210071}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{33.143988646375476`, 65.35514621935202}, {33.1306734919035, 
        65.06875087388498}, {33.01603215618658, 63.13705062294933}, {
        32.875970691049666`, 61.24136802700433}, {32.831044026804236`, 
        60.738477846005686`}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{32.803592635441625`, 60.43119851862021}, {32.7100338653731, 
        59.383941002309996`}, {32.51776644803728, 57.567007465126444`}, {
        32.30344719531023, 55.831147839308436`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{32.26065979612715, 55.52563223864069}, {32.052418913909335`,
         54.063572518331924`}, {31.77842833487796, 52.381546941241105`}, {
        31.515187644239997`, 50.959164541207514`}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{31.456884893851015`, 50.6562388033169}, {31.1456905327625, 
        49.168901701377195`}, {30.78638623700889, 47.64467911821147}, {
        30.397988799242313`, 46.17892093288171}, {30.390672371651345`, 
        46.15432703532986}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{30.3027059287209, 45.85863112929735}, {29.980113666257083`, 
        44.77424931106539}, {29.05439210180794, 42.15865442068323}, {
        28.75935581525124, 41.50010658362958}}]}, 
      {Arrowheads[{{0.02052498007366204, 1.}}], 
       ArrowBox[{{28.63322303313118, 41.21856673706986}, {28.006145118016022`,
         39.81887177248512}, {26.899378548470995`, 37.842154784489594`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999977`, 1.}}], 
       ArrowBox[{{1.1877839146345988`, 197.14244451277008`}, {
        1.726427649640342, 197.19562604504287`}, {2.5087148686509706`, 
        196.93634687568039`}, {3.1239279864419656`, 196.5814067762546}, {
        3.8802478151802458`, 196.0428580800406}, {4.785593798444957, 
        195.30368568053538`}, {5.123682525151464, 194.99971104983842`}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{5.353094029547918, 194.79344780644112`}, {5.831367712728095,
         194.3634332725848}, {6.609265399698234, 193.61851024406025`}, {
        7.430908618944678, 192.7961367140168}, {8.285480468952844, 
        191.90551731176643`}, {8.631880855226028, 191.53047445006527`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{8.841199890840647, 191.30384765276278`}, {9.162568326601829,
         190.95590653437947`}, {9.25113784780645, 190.8580470939724}, {
        9.339827604600435, 190.75969432464086`}, {9.428628956169508, 
        190.6608563792482}, {9.473056459197085, 190.61131712526685`}, {
        9.51750920431356, 190.5616591186896}, {9.561986147069321, 
        190.51188335083663`}, {9.606486251745833, 190.46199080649544`}, {
        9.651008491375292, 190.41198246388277`}, {11.036230986664766`, 
        188.80757580015165`}, {11.860577708917395`, 187.79823890209389`}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{12.055724385727535`, 187.5592997080378}, {
        12.416428146857209`, 187.1176510600253}, {13.674086968704684`, 
        185.494622837656}, {14.861732626375705`, 183.8804056254644}}]}, 
      {Arrowheads[{{0.024999999999999946`, 1.}}], 
       ArrowBox[{{15.0394742992574, 183.62826790717324`}, {16.07847881063906, 
        182.1402866624772}, {17.22521183072596, 180.40897870966768`}, {
        17.61784280166707, 179.7863642580776}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{17.782401729391736`, 179.52541498478428`}, {
        18.15613787735898, 178.9327629934035}, {19.0538380049731, 
        177.4431450112209}, {19.848702977911056`, 176.06536678260116`}, {
        20.13765899851448, 175.5428794822167}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{20.286961981095782`, 175.27291136684278`}, {
        20.615208865470358`, 174.67937873125925`}, {20.665925534732345`, 
        174.58566822183263`}, {20.716514032460385`, 174.49192573183632`}, {
        21.619430922097354`, 172.72321305295011`}, {22.382101561872574`, 
        171.14773932249167`}}]}, 
      {Arrowheads[{{0.025000000000000046`, 1.}}], 
       ArrowBox[{{22.515525059717838`, 170.86958629521308`}, {
        23.60885197558551, 168.53382364060212`}, {24.427984041749465`, 
        166.65615564762192`}}]}, 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{24.551341078284175`, 166.37338859603423`}, {
        24.66535140430171, 166.1120466844242}, {25.64913083639465, 
        163.68093549554794`}, {26.250615071141485`, 162.06974594008219`}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{26.358511138831187`, 161.78072586724412`}, {
        26.56019027186432, 161.24049007397326`}, {27.405909558674978`, 
        158.79378854310576`}, {27.853494269827753`, 157.40182902859456`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{27.94793139861047, 157.10813566361418`}, {
        28.193668544790864`, 156.34390902635116`}, {28.92346723021198, 
        153.8908515237094}, {29.25733835538302, 152.67022149588772`}}]}, 
      {Arrowheads[{{0.024999999999999935`, 1.}}], 
       ArrowBox[{{29.33873143000114, 152.37264909909925`}, {
        29.595305614938333`, 151.43461603518045`}, {30.21589296515104, 
        148.97685416249305`}, {30.471518396141803`, 147.88625569434313`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{30.541920412524536`, 147.58589304683937`}, {
        30.791938547031208`, 146.5192175073758}, {31.323442360578856`, 
        144.06170606982874`}, {31.521252356285856`, 143.06348544380575`}}]}, 
      {Arrowheads[{{0.024999999999999935`, 1.}}], 
       ArrowBox[{{31.581220052490043`, 142.76086680700658`}, {
        31.81040440579397, 141.60431984985186`}, {32.22098963145675, 
        139.3377411831013}, {32.408606833049376`, 138.20817285531896`}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{32.459155553826484`, 137.90383917207964`}, {
        32.59732438307537, 137.07197976856298`}, {32.94224540296938, 
        134.80769630654495`}, {33.149141046849905`, 133.32820606256914`}}]}, 
      {Arrowheads[{{0.025000000000000064`, 1.}}], 
       ArrowBox[{{33.1918671464718, 133.02267595875395`}, {33.25858943345828, 
        132.54555149735512`}, {33.54919321686165, 130.2862060413015}, {
        33.76929856896076, 128.43139866730843`}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{33.805652785747185`, 128.1250450565119}, {
        33.816893495499016`, 128.03032063869207`}, {34.06452701168992, 
        125.77855598983476`}, {34.2949305077539, 123.53157279503759`}, {
        34.29568998900248, 123.52355642253532`}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{34.32478766497283, 123.21642861659886`}, {34.50734812730867,
         121.2894914170409}, {34.69991859898678, 119.05226596087195`}, {
        34.7346009670803, 118.60713237032898`}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{34.7585652073802, 118.29956143686312`}, {34.87382054263, 
        116.82030774026904`}, {35.03023257808011, 114.59402806897049`}, {
        35.08767097323355, 113.68379638096725`}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{35.10709981536812, 113.37590567954948`}, {35.17033332517889,
         112.37383826071458`}, {35.29530140376809, 110.1601496292396}, {
        35.36595598392591, 108.75565290164707`}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{35.38145593349518, 108.44753942338042`}, {35.40631543368952,
         107.9533734882839}, {35.504554034784945`, 105.75392115158579`}, {
        35.57927340531419, 103.82425668992829`}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{35.590908150188504`, 103.51597389402738`}, {
        35.65972922962796, 101.37973020844869`}, {35.71586458796183, 
        99.20626480874108}, {35.72204230616896, 98.89032083533931}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{35.728073378656234`, 98.58187669113995}, {35.7581713466591, 
        97.04259126514413}, {35.78700417553619, 94.8892384338105}, {
        35.793857231228316`, 93.9548425432451}}]}, 
      {Arrowheads[{{0.025000000000000026`, 1.}}], 
       ArrowBox[{{35.796119796914724`, 93.64634773822769}, {35.8027177444095, 
        92.74673517089278}, {35.80566672309539, 90.61561033254344}, {
        35.79853818681358, 89.01884335612205}}]}, 
      {Arrowheads[{{0.023831181059344377`, 1.}}], 
       ArrowBox[{{35.797160932854204`, 88.71034332841094}, {35.7962057814103, 
        88.4963927749152}, {35.774048245288576`, 86.39048646964646}, {
        35.73871010408551, 84.29956465467914}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{40., 14.023394304819927`}, {39.30801894199879, 
        13.976139389030685`}, {37.61249959547127, 13.893649247618722`}, {
        35.97686359268448, 13.848544220548817`}, {35.37669246677031, 
        13.848185154881358`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{35.06818942000969, 13.84800058610153}, {32.88228186204385, 
        13.846692818495901`}, {30.442136273885396`, 13.932065331287978`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{30.13382181274878, 13.942852220564216`}, {30.02131399378762,
         13.946788491932647`}, {27.383824292634223`, 14.133716459332323`}, {
        25.523518755822106`, 14.332202595977863`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{25.216756789338415`, 14.36493270207725}, {
        24.959677063302113`, 14.392361939168207`}, {23.858409965537785`, 
        14.54212127656994}, {22.802851505469796`, 14.705105362396639`}, {
        21.09503554483423, 15.012414403104636`}, {21.039609526347082`, 
        15.023343438781861`}, {20.98432208065419, 15.034308877500743`}, {
        20.65079259546, 15.107356191810341`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{20.34943246914482, 15.173357996282014`}, {20.075367060806, 
        15.233381900953164`}, {19.20437199921492, 15.441779223328433`}, {
        17.39812185433061, 15.913099367987005`}, {15.884844123226436`, 
        16.38340512813587}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{15.594481274974681`, 16.48702230797306}, {
        12.910666782948727`, 17.543424278638874`}, {11.36654107355519, 
        18.352615506636003`}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{11.093285740254121`, 18.495813574879747`}, {
        10.568777345237773`, 18.770679532797626`}, {8.94018338404572, 
        19.870350800082193`}, {7.560795271816541, 21.018065918745187`}, {
        7.366591452193719, 21.213985246149676`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{7.149408174743152, 21.433087021409595`}, {6.386268883715335,
         22.202967536141443`}, {5.391885571022991, 23.420283553161482`}, {
        4.355000883154792, 25.097320199285814`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{4.1927637632652575`, 25.359719286281496`}, {
        3.8400425849900612`, 25.93020349610025}, {2.737253603235995, 
        28.51347855522866}, {2.388031800434857, 29.60708324553818}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{2.2941859242792058`, 29.900966071601218`}, {
        2.2514662355927295`, 30.034744809186787`}, {1.8541999317814348`, 
        31.568470338183676`}, {1.5289007339264638`, 33.11165908000701}, {
        1.305490621298403, 34.418368222722364`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{1.2553853806791495`, 34.72275093746666}, {1.047577293064693,
         36.218816654452766`}, {0.8720465071139439, 37.77966433788989}, {
        0.7317114534741488, 39.31971415868487}}]}, 
      {Arrowheads[{{0.006949433979049641, 1.}}], 
       ArrowBox[{{0.7086292618875155, 39.62734919036325}, {0.6141236952147705,
         40.91022609778878}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{24.23741200132958, 200.}, {24.72519502877346, 
        198.9027450192827}, {25.655250402798263`, 196.66230905136052`}, {
        26.016598627638288`, 195.7288653943696}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{26.12797050138742, 195.44116682005296`}, {
        26.524608967669806`, 194.4165605399645}, {27.33740713598702, 
        192.1667654228806}, {27.697219498436073`, 191.08848298493837`}}]}, 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{27.794870749947922`, 190.79584259639915`}, {
        28.314438347764654`, 189.23880711202514`}, {28.34594469253413, 
        189.13992231020623`}, {28.377356092579742`, 189.04103285635935`}, {
        29.135915989255523`, 186.45429895340587`}, {29.157625820819323`, 
        186.3742860054092}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{29.238410785413464`, 186.07654794364728`}, {
        29.838269868411082`, 183.86572961130943`}, {30.428597861989513`, 
        181.60473037144442`}}]}, 
      {Arrowheads[{{0.024999999999999953`, 1.}}], 
       ArrowBox[{{30.50653286273948, 181.30623363849023`}, {
        30.514278966953206`, 181.2765654947978}, {31.137598504268457`, 
        178.6862118294558}, {31.555791302783472`, 176.79941015888602`}}]}, 
      {Arrowheads[{{0.024999999999999953`, 1.}}], 
       ArrowBox[{{31.62254821812499, 176.49821640367136`}, {
        31.711882356236096`, 176.09515876703705`}, {32.24078439873539, 
        173.5038964592951}, {32.53058639629477, 171.96085587039286`}}]}, 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{32.58753145167085, 171.6576539169123}, {32.72742111153364, 
        170.91281632105762`}, {33.17490897439815, 168.32230976715226`}, {
        33.37088374946242, 167.09706970737597`}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{33.419608882570586`, 166.79243874156683`}, {
        33.472601855023335`, 166.4611251186047}, {33.7514721278172, 
        164.60042113270754`}, {34.01272385782135, 162.7403509043978}, {
        34.08220719468428, 162.212697485921}}]}, 
      {Arrowheads[{{0.024999999999999977`, 1.}}], 
       ArrowBox[{{34.12248430088014, 161.90683490461578`}, {34.25756111007735,
         160.8810675286125}, {34.487187949626815`, 159.02272410028877`}, {
        34.68559341303663, 157.31375562393046`}}]}, 
      {Arrowheads[{{0.02499999999999993, 1.}}], 
       ArrowBox[{{34.720105099063716`, 157.00719073760058`}, {
        34.9056266507725, 155.30946946577433`}, {35.0968466424519, 
        153.45486444945772`}, {35.198653534375154`, 152.40450490436666`}}]}, 
      {Arrowheads[{{0.02499999999999995, 1.}}], 
       ArrowBox[{{35.228415954222704`, 152.09744080309295`}, {
        35.27646459377506, 151.6017145685616}, {35.44410502417792, 
        149.75004582106786`}, {35.600414512017736`, 147.89996644416462`}, {
        35.63289818867817, 147.48765959604003`}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{35.657128582650515`, 147.18010951567237`}, {
        35.74603963565174, 146.05158467503995`}, {35.8816269734372, 
        144.20500875088214`}, {35.99383172798193, 142.56486472493216`}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{36.01440738745571, 142.25704928135582`}, {36.12527460489145,
         140.51770738621948`}, {36.23462805527474, 138.67719842009097`}, {
        36.29187602440544, 137.63785374114775`}}]}, 
      {Arrowheads[{{0.024999999999999925`, 1.}}], 
       ArrowBox[{{36.30884291336895, 137.3298175604723}, {36.33588044456172, 
        136.83894749811586`}, {36.42882888899386, 135.00308803112674`}, {
        36.513820156769924`, 133.16973714112743`}, {36.53334745390035, 
        132.70774802542533`}}]}, 
      {Arrowheads[{{0.02500000000000004, 1.}}], 
       ArrowBox[{{36.54637559107534, 132.39952013640817`}, {36.59120101608864,
         131.33901195012172`}, {36.66131823514877, 129.5110295801135}, {
        36.721422908419925`, 127.77530513615393`}}]}, 
      {Arrowheads[{{0.018496426973376563`, 1.}}], 
       ArrowBox[{{36.73132317382324, 127.46696133066004`}, {36.78114882528821,
         125.8637617911049}, {36.831555732765025`, 124.04471061611214`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{5.3756347378295715`, 76.15418172107175}, {6.206758263765832,
         75.98547126626923}, {7.323554898923964, 75.00865051677766}, {
        8.682257746178697, 73.15813057947862}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{8.85644866939536, 72.90389304058905}, {9.65533661283811, 
        71.56475594885484}, {10.552450541348247`, 69.86523578982643}, {
        11.036843970393091`, 68.82614329557445}}]}, 
      {Arrowheads[{{0.025000000000000036`, 1.}}], 
       ArrowBox[{{11.167191327405673`, 68.54652975790853}, {
        11.459444433472253`, 67.91960546305502}, {12.335135078639764`, 
        65.77603786170317}, {12.877234165306016`, 64.24910130679567}}]}, 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{12.980448476649611`, 63.95837640270232}, {
        13.022908920537969`, 63.83877759594276}, {13.632997829547907`, 
        61.836440066076555`}, {14.144612577024494`, 59.80915332525308}, {
        14.21010973531073, 59.49943450676952}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{14.273938181877103`, 59.19760658669726}, {
        14.358561827273041`, 58.79744364598982}, {14.541979460729374`, 
        57.79439998371399}, {14.673143471274358`, 56.95059106015665}, {
        14.681181265296003`, 56.894014968362214`}, {14.782634066850376`, 
        55.98089793554563}, {14.854144093694366`, 55.090282106568935`}, {
        14.876885895714652`, 54.61527266468259}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{14.891639053944278`, 54.30712252554832}, {14.93695350426615,
         53.3606367660831}, {14.90029691486088, 51.74567824214602}, {
        14.747885558481103`, 50.26620967195041}, {14.604605137514874`, 
        49.706968787505026`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{14.52803807452789, 49.40811824159325}, {14.063178432201273`,
         47.59371460036595}, {12.981626721949084`, 45.719434258492576`}, {
        12.518740636923498`, 45.35264799772501}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{12.276945196779051`, 45.161051731969195`}, {
        11.638713940396352`, 44.65532372759279}, {9.443600269052334, 
        44.462275313544254`}, {8.039894208922767, 45.250047754270234`}}]}, 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{7.770862168929353, 45.4010309499683}, {7.338350461976632, 
        45.64376040217089}, {5.5139803389415665`, 47.86623562745676}, {
        4.905592157583952, 48.965297778572754`}}]}, 
      {Arrowheads[{{0.009441272451751005, 1.}}], 
       ArrowBox[{{4.756183194938983, 49.23520725563418}, {4.735600518471692, 
        49.2723901618231}, {4.047855525797498, 50.83263512840472}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{40., 34.07626156945243}, {38.71275493672636, 
        32.6596741696054}, {36.849528058983935`, 30.857109581856577`}, {
        36.75662311853947, 30.779585834417954`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{36.51975362730216, 30.581932076428902`}, {34.97260186056974,
         29.290924275987066`}, {34.030101892593734`, 28.59579937372571}, {
        33.08647323583868, 27.95797544656502}, {32.82724580795551, 
        27.80221326537204}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{32.562808220482, 27.643320451634576`}, {31.603322956746247`,
         27.066793813529923`}, {31.553359925523086`, 27.039018975057427`}, {
        31.50340470603942, 27.011394190498102`}, {30.526668915518133`, 
        26.52649027302332}, {29.55709244488275, 26.094659375009385`}, {
        28.40266687862234, 25.636406308971672`}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{28.11592868860721, 25.522584631277727`}, {
        27.636047374041915`, 25.33209414825238}, {25.759108586287116`, 
        24.76122759928141}, {23.94081859048555, 24.361292959992735`}, {
        23.65517124726135, 24.327379943432376`}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{23.348819640028097`, 24.291008846778276`}, {
        21.24738017024002, 24.04151886120686}, {18.75575029568966, 
        24.021239330306045`}, {18.736203787630348`, 24.02311541468081}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{18.429111948399218`, 24.05259025486458}, {
        16.487811451775137`, 24.2389173224608}, {14.440423001011698`, 
        24.654965430560953`}, {13.879393578711857`, 24.831310260686788`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{13.585086753595728`, 24.923817863705583`}, {
        12.610629236186373`, 25.23011293227429}, {10.983147819145296`, 
        25.936380608906212`}, {9.544795929531904, 26.748583488298017`}, {
        9.398036263329043, 26.853037804799452`}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{9.146694361606825, 27.03192719063572}, {8.278326949316503, 
        27.649976596645732`}, {6.852014462975532, 28.941660064018855`}, {
        5.785663534632635, 30.18425655800315}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{4.544880839277144, 91.60854477089649}, {5.366254747550709, 
        91.34721505588145}, {6.857432309425567, 90.17176567953547}, {
        7.9798680961912085`, 88.96229630554093}, {8.114732550980415, 
        88.79256602426052}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{8.306653746604702, 88.55102841104808}, {9.290724839860538, 
        87.31255038717372}, {10.757985574141307`, 85.21916073940946}, {
        11.024666442534715`, 84.80890558739152}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{11.192803696162343`, 84.55024745806098}, {
        11.302790492367375`, 84.38104653236691}, {11.856941022707275`, 
        83.49359480388298}, {12.578366184331959`, 82.28337367002761}, {
        12.627243231414461`, 82.1991693891272}, {13.212710916686607`, 
        81.14270796747724}, {13.52428120175438, 80.55482197169255}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{13.668747877523918`, 80.28223520840731}, {
        13.793436286999183`, 80.04696704170384}, {14.604813182690343`, 
        78.46340048453796}, {15.394330603511492`, 76.81583726105289}, {
        15.702288636686012`, 76.12651707160882}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{15.828127116777923`, 75.84484555928573}, {16.15397078769133,
         75.1154909175255}, {16.875715973458565`, 73.37357500023269}, {
        17.553868835565652`, 71.60045394124683}, {17.568693508408707`, 
        71.55816351026863}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{17.670748818254776`, 71.26702973060979}, {
        18.182732048765054`, 69.80649217264026}, {18.6798026751829, 
        68.26209232403536}, {19.092947805450656`, 66.86442497349772}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{19.17678740028481, 66.56755757081342}, {19.553305167608848`,
         65.16594361012955}, {19.922888094038765`, 63.62954784350967}, {
        20.234207293953137`, 62.06418669642689}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{20.294383875084577`, 61.76160952774169}, {
        20.524724452225406`, 60.60342143605942}, {20.944174175317798`, 
        57.665567522633275`}, {20.984139433472798`, 57.18820825113064}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{21.009877745141303`, 56.88078069342204}, {
        21.179825553233194`, 54.85086357016532}, {21.23359049098748, 
        52.260893878554675`}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{21.223527613155266`, 51.95268556640555}, {21.11476221728007,
         49.711364562822865`}, {20.827748264491987`, 47.436437774266025`}, {
        20.8073126788369, 47.34814454444753}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{20.737748192952402`, 47.04758681916028}, {
        20.202223380676465`, 44.733818272379374`}, {19.398891328582945`, 
        42.62931818330033}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{19.270570745366847`, 42.34985400505218}, {
        18.262794242970216`, 40.62074191407673}, {17.0440236163572, 
        39.212974897570554`}, {16.389763956951445`, 38.81818735357129}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{16.12562306446944, 38.65880180577906}, {14.364160569174912`,
         37.59591577518419}, {11.805998370610393`, 37.34695503256548}}]}, 
      {Arrowheads[{{0.016793380605817792`, 1.}}], 
       ArrowBox[{{11.503046800387486`, 37.37403225908573}, {
        10.074408998097443`, 37.724793464019676`}, {8.611658318430067, 
        38.46066032064496}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{13.52033369630379, 200.}, {13.923330408754795`, 
        199.48244307093455`}, {14.674889977122344`, 198.46874282871744`}, {
        15.411591143122044`, 197.44317738366425`}, {16.235459534631783`, 
        196.2536914783826}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{16.409344488250174`, 195.9988778925216}, {
        17.256288789236002`, 194.72396142840316`}, {17.31645989112065, 
        194.63144518870746`}, {17.3764966311847, 194.538873549933}, {
        18.165165609541113`, 193.27217767678192`}, {18.876663956253516`, 
        192.08495261975392`}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{19.03251539745191, 191.8187205261554}, {20.38964476086486, 
        189.4732187581928}, {21.297805618756655`, 187.7841715334929}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{21.44390147706811, 187.51245446720802`}, {
        21.756607070488432`, 186.93086750480487`}, {23.029903385569753`, 
        184.3705420855173}, {23.49077994086614, 183.3632113899141}}]}, 
      {Arrowheads[{{0.02499999999999993, 1.}}], 
       ArrowBox[{{23.61913122614454, 183.08267598841618`}, {
        24.209533706108807`, 181.79224250033002`}, {25.304019173648967`, 
        179.20167142504334`}, {25.448581862021257`, 178.83281040607585`}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{25.56115263613421, 178.54557881877767`}, {26.32188092973359,
         176.6045315354576}, {27.186332721127233`, 174.21323353578168`}}]}, 
      {Arrowheads[{{0.025000000000000064`, 1.}}], 
       ArrowBox[{{27.289103609530258`, 173.92237501224605`}, {
        28.12773330753625, 171.39054531338886`}, {28.699513900512844`, 
        169.51534161951506`}}]}, 
      {Arrowheads[{{0.025000000000000064`, 1.}}], 
       ArrowBox[{{28.78949174051571, 169.2202515447334}, {28.924930864308113`,
         168.77606727484}, {29.663918579732112`, 166.15975700986036`}, {
        30.02743395549974, 164.76174587022132`}}]}, 
      {Arrowheads[{{0.02499999999999996, 1.}}], 
       ArrowBox[{{30.105070276754056`, 164.46317131412465`}, {
        30.34469645380826, 163.54161451845}, {30.967264486536536`, 
        160.92163980060883`}, {31.17585911368994, 159.9616228394064}}]}, 
      {Arrowheads[{{0.018134738914138172`, 1.}}], 
       ArrowBox[{{31.241362919215828`, 159.66015407587054`}, {
        31.461431186194407`, 158.64733187711613`}, {31.91651558934281, 
        156.3720784042921}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{34.39457648544936, 200.}, {34.62071768094246, 
        198.35154184053496`}, {34.876496403603575`, 196.36462251543534`}, {
        34.989748668010535`, 195.4109896078927}}]}, 
      {Arrowheads[{{0.025000000000000074`, 1.}}], 
       ArrowBox[{{35.02613045516043, 195.10463927006035`}, {35.23064677724186,
         193.38252363830924`}, {35.24202013894013, 193.28188529511408`}, {
        35.253355986277704`, 193.1812485038415}, {35.50355837182861, 
        190.69448649959463`}, {35.52125603426725, 190.5038462298844}}]}, 
      {Arrowheads[{{0.024999999999999963`, 1.}}], 
       ArrowBox[{{35.54977261552106, 190.19666392486047`}, {35.7343011365556, 
        188.20891174904585`}, {35.94850061811057, 185.72484085710363`}, {
        35.959395942279095`, 185.5873130936269}}]}, 
      {Arrowheads[{{0.02499999999999995, 1.}}], 
       ArrowBox[{{35.983760060711994`, 185.27977357802084`}, {
        36.14518470394291, 183.24216828879855`}, {36.34282355581401, 
        180.75964284420758`}, {36.34964214005979, 180.6667159076523}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{36.372218095565266`, 180.35903995773222`}, {
        36.524856544040006`, 178.2788099706819}, {36.6912836686209, 
        175.79966966822155`}, {36.694747517686295`, 175.74277115831842`}}]}, 
      {Arrowheads[{{0.025000000000000026`, 1.}}], 
       ArrowBox[{{36.7134937641262, 175.43483814259807`}, {36.84210492955668, 
        173.32222193682657`}, {36.97929670131964, 170.8467395163116}, {
        36.980905612783765`, 170.81504225816576`}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{36.996544694040026`, 170.50693581054793`}, {
        37.10483535838205, 168.3734951464914}, {37.218720900743904`, 
        165.9024888273659}, {37.21945447413378, 165.88477406944702`}}]}, 
      {Arrowheads[{{0.02499999999999993, 1.}}], 
       ArrowBox[{{37.23221873979228, 165.5765351402891}, {37.320953328405196`,
         163.43372055893516`}, {37.412890008915305`, 160.9674873648981}, {
        37.413393402091, 160.9525465855432}}]}, 
      {Arrowheads[{{0.011568476617483479`, 1.}}], 
       ArrowBox[{{37.42378176812043, 160.64421843928105`}, {37.49588830982359,
         158.50408626895359`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{40., 48.55908617703808}, {39.37763577323916, 
        47.10560280469558}, {38.64998357826448, 45.461807015842346`}, {
        38.124766166134414`, 44.32885367265984}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{37.99501394883216, 44.04896346913109}, {37.82041160235843, 
        43.672326465870555`}, {36.97779686191837, 41.96602209390175}, {
        36.01686074188897, 40.16365309913356}, {35.98406726073827, 
        40.1047521786967}, {35.95124608659113, 40.04598257992075}, {
        35.882590724095124`, 39.93308945790674}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{35.7222914397685, 39.66950208459271}, {35.060155169133665`, 
        38.580721426053024`}, {34.14965777615578, 37.21137077858591}, {
        33.16934856728165, 35.81171530176474}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{32.98032699465463, 35.56793424585802}, {32.142461616931996`,
         34.49493775969987}, {31.103946617926596`, 33.31093825383441}, {
        30.042153672658845`, 32.243083417020635`}, {29.899865093643886`, 
        32.12428934120508}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{29.663046834842557`, 31.926574202117234`}, {
        27.87842130235958, 30.436623692555386`}, {25.928451835057885`, 
        29.21183135558028}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{25.666180093207334`, 29.049648775810347`}, {
        23.491529281124073`, 28.059506003061657`}, {21.351937470930917`, 
        27.403188195579624`}, {21.351837686923332`, 27.403170710288833`}}]}, 
      {Arrowheads[{{0.020157655191839544`, 1.}}], 
       ArrowBox[{{21.04796467932544, 27.349922619434516`}, {
        19.293263693012232`, 27.0424439187761}, {17.34659520590225, 
        26.93229598556198}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{40., 22.927946822873082`}, {39.37123760980986, 
        22.656114023274228`}, {38.23646389382782, 22.206322321284336`}, {
        36.137539817928094`, 21.47724240786365}, {36.06757168367535, 
        21.455173358903544`}, {35.99766249102488, 21.433266377738423`}, {
        35.65735298543209, 21.33833874096028}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{35.36019434191348, 21.255447821624117`}, {34.84072187185542,
         21.110543570806854`}, {33.7033473931936, 20.828697181097144`}, {
        31.470392736491647`, 20.34180794073339}, {30.84725123642154, 
        20.242239187392073`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{30.542612533925606`, 20.19356244892477}, {
        29.325795489317073`, 19.99913316414354}, {27.277745447777452`, 
        19.782744701110182`}, {25.94301750725147, 19.728144182154846`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{25.634772211221595`, 19.71553460636209}, {
        24.463202527941576`, 19.66760850040658}, {21.87559146192606, 
        19.745533651594577`}, {21.01352451067879, 19.830181468313853`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{20.706497973094482`, 19.8603289250094}, {19.51820046309243, 
        19.97700987384881}, {17.380355387202922`, 20.339125214125424`}, {
        16.150946640207426`, 20.63809170551744}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{15.851179754093094`, 20.71098874191492}, {
        15.452321884017085`, 20.807982632898806`}, {13.718324218492144`, 
        21.366999168052356`}, {12.164238798435887`, 22.000776342373705`}, {
        11.5236631358352, 22.32251535863152}}]}, 
      {Arrowheads[{{0.0028620181952809577`, 1.}}], 
       ArrowBox[{{11.247979842721438`, 22.460981548815877`}, {
        10.774573482105502`, 22.69875720225919}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.0004915309243089558, 1.}}], 
       ArrowBox[{{7.736020448168252, 56.7776360271491}, {7.647186890504157, 
        56.79729710278575}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.00781745421506278, 1.}}], 
       ArrowBox[{{6.893035287526892, 62.46477481069313}, {6.803565173237479, 
        62.68035961432616}, {6.71086248414901, 62.99936526743542}, {
        6.680590895450599, 63.137252156343585`}, {6.663302677238241, 
        63.22933163588311}, {6.648073897444674, 63.32306137421523}, {
        6.635153877681116, 63.41769436784902}, {6.61952700702454, 
        63.574632678300226`}, {6.612065124359775, 63.72778020750365}, {
        6.613805283600151, 63.872807179287626`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02500000000000004, 1.}}], 
       ArrowBox[{{1.977015661743069, 167.06524410445454`}, {
        2.1773974359151658`, 167.055826611065}, {2.401185703386613, 
        167.01477213038055`}, {2.5227130496160273`, 166.9812612466519}, {
        2.6512567123219544`, 166.93830982473747`}, {2.9938008991010965`, 
        166.79157150311445`}, {3.385666980508659, 166.57829548518987`}, {
        3.441731573140869, 166.54476767363812`}, {3.6149925944270804`, 
        166.43291879715323`}, {3.797193178295238, 166.3088252761044}, {
        4.179698909948644, 166.0355877691066}, {4.598907920833262, 
        165.71109669539788`}, {5.055374164084877, 165.33346326124902`}, {
        5.8129513748989385`, 164.62913118575733`}}]}, 
      {Arrowheads[{{0.025000000000000036`, 1.}}], 
       ArrowBox[{{6.038891386828235, 164.41907101595922`}, {6.879629560962704,
         163.63742281603925`}, {8.611750212579675, 161.8297282745736}, {
        9.25595399875612, 161.09654781149024`}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{9.459582439894621, 160.86479444714416`}, {
        10.474338285085297`, 159.70988170608547`}, {12.38343602064045, 
        157.3529164968507}, {12.417767297232704`, 157.30738856119925`}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{12.603510238593266`, 157.06106819326158`}, {
        13.940518462774117`, 155.28801369491265`}, {15.32759452437586, 
        153.32100026570336`}}]}, 
      {Arrowheads[{{0.025000000000000053`, 1.}}], 
       ArrowBox[{{15.503201870791315`, 153.06739303700527`}, {
        16.914775247613218`, 150.92018060780043`}, {17.99063726683998, 
        149.1659025560009}}]}, 
      {Arrowheads[{{0.02499999999999994, 1.}}], 
       ArrowBox[{{18.15192112839741, 148.90291647285704`}, {
        18.304707545489293`, 148.65378614449952`}, {19.621207999988414`, 
        146.3487541422018}, {20.41023983112708, 144.86466394423445`}}]}, 
      {Arrowheads[{{0.024999999999999963`, 1.}}], 
       ArrowBox[{{20.5550628295669, 144.59226632484484`}, {20.86317480958635, 
        144.01273841307062`}, {22.0293166877561, 141.65316383514585`}, {
        22.58804986227381, 140.4360950543323}}]}, 
      {Arrowheads[{{0.0052380353894175115`, 1.}}], 
       ArrowBox[{{22.71676234486549, 140.1557251901327}, {23.121282668190496`,
         139.27457282765047`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{1.6879866506485053`, 180.57731315629076`}, {
        2.168644237060974, 180.52837117384905`}, {2.8000603020250763`, 
        180.28129016444697`}, {3.5573220632324603`, 179.8253073071619}, {
        4.5084979334145, 179.1079769938104}, {5.558584192364911, 
        178.19561453853893`}}]}, 
      {Arrowheads[{{0.025000000000000026`, 1.}}], 
       ArrowBox[{{5.787743404333031, 177.9891287882085}, {5.97023813532502, 
        177.82004417755394`}, {6.29105062452755, 177.515970297281}, {
        7.110150671341746, 176.71089644291612`}, {7.975450502505189, 
        175.82015249306895`}, {8.034552244587386, 175.7579992861362}, {
        8.093806331114564, 175.69550884914176`}, {8.506256139969162, 
        175.25084897947778`}, {8.923963004959536, 174.79199868546652`}, {
        9.021361915038431, 174.68121426825635`}}]}, 
      {Arrowheads[{{0.025000000000000046`, 1.}}], 
       ArrowBox[{{9.225059947151559, 174.44952206804354`}, {
        10.513955711754196`, 172.98349369041088`}, {12.122939279963058`, 
        171.027457407007}, {12.21000986639038, 170.91435947490152`}}]}, 
      {Arrowheads[{{0.02500000000000004, 1.}}], 
       ArrowBox[{{12.39820552268853, 170.66990792780737`}, {
        13.714088435719015`, 168.9606781814233}, {15.07352471639835, 
        167.08233496388857`}, {15.15905888749254, 166.95693939640807`}}]}, 
      {Arrowheads[{{0.024999999999999963`, 1.}}], 
       ArrowBox[{{15.33290164543553, 166.70208088774692`}, {16.38838481522666,
         165.15471204849885`}, {17.648270922302856`, 163.1914189756602}, {
        17.86624881988699, 162.83042294755583`}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{18.025714207333536`, 162.56633024767046`}, {
        18.85223178250865, 161.19752375350964`}, {19.9974627065709, 
        159.1798034667408}, {20.330864282921134`, 158.55466985288658`}}]}, 
      {Arrowheads[{{0.024999999999999946`, 1.}}], 
       ArrowBox[{{20.476041190222638`, 158.2824606878818}, {21.08402884845299,
         157.14247351046956`}, {22.11194363908928, 155.08961294128147`}, {
        22.554118180151598`, 154.1485904985673}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{22.68531764789933, 153.86937577189815`}, {
        23.082603708003333`, 153.02388363244302`}, {23.75935973967267, 
        151.50525630148792`}, {24.409202691605213`, 149.9834546406559}, {
        24.551397737157377`, 149.63535120214127`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{24.668058901305624`, 149.3497564950723}, {25.03213256380095,
         148.45847864994693`}, {25.62814935625989, 146.93032832936103`}, {
        26.197253068982025`, 145.3990036788982}, {26.32746514628315, 
        145.0304796069379}}]}, 
      {Arrowheads[{{0.02500000000000004, 1.}}], 
       ArrowBox[{{26.430242781093842`, 144.7396000412944}, {
        26.739443701967364`, 143.86450469855848`}, {27.2547212552159, 
        142.3268313883418}, {27.74308572872764, 140.78598374824816`}, {
        27.876189508048427`, 140.34427125305947`}}]}, 
      {Arrowheads[{{0.025000000000000064`, 1.}}], 
       ArrowBox[{{27.965199144092566`, 140.0488876911988}, {
        28.207915683452292`, 139.24341899022554`}, {28.652589680339585`, 
        137.7005943262218}, {29.07710771938951, 136.15750975623695`}, {
        29.224174057528725`, 135.59619594588392`}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{29.302363867660603`, 135.29776585772632`}, {
        29.481469800602078`, 134.61416528027098`}, {29.86567592397728, 
        133.07056089832395`}, {30.229726089515122`, 131.52669661039582`}, {
        30.391453406967972`, 130.80052251934367`}}]}, 
      {Arrowheads[{{0.011385286030896608`, 1.}}], 
       ArrowBox[{{30.458517518063186`, 130.4993970157256}, {
        30.573620297215598`, 129.98257241648656`}, {30.89735854707871, 
        128.4381883165962}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{1.4536587755692454`, 188.10057383380615`}, {
        1.8675085262578348`, 188.10590855386667`}, {2.4059496045767137`, 
        187.94924955267564`}, {3.1079186055725434`, 187.58027488010833`}, {
        3.292621233199174, 187.46298100831075`}, {3.487923642666767, 
        187.33171783513407`}, {4.057208658005836, 186.91376086690613`}, {
        4.704477129309104, 186.38929904270967`}, {4.750023707838047, 
        186.350895124805}, {4.795906686854995, 186.31201308539903`}, {
        5.065604226320336, 186.07606627807303`}, {5.345530060752943, 
        185.8250073771673}, {5.35451022099886, 185.81652149635295`}}]}, 
      {Arrowheads[{{0.025000000000000036`, 1.}}], 
       ArrowBox[{{5.578738460925225, 185.6046350636921}, {6.759923707133457, 
        184.48846375443645`}, {8.33115543534784, 182.87230756755784`}, {
        8.832811746740362, 182.31696797875463`}}]}, 
      {Arrowheads[{{0.024999999999999953`, 1.}}], 
       ArrowBox[{{9.039610590337569, 182.08803916402596`}, {9.992318158448777,
         181.03338039245398`}, {11.554359130369718`, 179.19203601026862`}, {
        12.049260420470997`, 178.57415379891606`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{12.242122255166045`, 178.33336659692168`}, {
        13.1295815363262, 177.22537735927716`}, {14.672985602100471`, 
        175.1751467583426}, {15.041354670096117`, 174.64967446867837`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{15.218443272010592`, 174.39706055180483`}, {
        16.139571553474774`, 173.08308652632778`}, {17.064188269054664`, 
        171.68305644996383`}, {17.528118868484242`, 170.95350839067405`}, {
        17.782328445549975`, 170.54575719595988`}}]}, 
      {Arrowheads[{{0.02499999999999996, 1.}}], 
       ArrowBox[{{17.945541522176885`, 170.28396404183968`}, {
        18.0084208433613, 170.18310584982464`}, {18.47990384366924, 
        169.40868416532246`}, {18.942468017808075`, 168.6305758726113}, {
        19.840640018137105`, 167.06469920596186`}, {20.26830114247184, 
        166.28231602687552`}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{20.416270221536468`, 166.01161450200544`}, {
        20.702819600850024`, 165.48738772151117`}, {21.529191266542668`, 
        163.90039121542893`}, {22.33158754026328, 162.2862985522029}, {
        22.519757517080073`, 161.89042380802405`}}]}, 
      {Arrowheads[{{0.02499999999999996, 1.}}], 
       ArrowBox[{{22.652197222230903`, 161.6117952229403}, {
        23.101068544795186`, 160.6674531817954}, {23.83763428013839, 
        159.04385510420633`}, {24.54128474629288, 157.4155043194357}, {
        24.55086224958757, 157.39218505104859`}}]}, 
      {Arrowheads[{{0.017230678976459513`, 1.}}], 
       ArrowBox[{{24.668067835746317`, 157.10681333819076`}, {
        25.212019943258674`, 155.78240082748354`}, {25.849839871035766`, 
        154.14454462834982`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{4.533737738978557, 98.93287607402902}, {4.886534812747349, 
        98.79810580178601}, {5.284104087111192, 98.58284010577296}, {
        5.73115301637393, 98.27787340942076}, {5.974472364124636, 
        98.089157038367}, {6.231703204991359, 97.87461905077947}, {
        6.780110290140317, 97.37250172947105}, {6.819045286573412, 
        97.3348938830715}, {7.18892014301759, 96.95444324168832}, {
        7.5799500346511985`, 96.53083315376588}, {8.044390096177466, 
        95.9952135450705}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{8.246496939525283, 95.76213204044562}, {8.616898974086148, 
        95.33496261806744}, {9.768217976103912, 93.87014460886313}, {
        10.733281639919877`, 92.54537896163643}, {11.048946120588559`, 
        92.08280196698861}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{11.222839204762941`, 91.82797779387597}, {11.73934071613128,
         91.07109277357306}, {12.769373595626357`, 89.46168426554446}, {
        13.694964261900932`, 87.91740495696492}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{13.851260980155601`, 87.65145615364119}, {14.83467509483369,
         85.8972691549937}, {15.838702029948898`, 83.97541095804692}, {
        16.03558523228598, 83.57278189173715}}]}, 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{16.171106433845473`, 83.29563902631556}, {
        16.735476964261597`, 82.14149292844199}, {17.599037157009562`, 
        80.25372535312975}, {18.094202818772953`, 79.08760901898009}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{18.214781443600643`, 78.80364606512715}, {18.41709229091235,
         78.32720352913691}, {19.17735204868952, 76.37702275349017}, {
        19.854201041430052`, 74.47719381148363}}]}, 
      {Arrowheads[{{0.021099377233815962`, 1.}}], 
       ArrowBox[{{19.95156658182861, 74.18447955080406}, {20.521841463896077`,
         72.43384578833894}, {21.106202800875952`, 70.45392345229263}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999963`, 1.}}], 
       ArrowBox[{{1.981068366177193, 173.08961780428336`}, {
        2.2484160511357327`, 173.0512436979087}, {2.600749835906721, 
        172.94215396031998`}, {2.7328170662361893`, 172.8844916565287}, {
        2.872234993590026, 172.81704817618956`}, {3.1664304698457384`, 
        172.66166654891077`}, {3.4925564429193323`, 172.46353375343844`}, {
        3.8528385686345574`, 172.21927740689554`}, {5.230104683055053, 
        171.11737322881984`}, {5.795610185235167, 170.5856191711102}}]}, 
      {Arrowheads[{{0.02500000000000004, 1.}}], 
       ArrowBox[{{6.020358598849389, 170.37428456792344`}, {6.958453298996249,
         169.49217880344207`}, {8.950802589116284, 167.39659388182892`}, {
        9.24799883462764, 167.06091866901124`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{9.452502497286973, 166.82993725009376`}, {10.00548612334229,
         166.20535703024132`}, {11.077672622765443`, 164.93788958098625`}, {
        12.246575170959968`, 163.4910153140618}, {12.41337104520226, 
        163.274692910892}}]}, 
      {Arrowheads[{{0.02499999999999996, 1.}}], 
       ArrowBox[{{12.60174816049084, 163.03038117076935`}, {13.41263616544563,
         161.97871701702317`}, {14.560768225233875`, 160.41545073531577`}, {
        15.338447402420487`, 159.2997690519439}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{15.514859861805322`, 159.0466824894796}, {
        15.675883969336152`, 158.815672514385}, {16.55003842736264, 
        157.49991717417274`}, {17.401778014448375`, 156.16481480616267`}, {
        18.019231127149272`, 155.15616934276812`}}]}, 
      {Arrowheads[{{0.025000000000000036`, 1.}}], 
       ArrowBox[{{18.180301098433414`, 154.89305220483}, {18.228799201652606`,
         154.81382774099777`}, {19.02879846003458, 153.45041830932092`}, {
        19.801576887598987`, 152.0761033796516}, {20.45510638078419, 
        150.86385521903165`}}]}, 
      {Arrowheads[{{0.016306472424683884`, 1.}}], 
       ArrowBox[{{20.599749967841152`, 150.591374860843}, {
        21.267982913208137`, 149.29776734564794`}, {21.960611385277844`, 
        147.8973358246735}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{5.280868964675092, 82.2385955233823}, {5.630771158717367, 
        82.13689788316438}, {5.82432384910739, 82.04559884556785}, {
        6.031282318319985, 81.92480579234483}, {6.308474378250321, 
        81.73068688925807}, {6.542554973816475, 81.5315776792702}, {
        6.790898361096887, 81.2992412304517}, {7.316368756721429, 
        80.76561826139195}, {7.899561729891373, 80.08957022396426}, {
        8.539448328755585, 79.26342545390219}, {8.617631764275494, 
        79.15090894122875}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{8.793671981653016, 78.8975633160605}, {9.417227965583855, 
        78.00018212141234}, {10.362607259844626`, 76.49286556578612}, {
        11.160368165278017`, 75.10736009205127}, {11.234036773431036`, 
        74.96897490494803}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{11.379005036963964`, 74.69665456693696}, {
        11.972068279170784`, 73.58259567815801}, {12.780819548800524`, 
        71.93593086150369}, {13.409629161871726`, 70.54011956142996}}]}, 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{13.536344316508432`, 70.25884134771334}, {
        13.569733921444833`, 70.18472417948558}, {14.323080345234544`, 
        68.35025668125581}, {15.025127768300493`, 66.45380941596649}, {
        15.196392039114185`, 65.94073465892906}}]}, 
      {Arrowheads[{{0.015825938353713157`, 1.}}], 
       ArrowBox[{{15.294072139534395`, 65.64810389857035}, {
        15.622667604766733`, 64.66369519682144}, {16.163250990329274`, 
        62.850976701098986`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{10.442324634687566`, 60.47069735008734}, {
        10.900084331695844`, 57.5806769306413}, {10.91076817225218, 
        55.87921280953671}}]}, 
      {Arrowheads[{{0.022974542407778277`, 1.}}], 
       ArrowBox[{{10.912705288019518`, 55.57071578927764}, {
        10.916473093000256`, 54.97067080018967}, {10.753262247846243`, 
        53.90123534306196}, {10.484436906907433`, 53.00680424025201}, {
        10.121319020318364`, 52.30808493591789}, {9.908380695061084, 
        52.0363395720386}, {9.67754331283442, 51.81819210073297}, {
        9.525786859871301, 51.709758289305015`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000026`, 1.}}], 
       ArrowBox[{{40., 76.0154777053897}, {39.74568242688206, 
        74.54229804548623}, {39.22226863552995, 71.48830519497594}, {
        39.216451065473386`, 71.45475070674289}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{39.163750002129866`, 71.150782350086}, {38.70216555601816, 
        68.48846290828651}, {38.36614960677493, 66.59249891238404}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{38.312313480992074`, 66.28872953359989}, {
        38.258204422251154`, 65.98342013547159}, {38.24316517811189, 
        65.899654645117}, {38.22811985443703, 65.81594277216855}, {
        37.705280071069474`, 63.024472913280476`}, {37.452089385968605`, 
        61.74191546579391}}]}, 
      {Arrowheads[{{0.025000000000000015`, 1.}}], 
       ArrowBox[{{37.39234065096397, 61.439253521388004`}, {37.16843401877151,
         60.305036760824045`}, {36.713361132774715`, 58.07617221549739}, {
        36.45818689052796, 56.90710352714723}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{36.392398417367886`, 56.605696757605656`}, {
        36.240283397751924`, 55.9087890098055}, {35.74920081370317, 
        53.80288714374843}, {35.325899256389455`, 52.10297012279223}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{35.25135436519557, 51.80360876402475}, {35.24011338062842, 
        51.75846661732616}, {34.70769988792385, 49.784989886062256`}, {
        34.1466391249856, 47.89191940548031}, {33.97261127661617, 
        47.35698679815437}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{33.87717058714733, 47.06361802217449}, {33.55693109181366, 
        46.079255175580315`}, {32.93857578840804, 44.346997196362274`}, {
        32.29447804855285, 42.71652120039924}}]}, 
      {Arrowheads[{{0.0075514766298671555`, 1.}}], 
       ArrowBox[{{32.17046896657231, 42.43405116952516}, {31.6062129206254, 
        41.15520847042712}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.018293594769487408`, 1.}}], 
       ArrowBox[{{5.361820167506735, 66.63578534268078}, {5.3460422900190965`,
         68.07014031636926}, {5.353788548824267, 68.20347342393295}, {
        5.363428749677902, 68.33416979573164}, {5.375017781313196, 
        68.46201029486309}, {5.390084220175965, 68.59906750398011}, {
        5.396965393614098, 68.65398961072935}, {5.416856863889017, 
        68.79341333542486}, {5.4263358068782805`, 68.85186066524147}, {
        5.444985009143602, 68.9556377075413}, {5.465529553823961, 
        69.05598559297098}, {5.488020771330979, 69.15270331114205}, {
        5.5125117065948235`, 69.2455834205392}, {5.880037753376069, 
        69.91338926740484}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{7.238791258424304, 200.}, {7.705782379433637, 
        199.52773152025736`}, {8.693808035088948, 198.48346407335006`}, {
        8.760602213078078, 198.41137632763312`}, {8.827484806990697, 
        198.33899141776007`}, {9.269345329470434, 197.85065153657942`}, {
        9.713147934597242, 197.35127965799433`}, {10.36580427524945, 
        196.59059496808067`}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{10.566689125863899`, 196.35645945022867`}, {
        11.45442320159945, 195.32178671656325`}, {13.173944268047487`, 
        193.17489494175933`}, {13.481421519528364`, 192.7634825161676}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{13.666107154965733`, 192.51636841298992`}, {
        14.841127801310343`, 190.94416073939863`}, {16.291629267552914`, 
        188.86994025044496`}, {16.36493703722537, 188.75814218403403`}}]}, 
      {Arrowheads[{{0.025000000000000053`, 1.}}], 
       ArrowBox[{{16.534102927086295`, 188.50015562307826`}, {
        17.67645108930587, 186.7580167437365}, {18.993020722979647`, 
        184.6159071983122}, {19.00794474253656, 184.58997315821543`}}]}, 
      {Arrowheads[{{0.02499999999999996, 1.}}], 
       ArrowBox[{{19.161817189236878`, 184.32258311712812`}, {
        20.238765624984683`, 182.4511285932109}, {21.409177983560507`, 
        180.27791622945395`}}]}, 
      {Arrowheads[{{0.021420854105020475`, 1.}}], 
       ArrowBox[{{21.548226635990087`, 180.0025308893911}, {22.52135312282706,
         178.07039287708392`}, {23.295594399931588`, 176.44355663356242`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{40., 92.50285384630774}, {39.99202917038874, 
        92.43639394096776}, {39.803858564604134`, 90.8330033142085}, {
        39.58723161756291, 88.95838704158326}, {39.46670643105797, 
        87.90614252575914}}]}, 
      {Arrowheads[{{0.025000000000000026`, 1.}}], 
       ArrowBox[{{39.43159970690763, 87.59964345260288}, {39.37372824982583, 
        87.0943969966301}, {39.16260589319872, 85.2416253900198}, {
        38.95312197948746, 83.40066443242353}, {38.90759598814868, 
        83.00186073668243}}]}, 
      {Arrowheads[{{0.021220964918311314`, 1.}}], 
       ArrowBox[{{38.87260564042677, 82.69534835603115}, {38.647894871662615`,
         80.72690170784986}, {38.6376076416148, 80.63714146711418}, {
        38.627319917216155`, 80.54741424141744}, {38.42260982716827, 
        78.79317210882351}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02499999999999994, 1.}}], 
       ArrowBox[{{29.521879043682276`, 200.}, {29.870207153620793`, 
        198.7921949960669}, {29.89766320868506, 198.6924355923035}, {
        29.925035050822263`, 198.5926736001259}, {30.647834813244128`, 
        195.71527367509646`}, {30.692028267844165`, 195.52349579592354`}}]}, 
      {Arrowheads[{{0.02499999999999993, 1.}}], 
       ArrowBox[{{30.761304387674713`, 195.22287147364165`}, {
        31.311131273871673`, 192.83689293674274`}, {31.78099303620763, 
        190.70911748468885`}}]}, 
      {Arrowheads[{{0.025000000000000053`, 1.}}], 
       ArrowBox[{{31.847515022360632`, 190.40787175561624`}, {
        31.946790808245424`, 189.95829999404356`}, {32.527176490111586`, 
        187.07928264265342`}, {32.74967603185057, 185.8693621016738}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{32.80547289920123, 185.56594675347915`}, {
        33.056612793576036`, 184.20028408968818`}, {33.539424192744654`, 
        181.32174754226372`}, {33.58780117874937, 181.00518485519825`}}]}, 
      {Arrowheads[{{0.025000000000000064`, 1.}}], 
       ArrowBox[{{33.634405448635704`, 180.70022222477513`}, {
        33.979194902721844`, 178.4440362762191}, {34.302447289010146`, 
        176.1212539555433}}]}, 
      {Arrowheads[{{0.0013537074453837778`, 1.}}], 
       ArrowBox[{{34.34497063586662, 175.8156955668541}, {34.37950913861198, 
        175.56751356739326`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000064`, 1.}}], 
       ArrowBox[{{0., 150.5208595089608}, {0.12711377599677462`, 
        151.45871870029134`}, {0.2746180177125814, 152.3907475262952}, {
        0.4458068792363493, 153.27396167312347`}, {0.651451867238498, 
        154.09325642211218`}, {0.7493816077743857, 154.40207113443614`}, {
        0.8576026310646192, 154.69393972136243`}, {0.9781223093239083, 
        154.96612174656372`}, {1.0055853805583848`, 155.01968711060107`}}]}, 
      {Arrowheads[{{0.0017661024321303934`, 1.}}], 
       ArrowBox[{{1.164058118195847, 155.28361867356818`}, {
        1.3596970506715462`, 155.54552476837173`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000036`, 1.}}], 
       ArrowBox[{{2.176179840573134, 145.7057790467152}, {2.634665101333651, 
        145.72361749825697`}, {3.391615006420987, 145.4827206667762}, {
        4.419047536459453, 144.85557479612072`}, {4.6628633217711295`, 
        144.67555071427518`}, {4.920511230831212, 144.47519209746082`}, {
        5.968811083770349, 143.5726528701333}, {6.00700350038547, 
        143.53769674682349`}, {6.045398559808579, 143.5024181171721}, {
        6.084504686555121, 143.46522314601947`}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{6.308043199946059, 143.25260918373763`}, {6.373666873189825,
         143.1901926051526}, {6.714965360120671, 142.85620032798914`}, {
        8.389046556438796, 141.1174504925018}, {9.470987397886626, 
        139.87729061586742`}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{9.673798261353511, 139.64482144030637`}, {10.24479117889874,
         138.9903286260464}, {12.192708370930042`, 136.5484490195949}, {
        12.572142538365352`, 136.0388504526005}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{12.756384089870751`, 135.79140507554712`}, {
        13.47783849784069, 134.8224566676103}, {14.76020952052205, 
        133.00512864523466`}, {15.422608720238642`, 132.01017173346082`}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{15.593573635247443`, 131.75337383284196`}, {
        16.01586877448592, 131.11906529537154`}, {17.220863595244083`, 
        129.18686696092445`}, {18.02631490446532, 127.81785927376457`}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{18.178398690380583`, 127.5494565835412}, {18.85554328341917,
         126.34594916350028`}, {19.633676252788067`, 124.89896866720167`}, {
        20.366258002513685`, 123.47239046296795`}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{20.502681944049996`, 123.19569734410292`}, {
        21.105448727620626`, 121.96602295393467`}, {21.799390941511398`, 
        120.48290101278391`}, {22.459829301776733`, 119.00293066540523`}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{22.580748572997557`, 118.71911473660083`}, {
        23.102345018168716`, 117.49229617334971`}, {23.711437046642956`, 
        115.9877822437728}, {24.29338677242388, 114.4779035375381}, {
        24.311690848977893`, 114.42798164967402`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{24.417891327354045`, 114.13833423933018`}, {
        24.848540314924318`, 112.96379749595394`}, {25.377243793557113`, 
        111.4466015603287}, {25.880180283564368`, 109.92701776790939`}, {
        25.930903417389523`, 109.7655765598256}}]}, 
      {Arrowheads[{{0.025000000000000026`, 1.}}], 
       ArrowBox[{{26.023375082500955`, 109.47125844098522`}, {
        26.35822540637635, 108.40549935362222`}, {26.81201410068812, 
        106.88281055529431`}, {27.24218130519476, 105.3597156107529}, {
        27.32970988588685, 105.03233736274991`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{27.409393137293307`, 104.73430256046751`}, {
        27.649399844393404`, 103.83661891635816`}, {28.034354199951053`, 
        102.31381414801893`}, {28.397696796317604`, 100.79189946288538`}, {
        28.52136735416624, 100.24271377635124`}}]}, 
      {Arrowheads[{{0.02044635936358142, 1.}}], 
       ArrowBox[{{28.589141678679617`, 99.9417473249601}, {28.74008005794291, 
        99.27147301810756}, {29.3645782747693, 96.23747747821966}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000053`, 1.}}], 
       ArrowBox[{{2.4329084507783403`, 132.3154443646602}, {
        2.9444506944730913`, 132.36047184190352`}, {3.6101247663676963`, 
        132.1753682847327}, {4.478494329014219, 131.68838196445031`}, {
        4.723084379899952, 131.51849394629886`}, {4.982797644588244, 
        131.3256344361808}, {5.860046033486573, 130.59631596773661`}, {
        5.923964638355166, 130.53946761374436`}, {6.248760163203779, 
        130.23738266689526`}, {6.346901857244096, 130.14283050622836`}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{6.569071583379866, 129.9287866398949}, {6.5888172158524165`,
         129.90976320411391`}, {7.631020441623927, 128.8555136135835}, {
        8.781120711772122, 127.59698339918593`}, {9.68855413133965, 
        126.51412673969536`}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{9.886703420251488, 126.27767162084623`}, {
        10.736422681992279`, 125.26368630640637`}, {11.758983559639475`, 
        123.95007627916311`}, {12.735455410488864`, 122.63257996864417`}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{12.915198537322985`, 122.38187001840863`}, {
        13.830170743877469`, 121.08557529145949`}, {14.85709159394066, 
        119.55617453745417`}, {15.496238090544699`, 118.54210514767823`}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{15.660733957945142`, 118.28111611814941`}, {
        16.46421858777287, 117.00630795978049`}, {18.00192108214066, 
        114.35454832739259`}, {18.027845228008943`, 114.30569385565747`}}]}, 
      {Arrowheads[{{0.025000000000000036`, 1.}}], 
       ArrowBox[{{18.172451449395677`, 114.03318109510768`}, {
        19.44670893604686, 111.63182227383076`}, {20.280412240645685`, 
        109.91444416640755`}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{20.41513939397902, 109.63691442371154`}, {
        20.796286446855316`, 108.85177467350556`}, {22.04453392834963, 
        106.03106323120555`}, {22.294843744132987`, 105.40934179674993`}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{22.410061959842206`, 105.12316191154657`}, {
        23.19210492991365, 103.18071760253245`}, {24.06071085440662, 
        100.80068206028095`}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{24.1664771022391, 100.51087580647393`}, {
        24.239303501824487`, 100.31132683433376`}, {25.189470813052623`, 
        97.43022534010916}, {25.583995774883416`, 96.10637582732754}}]}, 
      {Arrowheads[{{0.02500000000000004, 1.}}], 
       ArrowBox[{{25.67210450643808, 95.81072228794395}, {26.0635245542166, 
        94.49729147956131}, {26.848391435977703`, 91.57119360755419}, {
        26.901129386916292`, 91.34989087491964}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{26.972645126428294`, 91.04979145318032}, {27.54407145833594,
         88.65193172408785}, {27.984947906707287`, 86.53480977922916}}]}, 
      {Arrowheads[{{0.018616510617967052`, 1.}}], 
       ArrowBox[{{28.04784236379929, 86.23278585436009}, {28.1505646212913, 
        85.73950582916224}, {28.675395623722864`, 82.84460722067234}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.0019526820437628586`, 1.}}], 
       ArrowBox[{{1.9002136256710755`, 137.56895571311156`}, {
        2.2121613212208167`, 137.7515240058971}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{3.575665074877469, 138.29536228878177`}, {4.928431021470347,
         137.4160310819608}, {5.196023146834982, 137.20271818073377`}, {
        5.478180709793537, 136.9671422518784}, {6.5277112937711586`, 
        136.0110376936557}, {6.56561872285555, 135.97461426003622`}, {
        6.6037019702245825`, 135.93789589766314`}, {6.957025760505204, 
        135.58578341037625`}, {7.152802079011883, 135.3851935374782}}]}, 
      {Arrowheads[{{0.025000000000000046`, 1.}}], 
       ArrowBox[{{7.367005292880707, 135.16320401719355`}, {8.977050322246987,
         133.4203793625213}, {10.428360996811483`, 131.69467614471236`}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{10.626925687127725`, 131.4585697541046}, {
        10.783160738259562`, 131.27279607022146`}, {12.662515004146202`, 
        128.83361581234968`}, {13.422416958034962`, 127.77195541826873`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{13.60197679215223, 127.52109204928475`}, {
        14.184273802363123`, 126.70756384321942`}, {15.69645187899741, 
        124.45333923483292`}, {16.1798512714035, 123.67922033100744`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{16.343254286793787`, 123.41754568858373`}, {
        17.161875594327398`, 122.1066002484543}, {18.543371308631418`, 
        119.70300514534748`}, {18.689375448503228`, 119.42991377520143`}}]}, 
      {Arrowheads[{{0.024999999999999967`, 1.}}], 
       ArrowBox[{{18.834828963482167`, 119.15785231356732`}, {
        19.383199459059288`, 118.13216050704523`}, {20.19089827563769, 
        116.54252977281229`}, {20.921882890519015`, 115.02833332536095`}}]}, 
      {Arrowheads[{{0.008496421142536794, 1.}}], 
       ArrowBox[{{21.0522649533303, 114.74875087994539`}, {21.70762447799696, 
        113.31910065222513`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{4.73827980718606, 151.13592117797847`}, {4.998704644209536, 
        150.92632877726408`}, {5.272397529942968, 150.69710100643013`}, {
        6.4729072417076825`, 149.60222479789599`}, {6.516368622886137, 
        149.56041610040725`}, {6.560036619382623, 149.5182645155426}, {
        6.909738345691964, 149.17074977182904`}, {7.270707105101542, 
        148.80325501398286`}, {8.079589273145793, 147.94093959892368`}}]}, 
      {Arrowheads[{{0.02500000000000006, 1.}}], 
       ArrowBox[{{8.290651309930606, 147.71593519773458`}, {8.803539027283266,
         147.1691670745887}, {10.450784983984821`, 145.2654158946665}, {
        11.30194410316459, 144.20418592083232`}}]}, 
      {Arrowheads[{{0.02500000000000005, 1.}}], 
       ArrowBox[{{11.494965084738435`, 143.96352627610872`}, {
        12.152153341459654`, 143.14414026382414`}, {14.012118975493113`, 
        140.6427107651931}, {14.275877867480183`, 140.26581495924526`}}]}, 
      {Arrowheads[{{0.02500000000000007, 1.}}], 
       ArrowBox[{{14.452762094918297`, 140.01305789404265`}, {
        14.929343032817979`, 139.33205201273998`}, {15.825563549323917`, 
        137.99343697507788`}, {16.698566906193477`, 136.63034941165364`}, {
        16.995077186293887`, 136.14737912775252`}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{17.156485522919333`, 135.88446942311225`}, {
        17.550230717152537`, 135.2431182086481}, {18.37731855524781, 
        133.8360158438246}, {19.176593993526012`, 132.4133147949464}, {
        19.465556568899327`, 131.87502319242938`}}]}, 
      {Arrowheads[{{0.025000000000000026`, 1.}}], 
       ArrowBox[{{19.611470590132416`, 131.60320843504155`}, {
        19.947638757565063`, 130.97698027615715`}, {20.69164494581784, 
        129.5276590652465}, {21.40779169064351, 128.0676459854466}, {
        21.68825557787917, 127.46858253795473`}}]}, 
      {Arrowheads[{{0.012250742244939534`, 1.}}], 
       ArrowBox[{{21.819062006640273`, 127.18918346472616`}, {
        22.095258124401248`, 126.59923585998969`}, {22.75441246375553, 
        125.12352231130433`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.019290589276532148`, 1.}}], 
       ArrowBox[{{0.9287342046428377, 124.37190874513213`}, {
        1.1584987820112034`, 125.44614137872479`}, {1.270699640295517, 
        125.85270573527842`}, {1.3959541190644014`, 126.23557123218448`}, {
        1.5368622635012705`, 126.59084382706756`}, {1.6140447317209021`, 
        126.75685956586658`}, {1.6963817859953625`, 126.91414634410712`}, {
        1.9017204722935857`, 127.22897418249605`}, {1.991575910991892, 
        127.33007722180044`}, {2.087449523164963, 127.42150829804721`}, {
        2.292599565544837, 127.58313676300877`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{4.730510152429383, 126.14337874431466`}, {5.486159580677014,
         125.56499367177199`}, {5.541279143122309, 125.51931859977515`}, {
        5.850222657036531, 125.24848203752373`}, {6.175948258790657, 
        124.95007401976555`}, {7.216107263617621, 123.93666887070884`}, {
        8.103132821330318, 122.98692295398526`}}]}, 
      {Arrowheads[{{0.024999999999999984`, 1.}}], 
       ArrowBox[{{8.313705726646658, 122.76146072771918`}, {8.389922393155981,
         122.6798548853913}, {10.356997916182827`, 120.35889734132685`}, {
        11.265364001013342`, 119.19872025305324`}}]}, 
      {Arrowheads[{{0.019200623933149336`, 1.}}], 
       ArrowBox[{{11.453774627524028`, 118.95445959532128`}, {
        12.465125377818628`, 117.59360311497518`}, {13.536799604081086`, 
        116.07513118104359`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{4.008566924540302, 104.1117475674927}, {4.320099525128769, 
        104.04422580187772`}, {4.671152613994041, 103.908664649828}, {
        4.862832002788051, 103.81305056233681`}, {5.066165189827721, 
        103.69728852223669`}, {5.587319282270472, 103.34361850079028`}, {
        5.828087997872904, 103.1509249847175}, {6.081976290238816, 
        102.93470169023011`}, {6.616206371372245, 102.45387346147703`}, {
        7.20373638658604, 101.87372651031656`}, {7.660617351408538, 
        101.38619774820566`}}]}, 
      {Arrowheads[{{0.024999999999999974`, 1.}}], 
       ArrowBox[{{7.870292022035544, 101.15994428451192`}, {8.913123386335979,
         99.94557649668232}, {10.083900942927562`, 98.45872847244357}, {
        10.755606587107113`, 97.54458224604808}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{10.938279547217576`, 97.29597662750598}, {
        11.067526262864167`, 97.12008053610622}, {12.085078945942694`, 
        95.64856603867707}, {13.12091884988886, 94.05801901870794}, {
        13.49803712458493, 93.44222254794991}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{13.6591542923285, 93.17913430764924}, {14.159405832428366`, 
        92.36227351475068}, {15.187145566366393`, 90.5757763735212}, {
        15.950132464533246`, 89.15957860920467}}]}, 
      {Arrowheads[{{0.0010739639700300078`, 1.}}], 
       ArrowBox[{{16.096456000895714`, 88.88798408305843}, {
        16.190743724508117`, 88.71297444173537}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{19.388196327492803`, 200.}, {19.80787950264969, 
        199.28693117607355`}, {19.862757068485504`, 199.19162288155283`}, {
        19.917493996349712`, 199.09628199258586`}, {20.799047891223736`, 
        197.48060714654417`}, {21.601536497071372`, 195.93705263310167`}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{21.74128540118558, 195.66202343820763`}, {
        22.814399379362037`, 193.53019664649025`}, {23.768453018991906`, 
        191.5025754103468}}]}, 
      {Arrowheads[{{0.02500000000000004, 1.}}], 
       ArrowBox[{{23.89979908055525, 191.22342961324782`}, {
        23.913895604146504`, 191.1934706996164}, {24.941108410555742`, 
        188.84785283662274`}, {25.705474603312187`, 186.9632028318993}}]}, 
      {Arrowheads[{{0.02499999999999995, 1.}}], 
       ArrowBox[{{25.821422338838193`, 186.67731773863173`}, {
        25.896037798589738`, 186.49334305750924`}, {26.785912632149877`, 
        184.13259618923334`}, {27.418671233318147`, 182.33456586144223`}}]}, 
      {Arrowheads[{{0.015035555820850411`, 1.}}], 
       ArrowBox[{{27.521082366539126`, 182.04355705793517`}, {
        27.617961775137537`, 181.76826705875254`}, {28.392185227552716`, 
        179.40035566606687`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.0012464443687117198`, 1.}}], 
       ArrowBox[{{1.0347363647082388`, 192.40056229274418`}, {
        1.2389002792726305`, 192.50802592637578`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999977`, 1.}}], 
       ArrowBox[{{38.93662480076875, 200.}, {38.942989521414056`, 
        198.10068289277092`}, {38.9432745320644, 197.99939182999154`}, {
        38.94355597023258, 197.89810343847003`}, {38.94735354003774, 
        195.67699822953767`}, {38.947423316065255`, 195.37246818111078`}}]}, 
      {Arrowheads[{{0.02500000000000004, 1.}}], 
       ArrowBox[{{38.94749400242438, 195.06396508723705`}, {38.94786165773063,
         193.45937261902594`}, {38.947053994578624`, 191.2431388478825}, {
        38.94699949367508, 190.43641874878955`}}]}, 
      {Arrowheads[{{0.024999999999999953`, 1.}}], 
       ArrowBox[{{38.94697865162865, 190.12791564752177`}, {38.94690422184905,
         189.02620915705486`}, {38.945479163018845`, 186.81101955082985`}, {
        38.94271903054013, 185.50037248515926`}}]}, 
      {Arrowheads[{{0.015135958185949885`, 1.}}], 
       ArrowBox[{{38.94206934568931, 185.19187006728248`}, {
        38.940822501711025`, 184.59980703621736`}, {38.93487319941215, 
        182.39018535824988`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{40., 27.79047991998223}, {39.24155023186808, 
        27.25006612973871}, {39.180539280519916`, 27.209231924346952`}, {
        39.1195379858996, 27.168580784654303`}, {38.0444579866013, 
        26.507751239037038`}, {36.974719514106035`, 25.9013995581591}, {
        36.03602290746204, 25.413404749915863`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{35.76229856428285, 25.27110524929362}, {34.84732685069586, 
        24.795444164807346`}, {32.750341341048646`, 23.89515862179883}, {
        31.50848397585508, 23.465002407444587`}}]}, 
      {Arrowheads[{{0.011774175273512072`, 1.}}], 
       ArrowBox[{{31.216973346146943`, 23.364028565815257`}, {
        30.696555403371455`, 23.183765503066954`}, {29.126795882004906`, 
        22.7496977928629}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{39.38588427360094, 121.71883120030768`}, {39.24874920244715,
         119.06053931611491`}, {39.1494734937527, 117.09732804496406`}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{39.13389301032938, 116.78921862858326`}, {39.10366589873399,
         116.19146710448136`}, {39.09881811620477, 116.09481186584154`}, {
        39.09397308029799, 115.99816920794291`}, {38.96604137105343, 
        113.4238960976387}, {38.90394919743568, 112.16738889730904`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{38.888722637656315`, 111.85926178749312`}, {
        38.83930273697618, 110.85919273810788`}, {38.71197636182933, 
        108.30593171291017`}, {38.65846877705942, 107.23744732376383`}}]}, 
      {Arrowheads[{{0.025000000000000036`, 1.}}], 
       ArrowBox[{{38.64303888741275, 106.92933032904963`}, {38.58465585102519,
         105.76348882752566`}, {38.46730193533994, 103.44540387571077`}, {
        38.40821096657902, 102.30774696616203`}}]}, 
      {Arrowheads[{{0.004651982139464757, 1.}}], 
       ArrowBox[{{38.39220859715663, 101.99965917331868`}, {38.3475429551114, 
        101.13972782750204`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999935`, 1.}}], 
       ArrowBox[{{39.39344282057726, 157.8582758346721}, {39.319308221040224`,
         154.90139162161324`}, {39.316841901070504`, 154.80166589031603`}, {
        39.31437775541571, 154.70194578308528`}, {39.27866233669383, 
        153.2321533104513}}]}, 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{39.2711951699032, 152.92374059769287`}, {39.23138841899913, 
        151.2468867047225}, {39.190862944295155`, 149.52341456079472`}, {
        39.1618985664171, 148.29748499118526`}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{39.1546117632289, 147.98906795789185`}, {
        39.150122093256876`, 147.79904077347723`}, {39.10937752156016, 
        146.07689993523795`}, {39.06908915535343, 144.3598811172311}, {
        39.04577168892946, 143.36280159609183`}}]}, 
      {Arrowheads[{{0.011485831687870325`, 1.}}], 
       ArrowBox[{{39.03855908017347, 143.05438281877574`}, {39.0289832713427, 
        142.64491110731728`}, {38.98878614623397, 140.92891669335694`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.0010699151219555351`, 1.}}], 
       ArrowBox[{{4.439366773546875, 86.34686115818913}, {4.6290458919436706`,
         86.40380826477615}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{24.148387468995526`, 63.35523065698165}, {24.36804478700445,
         61.61844518410066}, {24.549116342106036`, 59.801905328804644`}, {
        24.554308687572217`, 59.74123218087513}, {24.559439309491463`, 
        59.680604341107596`}, {24.612379666596457`, 58.75246877112953}}]}, 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{24.629947962708133`, 58.44446630539597}, {
        24.655042507714132`, 58.00451574393126}, {24.703278970200767`, 
        56.371483580334704`}, {24.727670227090655`, 54.76222260305587}, {
        24.713592948922578`, 53.8186369719486}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{24.70899092806427, 53.51016819665645}, {24.70437107278706, 
        53.200503998412486`}, {24.517667305218872`, 50.23375195260555}, {
        24.338562636509696`, 48.90050153427205}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{24.297488264800496`, 48.59474499727748}, {
        24.150088974507415`, 47.49750857758137}, {23.757665031590555`, 
        45.5906430564154}, {23.34036098247555, 44.073355733534015`}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{23.254561363084274`, 43.777153949870524`}, {
        22.703601727766912`, 42.228109953196444`}, {22.052911026800086`, 
        40.792099555422}, {21.303541113620774`, 39.6014002035054}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{21.13921833967576, 39.34030215699943}, {20.55163551816907, 
        38.40667181975111}, {18.853750636346014`, 36.64712176403206}, {
        17.946933947095765`, 36.06193329614121}}]}, 
      {Arrowheads[{{0.004154693435392697, 1.}}], 
       ArrowBox[{{17.687718765596014`, 35.89465612015397}, {
        17.041542997837325`, 35.47766488917482}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.008966745306717004, 1.}}], 
       ArrowBox[{{0.9550086923301041, 140.67932616237874`}, {1.07788969579857,
         141.03152503097476`}, {1.1448261307706722`, 141.19835844583667`}, {
        1.2159839404003, 141.3582304776945}, {1.4174790968022517`, 
        141.72513812254167`}, {1.4952405085451421`, 141.83171148953426`}, {
        1.578046636604628, 141.93046845571212`}, {1.7549381917104268`, 
        142.11077303243508`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02500000000000003, 1.}}], 
       ArrowBox[{{30.227941780318986`, 124.66278999469195`}, {
        30.248612163888232`, 124.5686846596166}, {30.26921496094935, 
        124.47458156179934`}, {30.86432458631309, 121.45980338473281`}, {
        31.102879312175705`, 120.11894669240577`}}]}, 
      {Arrowheads[{{0.024999999999999963`, 1.}}], 
       ArrowBox[{{31.15691720773681, 119.8152131417902}, {31.39973634344539, 
        118.45038726394357`}, {31.90709516731157, 115.44456290035926`}, {
        31.935807517821196`, 115.25376519872722`}}]}, 
      {Arrowheads[{{0.013673310625160692`, 1.}}], 
       ArrowBox[{{31.981715952449868`, 114.94869704313545`}, {
        32.3583481246455, 112.4459220511848}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.018535888578187908`, 1.}}], 
       ArrowBox[{{5.18683545697011, 57.572862008353866`}, {4.927819076253576, 
        58.22101950338325}, {4.678127616331807, 58.91084066505195}, {
        4.55716215537087, 59.2700332510298}, {4.3286979864089865`, 
        60.03268256946788}, {4.111262605496907, 60.82774919325118}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.01394816848665691, 1.}}], 
       ArrowBox[{{0.11877402892844474`, 174.99042083792526`}, {
        0.19641866041685763`, 175.3462555971493}, {0.28096205710757166`, 
        175.69005444089672`}, {0.373869846737533, 176.0198658749745}, {
        0.4239442207475213, 176.1788854420066}, {0.4768110886188191, 
        176.33348266340133`}, {0.5608184734346342, 176.5531196207403}, {
        0.6657124613714646, 176.7877159802048}, {0.7236631709099213, 
        176.89504567590902`}, {0.7851271835479153, 176.9972441273587}, {
        0.9159540164737742, 177.19029355782288`}, {1.064225151535302, 
        177.3585468754644}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{17.836758333635, 52.41882716562478}, {17.68552858392814, 
        49.50419982918244}, {17.386205959045096`, 47.82161799275167}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{17.332173166462166`, 47.517883534298385`}, {
        17.235295332165666`, 46.97330430510135}, {16.68524897493003, 
        45.23480079781665}, {15.989397483705355`, 43.78520404483111}, {
        15.620103758992082`, 43.25881313053876}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{15.442924877466647`, 43.00626252597086}, {
        15.176267410769476`, 42.62616923354736}, {14.734157337672588`, 
        42.154269163292}, {14.274053404775824`, 41.752231466013406`}, {
        13.861698218491442`, 41.45774326078305}, {13.317368165939145`, 
        41.19294273996248}, {12.767477910270484`, 41.00413245461465}, {
        11.665214665996123`, 40.76978970525782}, {11.580013060613053`, 
        40.772736660201545`}}]}, 
      {Arrowheads[{{0.003783985651606831, 1.}}], 
       ArrowBox[{{11.271694329177599`, 40.78340079505863}, {10.57169013565357,
         40.80761255503025}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{40., 18.293247660539553`}, {39.91838280217102, 
        18.274398429640524`}, {37.43490582068342, 17.790284758124628`}, {
        37.35279068120179, 17.77627936714763}, {37.27078855074685, 
        17.76242030591259}, {35.99740296183149, 17.57859530021521}, {
        35.44102208566755, 17.510707236732227`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{35.13479018366284, 17.47334166272626}, {34.7543298364543, 
        17.426918938095373`}, {32.33034037425332, 17.183186375363665`}, {
        30.525297712726505`, 17.07891018199941}}]}, 
      {Arrowheads[{{0.012718978153452501`, 1.}}], 
       ArrowBox[{{30.217308109712004`, 17.061117813939283`}, {
        30.03259923882393, 17.05044729719896}, {27.863625715284368`, 
        17.01341142342857}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.011483460828984878`, 1.}}], 
       ArrowBox[{{0.12295263033912684`, 182.70476500423567`}, {
        0.19983024646919756`, 183.01812679462265`}, {0.28372783964686416`, 
        183.31988162113817`}, {0.3760832738019105, 183.60814782413175`}, {
        0.4259062716821176, 183.74660629727313`}, {0.4785290416349491, 
        183.88080399267287`}, {0.5718751763710227, 184.09082252950955`}, {
        0.689742949723346, 184.31150040121193`}, {0.7484404718479976, 
        184.40027414235462`}, {0.8106929278880386, 184.4840250098077}, {
        0.9431508232456599, 184.64044591109177`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{39.8360450182182, 100.4977532139398}, {39.57121189022927, 
        97.69901072197433}, {39.56240218353675, 97.60484593462115}, {
        39.55359999271348, 97.51070148345008}, {39.40427898791665, 
        95.89039644906224}}]}, 
      {Arrowheads[{{0.0011060952624654043`, 1.}}], 
       ArrowBox[{{39.37596850564588, 95.58319508103173}, {39.357180051455195`,
         95.37931869435087}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.012545369800822255`, 1.}}], 
       ArrowBox[{{0.21213909589771474`, 161.89382865931003`}, {
        0.3532389696475206, 162.56492336961455`}, {0.41325022262690353`, 
        162.81299766238092`}, {0.4771889345455679, 163.05426001487962`}, {
        0.630776965670129, 163.5453285991215}, {0.6878159517222749, 
        163.69376608325308`}, {0.748313145164596, 163.83677686942525`}, {
        0.8771598409637762, 164.11074785706487`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999935`, 1.}}], 
       ArrowBox[{{24.050667375430425`, 139.09277282855166`}, {
        25.138808415819433`, 136.35637289634818`}, {25.174019554567657`, 
        136.26383394033988`}, {25.20913199475756, 136.17128239786814`}, {
        25.703998518894785`, 134.77144831297122`}}]}, 
      {Arrowheads[{{0.024999999999999935`, 1.}}], 
       ArrowBox[{{25.806823732076115`, 134.48058556276}, {25.985404098430884`,
         133.97543342269026`}, {26.711557848753365`, 131.77539136752287`}, {
        27.250892169280117`, 130.08434046488162`}}]}, 
      {Arrowheads[{{0.013648240463813195`, 1.}}], 
       ArrowBox[{{27.344632279852046`, 129.7904238855667}, {27.41366349211637,
         129.5739805972998}, {28.067672921560426`, 127.36983239696549`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{15.645940531308757`, 28.478498060954184`}, {
        14.923832344683815`, 28.54094835276115}, {14.103532716414321`, 
        28.657360862791094`}, {14.049317311659843`, 28.666771891383473`}, {
        13.40184114910029, 28.813012909531952`}, {12.77726104374758, 
        28.98525162651727}, {11.187054747483032`, 29.60723405321278}}]}, 
      {Arrowheads[{{0.004534539575625783, 1.}}], 
       ArrowBox[{{10.899746775035345`, 29.719609730715597`}, {
        10.118061152161243`, 30.025352904900174`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{7.865619256051494, 41.100436269100896`}, {7.485421807031099,
         41.41217749322051}, {7.122723225898123, 41.74445103176369}, {
        6.778217739810412, 42.111194809821235`}, {6.446503885609523, 
        42.49839496127144}, {4.976207228327316, 44.68017509349443}}]}, 
      {Arrowheads[{{0.0009453117968391177, 1.}}], 
       ArrowBox[{{4.803801897579, 44.93600817551429}, {4.7060158217824, 
        45.08111339378734}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02388842384113254, 1.}}], 
       ArrowBox[{{40., 39.05219920228237}, {39.49104495545904, 
        38.2761521736692}, {39.44950916503885, 38.215031477106045`}, {
        39.40796230407946, 38.15405308472401}, {38.40454552993261, 
        36.77625952089566}, {37.392955083271566`, 35.48338156965631}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{30.535524069969057`, 0.}, {29.547727477342576`, 
        0.22762360385071378`}, {27.33746943198886, 0.7704619417750989}, {
        26.044040748879585`, 1.1126215431799973`}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{25.745796723298977`, 1.1915180902000793`}, {
        25.296134336685355`, 1.3104703795529309`}, {23.410614619265985`, 
        1.8479155198038373`}, {21.66780270756462, 2.383063965147447}, {
        21.30845617189129, 2.5024940967986633`}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{21.01569850227561, 2.5997931759691064`}, {19.74536522173515,
         3.0219930746034143`}, {17.997354083744764`, 3.657822268362049}, {
        16.670052629488335`, 4.186811121073573}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{16.383806591328913`, 4.301830190688809}, {
        14.962851018316348`, 4.922452849825514}, {12.451592546913368`, 
        6.181306859167655}, {12.218117576960465`, 6.3125900666474015`}}]}, 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{11.949878443049498`, 6.464962618275959}, {11.61486140550396,
         6.660148373201278}, {10.599656379331991`, 7.290515533628367}, {
        10.534679072460255`, 7.332910853300788}, {10.166348266545139`, 
        7.5833563681928045`}, {9.811205098700604, 7.833835065388892}, {
        8.160559570032357, 9.111314607875318}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{7.933002694319545, 9.319357391825992}, {6.733709231306435, 
        10.447316824220506`}, {5.585097319049005, 11.759354271597177`}, {
        4.890329619184001, 12.783274538546694`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{4.717110722636683, 13.038557475315189`}, {4.167691220757347,
         13.848269503005696`}, {3.1107208288798436`, 15.946894352555224`}, {
        2.6568742421484943`, 17.16431061118473}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{2.549110611177762, 17.45338009031773}, {2.325257315819653, 
        18.053853134038278`}, {1.7426821606415652`, 20.1675667743481}, {
        1.4001817272608785`, 21.928749214773394`}}]}, 
      {Arrowheads[{{0.019771158054646343`, 1.}}], 
       ArrowBox[{{1.3412898441985879`, 22.231579051539185`}, {
        1.1904488650529346`, 23.007223278162996`}, {0.8188769360312369, 
        25.852567029752194`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{40., 5.403538481401985}, {39.00512926264856, 
        5.539045771145096}, {37.30261618800505, 5.781148090332132}, {
        35.67730544359599, 6.023992593058504}, {35.57057410390004, 
        6.040352692332055}, {35.46417482212044, 6.056717077826834}, {
        35.41987425527434, 6.063829672936758}}]}, 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{35.1152720867353, 6.112734507539648}, {34.23511890906869, 
        6.254045863875177}, {33.05028347930325, 6.452038220226264}, {
        30.553591594386397`, 6.890251344920769}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{30.24973337863292, 6.943583780129875}, {30.22401494852211, 
        6.948097814756727}, {27.64702643407747, 7.450051304395183}, {
        25.71569902110097, 7.867917129292973}}]}, 
      {Arrowheads[{{0.024999999999999998`, 1.}}], 
       ArrowBox[{{25.41417280076142, 7.933155939628252}, {25.29725903258924, 
        7.9584516341080835`}, {23.15265384067734, 8.47385174886188}, {
        21.195250530445705`, 8.996434939854424}, {20.930341130541834`, 
        9.074944962226056}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{20.634554519513983`, 9.16260592653103}, {
        19.407088773998286`, 9.526384498283559}, {16.897564485241, 
        10.382163481152837`}, {16.25175658161774, 10.641360880236048`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{15.96545248315621, 10.756270092792517`}, {
        14.720822984890175`, 11.255806761456451`}, {12.821137694112196`, 
        12.146730954310483`}, {11.779684933632044`, 12.718714752315634`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{11.509280277857652`, 12.867225647746748`}, {
        11.16966763878491, 13.053746759907249`}, {9.732228709811578, 
        13.975874995422588`}, {8.482736465476595, 14.912043637553985`}, {
        7.774869168430027, 15.576694628007584`}}]}, 
      {Arrowheads[{{0.017058822330038217`, 1.}}], 
       ArrowBox[{{7.549967299792081, 15.787865917271484`}, {6.449362538119021,
         16.821277190819586`}, {5.396684566840201, 18.089120280751537`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{8.104599793864214, 0.}, {6.989436155655331, 
        1.0093965637675444`}, {5.761749246790267, 2.357607849401707}, {
        5.6399644477330835`, 2.507212519017504}, {5.520778989192735, 
        2.656797742712601}, {5.028012027059685, 3.3113016056513556`}, {
        4.996635239618653, 3.35509925645951}, {4.97227254791912, 
        3.3901150810863965`}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{4.797404292201861, 3.6442649630878994`}, {4.758930746444718,
         3.7009351200687886`}, {3.9066743891689177`, 5.080859370950336}, {
        3.2088910223397975`, 6.459786300161124}, {2.675784767490891, 
        7.745367383603055}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{2.5742351618616386`, 8.03641862226105}, {
        1.9302345386780386`, 10.060490690935088`}, {1.413044096416233, 
        12.282559921705058`}, {1.3759540388657896`, 12.501468852801494`}}]}, 
      {Arrowheads[{{0.009308883716752198, 1.}}], 
       ArrowBox[{{1.3244183944368924`, 12.805636966316893`}, {
        1.0365748016829968`, 14.504516325752132`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024999999999999988`, 1.}}], 
       ArrowBox[{{0.938527464269828, 112.36552036773257`}, {
        1.1180288404269756`, 113.74315388632502`}, {1.3422876516468967`, 
        115.02437387373278`}, {1.4540775029080921`, 115.51691400019837`}, {
        1.5797285729819268`, 115.9827863955835}, {1.722055090101751, 
        116.41752067789355`}, {1.8004066343411889`, 116.62174361449762`}, {
        1.8842843681799886`, 116.81606700996572`}, {1.9130070965891568`, 
        116.8711850370492}}]}, 
      {Arrowheads[{{0.003354790652010933, 1.}}], 
       ArrowBox[{{2.0555755112899843`, 117.14476941353279`}, {
        2.0566085519210295`, 117.1467517865396}, {2.146892716173467, 
        117.27951971345647`}, {2.243493346227039, 117.40153350062855`}, {
        2.450835525954762, 117.62187940521952`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.02499999999999999, 1.}}], 
       ArrowBox[{{40., 0.5243419758838817}, {39.45239976243141, 
        0.6188242600416942}, {39.01719805879589, 0.6959055646356644}, {
        38.58690065763156, 0.7728902303729056}, {36.821892839376176`, 
        1.096779751238512}, {35.448558240280924`, 1.3596724632235808`}}]}, 
      {Arrowheads[{{0.006911920529478888, 1.}}], 
       ArrowBox[{{35.1455568023092, 1.4176749848350216`}, {35.1395726218091, 
        1.418820515896218}, {35.03125849845482, 1.440016091615171}, {
        34.92328793101124, 1.461203445911137}, {34.40314404051079, 
        1.5649535933256804`}, {33.89097964692819, 1.6685066314607166`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{14.723570168592861`, 0.}, {14.03975236685052, 
        0.32423262075718373`}, {13.912427553690199`, 0.38798586457372153`}, {
        13.786265272718879`, 0.4517315505690667}, {12.551360044297283`, 
        1.1077096192341918`}, {12.474361804450863`, 1.1506763947485517`}, {
        12.311525399539804`, 1.2431605398224221`}, {12.150838076876811`, 
        1.3356239330539263`}, {10.688725353967625`, 2.25633561165432}}]}, 
      {Arrowheads[{{0.0024239818020417247`, 1.}}], 
       ArrowBox[{{10.42766973476258, 2.4207257804835067`}, {10.04799329259832,
         2.659813047089416}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.024770017354285544`, 1.}}], 
       ArrowBox[{{1.42593092268797, 0.}, {1.3540299653882413`, 
        0.33062004849268056`}, {1.341545321346001, 0.3954704084961099}, {
        1.329176220355461, 0.46032035471024413`}, {1.2026486570731225`, 
        1.1602636104513429`}, {1.1865110894934738`, 1.255530983072062}, {
        1.1705913405814399`, 1.3507972279808667`}, {0.9320696342692275, 
        2.941500341782651}, {0.7426308301986209, 4.531839683289025}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025000000000000012`, 1.}}], 
       ArrowBox[{{4.8051365899736265`, 115.2919460353639}, {5.019363139914243,
         115.14934714606842`}, {5.667645772126342, 114.65627527929607`}, {
        5.714550656667727, 114.61769701536684`}, {6.033011452571769, 
        114.33798569473053`}, {6.3702742631644975`, 114.02596894927606`}, {
        8.179300557583453, 112.14229749964736`}}]}, 
      {Arrowheads[{{0.02500000000000001, 1.}}], 
       ArrowBox[{{8.392991906025628, 111.91978868740122`}, {8.419343299628274,
         111.89234996639404`}, {9.398258500141388, 110.74336213270709`}, {
        10.437456938444498`, 109.44498392738171`}, {11.290963021901883`, 
        108.3138643829696}}]}, 
      {Arrowheads[{{0.025000000000000022`, 1.}}], 
       ArrowBox[{{11.476783972469523`, 108.06760285886087`}, {
        11.519859318943563`, 108.01051672060893`}, {12.628386346044548`, 
        106.4532618825798}, {13.746776072408604`, 104.78861982551146`}, {
        14.088593725459052`, 104.24864509797607`}}]}, 
      {Arrowheads[{{0.017721235612820702`, 1.}}], 
       ArrowBox[{{14.253601637339752`, 103.98797950196656`}, {
        14.858766550696888`, 103.03199096162113`}, {15.961776862750945`, 
        101.18788781356518`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{40., 9.65920888808991}, {38.85114716744032, 
        9.727674468609901}, {37.28635963161565, 9.836342381026773}, {
        37.18305860236704, 9.844056437656114}, {37.08003469938909, 
        9.851819397056012}, {35.50286760163524, 9.988240140091735}, {
        35.385284184972264`, 9.999678013446358}}]}, 
      {Arrowheads[{{0.025, 1.}}], 
       ArrowBox[{{35.07823038590232, 10.029546532039285`}, {33.99149517162181,
         10.13525820553639}, {31.071276813496493`, 10.450470630845288`}, {
        30.47794070979657, 10.528925707836326`}}]}, 
      {Arrowheads[{{0.023048003175029808`, 1.}}], 
       ArrowBox[{{30.17209968308247, 10.569366161650354`}, {
        28.397689749860923`, 10.803991135685244`}, {25.951821979555753`, 
        11.191492714599885`}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.01092451921471433, 1.}}], 
       ArrowBox[{{11.648372496980263`, 49.381865699626694`}, {
        11.057286139796876`, 48.63984293829532}, {10.728993140524192`, 
        48.371907734068515`}, {10.383940227890013`, 48.17233440005357}, {
        10.151034313296236`, 48.07846048502435}}]}}, 
     {GrayLevel[0.5], 
      {Arrowheads[{{0.01016733133707341, 1.}}], 
       ArrowBox[{{3.9446331171352647`, 71.96525368026532}, {
        3.9327031262082794`, 72.58801063727077}, {3.9309040889395397`, 
        72.89663340925013}, {3.930896179036124, 72.94970590104464}, {
        3.9309928167942063`, 73.01328587450229}, {3.9322459793607223`, 
        73.22424939409825}, {3.934960155869163, 73.43361448891835}, {
        3.939173950315268, 73.64124062047092}, {3.9449285043449605`, 
        73.84698152610113}}]}}}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 14},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\[Alpha]", TraditionalForm], None}, {
     FormBox["\[Gamma]", TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {50., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {100., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {150., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-50., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-30., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {30., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {60., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {70., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {80., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {90., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {110., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {120., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {130., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {140., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {160., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {170., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {180., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {190., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {200., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {30., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {24., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {26., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {28., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {32., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {34., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {36., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {38., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 39}, {0., 164.3873468765934}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.606642867705184*^9, 3.606642923965519*^9}, {
   3.606642955469207*^9, 3.606642996352227*^9}, {3.606643252200482*^9, 
   3.606643293602481*^9}, 3.6066433510217323`*^9, {3.606643433897396*^9, 
   3.606643455407217*^9}, {3.60664349699514*^9, 3.6066435168051853`*^9}, {
   3.606643569842493*^9, 3.6066436581578503`*^9}, {3.606643692475924*^9, 
   3.606643701460927*^9}, {3.606643750003479*^9, 3.606643771815401*^9}, 
   3.606643822762142*^9, 3.606643866504662*^9, {3.6066439653898363`*^9, 
   3.606643984086832*^9}, {3.606644014196538*^9, 3.6066440656355*^9}, 
   3.606644166546525*^9, {3.606644222013453*^9, 3.606644236260991*^9}, 
   3.6066455355287113`*^9, 3.737296873198392*^9, {3.7389981963458023`*^9, 
   3.738998226013083*^9}},
 CellLabel->"Out[14]=",ExpressionUUID->"54545d47-9c9d-4546-b3d0-2a854edc8cc7"]
}, Open  ]],

Cell[TextData[StyleBox["Check instability of steady state and whether \
oscillations take place",
 FontWeight->"Bold"]], "Text",ExpressionUUID->"0071a6b9-536b-4582-ac34-\
7a5658955eba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Jacobianmatrix", "=", 
   RowBox[{"Outer", "[", 
    RowBox[{"D", ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Odes", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"Odes", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "/.", "Fcs"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Gamma]", "[", "t", "]"}], ",", 
       RowBox[{"\[Alpha]", "[", "t", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.425625645235997*^9, 3.425625651131467*^9}, {
  3.425626078673089*^9, 3.4256260810459642`*^9}, {3.73899823784909*^9, 
  3.7389982418120213`*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"457d2f4c-29c3-4e91-8928-eeac0fbb7e7b"],

Cell[CellGroupData[{

Cell[BoxData["Odes"], "Input",
 CellChangeTimes->{{3.738998230538562*^9, 3.738998231025176*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"c9abe065-f27d-40eb-b120-09919ca1cd21"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", " ", 
      SubscriptBox["\[Sigma]", "M"]}], "-", 
     RowBox[{
      SubscriptBox["k", "s"], " ", 
      RowBox[{"\[Gamma]", "[", "t", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
    RowBox[{
     SubscriptBox["\[Sigma]", "1"], "-", 
     RowBox[{"\[CapitalPhi]", " ", 
      SubscriptBox["\[Sigma]", "M"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.738998231570306*^9, 3.7389982437141533`*^9}},
 CellLabel->"Out[23]=",ExpressionUUID->"ad588b97-82c7-4708-8e38-52121e9fc3f9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Odes", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{"Odes", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "}"}]], "Input",
 CellLabel->"In[24]:=",ExpressionUUID->"8400dc9b-e2e5-46e5-9207-eb268f1c7523"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", " ", 
     SubscriptBox["\[Sigma]", "M"]}], "-", 
    RowBox[{
     SubscriptBox["k", "s"], " ", 
     RowBox[{"\[Gamma]", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Sigma]", "1"], "-", 
    RowBox[{"\[CapitalPhi]", " ", 
     SubscriptBox["\[Sigma]", "M"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7389982062563143`*^9, 3.7389982447115307`*^9}},
 CellLabel->"Out[24]=",ExpressionUUID->"0c11fc88-2f6c-4c1f-8076-84caf2e3f5d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SS", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Odes", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Odes", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}]}], "}"}], "/.", 
     "Fcs"}], "/.", "Parm"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"SSnum", "=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{"SS", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]", "[", "t", "]"}], ",", "50"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Gamma]", "[", "t", "]"}], ",", "10"}], "}"}]}], "}"}]}], 
   "]"}]}]}], "Input",
 CellLabel->"In[25]:=",ExpressionUUID->"8af65177-4ab0-448f-a22c-a2d803aeaad4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", "62.81267610596473`"}], 
   ",", 
   RowBox[{
    RowBox[{"\[Gamma]", "[", "t", "]"}], "\[Rule]", "6.999999999999999`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.425623905567531*^9, 3.425626082307185*^9, 3.606642235435719*^9, 
   3.6066441726286993`*^9, 3.6066455358544903`*^9, 3.7372968734802847`*^9, {
   3.7389982263215427`*^9, 3.738998245833909*^9}},
 CellLabel->"Out[26]=",ExpressionUUID->"bbe8dca6-9cbf-4e1e-9c3d-f9977e830bc1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Jacobianmatrix", "/.", "Fcs"}], "/.", "Parm"}], "/.", 
  "SSnum"}], "\[IndentingNewLine]", 
 RowBox[{"Eigenvalues", "[", "%", "]"}]}], "Input",
 CellLabel->"In[27]:=",ExpressionUUID->"ab106fb6-e900-4118-b52b-785d287dda1a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.043452687526308084`", ",", "0.018172067061755143`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.14345268752630808`"}], ",", 
     RowBox[{"-", "0.018172067061755143`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.425623906489584*^9, 3.4256260833030863`*^9, 3.606642236119412*^9, 
   3.6066441774470873`*^9, 3.6066455359721003`*^9, 3.737296873880636*^9, {
   3.7389982264223747`*^9, 3.7389982502026577`*^9}},
 CellLabel->"Out[27]=",ExpressionUUID->"33952f21-e2ea-4b9b-bf96-1a220e1032b2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.012640310232276474`", "\[VeryThinSpace]", "+", 
    RowBox[{"0.04071153722726913`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"0.012640310232276474`", "\[VeryThinSpace]", "-", 
    RowBox[{"0.04071153722726913`", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.425623906489584*^9, 3.4256260833030863`*^9, 3.606642236119412*^9, 
   3.6066441774470873`*^9, 3.6066455359721003`*^9, 3.737296873880636*^9, {
   3.7389982264223747`*^9, 3.7389982502164297`*^9}},
 CellLabel->"Out[28]=",ExpressionUUID->"c0c903e9-9083-4d40-836c-b2d0a8504a5a"]
}, Open  ]],

Cell["\<\
This indicates indeed that the system is oscillatory, positive eigenvalues. \
This you can also conclude from calculating the trace and determinant of the \
Jacobian matrix.\
\>", "Text",
 CellChangeTimes->{{3.7389982667882233`*^9, 
  3.738998317106442*^9}},ExpressionUUID->"c970e237-a0f3-4155-96c5-\
66ed01fe65cc"]
},
WindowSize->{1440, 855},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"13.2 for Mac OS X ARM (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"9ebe5b37-020a-426f-ae12-e6da6cececa5"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 429, 9, 81, "Text",ExpressionUUID->"7c230cf9-21f3-4e48-9c7e-7eca40ed24ff"],
Cell[977, 31, 3543, 92, 98, "Input",ExpressionUUID->"24404dde-2eae-4a6f-a8e8-6e5d3419ca58"],
Cell[4523, 125, 3687, 105, 289, "Input",ExpressionUUID->"296f46ce-02f4-4cd4-867d-3d01cffcaee2"],
Cell[8213, 232, 492, 15, 30, "Input",ExpressionUUID->"77662464-de02-4001-a7f2-526dae05c13e"],
Cell[CellGroupData[{
Cell[8730, 251, 1774, 45, 136, "Input",ExpressionUUID->"4c84379a-cc8c-4d9a-87ea-b40f161a8e53"],
Cell[10507, 298, 57766, 978, 440, "Output",ExpressionUUID->"cb9b583f-b6ee-4057-9e2a-1cb6f6d90936"],
Cell[68276, 1278, 750, 11, 104, "Output",ExpressionUUID->"af33bfb9-7532-4d98-b83e-a0b6080968c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69063, 1294, 719, 19, 52, "Input",ExpressionUUID->"ee989146-4196-49f4-ba9a-8837bbd65160"],
Cell[69785, 1315, 4284, 105, 162, "Output",ExpressionUUID->"24aa40d0-75ab-4bb2-8bf8-dcaa39aae356"],
Cell[74072, 1422, 634, 15, 34, "Output",ExpressionUUID->"c3fb94e3-58b6-4a56-9e30-c05233df91cd"]
}, Open  ]],
Cell[74721, 1440, 158, 2, 58, "Text",ExpressionUUID->"71f09bf2-f3a6-4f59-a126-1df6e80f1b8b"],
Cell[CellGroupData[{
Cell[74904, 1446, 715, 19, 52, "Input",ExpressionUUID->"29949b17-efc7-44e8-b706-06b106990a97"],
Cell[75622, 1467, 5705, 141, 152, "Output",ExpressionUUID->"f1037ca5-26aa-4b84-872a-87b0adf790ed"],
Cell[81330, 1610, 630, 15, 34, "Output",ExpressionUUID->"dfb7fcc7-a066-426e-9919-0f1a22235348"]
}, Open  ]],
Cell[81975, 1628, 97, 0, 35, "Text",ExpressionUUID->"0b64dc8d-58d8-4883-a6a2-8fcee904b42f"],
Cell[82075, 1630, 1735, 45, 73, "Input",ExpressionUUID->"34c67952-6840-4058-92cf-15011cb23e1f"],
Cell[83813, 1677, 1141, 29, 30, "Input",ExpressionUUID->"3f7a5434-4483-4652-b33f-76d4dd9ada96"],
Cell[84957, 1708, 1704, 39, 52, "Input",ExpressionUUID->"019eb0ae-cfe4-4e50-aac3-1700013d7b6a"],
Cell[CellGroupData[{
Cell[86686, 1751, 342, 6, 30, "Input",ExpressionUUID->"3c7accf7-e2f4-4c1b-a3b4-8e8dec9ddee1"],
Cell[87031, 1759, 183413, 3060, 372, "Output",ExpressionUUID->"54545d47-9c9d-4546-b3d0-2a854edc8cc7"]
}, Open  ]],
Cell[270459, 4822, 185, 3, 35, "Text",ExpressionUUID->"0071a6b9-536b-4582-ac34-7a5658955eba"],
Cell[270647, 4827, 880, 24, 30, "Input",ExpressionUUID->"457d2f4c-29c3-4e91-8928-eeac0fbb7e7b"],
Cell[CellGroupData[{
Cell[271552, 4855, 175, 2, 30, "Input",ExpressionUUID->"c9abe065-f27d-40eb-b120-09919ca1cd21"],
Cell[271730, 4859, 801, 22, 34, "Output",ExpressionUUID->"ad588b97-82c7-4708-8e38-52121e9fc3f9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[272568, 4886, 377, 11, 30, "Input",ExpressionUUID->"8400dc9b-e2e5-46e5-9207-eb268f1c7523"],
Cell[272948, 4899, 527, 14, 34, "Output",ExpressionUUID->"0c11fc88-2f6c-4c1f-8076-84caf2e3f5d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[273512, 4918, 963, 30, 52, "Input",ExpressionUUID->"8af65177-4ab0-448f-a22c-a2d803aeaad4"],
Cell[274478, 4950, 544, 13, 34, "Output",ExpressionUUID->"bbe8dca6-9cbf-4e1e-9c3d-f9977e830bc1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[275059, 4968, 270, 6, 52, "Input",ExpressionUUID->"ab106fb6-e900-4118-b52b-785d287dda1a"],
Cell[275332, 4976, 594, 14, 34, "Output",ExpressionUUID->"33952f21-e2ea-4b9b-bf96-1a220e1032b2"],
Cell[275929, 4992, 614, 12, 34, "Output",ExpressionUUID->"c0c903e9-9083-4d40-836c-b2d0a8504a5a"]
}, Open  ]],
Cell[276558, 5007, 325, 7, 35, "Text",ExpressionUUID->"c970e237-a0f3-4155-96c5-66ed01fe65cc"]
}
]
*)

