(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    175705,       3520]
NotebookOptionsPosition[    171588,       3446]
NotebookOutlinePosition[    171988,       3462]
CellTagsIndexPosition[    171945,       3459]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Differential equations and mass action kinetics", "Subsubsection",
 CellChangeTimes->{{3.892866508209785*^9, 
  3.892866520200396*^9}},ExpressionUUID->"1d84409a-499c-4071-96d0-\
1af53544db84"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"odes", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"s", "'"}], "[", "t", "]"}], "==", 
      RowBox[{"-", "v1"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"es", "'"}], "[", "t", "]"}], "==", 
      RowBox[{"v1", "-", "v2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"ep", "'"}], "[", "t", "]"}], "==", 
      RowBox[{"v2", "-", "v3"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"p", "'"}], "[", "t", "]"}], "==", "v3"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rateeqs", "[", 
    RowBox[{
    "k1f_", ",", "k1b_", ",", "k2f_", ",", "k2b_", ",", "k3f_", ",", "k3b_"}],
     "]"}], ":=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"v1", "->", 
      RowBox[{
       RowBox[{"k1f", " ", 
        RowBox[{"e", "[", "t", "]"}], " ", 
        RowBox[{"s", "[", "t", "]"}]}], "-", 
       RowBox[{"k1b", " ", 
        RowBox[{"es", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"v2", "->", 
      RowBox[{
       RowBox[{"k2f", " ", 
        RowBox[{"es", "[", "t", "]"}]}], "-", 
       RowBox[{"k2b", " ", 
        RowBox[{"ep", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"v3", "->", 
      RowBox[{
       RowBox[{"k3f", " ", 
        RowBox[{"ep", "[", "t", "]"}]}], "-", 
       RowBox[{"k3b", " ", 
        RowBox[{"e", "[", "t", "]"}], 
        RowBox[{"p", "[", "t", "]"}]}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"moicons", "[", "Et_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"e", "[", "t", "]"}], "->", 
    RowBox[{"Et", "-", 
     RowBox[{"ep", "[", "t", "]"}], "-", 
     RowBox[{"es", "[", "t", "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.892866380292467*^9, 3.892866498321704*^9}, {
  3.89286655798112*^9, 3.8928665847467213`*^9}, {3.89286662722298*^9, 
  3.892866627531842*^9}, {3.892866666540547*^9, 3.89286666871583*^9}, {
  3.8932911105974092`*^9, 3.893291158689946*^9}, {3.893291284908649*^9, 
  3.8932913052026653`*^9}, {3.89329149924*^9, 3.89329149939263*^9}, {
  3.8932916042236137`*^9, 3.893291636013607*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"92c82faf-5d0c-4ac9-b045-680cec652486"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analytical solution of steady state concentrations", "Subsubsection",
 CellChangeTimes->{{3.892866526103458*^9, 
  3.892866537374724*^9}},ExpressionUUID->"495549f3-2f79-4891-848b-\
9161b777db66"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"#", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "==", "0"}], "&"}], "/@", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"odes", "[", 
      RowBox[{"[", 
       RowBox[{"2", ";;", "3"}], "]"}], "]"}], "/.", 
     RowBox[{"rateeqs", "[", 
      RowBox[{
      "k1f", ",", "k1b", ",", "k2f", ",", "k2b", ",", "k3f", ",", "k3b"}], 
      "]"}]}], "/.", 
    RowBox[{"moicons", "[", "Et", "]"}]}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"ss", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"es", "[", "t", "]"}], ",", 
        RowBox[{"ep", "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.892866539430002*^9, 3.8928665491875963`*^9}, {
  3.8928666128921013`*^9, 3.892866672901738*^9}, {3.892866712696837*^9, 
  3.892866713027645*^9}, {3.892866836039765*^9, 3.892866836581771*^9}, {
  3.8932913134823933`*^9, 3.893291336514596*^9}, {3.893291503527431*^9, 
  3.893291504005939*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"ced208a1-1692-4787-b252-c7bae7d0a7c5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"k2b", " ", 
      RowBox[{"ep", "[", "t", "]"}]}], "-", 
     RowBox[{"k1b", " ", 
      RowBox[{"es", "[", "t", "]"}]}], "-", 
     RowBox[{"k2f", " ", 
      RowBox[{"es", "[", "t", "]"}]}], "+", 
     RowBox[{"k1f", " ", 
      RowBox[{"(", 
       RowBox[{"Et", "-", 
        RowBox[{"ep", "[", "t", "]"}], "-", 
        RowBox[{"es", "[", "t", "]"}]}], ")"}], " ", 
      RowBox[{"s", "[", "t", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "k2b"}], " ", 
      RowBox[{"ep", "[", "t", "]"}]}], "-", 
     RowBox[{"k3f", " ", 
      RowBox[{"ep", "[", "t", "]"}]}], "+", 
     RowBox[{"k2f", " ", 
      RowBox[{"es", "[", "t", "]"}]}], "+", 
     RowBox[{"k3b", " ", 
      RowBox[{"(", 
       RowBox[{"Et", "-", 
        RowBox[{"ep", "[", "t", "]"}], "-", 
        RowBox[{"es", "[", "t", "]"}]}], ")"}], " ", 
      RowBox[{"p", "[", "t", "]"}]}]}], "\[Equal]", "0"}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.892866555109042*^9, {3.892866607244348*^9, 3.892866673414481*^9}, 
   3.892866713585157*^9, 3.892866837065929*^9, 3.893241954937923*^9, {
   3.893291224521681*^9, 3.893291251207412*^9}, 3.893291340817047*^9, 
   3.893291504685185*^9, 3.8932916377421293`*^9, {3.893292248434857*^9, 
   3.893292269130451*^9}, 3.893340256963539*^9, 3.893389556422398*^9},
 CellLabel->
  "Out[102]=",ExpressionUUID->"88c6c89c-772d-48c3-b9e6-7b2197e66583"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"es", "[", "t", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"Et", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k2b", " ", "k3b", " ", 
         RowBox[{"p", "[", "t", "]"}]}], "+", 
        RowBox[{"k1f", " ", 
         RowBox[{"(", 
          RowBox[{"k2b", "+", "k3f"}], ")"}], " ", 
         RowBox[{"s", "[", "t", "]"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"k1b", " ", "k2b"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
       RowBox[{"p", "[", "t", "]"}]}], "+", 
      RowBox[{"k1f", " ", 
       RowBox[{"(", 
        RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}], " ", 
       RowBox[{"s", "[", "t", "]"}]}]}]]}], ",", 
   RowBox[{
    RowBox[{"ep", "[", "t", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"Et", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
         RowBox[{"p", "[", "t", "]"}]}], "+", 
        RowBox[{"k1f", " ", "k2f", " ", 
         RowBox[{"s", "[", "t", "]"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"k1b", " ", "k2b"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
       RowBox[{"p", "[", "t", "]"}]}], "+", 
      RowBox[{"k1f", " ", 
       RowBox[{"(", 
        RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}], " ", 
       RowBox[{"s", "[", "t", "]"}]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.892866555109042*^9, {3.892866607244348*^9, 3.892866673414481*^9}, 
   3.892866713585157*^9, 3.892866837065929*^9, 3.893241954937923*^9, {
   3.893291224521681*^9, 3.893291251207412*^9}, 3.893291340817047*^9, 
   3.893291504685185*^9, 3.8932916377421293`*^9, {3.893292248434857*^9, 
   3.893292269130451*^9}, 3.893340256963539*^9, 3.8933895564811897`*^9},
 CellLabel->
  "Out[103]=",ExpressionUUID->"b78a1b8f-8a8f-4414-9ad0-adbf97f3fd55"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Et", "-", 
  FractionBox[
   RowBox[{"Et", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k2b", " ", "k3b", " ", 
       RowBox[{"p", "[", "t", "]"}]}], "+", 
      RowBox[{"k1f", " ", 
       RowBox[{"(", 
        RowBox[{"k2b", "+", "k3f"}], ")"}], " ", 
       RowBox[{"s", "[", "t", "]"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"k1b", " ", "k2b"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
     RowBox[{"p", "[", "t", "]"}]}], "+", 
    RowBox[{"k1f", " ", 
     RowBox[{"(", 
      RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}], " ", 
     RowBox[{"s", "[", "t", "]"}]}]}]], "-", 
  FractionBox[
   RowBox[{"Et", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
       RowBox[{"p", "[", "t", "]"}]}], "+", 
      RowBox[{"k1f", " ", "k2f", " ", 
       RowBox[{"s", "[", "t", "]"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"k1b", " ", "k2b"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
     RowBox[{"p", "[", "t", "]"}]}], "+", 
    RowBox[{"k1f", " ", 
     RowBox[{"(", 
      RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}], " ", 
     RowBox[{"s", "[", "t", "]"}]}]}]]}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.893389691665616*^9, 3.893389716700947*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"bf0cdfbc-ad46-4618-8814-d858de992959"],

Cell[BoxData[
 RowBox[{"Et", "-", 
  FractionBox[
   RowBox[{"Et", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
       RowBox[{"p", "[", "t", "]"}]}], "+", 
      RowBox[{"k1f", " ", "k2f", " ", 
       RowBox[{"s", "[", "t", "]"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"k1b", " ", "k2b"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
     RowBox[{"p", "[", "t", "]"}]}], "+", 
    RowBox[{"k1f", " ", 
     RowBox[{"(", 
      RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}], " ", 
     RowBox[{"s", "[", "t", "]"}]}]}]], "-", 
  FractionBox[
   RowBox[{"Et", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k2b", " ", "k3b", " ", 
       RowBox[{"p", "[", "t", "]"}]}], "+", 
      RowBox[{"k1f", " ", 
       RowBox[{"(", 
        RowBox[{"k2b", "+", "k3f"}], ")"}], " ", 
       RowBox[{"s", "[", "t", "]"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"k1b", " ", "k2b"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
     RowBox[{"p", "[", "t", "]"}]}], "+", 
    RowBox[{"k1f", " ", 
     RowBox[{"(", 
      RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}], " ", 
     RowBox[{"s", "[", "t", "]"}]}]}]]}]], "Output",
 CellChangeTimes->{{3.893389708938202*^9, 3.8933897171723747`*^9}},
 CellLabel->
  "Out[105]=",ExpressionUUID->"fbaa2cd1-7f62-4b3c-a3a0-0a84fa7bae8e"],

Cell[BoxData[
 FractionBox[
  RowBox[{"Et", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"k2f", " ", "k3f"}], "+", 
     RowBox[{"k1b", " ", 
      RowBox[{"(", 
       RowBox[{"k2b", "+", "k3f"}], ")"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"k1b", " ", "k2b"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
    RowBox[{"p", "[", "t", "]"}]}], "+", 
   RowBox[{"k1f", " ", 
    RowBox[{"(", 
     RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}], " ", 
    RowBox[{"s", "[", "t", "]"}]}]}]]], "Output",
 CellChangeTimes->{{3.893389708938202*^9, 3.8933897171766768`*^9}},
 CellLabel->
  "Out[106]=",ExpressionUUID->"4b682ae1-f2a5-4f2e-b98c-e11e04797c68"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"venz", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"v2", "/.", 
      RowBox[{"rateeqs", "[", 
       RowBox[{
       "k1f", ",", "k1b", ",", "k2f", ",", "k2b", ",", "k3f", ",", "k3b"}], 
       "]"}]}], "/.", "ss"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox[
   RowBox[{"Numerator", "[", "%", "]"}], 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Denominator", "[", "%", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "p", ",", "k3b"}], "}"}]}], "]"}]], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 FractionBox[
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"%%", "/.", 
     RowBox[{
      RowBox[{"p", "[", "t", "]"}], "->", "0"}]}], ",", 
    RowBox[{
     RowBox[{"s", "[", "t", "]"}], "->", "Infinity"}]}], "]"}], 
  "Et"], "\[IndentingNewLine]", 
 FractionBox[
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"%%%", "/.", 
     RowBox[{
      RowBox[{"s", "[", "t", "]"}], "->", "0"}]}], ",", 
    RowBox[{
     RowBox[{"p", "[", "t", "]"}], "->", "Infinity"}]}], "]"}], 
  "Et"]}], "Input",
 CellChangeTimes->{{3.8928667185159187`*^9, 3.8928667722034283`*^9}, {
  3.892866822961439*^9, 3.892866828982123*^9}, {3.892866863528533*^9, 
  3.89286698286518*^9}, {3.893241961983035*^9, 3.893242002625409*^9}, {
  3.893242142767234*^9, 3.893242179115333*^9}, {3.893291356240945*^9, 
  3.893291370744598*^9}, {3.8932915077805023`*^9, 3.89329150823106*^9}, {
  3.893292073321842*^9, 3.893292090868145*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"fcb8f0d9-e7f3-4b92-81d1-e3795d208b42"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "Et"}], " ", "k1b", " ", "k2b", " ", "k3b", " ", 
     RowBox[{"p", "[", "t", "]"}]}], "+", 
    RowBox[{"Et", " ", "k1f", " ", "k2f", " ", "k3f", " ", 
     RowBox[{"s", "[", "t", "]"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"k1b", " ", "k2b"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
     RowBox[{"p", "[", "t", "]"}]}], "+", 
    RowBox[{"k1f", " ", 
     RowBox[{"(", 
      RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}], " ", 
     RowBox[{"s", "[", "t", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.892866721723578*^9, 3.892866772965178*^9}, {
   3.892866824291473*^9, 3.8928668665602503`*^9}, 3.8928669153220673`*^9, {
   3.8928669492031183`*^9, 3.8928669834220657`*^9}, 3.892867051215362*^9, {
   3.8932419550194407`*^9, 3.8932420032218523`*^9}, {3.893242147122579*^9, 
   3.893242179610984*^9}, {3.893291224579527*^9, 3.893291251236392*^9}, {
   3.893291347061714*^9, 3.893291371234935*^9}, 3.893291508883855*^9, 
   3.893291639271707*^9, {3.8932920772556543`*^9, 3.8932920920076103`*^9}, {
   3.893292248536272*^9, 3.893292269942358*^9}, 3.893340257064805*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"fae67853-4f23-4e67-b700-eb26a0ed2412"],

Cell[BoxData[
 FractionBox[
  RowBox[{"k1f", " ", "k2f", " ", "k3f"}], 
  RowBox[{
   RowBox[{"k1f", " ", "k2b"}], "+", 
   RowBox[{"k1f", " ", "k2f"}], "+", 
   RowBox[{"k1f", " ", "k3f"}]}]]], "Output",
 CellChangeTimes->{{3.892866721723578*^9, 3.892866772965178*^9}, {
   3.892866824291473*^9, 3.8928668665602503`*^9}, 3.8928669153220673`*^9, {
   3.8928669492031183`*^9, 3.8928669834220657`*^9}, 3.892867051215362*^9, {
   3.8932419550194407`*^9, 3.8932420032218523`*^9}, {3.893242147122579*^9, 
   3.893242179610984*^9}, {3.893291224579527*^9, 3.893291251236392*^9}, {
   3.893291347061714*^9, 3.893291371234935*^9}, 3.893291508883855*^9, 
   3.893291639271707*^9, {3.8932920772556543`*^9, 3.8932920920076103`*^9}, {
   3.893292248536272*^9, 3.893292269942358*^9}, 3.893340257071954*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"70f0a6bf-d3cf-4234-910d-04f6e3da170c"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"k1b", " ", "k2b", " ", "k3b"}], 
   RowBox[{
    RowBox[{"k1b", " ", "k3b"}], "+", 
    RowBox[{"k2b", " ", "k3b"}], "+", 
    RowBox[{"k2f", " ", "k3b"}]}]]}]], "Output",
 CellChangeTimes->{{3.892866721723578*^9, 3.892866772965178*^9}, {
   3.892866824291473*^9, 3.8928668665602503`*^9}, 3.8928669153220673`*^9, {
   3.8928669492031183`*^9, 3.8928669834220657`*^9}, 3.892867051215362*^9, {
   3.8932419550194407`*^9, 3.8932420032218523`*^9}, {3.893242147122579*^9, 
   3.893242179610984*^9}, {3.893291224579527*^9, 3.893291251236392*^9}, {
   3.893291347061714*^9, 3.893291371234935*^9}, 3.893291508883855*^9, 
   3.893291639271707*^9, {3.8932920772556543`*^9, 3.8932920920076103`*^9}, {
   3.893292248536272*^9, 3.893292269942358*^9}, 3.8933402570951366`*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"4daca4cd-f4b3-475d-9bb8-56173629aff2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "Et"}], " ", 
    FractionBox[
     RowBox[{"k1b", " ", "k2b", " ", "k3b"}], 
     RowBox[{
      RowBox[{"k1b", " ", "k3b"}], "+", 
      RowBox[{"k2b", " ", "k3b"}], "+", 
      RowBox[{"k2f", " ", "k3b"}]}]], 
    FractionBox[
     RowBox[{
      RowBox[{"k1b", " ", "k3b"}], "+", 
      RowBox[{"k2b", " ", "k3b"}], "+", 
      RowBox[{"k2f", " ", "k3b"}]}], 
     RowBox[{
      RowBox[{"k1b", " ", "k2b"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}]}]], " ", 
    RowBox[{"p", "[", "t", "]"}]}], "+", 
   RowBox[{"Et", " ", 
    FractionBox[
     RowBox[{"k1f", " ", "k2f", " ", "k3f"}], 
     RowBox[{
      RowBox[{"k1f", " ", "k2b"}], "+", 
      RowBox[{"k1f", " ", "k2f"}], "+", 
      RowBox[{"k1f", " ", "k3f"}]}]], 
    FractionBox[
     RowBox[{
      RowBox[{"k1f", " ", "k2b"}], "+", 
      RowBox[{"k1f", " ", "k2f"}], "+", 
      RowBox[{"k1f", " ", "k3f"}]}], 
     RowBox[{
      RowBox[{"k1b", " ", "k2b"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}]}]], " ", 
    RowBox[{"s", "[", "t", "]"}]}]}], 
  RowBox[{"1", "+", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b"}], 
     RowBox[{
      RowBox[{"k1b", " ", "k2b"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}]}]], " ", 
    RowBox[{"p", "[", "t", "]"}]}], "+", 
   RowBox[{
    FractionBox[
     RowBox[{"k1f", " ", 
      RowBox[{"(", 
       RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}]}], 
     RowBox[{
      RowBox[{"k1b", " ", "k2b"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}]}]], " ", 
    RowBox[{"s", "[", "t", "]"}]}]}]]], "Input",
 CellChangeTimes->{{3.893390443717086*^9, 3.893390460480742*^9}, {
  3.893390598725319*^9, 3.893390627075597*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"2f64e60e-9c24-4188-8de4-a4db79699725"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Et", " ", "k1b", " ", "k2b", " ", "k3b", " ", 
      RowBox[{"p", "[", "t", "]"}]}], 
     RowBox[{
      RowBox[{"k1b", " ", "k2b"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}]}]]}], "+", 
   FractionBox[
    RowBox[{"Et", " ", "k1f", " ", "k2f", " ", "k3f", " ", 
     RowBox[{"s", "[", "t", "]"}]}], 
    RowBox[{
     RowBox[{"k1b", " ", "k2b"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}]}]]}], 
  RowBox[{"1", "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
     RowBox[{"p", "[", "t", "]"}]}], 
    RowBox[{
     RowBox[{"k1b", " ", "k2b"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}]}]], "+", 
   FractionBox[
    RowBox[{"k1f", " ", 
     RowBox[{"(", 
      RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}], " ", 
     RowBox[{"s", "[", "t", "]"}]}], 
    RowBox[{
     RowBox[{"k1b", " ", "k2b"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}]}]]}]]], "Output",
 CellChangeTimes->{3.893390432308544*^9, 3.8933906543714123`*^9},
 CellLabel->
  "Out[110]=",ExpressionUUID->"0591f901-3891-4fcc-8f9f-a954642a7b1a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[Cell[TextData[{
  Cell[BoxData[
   FormBox[
    RowBox[{
     FractionBox["1", "Kp"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b"}], 
      RowBox[{
       RowBox[{"k1b", " ", "k2b"}], "+", 
       RowBox[{"k1b", " ", "k3f"}], "+", 
       RowBox[{"k2f", " ", "k3f"}]}]]}], TraditionalForm]],ExpressionUUID->
   "2fa4e8eb-7c18-4876-890f-fa8394890d96"],
  ", ",
  Cell[BoxData[
   FormBox[
    RowBox[{
     RowBox[{
      FractionBox["1", "Ks"], "=", 
      FractionBox[
       RowBox[{"k1f", " ", 
        RowBox[{"(", 
         RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}]}], 
       RowBox[{
        RowBox[{"k1b", " ", "k2b"}], "+", 
        RowBox[{"k1b", " ", "k3f"}], "+", 
        RowBox[{"k2f", " ", "k3f"}]}]]}], ",", " ", 
     RowBox[{
      SubscriptBox["k", 
       RowBox[{"cat", "+"}]], "=", 
      FractionBox[
       RowBox[{"k1f", " ", "k2f", " ", "k3f"}], 
       RowBox[{
        RowBox[{"k1f", " ", "k2b"}], "+", 
        RowBox[{"k1f", " ", "k2f"}], "+", 
        RowBox[{"k1f", " ", "k3f"}]}]]}], ",", " ", 
     RowBox[{
      SubscriptBox["k", 
       RowBox[{"cat", "-"}]], "=", 
      FractionBox[
       RowBox[{"k1b", " ", "k2b", " ", "k3b"}], 
       RowBox[{
        RowBox[{"k1b", " ", "k3b"}], "+", 
        RowBox[{"k2b", " ", "k3b"}], "+", 
        RowBox[{"k2f", " ", "k3b"}]}]]}]}], TraditionalForm]],ExpressionUUID->
   "727a159f-782b-45af-be2f-e6661d4d0434"]
 }],ExpressionUUID->
  "08cba256-c7f5-4e1b-8995-8d8cf07fe1a3"]],ExpressionUUID->"71205259-0850-\
4ff8-9027-ce5f337f6022"]], "Subsubsection",
 CellChangeTimes->{
  3.893291239299531*^9, {3.893390667433442*^9, 
   3.8933906916116123`*^9}},ExpressionUUID->"c0cf8336-51c5-44a4-991f-\
37632ea8d617"],

Cell[BoxData[
 RowBox[{
  RowBox[{"odescompl", "[", 
   RowBox[{
   "k1f_", ",", "k1b_", ",", "k2f_", ",", "k2b_", ",", "k3f_", ",", "k3b_", 
    ",", "Et_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"odes", "/.", 
    RowBox[{"rateeqs", "[", 
     RowBox[{
     "k1f", ",", "k1b", ",", "k2f", ",", "k2b", ",", "k3f", ",", "k3b"}], 
     "]"}]}], "/.", 
   RowBox[{"moicons", "[", "Et", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.893291091910738*^9, 3.8932910938183727`*^9}, {
  3.8932911692492867`*^9, 3.893291210792791*^9}, {3.8932915144351053`*^9, 
  3.893291517565653*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"bfc4b270-5d8d-4390-aba2-6b65911eb8b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"init", "[", 
   RowBox[{"s0_", ",", "Et_"}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "0", "]"}], "==", "s0"}], ",", 
    RowBox[{
     RowBox[{"p", "[", "0", "]"}], "==", "0"}], ",", 
    RowBox[{
     RowBox[{"ep", "[", "0", "]"}], "==", "0"}], ",", 
    RowBox[{
     RowBox[{"es", "[", "0", "]"}], "==", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.8932912577683277`*^9, 3.893291263299012*^9}, {
  3.8932913776748457`*^9, 3.8932914089237947`*^9}, {3.893291671546925*^9, 
  3.893291674523919*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"6f555d4b-ab30-44be-9be7-7713be1c6a15"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsol", "[", 
   RowBox[{
   "k1f_", ",", "k1b_", ",", "k2f_", ",", "k2b_", ",", "k3f_", ",", "k3b_", 
    ",", "Et_", ",", "s0_"}], "]"}], ":=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"odescompl", "[", 
       RowBox[{
       "k1f", ",", "k1b", ",", "k2f", ",", "k2b", ",", "k3f", ",", "k3b", ",",
         "Et"}], "]"}], ",", 
      RowBox[{"init", "[", 
       RowBox[{"s0", ",", "Et"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "es", ",", "ep", ",", "p"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "500"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.893291414665084*^9, 3.893291485902101*^9}, {
  3.893291520900271*^9, 3.8932915237284393`*^9}, {3.893291574762919*^9, 
  3.893291576191207*^9}, {3.893291790796453*^9, 3.8932917909605417`*^9}, {
  3.893292298175411*^9, 3.893292298679286*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"9d793ee5-fc6e-42e2-b5bc-15753579a922"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"plA1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"s", "[", "t", "]"}], ",", 
        RowBox[{"p", "[", "t", "]"}]}], "}"}], "/.", 
      RowBox[{"tsol", "[", 
       RowBox[{
       "10", ",", "1", ",", "10", ",", "1", ",", "10", ",", "1", ",", "1", 
        ",", "500"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "200"}], "}"}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"\"\<time\>\"", ",", "\"\<S and P\>\""}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", 
        RowBox[{"(*", "Et", "*)"}], "-", 
        RowBox[{"es", "[", "t", "]"}], "-", 
        RowBox[{"ep", "[", "t", "]"}]}], ",", 
       RowBox[{"es", "[", "t", "]"}], ",", 
       RowBox[{"ep", "[", "t", "]"}]}], "}"}], "/.", 
     RowBox[{"tsol", "[", 
      RowBox[{
      "10", ",", "1", ",", "10", ",", "1", ",", "10", ",", "1", ",", "1", ",",
        "500"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "200"}], "}"}], ",", 
   RowBox[{"Frame", "->", "True"}], ",", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<enzyme state concentrations\>\""}], 
     "}"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"plB1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"v2", "/.", 
       RowBox[{"rateeqs", "[", 
        RowBox[{"10", ",", "1", ",", "10", ",", "1", ",", "10", ",", "1"}], 
        "]"}]}], "/.", 
      RowBox[{"tsol", "[", 
       RowBox[{
       "10", ",", "1", ",", "10", ",", "1", ",", "10", ",", "1", ",", "1", 
        ",", "500"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "200"}], "}"}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"\"\<time\>\"", ",", "\"\<enzyme rate\>\""}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.89329152610915*^9, 3.893291534547098*^9}, {
  3.893291680483762*^9, 3.8932918689473953`*^9}, {3.8932919030696507`*^9, 
  3.893292055422885*^9}, {3.8933402522861137`*^9, 3.893340254423583*^9}, {
  3.893340390940796*^9, 3.893340395821859*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"9e0c96e4-ab91-47a5-a940-936877bcaffb"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13c8V98fB3CzInuTrIYRmQnFeVMZDaMo22d/Pkh2RraiZZZkhiRKSCjK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       "]]},
     Annotation[#, "Charting`Private`Tag$19912#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwd1nk4FV8YB3BKaCF7iEIqilCShPuSpJS9Ive6+5ItS0jce60layhbdhIl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       "]]},
     Annotation[#, "Charting`Private`Tag$19912#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"S and P\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"time\"", HoldForm], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200}, {0., 499.9797991481766}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.893291944173894*^9, 3.893291962741942*^9}, 
   3.893292020351172*^9, {3.893292050779099*^9, 3.8932920559427156`*^9}, {
   3.893292249241378*^9, 3.8932923029113407`*^9}, {3.893340255366991*^9, 
   3.893340257194615*^9}, {3.8933403929265347`*^9, 3.89334039674333*^9}, 
   3.89334394573433*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"4dbd8351-eb62-4397-9084-f3b6ce9859e0"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwd13k41F8XAPDRRiVRSFJNWlASkiTcg0IqNUhkm33Gln0LmZAty8wkSUJZ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       "]]},
     Annotation[#, "Charting`Private`Tag$19995#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13c8lV8YAHCktGQUSZJoqYR+kkTnoYwSlb3dfS9SdsgK0RJJlJBCKcmI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       "]]},
     Annotation[#, "Charting`Private`Tag$19995#1"]& ], 
    TagBox[
     {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nk0VV0UAHAqUpFUFCFJGRIpSYWzU6IoZZ69+b2SzDITomQsH4oMGSoq
Q0IJRSGVChWpl2fmvaKUKfKd+9ddv3XPPXufvfe9626iuJnRF/Hx8d3j5+Mj
rvIJ87mZsu/1+D7UVEY2pOtVCilvdGUVo13yl9VfCXxEz/zu5ymx6tAk//bS
gY1f0FWtfgeR+CaUaZKnTmv9ihp3eDAFWW9R99ikqJIBGwWJL1QtZLejh5Jx
csIMNkq5YqA3F/cJpepmcw3d2KhYNLZhOqAbfbB/pL/gwUbNsW1Gf5jfUNYH
vblRTzYajxQe8ivkoEf5letsvNgouKFYeSq7DxkONTJvYi9fZH7GJ3UAeexU
VOzDToHJ+xNxQ2hWfZ35Jm822hx67adH5AhSD37e4oRdUqOjOR7ARamWq1Uy
sF/ui3jEY46hJlQzLuHDRkU6a0J2F4+j12oipyywf3bTsrwLf6LqGrupJOwQ
KaHeX9kTKEj4zEERXzZKTT3OHIubQnKLetKXnGOjlqRuj2HmAtIOCI+b9GOj
i2kpL69q8EFI83Kp3f5spMpCdruK+UDDwKzSC9tzaVKgZyE/GJRNbvmJ/c9A
s3Y8ezGYqrV28ALYaH1DwMHvcUuh66VJyFAQGx2tWXp8kCkKQx87NUfD2Ehj
gfJHYlwU3h+scN1xno1i5ZxbN+usAoaQyBNfbG/KYx+L56sgI8Lk2uJwNjo0
6P78YYcYuBipWctGsFHv969kvz9rQJXsNmJ9gY3k5isz5rXWw0L2j6LuS2z0
RkRr2RJHObi4YytX8Sob6ScYPL1lqgR1tL5PMflsRFefFdEQ2QGXpwW/zVWx
0TFl+k8JQ0247NqW8vUtG5V1BPu81NaG8zb6j6SG2Gj/apXiJaE6UFL1MjF7
0TfE/HvlRr4NwDq26Uo7uW/IrXFoV/ExfVDK5nvWqfcNxdgJbpk/cwj85J63
M6jfELUpkKHBOgy7wnTunbz0DT1bKnnSxdYIron07swp+4Y0xMJSRryPglGy
okNf/zdEmtBVPX7GBKK1HOOHhHtQTuYL6am441A0zOBEbu9BD+L3dbeZnYAx
B8kWa7Me5P1Y98QNk5PQXWBsP+Lfg+pa8n9dsjeDgKqF/Z1FPeiU4d6aUzbm
EJciKZjR24N+KEm+KHUwh0jFrKgbfT3Ic/nM6xmSOZyI2vI0q78HBb2p+nLp
lDncSh4nFQz2oERz7bk7AeZw7ICX65PRHlThvGf/aIY5VI3n2glP9KBFfrsf
neaYgytHqRaWcFDGbY2HLqct4MzZ/MdKyhzU3EVtzjprAattEqdsVDjo9/KU
7nZPC/hxmSQZs42DjF1n+XUCLcDsmYbo2HYOmtVoOC4cawFzXJkvDTs5yLba
YvjuPQuQiVJpvqbDQRKt5zb8GLcAhZjh6/MnOChpoua8+zlL0Ltp5sIO4qCz
bYlkh0BLkFWYfq8VwkEmpdQDRqGW4C5lvTcxlIME3Zbxy0Vbgtz+tSsPh3NQ
0KhF2NsUSyhxyuHVRHMQg8MNUauwBOqQptO3Kxyk81YyiPcb7yfWoT5+h4MG
C318WZ5WcF5Osjqqm4OsZP6xb/tagcbPGx+PfuWgFwlRhiMBVmCqeMZr1TcO
yvNOXX86wgoOe57bk93LQRS9R49dkq1A0chkXdsIB7Hfz/07W2EFWYpjF8Km
OejDdES0z6wV7PD6a792XS96fvhKWni4NXy5fcs/yLYXDTCq3wREWUPV10P6
l+x7kWB0/yKvGGuQ85B9murYi4yatFypV6xB4fSu3kfkXvTasPvAoZvWYNd/
9cfq072o3UiBK1BvDb8zszMlA3tR79EK3Uv8NvAq827ohcxexG/6uTchzAam
7esEdLi9qLnWcrN3pA2kvA7dW/m9FyWqvafaXLSBJPf4MM3xXiS3srlfLtEG
qC1Bprv/9CJ483CwNMsGLI0oCicWelGYcdJoe60NBO1UMeKt6UN8Rka/1s3b
AOdTzsFXetgHKviz/W0hR5ZWG5Peh+wODbV0BtuC38uuwu7MPlRuuD5ZLNwW
jFZQk9Rv9iHW8YCtETG2wIt4YdVzuw+9t9czZqTbwtc/GvyMij5007cxWbXG
Fua0/YoXt/WhQ3c/Kj7is4PccN0LKSv60cV1U8faou2g4TNJJORiP0pubu6r
v2wHFhdaf1jG9qMs/+v+DxLsoHL2yvMdif2ools3PznVDuIpc6Zjqf1oICty
zuqWHSwuq/yTcKsf6SutLuputIP3k65s56Z+NKe9XWhAwB7Cog189i8bQO52
1PqpCHto//jpzsv/BhDnvCYN/ecA4QJ2dl6jg2jt1WufL+U4greOtuAx82G0
/MOa9575jpD2kSMdZzOM+NbFN9nfcQT5NOndrx2H0ffr4eXbSx2h1CEIGbKG
UeNNl/j3Tx1hrUlfinrwMPIr09WX7HEEUof577qCYfT1PefObVknYFT56/w3
PYwKVqn4N6U7QYNOpfen5BGkNmg7vSTbCSxrDHq510ZQZfWlc/p5TpAQlawz
lzmCmhkjPjV3nSBOcyRu1Z0RNPrktueDGid4lxt7WbBmBG0/pXgm65sTGFPf
3NjYP4LKnyk4n9vsDPNvpaZb1EaRTqoFu1zRGToTD+Ya7xpFL85EOv7a5gwT
JfaaTXtG0cd1/faums6wYt7m530YRVOuuTZUA2cQSK3DH4VRtE9K3syU6Qz6
h65SGd6j6JnnRgPFImcQP5ixO798FM3+GUuULnaGyNJayt6qUaTp//SL2ANn
4Isdqm2uHkW3Q8nec4+d4UfZ0YXO+lGUGJub+77FGba9qMquezeKSAWKi4JG
nUHmSPz2fO4oWuClOg+vJcHWnp6iDhkuylALE+iTIMFpCw+pt3JcpO3OKvq6
ngQbVqa2Pt/MRZ4T2lNt0iRIVI8Ru6nMRYMzXfE1CiSwrWjQV9jNRa2C0rVX
NEkg+joi64gxF2XKZUvrWpAgdgLtUfPmopUxGs3brUgQV73qa4wvF4VO1HvJ
2pDA/eMi+z4/LiI1DrQs2JPAJxDGooO5SP7MNv96KgnUxV4OZUVxUUFlxQdD
LxLMk3+Wr0zjIolNRue1fUgwdGfshcp1LoqO6VJVPkeCt6crf+pncBHLcS5i
eSDebyq9iJnNRSqL9Xe+CSfBztJrWyJuc9H942/iza6QgKeoqyFYxUWyVU77
DiaToGZBR3TwERclbBof2JVCgrJVrifrq7nI/fdqXfHrJBDiuyjuXsdFO6/b
cD/lkODjG59NOY1cVDHQZ+hYSgI/87QAxw4uqgma5WO9I4Hy2L4V5O9cNFk8
OB7eRgKPlECXyR9ctKOvredGBwloLof1L45zUd6RoqftnSRYLyB9JmeCi2Ik
HMIQhwSrmJ32hTNcZFVSsyDxiwT6d6oWNgjwUGLfnTGN3yR4nK2WFyjIQy8l
Ur6ZTJJAW0dZrnMpD+kEn60LnyVB15mkiujlPCR/dGPoj0VkyN5RwlcvykNj
fWH/Xqwhg1JO8KbbkjyktM71R484GcySo2c/SfEQ5agt++86MsioJi0VkOah
jyUatRrSZOg5vqnDSpaHngT3Bt9QIMP5lqZ3XfI8/L05NO+9mwwHRv5uoGzj
oU3GS+c2W5NhfZFQXvY+HtL8cLBNypYMZYKvzD3389Bh57DbYvZkyOjSUtDX
4aHTXjMWC05kqFkWr/VFl4fK07n3PjPIMJTbeWkW8HreW+ckXzIsp53d2neY
h2x8hbUu+uH8Rl2y0gzx83xHhEMDyPAyOMXLxIiHEtbWV50JIYOJX9T+4iM8
1KlTLmYURYYuS+VCsgleH5fW8O8/MhTVOY8EneShoHUfrv1JJcNnS61CSTMe
is8Rc+ddI8PlU2v/lmM/eBgj/fkGGewOGdgOmfPQ3Ncgn4f5ZDijLuq03wrH
UyMrnnlIhjuV6iq5djj/t8qXuzrI4Hhu9/ULFNyvzc/yZz+SofpBYPViKg+5
nLN5uqGLDI/Vs/8Lw5bfGP3H8SsZCupUz/vS8H5n+517B8gQHZESa87A+Ypk
aXInyRBcqbjiwylcD7KWqfAMGUhrV2yB07jeD9+c2v6XDOkGb7YWYnc6zGW6
LeB8flXxAlx4yOCu7bLfSykgMdn1RtSVh+SM17Ln1lNAnaKwZ5k7Pk9m0bTM
BgrkFv8VpmF/+qW/BslQwHDPpoka7PjrHkbnN1Ggsstm5qwHD/0daS0TUKHA
7bcvVRs98XxcvBS9cj8F8uLN6cY+PBTb+G+HnCMF1t9MtK/z5yHwGNSQcaaA
ygtnjTns3xtad0qRKZCQ98tNO4CHHDxuaK6lU+BQndz2Yuzt0jraQq44Pqu9
9b9AHmr18EfjQRTQbZtiGwXzUDiexe8hFBjYUDkQhK3VZHRgNIwCluWZp0uw
M6XXH+yPpIDIn54J8RAecmuqONwZS4GeCJGt3dirZH4fe5pBgS9nL4iahvHQ
86bu4zWZFIgy04wOxPbzbDB9nE2BfabRCbewe5qunCzPo0BHsofVP+xSTw3L
23cp4OOf/rngPA+ZNZ91SHxCAXZ7243+cB666jVymvSFAhFwp1DyAg9JHQ7w
MGdT4K7WZv+92DfXr/A73EOBloUNMzbYZTWqF1T7KXCtOWVVKva7pe5Z01wK
VDsLlYlG8dDKjMn2xL8U8Pa75DCBnXI2+nPEPAVSlnxOWxnNQzIH1nN8FyhA
O9uUpIytOrj3h8NiKtxpE3nihG28I1hIeQUVzuiaL2nEvvh8se4zKSocWcjh
XryI65GafLBcmgrSUmI62dipp7YcvSWL78c3mVViF6w0tI6Tp8Koh86HfuwX
NjEetipUQPa/dXQv8dCi76sKfu6lQmh/p3A/dpC4rKi8LRV2WoCkyGUeelO6
zA7ZUyHxy2D6RmzZ43/yHBypIHOxlKeBXRf1el8qmQpz459nLbEXTQcwhE9T
gfX42qd07OjPn2omA6gwbem0IBuL59u3QWhtMBUGe8ay1LCV1hSba4RS4fUt
Wwk97BbjqBGXCCo07PKOcsAWrtEU51ymgrjJTGgq9pWspDOvMqjQ8aZ1t2Ac
D/XtD64czqSC0qLzjDXYmp2sRYI5VGBXp3vJYX9YBWmQT4WP/5IU9mGvD//R
8PAeFewRi+uCnUkz3pBdS4WjAfL2L7HvKAu0ePdQwaHLY9nZeB5qkz7w17WX
Cj9oca2+2HOiwarMfirIWsQEh2Ifn/wdbztMBZMLi68nYv+u7zfXG6cCd31F
Wyk2ODz/upSPBhaxGzzGsU+b8onyL6LBqyr+71PYV/V1YHYxDYL1FiwXsAeV
ym/yltKgN2R+TCQBv49/cpnvRWkw/3vnERXszviIn9c30mDpIaEqZ+xF4XXy
yZtoMJbZKsXA3ubz1zxuMw2ypLxcz2CH2HtVhCrSIG72X68ftoISNZCmToMv
R+hrkrDdnukLqCEadG/NL6zFFvzNL/nMiQalW8XuiSby0HRJWnw/iQa77stV
rMXmuqovEaLSoOQerVQS+92Qw9hxJg183beEbsa+3l354osbDXK+pAVqYas1
uHpOh9Fgq1i7hB22XNiS4Q0RNGgsFbVwwl6jm+6ILtBg4cz9CxQiXkWzUdQl
GqzbE994Gru+cPPGtVdoUKG5vz4A2+pK1yv1XBosjm+oTsM2MnU/YJ5Pg/zR
E8cysPcLL630vYXz8xb/kEXEi9K8WVNEA7nB0qYC7FH/BD/jchpIZSvplGOH
kA22MF/Q4L++nHNvsG/tKA3JHKKBblNk9wz2WfGfM5UjNFDMlbGew9ac3eHz
nkuDQarg63/YTxtKXJaM00ArWPTm4iTcH6sSm9PTOB5zik8EWyi4eKfWMjq8
+jeRJovdSh67Z7qCDrX9WaVy2MmH1ZVPidChXeLWc3lsuVXFGzPE6HD+leDn
rdjaufeFF0nRQW0qt0ENm/Xy3uAbFTo8M0/M1MVWu/+dPKRKh8i2CirC/n1l
+1c+dTrs15FSOIAd5nCvfdcuOqj8aEo5hJ02dvfptf10CL+/xsAYu1n87nW6
CR0qekTeWWMrUwqPz7vSgf/yo++uxP0b+0p+udHhc5raBjdsRleL2LAHHSRO
3jNwx847we1o86FDzc2BJE8if6RqfzuYDt+nVwudw5aQvs80j6ND4ViGRyj2
Q2u9l0YJdAgwXuEVhm1xtVVFL4kOD7R+eZzHTlo+9l3pPzr+Pz3IisAWnlH3
/pdBh7yCwj3R2Is+lobduUuHfpFSRjx2jph+b+Z9Opgfu6CfgA3H2g4ml9Dh
V/kO6UTs4Oe/BEPL6TCTsvllEvZ02a44iyd0YD1Yu/w/7B8JD68tvKKDZnOk
ajp295FHZZZcOoitaFxbgK1vmmfj850O21VD6gkXWiT8Sx6jg8FH+7O3sAOc
6Uc7JugwNJbx9Da2lI9Yr9kcHXp120yLsG2yT4mdEGGAcbO7TAn203yLSjdR
BoS1cIsJKxUhxwQxBjy27YZSIr+H4ndaxRnACVNxKsNOffUMjskyQKgsN6oc
++OkpPtRdQZc3VaQVIWtN7dE4rQGAw5r1Qk/wi7gH6++tIsBsvqhUYR9hRuX
vtzDAOt4Sd/H2OLynlmGwICe/uWGT4j6H2tpPXSSAfrv4x/UYbflBmxHXgww
OSVX+QJ7NV/Fo30+DPBbtk6oEdvc4aeB1jkGfD9naUO4Yy3LaXsgA2L7n04S
/nTBMmFDBAO0Dppua8b+wtzxc+oKAwaPanq1YEs/dwmeSMb5P1j5iLCj3K1l
YykM2L1X6R9hdqeM/OB1BiT/3BL1CrvnyArzjpsMiA5+G/cae2DbYHlJGQOQ
9mRoK/bWi5sO3C1nQGf7+2rCjH6HN7cqGPBZaeUU4eGM9oHMxwwwbchzeYs9
KvJMIq4e1/uk47F3RP/H0v1OtTHg6JW0ifdE/R+c1JH/xYA9FjI9HcT8aWu1
rvnNAGkVheUfiPl+IkUSmGSAUUzDLsJGz/sihmcYsL248wLhax0+r+7zM8F4
SemWj9j7/lyz2y/GhJG8GqtP2Mf9Q3iqa5ggk1QaSJgyTwmRFWfCuODebMIx
Aqo3+SWZEPb9zxDhbvHakSY5JtieN/DsxA7S6vWz2MGEhAwVry7sxMeNyw/v
ZAJN/EIS4Ty9oow9mkx4IJhXTPj1Ye+nUtpMSP1uwiUsYy0oxEFMcH62kfQZ
u/acSqqrKROclDz0urEXqjwfRp1lgnXe66YvRP8Eyy7fdGdCaDq1h/Bji5/k
Wk8mkBdqpwl7j7utnPRlQtSF20pfiXorujLpoUyg9NleINyWwpQ8lMiE0r0d
O9nYxf0FY85XmLDQcs6QcOzOwReByUzYtnvUnrBhK83zQRoTrv7dF0n4iQDl
lXwOEy5yotsI53s7BPOXMWHxtSL6N+zw+nRzmXJcryHlc4RJq7qV91YwQYDk
e5Gw1F3bj+6PmVBPCSskHN9npd5Tz4QTdx15hP3MTnJq25kQKE1n9iQR/1uH
DYL+MCFA1BM42HwfPvB7TzFBwlTDhHCFP73WZYYJXgc/WxOWb4jcYz/PhJnG
gbOEZy0blPcJsGAyxjidcGEgrJxey4IVDQe+EybJvWsZk2DBlED/JGGJF87R
Q+tZYNRM4+slzrMylO+TNAuWWCxeQ9gup+bXQwUWnIwU20N4WdO+T16aLOjq
ag4mXOvSctVFiwVtMtFRhL1X2Z2garNgcS4kEO6x9X9ppsMCNbOCbMJVvMpq
jUMscGPrNRA+m2Top3yYBdKMh68IK2h90txkxIJX1Ll2womhk/dWmbCAXvS3
jzBr9e7sMXMW8LXX8vdhy1Y+dxiyZIGmZ5UQ4Q57C8lv1izosA8XJQz5Xlda
7VmQMB0lTXi9dlnkPSoLaHVmmoSbHNVPuXixoFKMyyK8msqqvuHDApNDWW6E
nVg5Iu/OsSBku40v4UnPNWWaQSyQ8CyNIKxwcWp2PhKv1zp5g3BYWV1sYgoL
xH/deUP4deU0uz4N57PHpZ3wuhoNjT/XWcDrlO4ifL8p94NtFgtKQk70E/76
JVp2821cb9GpGcL7lp4oefiIBRM3wuT7saOELy0armZBod4JRcLvxeotpGpZ
oBK9WpUwS1pzJqSeBUdPue0mnKqxXt/oFQsuDcYaEv5t39P++QueD9bpU4SB
LLlV5BsLrETdXAlfZpj5IQ4LWH+YHoTlPZ5L5w2wwNl4jz/hk1G36a4/WIDG
TlwknHGZU5k1jvtxc+4y4eFEqeVtv1gQOX8jgXBYeux9rSkWjDjVpxB+nf2C
79QMCz49MbhOeF3BP7P0vyzI9Kq7QZhStCf/zTwLDhWr5xC+X+I+tbDAgrfp
KXmE/wdBbUgr
       "]]},
     Annotation[#, "Charting`Private`Tag$19995#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"enzyme state concentrations\"", HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox["\"time\"", HoldForm], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200}, {0., 0.9797991481822668}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.893291944173894*^9, 3.893291962741942*^9}, 
   3.893292020351172*^9, {3.893292050779099*^9, 3.8932920559427156`*^9}, {
   3.893292249241378*^9, 3.8932923029113407`*^9}, {3.893340255366991*^9, 
   3.893340257194615*^9}, {3.8933403929265347`*^9, 3.89334039674333*^9}, 
   3.893343945760745*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"fe1c64e4-0aca-443b-a2d6-fe6cf7c77f84"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwd13c81f8XB/BLUWRcIyQkSikSSb7SPYcGJSp7uxchIzIyIkLLTjJKRkXS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       "]]},
     Annotation[#, "Charting`Private`Tag$20074#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"enzyme rate\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"time\"", HoldForm], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200}, {0., 6.206659730728467}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.893291944173894*^9, 3.893291962741942*^9}, 
   3.893292020351172*^9, {3.893292050779099*^9, 3.8932920559427156`*^9}, {
   3.893292249241378*^9, 3.8932923029113407`*^9}, {3.893340255366991*^9, 
   3.893340257194615*^9}, {3.8933403929265347`*^9, 3.89334039674333*^9}, 
   3.893343945786131*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"384bd6b0-1163-4722-86a4-609f00fe614d"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"odes2", "[", 
    RowBox[{
    "k1f_", ",", "k1b_", ",", "k2f_", ",", "k2b_", ",", "k3f_", ",", "k3b_", 
     ",", "Et_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"s", "'"}], "[", "t", "]"}], "==", 
       RowBox[{"-", "v"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "'"}], "[", "t", "]"}], "==", "v"}]}], "}"}], "/.", 
    RowBox[{"v", "->", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "Et"}], " ", "k1b", " ", "k2b", " ", "k3b", " ", 
        RowBox[{"p", "[", "t", "]"}]}], "+", 
       RowBox[{"Et", " ", "k1f", " ", "k2f", " ", "k3f", " ", 
        RowBox[{"s", "[", "t", "]"}]}]}], 
      RowBox[{
       RowBox[{"k1b", " ", "k2b"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
        RowBox[{"p", "[", "t", "]"}]}], "+", 
       RowBox[{"k1f", " ", 
        RowBox[{"(", 
         RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}], " ", 
        RowBox[{"s", "[", "t", "]"}]}]}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"init2", "[", "s0_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "0", "]"}], "==", "s0"}], ",", 
    RowBox[{
     RowBox[{"p", "[", "0", "]"}], "==", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"odes2complete", "[", 
   RowBox[{
   "k1f_", ",", "k1b_", ",", "k2f_", ",", "k2b_", ",", "k3f_", ",", "k3b_", 
    ",", "Et_", ",", "s0_"}], "]"}], ":=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"odes2", "[", 
     RowBox[{
     "k1f", ",", "k1b", ",", "k2f", ",", "k2b", ",", "k3f", ",", "k3b", ",", 
      "Et"}], "]"}], ",", 
    RowBox[{"init2", "[", "s0", "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.893292080438322*^9, 3.893292165363051*^9}, {
  3.893292217622164*^9, 3.8932922541698103`*^9}, {3.893292309517599*^9, 
  3.893292441276848*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"887904a6-2f52-48cb-9df1-85bedc68e8fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsol2", "[", 
   RowBox[{
   "k1f_", ",", "k1b_", ",", "k2f_", ",", "k2b_", ",", "k3f_", ",", "k3b_", 
    ",", "Et_", ",", "s0_"}], "]"}], ":=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"odes2complete", "[", 
     RowBox[{
     "k1f", ",", "k1b", ",", "k2f", ",", "k2b", ",", "k3f", ",", "k3b", ",", 
      "Et", ",", "s0"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "p"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "500"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8932923493018103`*^9, 3.8932923598393087`*^9}, {
  3.893292445822926*^9, 3.8932924460858383`*^9}, {3.893340125864005*^9, 
  3.8933401736362457`*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"5ec075e7-8dda-42e4-b7ab-e08a0778c53e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plA2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"s", "[", "t", "]"}], ",", 
        RowBox[{"p", "[", "t", "]"}]}], "}"}], "/.", 
      RowBox[{"tsol2", "[", 
       RowBox[{
       "10", ",", "1", ",", "10", ",", "1", ",", "10", ",", "1", ",", "1", 
        ",", "500"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "200"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8933403636506968`*^9, 3.8933403717000713`*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"a66b275b-2a70-48a4-918a-677966c620c6"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nc8V98fB3Bklr2zaZglpdLgvFOhjGQUWZ/9+SDZIRlRKbsSJasyItmj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       "]]},
     Annotation[#, "Charting`Private`Tag$21216#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwd1nc8Vl8cB3CkNEiSmaxKFJlJoudbMkIKDePh2cPeo/I8jxYqMyXKjGSV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       "]]},
     Annotation[#, "Charting`Private`Tag$21216#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200}, {0., 499.9999805841794}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.893340372280435*^9, 3.893340400196351*^9}, 
   3.893343950401001*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"fa8533b6-2e48-4eb3-b0e1-2663031dae3f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plB2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "Et"}], " ", "k1b", " ", "k2b", " ", "k3b", " ", 
          RowBox[{"p", "[", "t", "]"}]}], "+", 
         RowBox[{"Et", " ", "k1f", " ", "k2f", " ", "k3f", " ", 
          RowBox[{"s", "[", "t", "]"}]}]}], 
        RowBox[{
         RowBox[{"k1b", " ", "k2b"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"k1b", "+", "k2f"}], ")"}], " ", "k3f"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"k1b", "+", "k2b", "+", "k2f"}], ")"}], " ", "k3b", " ", 
          RowBox[{"p", "[", "t", "]"}]}], "+", 
         RowBox[{"k1f", " ", 
          RowBox[{"(", 
           RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}], " ", 
          RowBox[{"s", "[", "t", "]"}]}]}]], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"k1f", "->", "10"}], ",", 
         RowBox[{"k1b", "->", "1"}], ",", 
         RowBox[{"k2f", "->", "10"}], ",", 
         RowBox[{"k2b", "->", "1"}], ",", 
         RowBox[{"k3f", "->", "10"}], ",", 
         RowBox[{"k3b", "->", "1"}], ",", 
         RowBox[{"Et", "->", "1"}]}], "}"}]}], "/.", 
      RowBox[{"tsol2", "[", 
       RowBox[{
       "10", ",", "1", ",", "10", ",", "1", ",", "10", ",", "1", ",", "1", 
        ",", "500"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "200"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.893340176237804*^9, 3.89334026078808*^9}, {
  3.893340291610001*^9, 3.893340356326234*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"13870b95-2898-4a30-b0bc-413bd171c809"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVVnc0Fg4XRohsIiREZTQQqZT33hRJpaxs7x7Ze68fDSQkISObhkpCk6RE
okKkRHakkOyRz/fXPc957jn33uc+59y7meJmSudgY2O7zM7G9v+oEL+cd0O2
maBHVji3bq0YPuJRkXNh3Yd5KV2f79xi+NL/Xr4y6wXUSqTalK3iN+oeTG7W
B/AUWWJ3WMX1sS2G08zvQE6crSnhEsO3OpFPfjHHQW0gkdecUwwbrnR6DDNX
IPT1+YtX2MXQqHKt8RBTCDnvC6n9WBTFJgFtXk57edx4ZK/t8Jgo6sXrVxed
UsbobgezD72iSFdbENAQUEeBt1vCp1tF8aQK/Y/EUS3U+lSy9/YrUSz9FOLz
dt8+bJwvTtv0UBQPiKre5ww7iMq/OOLPZYkiczExs8AK0TnTQM42RhTd3vzQ
vH9SD/MkvCoLvEUxxoZ767LzEeTSeqecYyOK1LoghgbLAO0lngcVgCi+XCtl
4mRtiPeDdadRQRQ1RMKTR7yNUNavmhH+TwRJf3V3GDufwM7x82u6OkQw50at
zOxlY3z7mOwSdFsEH8bpdLaYnkaF/fPz8r4i6P1U93TmCRNcLCY79euK4IuG
gsloW1PkCojmnZgRxrNH91eetTJDQ2//0K23hHFMWar2gZ0ZksIz6h4VCaPn
uvnGeZIZunE5rTtWKIzBTY+/RZ81w6vvBANYecKYYLZv6VagGfIZEbvTMoWx
grj3wM8MM1xW8RxovCKMHP57njj2mmG8jKa3Q4AwZtzUKHdyNMfARZWns0eE
sf4LtT7L1RxLFw6/O3pYGKfWJXe2epqjlql8avIhYTzussB+MMgcucpESOoE
YVzQeGXMH2uODYFS5833CqP1M/Ph4rvmKPDRj81BRRgl3vttHJswR8eQzGPO
/MJ45W/lf+5+Fpj8TnO3UYYQurYkkO2CLPBcUXu+f6oQnnhAPWQYZoERGr8h
P0kIud142eUvWuAnJZeByVghDP5pHv4h2QK9JmtTXUKEkNE7GrqrwgK/VWlp
tdsL4cEPUsG/pizQgO/SC6KMEA7d9vFleZ5BVxfjl0Xxgnhm07/um75nUPNt
w3B+jCDWxl84OhK4yv+73ph5XhDzvVMkHSPPYGx2Q0VEkCBSCE+eOiWdWfVL
6FVJpiB2Ny/9c604gwTrGZK7riC2zUVe9Fk4g0lKCWvuDwnga4PE1IgIS9Tp
6f5tpCqAg4xnTYEXLPFulrlO4BYB5L44wOEVY4kSuzhL8mUF0LBO24WaaInv
qGaco6IC2Hi089CRXEu8FHuu8eAiP7YabhnlqrHEOoOC2xMN/NhnVKEbzW6F
lxPStvgx+JH91Ne++HAr3Pvj2YHvsXxYX2Wh6H3OCjdKRV9qO8+HCbuaqVZR
VvhbN3auNpQP5QXrB+QTVvnhI+LX3PkQm8qHHmRZ4Zqjum9Gzfgw/PiVn61V
Vmg/PeHiK8WHbIaGkxuWrXDu0+Xgb1nrkO1QBXt2gDWqpYx31Kbyos2RHw0d
IdbYxyacZx/Pi2VHJZNEIqxxm83y7K/zvMgyDtwWGWONL/PvKk968mKzLeE4
I90aq9gJf6+d4MVc3zdJOyqtUd/2So3uPx48Utyu9ITNBt22pSsP2vBg1IbZ
ky0XbbDutbGs+xw3JtXX99dcssGCj7yhF39zY1ZAWsDDeBucn6/xSO7jxopO
3YKkFBvcr0QVSG/kxsGsc0tnimwQnhr1E7K5UU9Z9E7nGxtUc73walyfG5f2
7eQZ5LJFN+lR4p8YLnS3odbMRtqiRqHT++LFNdj7nxYNrtnhBqfG/ge72XD9
1etfo3PssfWr4n/ZtnOwrk2s2bPAHu9Ldnfl684B24a4Ottb9lgryBF/T24O
fqdFlO18YI+Hw2/2tPTPwptcp7jmanvUKd8xRXeeBf9SXT2pHnvcLda0+Vfo
DHQ19966KeuAt++G1cndmYJCYdWAunQHjCXWbZje8Qd2DVnPcWY7YNLKTkq3
0B949CzaTy/fAQNM50u6JyegnjHiU1nsgPZrJQ9tfTIBP5/f9HxY6YD+fSrE
jwYTsPOsknPWdwfU5b0td6NpDMpebiH6KRLxuIZO01WfUTiYYt5dpkTEjJYK
4sShUah1Pmc/uZ2I0UOHey4IjkL7hgFbFy0izkzsLqPc/AmzLnlWVH0iRjhN
ZHzrHgEdaQXTU0wiKg3Qvfkth+Glp5y+0h0iDlUWXb3qMwgL0+MJMveJeP2R
kmfQiUHQCqj+JvKQiFGCDvppioNwM4zsvfSUiCeaydPBLQOQEJuX19xAxDEX
VeLn3QNAKlTiCP5JRB3pLNP+5T5Y+ZVCHF5PQpuGgxStyh7I2BXO1S9BwucW
+mLzaT2wz511p0uShKqRG7789e8Bz7/7ZltkSNiRbmVwaU8PDM1/iavcQsKm
va9ehlC+w3tumapELRJujY17TqB3wQ35bBldcxLO/xJ0z3r8BQRjNOp3niFh
6p3e44YRXyDsb42XrBUJLV3jfE+f+AKkN4MNK7YkrFe+cyaktwMUnLcH1FBJ
KBqrvQ+EO6DwUUXbUS8SbjDNfSEc1g4Smw3/2+dDwgcJjdyRxu1wMebLDhU/
Eto+lK0wlm0Hlv1S5LogEn5x9i2dqGoD1TV6u5siVuvNrtww42yDe8ZNcaaJ
JFymsjQPZLWC7GMHncNJJLTGboqYdyvEb54Y1EwmYf79CDfCsVZwnxLVFU8j
oZd1FPHSVAvsTrMa/ZxDQsEcf9cp4xaoGOw/av+AhD9vtUYVijZDZfACG+sj
CRV901W5C5pg5v7QREQLCVe2f+4UsWsC9f6WnsxPJIyTOaVZLdYE+cfuVLd2
kNDKFXXZzjdCjIRdOPSSkOHJe2TM9R2cKalckZgkIZ/Q45gk4ltI6L81rjFF
Qi3xWY2j8m/hrUTy9xMzJBR/+oTrUm89HAxxfRGxQMJkuYT1NfR6UDCSCxvj
IKO0R5xls3cdjPeH/6sVI2NJQID1peJaUN7gMtYjTkZZ6Zmvn3xqgWJk3b24
gYwT/fEbs6AW2ks0qjRkyPjkX93Yg0+v4XlIX0jmFjImD22SK+d8DVEbjix7
7yFj6Jbu82ZBNbD5+NolRUsyLta3XX7j/wK02g63SFuTsT0i6oLOzhdgQAy/
KWJLxscz3eM2fVXg6DVvvuJARr22FIt04yooSx+9+5VBxtprC+umd1WCwa8P
xCu+ZLxe5r9uROAZWPnya0f5k1Gx/9pMZONTcGQ7xh8WSMbLhl81Ky49hfj1
NY+dQ8l4NTx3sJPvKXQcLBMxvEDG26/7mteJPQHHy6mv/l0jY7YdR8jIgUcQ
vKHt+nQKGbctPd/tuOYRxOWIuP+6TsYe5etEt3cV8LA8RuZrJhnjROdecthX
wFJXsE95ARl1cmxmd10oh/hdZCXncjImbksWuzn+EMo+qFz68omMTXoEN3bJ
B5Cg+LJgoZ2MX9UO7In6WQJOflbVG7+QUaa/ru1cZQkoyF2ctu8io7JKP3cn
rQTiXQeIfYNklOPYJFPhcR8cBbK0RmdW59+qUxj8sxgMyNqn+OfJOBaxzI+Z
xbC5vOnszkUy2jTf3tp0uhg67JZuuK2Q0WTvX8WDT++AfrE179RaChZ+6e3Y
m3wb5I+v716SpGAS682csMdNWLpxZ27TRgqmyy12XVa7CZ8n9cRgEwUX8p59
qRgrgrg0D8P/NlPwP+dCMrdbESyOvC/lUqVgfvUtUze/QmiPir4oeICCmclr
ZDkL8yH2zT91eXsKmmXrMzLccgA9hjQ2ESmocdV24NHhHJja+H63NJmC3zym
GCiZA3YemVrr6RQce6USmVSTDTtlDu7jcaGgulTEiZ0y2fDeIwAmgiloY9EW
dv51JkSsevF3KAX39ceougdkgnad4aGf4RR8P2awSUItE27ISB4eOEdBVy3h
idiMDHCrqzDoiKXggdf576bD0kF409TJ6gwKFjik1Gswr8Pruk7jyhurelhb
qa5Rug7+nq9OPc2moE576V6fH6nQU5doUpZPwVG/4FN7HFPhgaeGxc1iCjaZ
5R5c9E0B03pXu4TnFHxQuuewcfE1uOo14kj6RsHrDnI3coITQdog0MOsm4Ie
FXMnKowTIVeSz9+gh4KRhloKBzcnQmnljvM7Bijo+O+zdkrdFfi41j1rbpSC
0Xmfa1ylroBgxkxrwiIFuy8W3fgvJx6SXS9+jVymoNdxje1dpvGw6ZBkr+8K
BR8bFWUvcMbDjqH9Y3ZrqBhiqdXp5RQHx9VDeFT4qPjY4CBD/dBliHq9Rvel
NBXXOVanWQleAuGUpMNlMlTMOqWowvUuBlLObjUqkqWi6pN4F6uoGCgUPGp5
WYGKdYIuFr84Y6DWKsbDWpWKAqaLVulc0cDxW7jwz34q8lQU6jUrXoRgcVkh
BWsqxtLDRb+8jYSmB7w2YEvFtXQTNnJSJMgaT+fb2VPxo+x2gQBiJLy40KiT
QqZiG7El3mw2AjjmAhn8jlQkDc+ej9oZARe/fq6cCaRiBkfJmlul4dDh+4pn
fQgV0319SyPPh4Oy2H0zjTAqapGLtnRYhUPD8QsjTpFUHDp9kzLCFg78lVri
vZeoWCa5y1r8bigkZl1xfpdBXb0nZ8+zdgZD/4GQR8M3qOgqS2FT7w0CrQ4W
B3cOFVcapkRqrwVBmzCmYgEVNbqr606xB4FkxNir8rtULDdfkbvXGwA3aMc3
ZldR8Xw2+9FXtX5wS4WrwbuHioO8YaICgt7QInNo0aWPikXs4u32nV6wJBSy
gzmwug956427bnmB8cxUnPUwFTVdxSwNDbxgqmbAjDCxqn9wY/nhC56Adq+7
1rLRcGF2VsxSxgMcT7EJsXPQMHYgc178jztc1TuIC2toWCpVLKL3xh2GlMty
f62lYdzi72NdHu4QO53HbBai4TjTaRt7hht0xEX+SZOj4Q8P63bc7QIcES8U
kjbTsL4IxF2GnWG7z6LZZUUaRv4+IGCe5Qyhtl4VYUo0XPPS6J6RkDNsUaYG
0dRoeFmax7Zw1hHcXupx7QIaKs9LLEcOs4B7il3qpQMNT0RNVn0GOsyVpMYN
kGhIM/29JpOLDqMuapw81NV60VmJ7I00+PjDbtyYScN/2h7KuTY0SOt8VPvN
jYbXP815rg+jwq5XLp5z4TSMuLJgZtlPBvlwzuGNkTTkfiZjZVJKBjHddHs4
T8NUran9zf+RYa6i3vBCNA3LqF029gpkqLmtKLc+kYYHxzKpEWdJcCbxyzu1
PBqqhP+TLdvkAIan3A+ZFdCQniwYqPLOHg7wr33kW0RD3uy83PAAe5C/oJVb
eYeGm3wWxt522MHPgHj/42Wr/VkKGkXl2EIoWX8rs5aGinz2yS3W1lCk/iD0
xo9V/Xpl9LrOWICr+J/5RyM0LPyhFOi8yQK0FtR9mkdpuCcgwj95wByqX5U4
cU7QcO7uCbkyb3PoOFNi5ThHw2hVmu+PdDPgCbm/W5uXjmL6YSEfOE3hPXn8
7ik+OiZCGJ78ZAJJBmoqZwXomJH57MXJfBOQF74vlyFCx3/Lz0Ob9U1gX949
fg5pOlI+CjZXxp0G1tu7Q02qdExa4zs752IMu+79Jv/YQcc7eIDEJ2MMU4k7
u9jU6Lin4ZnzQsNJCLe726qpSccBe2IEfftJSB0vrr5+gI6+FxylNGaOQ714
cRr9BB2Xm96uvf3gGKhQbhsvu9Dx9WM/npkH+lCfqVMy6UZHw6NW/V5B+sD4
0iAy7EHHHfbHDgfq60P+6dFPLT50ZHz/67yx8wjIww7bmyF0VL8qcfYy/xGQ
kLnHNLtMx6tLlh/kLupBuSXhrWH8Kh9T/irRSg/Mr75XJVyho+fKq4eBqnpw
Zd34b+VrdDQydrid/+EQ8M+ref/LoGNZYcVmkDsEHO0Pwm8V05E6aNl6uAAg
R0Sv78Y9Olrf2vG1ygIAT7YcTiqhYxqbnTTHWoCQ15PcYWV0/G/jiPcXJwLM
lWpeNn9Ox5Hj+9qSCLowFl9+feUdHa+HshtEcx+AzmNPSi1G6ej+q0uaun4v
6J3Kt/L5TUf9DUkrUW3acNs8/l/SOB1bvNfy2qRoQyCRbvTp72r/X0qLp2W0
QdpHpM90iY7aQqzCLrU9YJV9VuS0AAPnxqvZubw0obrA/JGbEAMDT4r28BE0
QfkO2MeLMDCbeNcyj1cT5srFb70XZ6Dcob3fQ3J3Q8q7l3hSloELzjeHyr9q
QPuMlLuRGgOrz+9r6aSqA2GJU8JRg4Etk3kh2nvVoZB94lm0JgNLHlx7u45P
HXz536x9u5eBjycFKrVZaiCu4Jl1FBkY86ciwHvDLjA/2fD+iAkD/STSk59k
bYeWvMCd4MXAs5qaF08cVQJRtoonOj4MfDgpEibBrwRmdn/0tf0YSL37wtiv
eRt8Ws9y2BnEwNSh0ztn7bfB5/MW8RsjGfiecvf3q5Ct8I2p/mc2kYHTcUuf
jD4rgsxrp5C/SQz02HNn4WO+ItjLF/GOJzPwmMnyk8+eitDdsUlhKI2BxU4d
whRhReg5xmf2KZeBmzndXI+aKMDg9qGyklIGLprsJ8GIPGyL2nyouIyBrTcF
A3Wq5IExYNdUVMFAzv1CablX5WE4o3XwxlMGZhHiuCpW3flT4KXE5RoGzoQc
O5OxXw7GxtP9z7YwsGOJ3bG5VQbmHpocVJhk4J/Mb/3siZLAv0/7vdjqq8MT
NUt+bC4J8s+lSVwzDPxbVbayVlISDF/3Rw7PM1Ddv7/VOXsDXP/k8+4eOxO1
T+V6bXksATrT120OiDCRuNFJi4dDHIwDQn/tEFvFU3qeeU3rgbJMCZUVZ+Jp
rqbn1dfXQwzXjlx2KSamJeRVB2uuh07xqpE6eSYa7OUW6XQWg2DtPn9zdSaO
D5qMaM2IQMLTN+sMdjMxXMr0L+utCOQT7mTs1WJiH/PTPH+mCDQaeFdL72Ni
IP/j4Gx9Edhkyc3TC0zk5SB/a0sXhio/1RSXU0zst1+fzvNIEFYee5ZfcGWu
zhd0Y0xvHXzjLr2U687Eqe3dYsOLvPDU/A+5ynM1/9tJ25xyXvCecBOc8WVi
jmKii9F2XhhWcmHSw5h4jfD1tq4cD7QkM6WOJDCxnbFNT1aZG+4PFI4TE5n4
K7H5g9ovLojdPVQblMREVN3W31/CBUff0zwfpjIx2nIxd8dBLnjORXmnkMPE
TStp1UI2nFDgbRfCXspEr15jq4wHHBBRk262qYyJ82P8auvCOIAk3Kmyv4KJ
rCpaC9tJDpAutm53f8rEoTgUifzJDnH9Z9R6apjodFrXvXw7O/ibmvRWtTLR
n++I2+FLK4Tj6gb6wdNMfJFT4SSUuUBga2tj955l4ku9Kvcu6wVCRQC9ymme
idL8QjEWGxYICq/O7bVdZqLad72NuknzhAWLVyo6XCxs9/2d9+TaHOF2EArO
rWdhiNQr1lj5DIEk/7FhXIKFhu2kgaTgGYJELfHiD0kWtoW8U208PEOIEAxj
+yzDwubclKofrdMEm5zKyfItLJR6Pxt/d2GKwFun89lLi4WV2SLHDMl/CVVO
DVedtFl4+fahGRv1vwRvYZvT1H0s/P3En2dkZZLQYx3w1vQgCz8FRXF4Zk8S
Hv969EzjCAsfq5nyiv74Q2CJ7skeN2MhVWnOJDV6glBnr3bWyYuFTt1ZEv77
fxFEqaxnmT4sjI05YL04MkpwYOUIfPRjobiJi5hD+ihhxlOsVCuYhTsc/Ror
2EYJW6JmF5bPsfDRDolzzm0jhPDSF7EJySwcKY0TES/4QWh8NNddk8pC9xeS
Jv6UH4QNlRoa02ks7DtX9DdF/gfhXl1em3UWC/c+7j3MmTVE6Pp2UVbxJguD
r+4Cq/xBgs7a0yXlT1g4zbF7vdKHfsIF/miO4WcslF0oZrdP6Sc0i9SYS1ex
MFeJ+nUXqZ/AktGaD61hYRTdzyTrbx8hRUNSz/AdC1U8UqUub+4jTNn2tH79
xsLs46dMTFN7CEiW2ibwnYVb7WVlks72EC4xTP2hl4XbK+PkbQ70EBQ8Xsvk
D7Iw4kTS9y/V3wkmF27SXcZYyFf78SEPuZuQcan3UdYEC+et/h0N4esmDCdI
r2uZZGEpt2F5X0UXITw99p72LAsPK2w09hbuIjRm17KdnWfhTn3pq2lV3wgb
Cv+Zpi+y0OaX/ECByzcC5c7egqZlFkrs+nny6qZvhHsl7rMrKywMEAvvIr7v
JPwPLr9O+w==
       "]]},
     Annotation[#, "Charting`Private`Tag$21694#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200}, {0., 4.756876053427108}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.893340338859585*^9, 3.8933404016599283`*^9}, 
   3.89334395190208*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"fd503c08-ebbc-475c-9802-a82c0c381581"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Show", "[", 
  RowBox[{"plA1", ",", "plA2"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"plB1", ",", "plB2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.893340263033143*^9, 3.8933402711755*^9}, {
  3.893340378919846*^9, 3.893340383313661*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"870deb04-9b54-4619-b946-cec114ed4f0a"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13c8V98fB3CzInuTrIYRmQnFeVMZDaMo22d/Pkh2RraiZZZkhiRKSCjK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        "]]},
      Annotation[#, "Charting`Private`Tag$19912#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwd1nk4FV8YB3BKaCF7iEIqilCShPuSpJS9Ive6+5ItS0jce60layhbdhIl
JVu/SiFLqSSlRIrIkmQte35n+muezzNn5rzn+55nzihSztrQV/Dw8ITy8vBg
V6W4pbzMTW8Ne6w0mza+TTGoElTd7Ma6i8sX6hb5eqgGV3u+JF+F9RRH8JUQ
3zX0EZeo048Xim3CEYqnBNv7+nGNmp5MftYbnLLmwvcb8r9wgZLLD5az3+HG
dNojBiumcEkJhwwXYz7iUmYV3tQSZ3HPo9vMfjO/4rytrRaiO3nghV7ofz+Z
Y7gmquZyfJ0oNMd3eQ4xl3ETCW+9E/cqwdFqAYsB5nrQrjwUttJtN7wW0lnN
R1CAqkb33pBjB8E47lDNTUsV0MsfVf1x7xjQNeaFtIQ0wZMrtql5zAaOq9In
pA5rw3MJRk7twCm4/57t80JXF5prPUI7wvBwQGzHXT6uPrClIgQu15CAuZCQ
ccMeYPKVyoidJhXONg7uuXvcGI4/nShI8KZD5Gn+rUuuJpCvdOViSD8TqE0B
DC2WKfCZkP9kqzhDrYCMtYuDGXTXvt85SHAFLdGgpOFzR6FPNurHryfuQJoy
ULNwPQbd8loyp/w9ICezQW4mxgLueufpSBR6QlmsXlebjRVs/u9s3ZoWLzj3
0MAq45g1vBg7XNz92RueNt+YvOxoA88FIvKof8/BmcP7q8/Y28J1WqQNr6Av
pBdqVbg420G3e7lil6IfxE9VB3v4nQCLWlm2g8Z5GLjl48vyOgmVr+Jbp5T8
od40ISUk5BR4rUixL1C4ALyWnd/iguyhq+p3iD9vAPAYVfJm+zvA0gll2uCb
AIjYMHO87dJpWAzvw3umB4LHaWrdTKgjlAa5Fc2bsEE460ePfoQj0J0EPbMO
s6G4z3M5ONoRbB3FbY2PsmHQNUh/3TVHcGmOJodYssGJm1GpUOAITdnvw0cc
2HAs/+OtI88dwSSxtYvkzgaVX+aJ19fhoRPy4t9cY0Pj7nelPSJ4IJfecdyb
wgaa3+nWrZJ44P3C2piaxoYsnjNC9+TxMKRU53c6iw1S4hcv1e/CQ8yJN5fq
C9nAp1sTMGqFB0v8hPreR2zoDdam4a7hIf4MkRDyhQ3bpIRjPVLxUDR5Qf56
Dxucbw1W5WSg5+sKX5Z+Y8N0W9pavgI8BN8UHe8YYIOgMm/Z80o8pD79ZiY8
xoZdja95bTrwYDX29qnEMhsurGFm0TYSQPTk9pcx8hx4mgkvrm0mAGXQj0bd
zAG+PbJTjVsIUDbm9VVHkQMxjq9NVdUIEJkz5P9RmQPZxXt+jeoTYFg21HB5
JweaLHgM/JwIYPjqIu/wfg5IJKZ2Xs4hgLCVg8E2Ow6saRd/63WDAPsvDKhl
nOAAz4bYJsciAnS0jZiJneLAaFpIuXopARo6GwRmHDjQmOsS+7aGAAHnrItv
ETlw/r6BsUwPAYB0fvahMwe63/YWFW5yAoucY6mhXA68F8dnxys5wWfWY+na
IA40n/iQdGGbE1jHNnxcDOZA5afm0GO7nOBoG4/02TAOXOktI4wbOIHwQvsD
w8scMJ4IF9UlOIHG6wdmUQkcKBDZ4d903QlO8VJKe/I4sGvAYZYv2wn27c7b
8TefA1WPLvsZ5zvBxKaARzIFHHjOGPapLnaCD5l7d5gXcuDH40KvsmoniBNj
spKLOaB+Zrtr1lcnUM6N7PxQjuoxPDXyuc8J3HXXxn+o4IChxCVn2SEnGHjR
5/++kgMWTwdY18adIID7eLj5AQc8JAvoUbxE6GTTzuU+5kB5rTLRbwsRCEmt
75aecUA/2e5L+XYiTJl5RPXWc6DBNYwwuZMIUl0aic8aOPBhQ7+jmzYRYntb
00KaODDjlmdPPUSEbPMjtT+bOaAnq2RjySTC7VhlFe+3HKj12nxo+20iPAhM
SzjZzYH532NX5O4Swe/agMsisrZ/zWfRMiJ4LTNX5XzhQCGXfG7xIarn+Ffu
wFeUb3Re3ttmInDP76qjfOMAqWD7isAfRKCN9c8pDnIgTXX2uOcvVN+d7txy
5PfFz1MZk0TYU2q63XSIA2ZlZ7Ss54nwx2/fC/owB6R7TmiKryKBXiNPTvII
B5Z/JhOHJEjwrnOlbNMYB9J3Ba3qkyJBeFididk4B3Q9WLe7pUnw8m4v/Tmy
15TuTJscCQpufY5vmODAwNyn2GplEoTlKz0tm+JAC7/ckwRtNP4Q5QtphgOZ
CtlyBnYkcA2r8lz9lwPCkVrP1U+SYEea8XVnZO5UnfcmexI8fJH6pxmZ1Pi9
edmRBE+vUM0uL3NAyXWnfx2VBEXKIkGLPFwoqKpsP+xNguCwUr8nK7kgpWgW
rOtDQt9ddYY4HxcuRX5SU/UjgeHn9HQmMouwGLomgAT0wqIBoVVc2LHSePfr
EBIk0xMkbPi5UGLxOtYmgQRqIfvm/xPkwqYHTnoHr5IAOsv5+FZzIU5x/Pue
JBL8d7LO5Tiyx7SYgWQaCeROc+y+IO9Osx/5mEOCSc/a+7NruFD5ve8woZQE
8k5yJSJCXKgOnOdhtZKAFSta2C7ChT93B8ZD2kjQK33ZREyUC5p9bT0Z71E+
XVRzC+T8I7dr3nWQQBgXkVGPHCmFD8L1ov703fG7JcaFk/eql6UmSYCreSqH
l+DClb6iMa1p1I/kxpk45BdSSV+P/SHBX4qC9TNkfbb705B5EnjIng1VkeSC
0tHN3F8ryNCuosc/ijzWF/S3QZwMMr7BXOIGLqhscPvVI0mGsrb8xihkylGH
LwsbyJBs1JhRhfzhntYTLTkyLK5Q5hGW5sJj9jd2hjIZLP2tSyuQIzaYLJ3b
SwZ3fHfuhAwXFM0FFrecIkPim2gjJTkuaLcfbJN1IEOgroMBIJsSgwpFHckw
x103QUB29p6zW3YiA59EfUgKcvn1kTudDDJA6iBpjTwa//MNMd6XDBVGz+N7
ke191+lEnCdDepH7yQVkZ54j67gXyLAccvezxCbUP4m6B64cMjwjWGoeRu7Q
Lxc1u0gGgT2ZK4uQnWNSnv29RoZXgXpt5M1cCNzQnvo7mQy9fKsn/ZBjc0Q9
fqaSwXPnVFcMcllFpFxnBhluSYmK/Ie82B3oU3GDDCeVdgsIKaD5dpG3u1aQ
wZqVlXYbufyNatSn92S4HK7m0qiI+rWl9sb8BzKoTGet60B28bOv2fiJDAbn
ZbjDyEqbL/0mdJNhr7LQp7VK6H3u/cRv38kwZb/P3QLZWShLe+QPGcRavIJf
IpuSdSzXzZFBiKju3ImsWPH6jPoCGarD+HcOI3fgFzPPLpMh2/++Dv8WLhwq
dlg9LUABncMQbIisYC7xZVGaAhUBp/YXIi9m3p6V30iBVfJdbeXIHyeNxXHy
FCBOJBytRY5N8zQLVqSAyq3Z9k/IC8Mt91ftoMCzLGHGamW0PyIuXxI+QIHF
g0YVFOToxr+aCgQK7OpJ1uTZygXwHNCSJ1JA+uPea4LI0xtbdsuSKZAbdadf
BBnvmaEtQadACGfJRBFZXU5fV9CNAho3akSMkFs8/XHjgRTQjLbkYSOHoL04
yqFAtrXqjjBknSYzox9BFLi6d9QoCjlTTvpgfxgFzOWGD6Qin22qNO2IpkCk
WZhTObKI/PTxmnQKBO7KCB1Erm/qsqjOpIB6KyF7FPm81zPLh9kUCNtQdGcK
uacpwbo8nwIHtrDTlpFLvbROFBZToFUXaqW2ccHmuTv+ymMKDAeupxojJ3oP
O5M+U+DsG6mBOGRZ0wuetl8o4JZiZXwVOVd67XnTHgr8vFaWmIJ8v1otXK2f
AifSKVI5yK0CHlmzIxS4eN8gsxRZOP3PuysLqH9fpl+3Iie5X+oMXaLAkcXG
iPfI8kbSvb7LFLi8y0qvA1ltYP8v/EoqhEv2B39FNtdkC6qupcJxz6Qbo8gR
9SsNamWpkOcpbCO4HeWRfPVguRwVckTuhKxFTj6z9ejNTVTY7+N4Wxi5QPjw
qRglKrhT936XQG6wj/R02EGF2ycHFxWQV4yKFEzsp8K14KhX+5ADJTetV3Kg
QuN6OQYJ+XXp6tM4R/TffTJmlIK8yeJ3Pp5Ahc0SKu505KcXX+klk6nAZ7zN
0Rl73+wFxjpnKoxf2zfgjXyp82P1nwtUoMcUvwlH7vB9JijBpoI5/+TEJWQV
8bu2Wlwq1GzzFI5Ebja/OOwSSoUXgw46scjrqrUle6OokKQWdjAJOSEr3vVl
OhUWH2wi3UDuO8CuGsqkgqHmrNpNZO0O1gr+HCpkvpicLkRuF4EUuEGFrN3B
vsXI0iG/nlXcoULaFqJRGXImzXxj9hMqKL0f5KlBLlJd1XyuhwreWfv9PiC3
yRktuH2jAjqRij4iL65nqzH7qRCjEdXRgWzxZzrWYYgKx5b61LuQp+v6bQ3H
qbA9OrHiKzLg67sFeGjwXWs/bgjZ2ZJnPe8KGmy942oyjJxorA/zK2kQrrD2
8A/kAZXy3J8CNNjZlWvyEzn6dx7z7XoaNIpMKY5j+cWGTqRtpoHX3iDnGSzv
kKdKVxVpIKhlc2QWeafPgm3MFhq0BI5vnUPmOHpXcrfTYM+Goo55ZGUVagBN
gwYX47KU/yKfrTVetQtHA+ET6o58Klzgn+aVqXVC81FW0Ncjz95Lie0n0YC5
MV9CBHnETYNPkEoDIXVaHebWQfyYBZMGYil20mLIaV1VDZ/P0uBpYFiJBPKu
Z25es0E04Pt0LEIGWSGIb2hjKA0GVbfIySKLG1wn4MJpcGEFrQTzbOVzs4uX
aVCjp9OyEbnu1pbNEgk02G6fuCCPfDLh00uNPBpQ7r4WUUI2s/Qwsr1BAw97
/RjMB9YJVPnepAEknRDcgs13UTu3+jYNeN8kzWP+4R933rycBgIDD99sReaQ
D21lNtDQ/3kAThX5pmYpJ3MQ1ccUN9dAdpecmKsapkGQQ04OZu15TZ+3IzSQ
4TedwVzz7J4L3zgNthC7szSRO07es3eepYFJVcSAFrIg++5undV02Nny0Vwb
uYU8dsdyLR36I0euYr5qqqF6RogODf563ZgVRO5uThelw/6rCS57kXXzStat
kKUD0KhcHWTWizsDr3fQYQdud7gulm/JKHlQjQ4TPt/rME8nqHfzaNDhSfbk
MuYg/J13e/bQIY2seH4/cspYcU3qATqM8y+T9JCfSxan0Y/RYVeDupQ+sirl
lsWSGx3W3VmWxmH3M/TuTZ6lw1mLNcaYGZ+aRYc86XCg+I4z5nyrkfdtPnTg
3q17iFkBp+ZYyKbDuxPGJwFZSq6EaRtDh2icZ4ARcsUpwxdmcXRoF2NnYrZL
bNlhGE8Hh4eatZjj14yNqlyjw1aRxFXGyOvmNM79TafDUjQ+EvOKD6VBRcV0
mKmqCjuInCNq/C2zBNU3nJ+LGY63Hbx6jw4an0xrMLPrJ/m55XR4K1A8j3n2
/p4Yu8d0uBsu4mqC/CuuInX5JR1OdnYYHULuOvLf/RMjdJAZmaw2RTa2zLf3
GaWDfUJqO+ZbdnF/r47RobZx+SfmC0T60fdTdFCvFtp4GFnWR/SbzSIdSOsP
nsNsn31G1EqIASa2GRvNsP1yw67q7HoGHNwcpYFZ5TaOECfKAOcC44OYZysk
i1okGbCDKOqMOfllLRzfhMY36Vdg/vBHxuOoBgMiS8H4CLLhIp+UsxYDvpSs
tcVcwDv+6PIeBowtFFIx+65rFHixjwHfwvBhmCWVvLIOAwNWBZc9w2x3vLnF
xJoBVYxwvaPIbXkX1HHeDOhMq1prjizGU/mfng8DqjmdUpht8ROHdPwYMCvc
q4j5vQTLST2AAdkGafswfww/EbcxlAFlFvVkzJ+ZmhMzCQzw3bCnFLNcvQt7
6ioDWvPuPcRMULi5eiyJATdEpOoxf+mQVxpIY4ChR+oHzD1H1tq+z2VAYFLE
PObvOwfK791nwIU5PcNjyNsiFI2KyxmgGmVtipnRj399s5IBttG2FpiH0t99
z3zIgB+5sk6YfwjVSsXUMaD3ysNAzL/Grp8/04byG3WtxDxbZq2vNMkAXeNu
uePY/tPVaRGfZgChNUsJs8JjWdKqPyi/FXYqmM3q+0KH5hjwoj1+D+bU9z4v
S3iZYDbCOIJZ73fq6QOiTPDVuOqF2cKf81NNnAlGpUF+mClLFM4mSSZU/CIF
Yo5cpZbLK8OEPNGlcMxdkk+GmxSY0L71ZgrmQJ1v5+00mRA01/UI85WHjWtM
dzNBt1O0BnO+4e30fdpMaNhvUI/5lem5GlldJuxrOfcKs/wpfsFeHBMCBZ0/
Y37ityPZzZIJybkh85iXH3hVXHRnwiorMU0LrH/896NyPZjo3GXtwfzQboL8
xIsJhB8VOpjPjZ8V/uPLBPGmvQaYh7a7MelcJnCVXx/B3JbElDG5woT4Yncy
5rv9BWPEBCbQyDga5ujdAw0BV5lg5S/IxHy4heZVlsIEXoUwV8yPV1FeKuUw
IYu5xQ/zjXN4Nu99Jjz6IBaFOaTuuq18ORPuvPOKwUwS6VLdX8kEEearOMyy
xQ4fPB4y4VOU61XMsX0nNXrqmPDkKiUD83kb694n75hw6sueEszmmqaHAn8z
ISr9w0vMPO3tvOdmmPAy2Pk15kp/+hOXOSZ4uM23YFZ6FrbPcQnlEyLchnn+
xDNVvVUsMI8V7MB8KwCEZyVYIKJ0rO9ffQqtzWNSLEh6lN+PWaqBeGlQmgUH
fs19/7ceYS7PRzkWlBxMG8J8Oqd6skKZBQa3ykYxr27S++itzQIXO6sZzE9c
mhNddFjQ6uo7+68fIqetqLosSMtKncPc4+D/wkafBfreHxcwP/hZ9UjLhAWL
RVo8lth5IrY3e8yWBTJ+dEHMTQSNMy7eLLgVOyOFWYzKepThw4KECwMbMDux
coRa/Viwub1NGvMfL/H72oEsGKvPk8WsHDEzvxTGgtvHtm/CHHT/afSVJBYo
aVQrY35VNfulLoUFPvnhWzFvqNbS+p3GgjWix7ZhLmnKa3fIYsHu6LbtmLs/
X9q0pZAFZyrrd2DWE7C6V/EfCy5LHtHEfHHd5RVDj1iQlT3+z29F6+xkn7BA
50SS1r/1yWnPcepYkHj8827MyVrSxmYvWZC9ZLMX87Rjz7vOzyz4cHZsP2Yg
y2wT+soC55oAPcxRDJvzuF4WzDjzH8Cs5Fkvl/+dBTGfpPQxW18spLv9YkH0
X2VDzOlRvVVZ4ywIbM3/56ErsmvaJlmwWmcL7l8e16NLdGZQPz9vhH95ZDfw
nJljgaB60j9vKPhrc32BBeVa640wU27vu/F6iQW2kxf/ueSex8zyMgv++C79
8/8LfqZD
        "]]},
      Annotation[#, "Charting`Private`Tag$19912#1"]& ]}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1nc8V98fB3Bklr2zaZglpdLgvFOhjGQUWZ/9+SDZIRlRKbsSJasyItmj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        "]]},
      Annotation[#, "Charting`Private`Tag$21216#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwd1nc8Vl8cB3CkNEiSmaxKFJlJoudbMkIKDePh2cPeo/I8jxYqMyXKjGSV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        "]]},
      Annotation[#, "Charting`Private`Tag$21216#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"S and P\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"time\"", HoldForm], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200}, {0., 499.9797991481766}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8933402722781963`*^9, {3.8933403766525793`*^9, 3.893340402591868*^9}, 
   3.893343953105898*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"c2514655-fd58-4e30-9145-db86522fd16a"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwd13c81f8XB/BLUWRcIyQkSikSSb7SPYcGJSp7uxchIzIyIkLLTjJKRkXS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        "]]},
      Annotation[#, "Charting`Private`Tag$20074#1"]& ]}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVVnc0Fg4XRohsIiREZTQQqZT33hRJpaxs7x7Ze68fDSQkISObhkpCk6RE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        "]]},
      Annotation[#, "Charting`Private`Tag$21694#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"enzyme rate\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"time\"", HoldForm], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200}, {0., 6.206659730728467}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8933402722781963`*^9, {3.8933403766525793`*^9, 3.893340402591868*^9}, 
   3.8933439531153927`*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"a424fb26-64c9-4448-9426-4dce796b4a13"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The limit of ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SubscriptBox["k", "cat"], 
    SubscriptBox["K", 
     RowBox[{"M", ",", "S"}]]], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "59e0667e-dfa1-467a-bdfa-eec751eabe89"],
 "."
}], "Subsubsection",
 CellChangeTimes->{{3.893343964689883*^9, 
  3.8933439794543657`*^9}},ExpressionUUID->"f57c7455-144a-48ac-a4b1-\
8e6fb55de590"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"kcat", "=", 
   FractionBox[
    RowBox[{"k1f", " ", "k2f", " ", "k3f"}], 
    RowBox[{"k1f", " ", 
     RowBox[{"(", 
      RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}]}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Kms", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"k1f", " ", 
       RowBox[{"(", 
        RowBox[{"k2b", "+", "k2f", "+", "k3f"}], ")"}]}], 
      RowBox[{
       RowBox[{"k1b", " ", "k2b"}], "+", 
       RowBox[{"k1b", " ", "k3f"}], "+", 
       RowBox[{"k2f", " ", "k3f"}]}]], ")"}], 
    RowBox[{"-", "1"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    FractionBox["kcat", "Kms"], ")"}], 
   RowBox[{"-", "1"}]], "//", "Expand"}]}], "Input",
 CellChangeTimes->{{3.8933404342529*^9, 3.893340487909409*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"589d30b7-426e-4605-adda-f1689495d85e"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "k1f"], "+", 
  FractionBox["k1b", 
   RowBox[{"k1f", " ", "k2f"}]], "+", 
  FractionBox[
   RowBox[{"k1b", " ", "k2b"}], 
   RowBox[{"k1f", " ", "k2f", " ", "k3f"}]]}]], "Output",
 CellChangeTimes->{{3.893340463440032*^9, 3.893340488359297*^9}, 
   3.893343959053528*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"f7457358-e333-416e-8bcf-1c6118f563fd"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1244, 961},
WindowMargins->{{Automatic, -332}, {Automatic, 44}},
FrontEndVersion->"13.2 for Mac OS X ARM (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"c6de6f36-6a64-4681-9474-81c4dd71820f"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 198, 3, 45, "Subsubsection",ExpressionUUID->"1d84409a-499c-4071-96d0-1af53544db84"],
Cell[781, 27, 2359, 64, 220, "Input",ExpressionUUID->"92c82faf-5d0c-4ac9-b045-680cec652486"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3177, 96, 201, 3, 45, "Subsubsection",ExpressionUUID->"495549f3-2f79-4891-848b-9161b777db66"],
Cell[CellGroupData[{
Cell[3403, 103, 1204, 33, 52, "Input",ExpressionUUID->"ced208a1-1692-4787-b252-c7bae7d0a7c5"],
Cell[4610, 138, 1487, 40, 34, "Output",ExpressionUUID->"88c6c89c-772d-48c3-b9e6-7b2197e66583"],
Cell[6100, 180, 2219, 60, 96, "Output",ExpressionUUID->"b78a1b8f-8a8f-4414-9ad0-adbf97f3fd55"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8356, 245, 1743, 51, 120, "Input",ExpressionUUID->"bf0cdfbc-ad46-4618-8814-d858de992959"],
Cell[10102, 298, 1682, 50, 96, "Output",ExpressionUUID->"fbaa2cd1-7f62-4b3c-a3a0-0a84fa7bae8e"],
Cell[11787, 350, 807, 24, 53, "Output",ExpressionUUID->"4b682ae1-f2a5-4f2e-b98c-e11e04797c68"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12631, 379, 1588, 44, 159, "Input",ExpressionUUID->"fcb8f0d9-e7f3-4b92-81d1-e3795d208b42"],
Cell[14222, 425, 1425, 31, 37, "Output",ExpressionUUID->"fae67853-4f23-4e67-b700-eb26a0ed2412"],
Cell[15650, 458, 871, 15, 51, "Output",ExpressionUUID->"70f0a6bf-d3cf-4234-910d-04f6e3da170c"],
Cell[16524, 475, 896, 16, 51, "Output",ExpressionUUID->"4daca4cd-f4b3-475d-9bb8-56173629aff2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17457, 496, 2093, 66, 72, "Input",ExpressionUUID->"2f64e60e-9c24-4188-8de4-a4db79699725"],
Cell[19553, 564, 1396, 43, 75, "Output",ExpressionUUID->"0591f901-3891-4fcc-8f9f-a954642a7b1a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20998, 613, 1805, 53, 54, "Subsubsection",ExpressionUUID->"c0cf8336-51c5-44a4-991f-37632ea8d617"],
Cell[22806, 668, 652, 16, 30, "Input",ExpressionUUID->"bfc4b270-5d8d-4390-aba2-6b65911eb8b5"],
Cell[23461, 686, 656, 17, 30, "Input",ExpressionUUID->"6f555d4b-ab30-44be-9be7-7713be1c6a15"],
Cell[24120, 705, 1014, 24, 52, "Input",ExpressionUUID->"9d793ee5-fc6e-42e2-b5bc-15753579a922"],
Cell[CellGroupData[{
Cell[25159, 733, 2529, 68, 115, "Input",ExpressionUUID->"9e0c96e4-ab91-47a5-a940-936877bcaffb"],
Cell[27691, 803, 17689, 313, 250, "Output",ExpressionUUID->"4dbd8351-eb62-4397-9084-f3b6ce9859e0"],
Cell[45383, 1118, 28403, 491, 252, "Output",ExpressionUUID->"fe1c64e4-0aca-443b-a2d6-fe6cf7c77f84"],
Cell[73789, 1611, 10708, 196, 257, "Output",ExpressionUUID->"384bd6b0-1163-4722-86a4-609f00fe614d"]
}, Open  ]],
Cell[84512, 1810, 2221, 62, 115, "Input",ExpressionUUID->"887904a6-2f52-48cb-9df1-85bedc68e8fa"],
Cell[86736, 1874, 785, 19, 30, "Input",ExpressionUUID->"5ec075e7-8dda-42e4-b7ab-e08a0778c53e"],
Cell[CellGroupData[{
Cell[87546, 1897, 652, 17, 30, "Input",ExpressionUUID->"a66b275b-2a70-48a4-918a-677966c620c6"],
Cell[88201, 1916, 17135, 303, 237, "Output",ExpressionUUID->"fa8533b6-2e48-4eb3-b0e1-2663031dae3f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105373, 2224, 1724, 44, 94, "Input",ExpressionUUID->"13870b95-2898-4a30-b0bc-413bd171c809"],
Cell[107100, 2270, 10101, 185, 248, "Output",ExpressionUUID->"fd503c08-ebbc-475c-9802-a82c0c381581"]
}, Open  ]],
Cell[CellGroupData[{
Cell[117238, 2460, 367, 7, 52, "Input",ExpressionUUID->"870deb04-9b54-4619-b946-cec114ed4f0a"],
Cell[117608, 2469, 33076, 571, 250, "Output",ExpressionUUID->"c2514655-fd58-4e30-9145-db86522fd16a"],
Cell[150687, 3042, 19051, 336, 257, "Output",ExpressionUUID->"a424fb26-64c9-4448-9426-4dce796b4a13"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[169787, 3384, 424, 14, 56, "Subsubsection",ExpressionUUID->"f57c7455-144a-48ac-a4b1-8e6fb55de590"],
Cell[CellGroupData[{
Cell[170236, 3402, 927, 28, 140, "Input",ExpressionUUID->"589d30b7-426e-4605-adda-f1689495d85e"],
Cell[171166, 3432, 394, 10, 51, "Output",ExpressionUUID->"f7457358-e333-416e-8bcf-1c6118f563fd"]
}, Open  ]]
}, Open  ]]
}
]
*)

