(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    550745,      12145]
NotebookOptionsPosition[    539534,      11978]
NotebookOutlinePosition[    539935,      11994]
CellTagsIndexPosition[    539892,      11991]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Stellenbosch organism, note that the system with \
feedback (n=4) has a higher specific flux as function of S than without \
feedback (n=1)! ", "Subsubsection"]], "Text",
 CellChangeTimes->{{3.879226564246812*^9, 3.8792265717107363`*^9}, {
  3.879238180590241*^9, 
  3.879238215983329*^9}},ExpressionUUID->"385965a2-6a0f-419f-95aa-\
530122e38a7e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SetOptions", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Plot", ",", "LogPlot", ",", "LogLinearPlot", ",", "ParametricPlot", 
       ",", "ListLinePlot", ",", "ListLogPlot"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
        RowBox[{"FontColor", "\[Rule]", "Black"}]}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "18", ",", 
        RowBox[{"Thickness", "\[Rule]", "0.0025"}], ",", 
        RowBox[{"PlotTheme", "\[Rule]", "\"\<Marketing\>\""}]}], "]"}]}], 
     "\[IndentingNewLine]", ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"ColorData", "[", 
       RowBox[{"68", ",", "\"\<ColorList\>\""}], "]"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Prolog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        InterpretationBox[
         ButtonBox[
          TooltipBox[
           RowBox[{
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
                Rational[223, 255], 
                Rational[72, 85], 
                Rational[40, 51]], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5830065359477125, 0.5647058823529412, 0.5228758169934641],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None], "\[InvisibleSpace]"}],
           "RGBColor[{223/255, 72/85, 40/51}]"],
          Appearance->None,
          BaseStyle->{},
          BaselinePosition->Baseline,
          ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
            If[
             Not[
              AbsoluteCurrentValue["Deployed"]], 
             SelectionMove[Typeset`box$, All, Expression]; 
             FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
             FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                Rational[223, 255], 
                Rational[72, 85], 
                Rational[40, 51]]; 
             FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
             MathLink`CallFrontEnd[
               FrontEnd`AttachCell[Typeset`box$, 
                FrontEndResource["RGBColorValueSelector"], {
                0, {Left, Bottom}}, {Left, Top}, 
                "ClosingActions" -> {
                 "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
          DefaultBaseStyle->{},
          Evaluator->Automatic,
          Method->"Preemptive"],
         RGBColor[{
           Rational[223, 255], 
           Rational[72, 85], 
           Rational[40, 51]}],
         Editable->False,
         Selectable->False], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"Scaled", "[", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
          RowBox[{"Scaled", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "]"}]}], "}"}]}]}], 
    "]"}], ";"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.8957313438633137`*^9, 3.895731346199738*^9}, {
  3.8957314075250053`*^9, 3.895731407765477*^9}, {3.895732054755292*^9, 
  3.895732058844223*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"6a4daa6c-e4e4-4228-962e-6a0ba400b636"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ColorData", "[", 
  RowBox[{"68", ",", "\"\<ColorList\>\""}], "]"}]], "Input",
 CellLabel->"In[2]:=",ExpressionUUID->"4ce1c051-c1eb-447d-9b12-aab51492ab3c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[<|"color" -> Hue[0.55, 1, 0.7]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.06, 1, 0.9]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.25, 1, 0.55]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.11, 0.9, 0.85]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.5, 1, 0.5]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.2, 1, 0.7]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.08, 1, 0.7]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.5, 0.8, 0.75]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.45, 1, 0.5]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.6, 0.5, 0.9]|>,
    "HueColorSwatchTemplate"]}], "}"}]], "Output",
 CellChangeTimes->{3.8957312034165163`*^9, 3.895731416203018*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"48363e55-e17c-404a-8f25-401031fa0652"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"rateeqsNF", "[", "s_", "]"}], ":=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"v", "[", "1", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"k1", " ", 
        RowBox[{"e", "[", "1", "]"}], 
        FractionBox["s", "s05"], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], 
           RowBox[{"s", " ", "Keq1"}]]}], ")"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["s", "s05"], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "x1105"]}], ")"}], 
         RowBox[{"n", "-", "1"}]]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["s", "s05"], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "x1105"]}], ")"}],
          "n"], "+", 
        FractionBox[
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{
              RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], "x3105"], ")"}], 
           "n"]}], 
         RowBox[{"1", "+", 
          RowBox[{"\[Alpha]", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              RowBox[{
               RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], "x3105"], ")"}],
             "n"]}]}]]}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"v", "[", "2", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"k2", " ", 
        RowBox[{"e", "[", "2", "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "-", 
          FractionBox[
           RowBox[{
            RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}], "10"]}], ")"}]}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "+", 
        RowBox[{
         RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}]}]]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"v", "[", "3", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"k3", " ", 
        RowBox[{"e", "[", "3", "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}], "-", 
          FractionBox[
           RowBox[{
            RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], "10"]}], ")"}]}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "+", 
        RowBox[{
         RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}]}]]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"v", "[", "4", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"k4", " ", 
        RowBox[{"e", "[", "4", "]"}], " ", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}]}], 
       RowBox[{"0.01", "+", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}]}]]}]}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"parmNF", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Keq1", "\[Rule]", "400"}], ",", " ", 
     RowBox[{"x1105", "\[Rule]", 
      SuperscriptBox["10", "4"]}], ",", " ", 
     RowBox[{"n", "\[Rule]", "4"}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"vs", " ", "1"}], " ", "*)"}], ",", " ", 
     RowBox[{"x3105", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Alpha]", "\[Rule]", "0.001"}], ",", 
     RowBox[{"s05", "\[Rule]", "1"}], ",", 
     RowBox[{"k1", "->", "10"}], ",", 
     RowBox[{"k2", "->", "100"}], ",", 
     RowBox[{"k3", "->", "100"}], ",", 
     RowBox[{"k4", "->", "10"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{"odesNF", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "i", "]"}], "'"}], "[", "t", "]"}], "==", 
     RowBox[{
      RowBox[{"v", "[", "i", "]"}], "-", 
      RowBox[{"v", "[", 
       RowBox[{"i", "+", "1"}], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"initNF", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "i", "]"}], "[", "0", "]"}], "==", "1"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"varsNF", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"x", "[", "i", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.879226841658342*^9, 3.879226888954185*^9}, {
   3.879226937875989*^9, 3.879227033165056*^9}, {3.879227134655717*^9, 
   3.8792273656002703`*^9}, {3.879227722448216*^9, 3.879227727014666*^9}, {
   3.879227829949151*^9, 3.879227838131926*^9}, 3.8792279638941803`*^9, {
   3.879230894179899*^9, 3.879230894335688*^9}, {3.8792309794555063`*^9, 
   3.879230979701048*^9}, {3.8792311911938763`*^9, 3.879231212554378*^9}, {
   3.8792313020983*^9, 3.879231302487424*^9}, 3.879238033270762*^9, {
   3.8792381462133923`*^9, 3.8792381464136*^9}, {3.879238228002891*^9, 
   3.87923823021323*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"91eb1491-bcd0-43a4-83ca-d2dbdc7386d1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"x", "[", "1", "]"}], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
    RowBox[{
     RowBox[{"v", "[", "1", "]"}], "-", 
     RowBox[{"v", "[", "2", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"x", "[", "2", "]"}], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
    RowBox[{
     RowBox[{"v", "[", "2", "]"}], "-", 
     RowBox[{"v", "[", "3", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"x", "[", "3", "]"}], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
    RowBox[{
     RowBox[{"v", "[", "3", "]"}], "-", 
     RowBox[{"v", "[", "4", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.879227282683898*^9, 3.879227334677258*^9}, 
   3.87922736793754*^9, 3.879227747976284*^9, {3.879227831578679*^9, 
   3.879227838784717*^9}, 3.879227964443524*^9, 3.879229051068824*^9, 
   3.8792308947333*^9, 3.8792309801436167`*^9, {3.8792311918295383`*^9, 
   3.8792312201644363`*^9}, 3.879231305740424*^9, 3.8792374631544847`*^9, 
   3.879238034091954*^9, 3.879238146770803*^9, {3.87923821905427*^9, 
   3.879238245896144*^9}, 3.895724744614245*^9, 3.895724782393289*^9, 
   3.895730251455361*^9, 3.895730610822873*^9, 3.8957314165022717`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"91d214a6-5595-44ac-8a7d-410420820050"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], "[", "0", "]"}], "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "2", "]"}], "[", "0", "]"}], "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], "[", "0", "]"}], "\[Equal]", "1"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.879227282683898*^9, 3.879227334677258*^9}, 
   3.87922736793754*^9, 3.879227747976284*^9, {3.879227831578679*^9, 
   3.879227838784717*^9}, 3.879227964443524*^9, 3.879229051068824*^9, 
   3.8792308947333*^9, 3.8792309801436167`*^9, {3.8792311918295383`*^9, 
   3.8792312201644363`*^9}, 3.879231305740424*^9, 3.8792374631544847`*^9, 
   3.879238034091954*^9, 3.879238146770803*^9, {3.87923821905427*^9, 
   3.879238245896144*^9}, 3.895724744614245*^9, 3.895724782393289*^9, 
   3.895730251455361*^9, 3.895730610822873*^9, 3.8957314165044622`*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"13632d09-354c-4465-a091-7aed4b2fc3ed"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}], ",", 
   RowBox[{"x", "[", "3", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.879227282683898*^9, 3.879227334677258*^9}, 
   3.87922736793754*^9, 3.879227747976284*^9, {3.879227831578679*^9, 
   3.879227838784717*^9}, 3.879227964443524*^9, 3.879229051068824*^9, 
   3.8792308947333*^9, 3.8792309801436167`*^9, {3.8792311918295383`*^9, 
   3.8792312201644363`*^9}, 3.879231305740424*^9, 3.8792374631544847`*^9, 
   3.879238034091954*^9, 3.879238146770803*^9, {3.87923821905427*^9, 
   3.879238245896144*^9}, 3.895724744614245*^9, 3.895724782393289*^9, 
   3.895730251455361*^9, 3.895730610822873*^9, 3.895731416506291*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"1898ae25-1db1-4f57-9ef6-7544c8bbc45d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsolNF", "[", "s_", "]"}], ":=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"odesNF", "/.", 
         RowBox[{"rateeqsNF", "[", "s", "]"}]}], "/.", "parmNF"}], ",", 
       "initNF"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"e", "[", "1", "]"}], "->", "1"}], ",", 
       RowBox[{
        RowBox[{"e", "[", "2", "]"}], "->", "1"}], ",", 
       RowBox[{
        RowBox[{"e", "[", "3", "]"}], "->", "1"}], ",", 
       RowBox[{
        RowBox[{"e", "[", "4", "]"}], "->", "1"}]}], "}"}]}], ",", "varsNF", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.879226890723072*^9, 3.879226943890732*^9}, {
  3.879227043253235*^9, 3.879227066475953*^9}, {3.879227345719556*^9, 
  3.8792273541985273`*^9}, {3.879227807055496*^9, 3.8792278162825527`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"a1677eed-13ea-4187-bf42-5a4e6b0ca645"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tsolNF", "[", "1", "]"}]], "Input",
 CellChangeTimes->{{3.8792278411555443`*^9, 3.879227843794096*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"e402dedd-4043-42c8-a736-ddf35888d330"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], "\[Rule]", 
     InterpretationBox[
      RowBox[{
       TagBox["InterpolatingFunction",
        "SummaryHead"], "[", 
       DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
        "Ready"}, 
        TemplateBox[{
          PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SummaryBoxOpener"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                  "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ3X7UR3/9Jl2H0OO+yqHd6+0FVnb6MqTrOSRB+REH
Ck12fDNwyIDyQx8t//pltpFDOpT/sScu4IWFCVyeJ7VF4NsPU4T6YuMWjtnm
DplQvtz6wFjTBEs4v7X4w3kJWWs4XzJP4hvDHhs4X3fa+kbmOjuHLCjf4ld6
AqugA5wveWC90bQvCL7nqe2BTFcc4fz+/JZTBUuc4PypqznKctqc4fxNTYHV
WZEucL7cvKizzhqucL5XgHTQKg43OL937gID4VsIfn/jXUfOve5w/sOVt+bf
mu2BcE/unPB12Z5wfuFxUSd+Xy84f8Oe4LYieW843+5boPjGtwh+zzH22zVn
feD8D4ZNP7zm+cL5IiZbPJY1+MHDy//iqk/MIf5wfu7NDSXzBAPg/EmiGZ2M
TQi+03zG009fIfhBX74tnRATCOd3Zfuoa55B8H0NWq46mQTB+QUHxGWVlyL4
8vN6J7bwBcP5X+cmr7lciuBrZ05NePkUwX/TuNKxwS8EzudNk9xzdz+CH5bz
8o6Gfiicr3VgttbXaQh+3P2Vgh3sYXC+rM8s1TkFCL5Ny7NLZY8Q/OZ7k9Ts
g8Lh/NA2xeUduxD89p/cB2doR8D5rrtusGtNRfDtJJ/8+P8fwQcAXOhm1Q==

                    "]], 
                    
                    LineBox[{{1.6301769472372045`, 0.061609898147152876`}, {
                    1.630176947237205, 0.0616098981471526}}]}, 
                    Annotation[#, "Charting`Private`Tag$5172#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0.0616098981471526}, 
                  BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
                  DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 100.}, {0.06160989814715271, 
                   0.061609898147152765`}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Prolog -> {
                    RGBColor[
                    NCache[{
                    Rational[223, 255], 
                    Rational[72, 85], 
                    Rational[40, 51]}, {0.8745098039215686, 
                    0.8470588235294118, 0.7843137254901961}]], 
                    RectangleBox[
                    Scaled[{0, 0}], 
                    Scaled[{1, 1}]]}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SummaryBoxCloser"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                  "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ3X7UR3/9Jl2H0OO+yqHd6+0FVnb6MqTrOSRB+REH
Ck12fDNwyIDyQx8t//pltpFDOpT/sScu4IWFCVyeJ7VF4NsPU4T6YuMWjtnm
DplQvtz6wFjTBEs4v7X4w3kJWWs4XzJP4hvDHhs4X3fa+kbmOjuHLCjf4ld6
AqugA5wveWC90bQvCL7nqe2BTFcc4fz+/JZTBUuc4PypqznKctqc4fxNTYHV
WZEucL7cvKizzhqucL5XgHTQKg43OL937gID4VsIfn/jXUfOve5w/sOVt+bf
mu2BcE/unPB12Z5wfuFxUSd+Xy84f8Oe4LYieW843+5boPjGtwh+zzH22zVn
feD8D4ZNP7zm+cL5IiZbPJY1+MHDy//iqk/MIf5wfu7NDSXzBAPg/EmiGZ2M
TQi+03zG009fIfhBX74tnRATCOd3Zfuoa55B8H0NWq46mQTB+QUHxGWVlyL4
8vN6J7bwBcP5X+cmr7lciuBrZ05NePkUwX/TuNKxwS8EzudNk9xzdz+CH5bz
8o6Gfiicr3VgttbXaQh+3P2Vgh3sYXC+rM8s1TkFCL5Ny7NLZY8Q/OZ7k9Ts
g8Lh/NA2xeUduxD89p/cB2doR8D5rrtusGtNRfDtJJ/8+P8fwQcAXOhm1Q==

                    "]], 
                    
                    LineBox[{{1.6301769472372045`, 0.061609898147152876`}, {
                    1.630176947237205, 0.0616098981471526}}]}, 
                    Annotation[#, "Charting`Private`Tag$5172#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0.0616098981471526}, 
                  BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
                  DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 100.}, {0.06160989814715271, 
                   0.061609898147152765`}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Prolog -> {
                    RGBColor[
                    NCache[{
                    Rational[223, 255], 
                    Rational[72, 85], 
                    Rational[40, 51]}, {0.8745098039215686, 
                    0.8470588235294118, 0.7843137254901961}]], 
                    RectangleBox[
                    Scaled[{0, 0}], 
                    Scaled[{1, 1}]]}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic]},
         "SummaryPanel"],
        DynamicModuleValues:>{}], "]"}],
      InterpolatingFunction[{{0., 100.}}, {
       5, 7, 1, {247}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
        False}, CompressedData["
1:eJxF1Xk0FYgXB3AhIiSZ8X5ZnySjRSVrxvcVw0MNRSlbkixpE1p+TbL0lJYn
y6jUjEgzJcYT2V62R2QLz/72Z69o4emJwc85dc7vnnPP53zvuX/c/y7R79Te
o5ISEhJLFlss8f/KJWQ7lPK51t8c/+6cdUwSxI2BMviWFXGnK1yHscYQ3+am
MC+z5RWWA+JPWX6t8bYQ5p6y6G3xBUXbNM3qwnGkkCMvuaiEIyBamCs5euH7
/mVwA/ZLbaqNRfrp63ein16F738r1ndRb4B4ZaLSIDwBn+1WGVbkJILptFEU
mJ4M36yS50nqqRj/1ya0/M5dXNzXajS66j7k/vH4oHL7DzhJhXVryTxEUl6J
yTbbDPR5zqc4xGSiqoJPbtPOwt/E6n/3lz8G9UomjevxN86OxPr7Tz+Bt+NR
wvvfs2Gba9ccapyDDcoGUdNtuVgVJrft8sk8zB2bmpSMoyFUY3h3nVs+xm5k
/KUmykfArNdCUPJzCI8RDpRtLYAXq4O2nFmAHocEOe/QQuwtdfT7R/kFWgxk
6At5L2A9ydOVty8Crbz4uiqvCMRrtye0IoqRvDfY4yeFEizV3MkwflSyeNdq
Q2vLUozmTyaS20sRm3Cr5efzZdA+sU7OWJsOumO1rUEdHfsNPKM0T7zExNIp
uopqOagDVLEsvRwhac/TZ4Mr4LCn2/4joRLrls187K+vRAxfaVfI9ip8LtPR
GUqqgm/qVpHPuyogJfTd7cPV0E6iCRi91VhI+NgtcmaAd2tTi349AxU3TtQc
sK7Bn/E5pddf1CBeTGiSJtUi/CiFE9lYi0Mdn8en3V7BaYfPwhn+K5jmNSqP
B9eBqGmmGyiqg8KNR8bCyHqoRj/vPav4Gurnqi8pPHiNNSfadDMNG2B4hF9v
VtqArQc/HG+xb4SF89zKI92NOJC/2801sAlnV/2ZajPdhJSID73G8c143mOt
rre6BW0WCd6qz1rw8T4/XdrqDRTnjfpFzW+w3jdKb8i7FRSlq395Sbdhaqyl
rO5gG/ybVFs357Wh86nnQJp0O2yvZYqlPdpREPB2+am8drSEXMwrkGVi+LSi
6/QhJhYi0r9YlTBBuLglLVq5A1uian6uC+qAE2WfUL66A32I05+W7ETgTFHI
kG0nvhSO0JhxnbhyivCl8nUnVAwdtufKd4ExGSjtYdeFM+VxLTIxXSBefZxa
UN6FdpfaQ75fuxC1esBA0aQbTWrWDzOTu/HjD/fUzCe6cVhFRG1x6UHOCmeZ
I3k9ECtkX5pW7IWK1EqS/YFebPx6TjI1sxdJQ/n2MYJeTLe/v3lSqw/eFWuZ
Hl59kNvCCyAk9OHFo9TZruo++P3ofDtZ1AeleNm1e9axUDZbWarkwULAyfO/
Nt9kQUW4eSC+koX5324dT1v0HeHdVPai3YV2l+mLVrs8Wta8aO7YQiJnUYpe
adbcot5eZ4q1qlgwSVnfiEUzGYGU69UsrPj8iNTFYOE3bcGsdi0Lb3drFB97
xcImrbOy+5ksnPnQ6r6Dz0JRxU9PNoyxMEONnVb7ygIOcclSMmzYduZRZrXY
cHJ1JIdsZMOVOSjP3s6GKtnfyM6eja7yAdf8vWykGh85r+HDhvvT/gdXg9lw
yW+djjvHhkPpS7c4Chs21U9plGQ2rBpSFSgZbJi2xwZdyVvca1iWkclg48vM
K31vJhv3N8TmqPWzscOHtJX5mY3hhLnim0s4uFld9rP9Sg4WllrO3FvDQahj
adGYCQeDVPMwkDlw7yg2SvLgoEHNbGzwOAdWXkVPzC5zELTH2i8glYMUuzr1
33M5qNr+a1dNLQdjm7upE2wOCPo+ZOIkBzbqw0tc5Lmgv/w6G6DDhbGP4pdL
plw8W9D5lLKLC92Mbe+e+XGRtpM8yDjPhcqgJ6+PyoViSrgbMYcLOdtbjUEN
XEiLHpNow1xIZFUUiaV4mHXt2QAiD2KpT5lx1jxMFCz7zxtPHsaPEBN+uMCD
QmKh870/eFhfYa+syeDB8T2r7eEwD8GEk4l6y/mwSPw0uMmSD3n5MHOLYD5Y
MVM3bO7ykT17jr+7ng9JJ968UFoAo7sSSpr6AngN6WoesBcgfusvG5KDBCi6
HLj9TbwAsxqbiHdpApDKRDJ+PQJQ3Olj6+cFaBBFM6f0hFBKIpdUOglRR99/
29pbiMgh/6Dyk0KYrAgjWUUJMW4eTaAnCuGVNxgqzhSiaS25ybhQCMsHz/RO
vxJCZ3OkZMi8EDK1LoKjZv0Yc19T4Xu6H8z3U/c9n/bDu8klcs1oP95mP/N9
rz+AiOsyNgVHB7Dk2OG1F7MGsDyBdW3j1wGoFrqO8XcPQquv2TkpcxDr5n8p
sBUPImInLULv1BBq4labS48MQbnpysyAzzAm7+5alx49gu4AVTePrFHwBLJR
/uKPCM+d22f2eBJtV/kEE10FUpiGr82IuRrJUomWEfbAiKQp29tm8caCRJU6
PqoxsuO7dt91ItUvMQ2nhrl8c3Lv97yPNCihbllv4U769q0Pkv4HHQ3cRg==

       "], {Developer`PackedArrayForm, CompressedData["
1:eJwl0oFGHgAAhdF/SZIkSZKkJUmSJEmSJEmSJEmSJEnSkmSSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSzMzMzOxMl/ME9/vc9KWq41MgEPgV+FgQwYQQShjhRBBJ
FNHEEEsc8SSQSBLJpJBKGulkkEkW2eSQSx75FFBIEcWUUEoZ5VRQSRXV1FBL
HfU00EgTzbTQShvtdNBJF9308JVe+uhngEGGGGaEUcYYZ4JJpphmhlnmmGeB
RZZYZoVV1lhng0222GaHXfbY54BDjjjmhFPOOOeCS6645oZb7rjngUeeeOaF
V9545xvf+cHPwMfnv/nDXwJCCCKYEEIJI5wIIokimhhiiSOeBBJJIpkUUkkj
nQwyySKbHHLJI58CCimimBJKKaOcCiqpopoaaqmjngYaaaKZFlppo53/kXfS
RTc9fKWXPvoZYJAhhhlhlDHGmWCSKaaZYZY55llgkSWWWWGVNdbZYJMtttlh
lz32OeCQI4454ZQzzrngkiuuueGWO+554JEnnnnhlTfe+QfPCnps
        "], CompressedData["
1:eJxF1Xk8lGsbB/AZIQp5vTq2shSyZAmRrdtSioMkOy20WSI0LZTsWxiyJUv2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        "]}, {Automatic}],
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}], ",", 
    RowBox[{
     RowBox[{"x", "[", "2", "]"}], "\[Rule]", 
     InterpretationBox[
      RowBox[{
       TagBox["InterpolatingFunction",
        "SummaryHead"], "[", 
       DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
        "Ready"}, 
        TemplateBox[{
          PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SummaryBoxOpener"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                  "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQbcPCHs3spOfwYWahUqjKWnuBlZ2+DOl6Dt+g/IgD
hSY7vhk4MM2C8EMfLf/6ZbYRnP+xJy7ghYUJnM+T2iLw7YcpQn2xcQvHbHMH
Zihfbn1grGmCJZzfWvzhvISsNZwvmSfxjWGPDZyvO219I3OdHZxv8Ss9gVXQ
AW6+5IH1RtO+IPiep7YHMl1xhPP781tOFSxxgvOnruYoy2lzhvM3NQVWZ0W6
wPly86LOOmu4wu3zCpAOWsXhBuf3zl1gIHwLwe9vvOvIudcdzn+48tb8W7M9
4HzP3Dnh67I94fzC46JO/L5ecPs27AluK5L3hvPtvgWKb3yL4PccY79dc9YH
zv9g2PTDa54vnC9issVjWYMfnO9/cdUn5hB/OD/35oaSeYIBcP4k0YxOxiYE
32k+4+mnrxD8oC/flk6ICYTzu7J91DXPIPi+Bi1XnUyC4PyCA+KyyksRfPl5
vRNb+ILh/K9zk9dcLkXwtTOnJrx8iuC/aVzp2OAXAufzpknuubsfwQ/LeXlH
Qz8Uztc6MFvr6zQEP+7+SsEO9jA4X9ZnluqcAgTfpuXZpbJHCH7zvUlq9kHh
iPTZpri8YxeC3/6T++AM7Qg433XXDXatqQi+neSTH///I/gA0zg6Rg==
                    "]], 
                    
                    LineBox[{{1.630176947226682, 0.056917820410309045`}, {
                    1.6301769472266825`, 0.056917820410308795`}}]}, 
                    Annotation[#, "Charting`Private`Tag$5401#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0.056917820410308795`}, 
                  BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
                  DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 100.}, {0.056917820410308906`, 
                   0.056917820410308934`}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Prolog -> {
                    RGBColor[
                    NCache[{
                    Rational[223, 255], 
                    Rational[72, 85], 
                    Rational[40, 51]}, {0.8745098039215686, 
                    0.8470588235294118, 0.7843137254901961}]], 
                    RectangleBox[
                    Scaled[{0, 0}], 
                    Scaled[{1, 1}]]}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SummaryBoxCloser"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                  "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQbcPCHs3spOfwYWahUqjKWnuBlZ2+DOl6Dt+g/IgD
hSY7vhk4MM2C8EMfLf/6ZbYRnP+xJy7ghYUJnM+T2iLw7YcpQn2xcQvHbHMH
Zihfbn1grGmCJZzfWvzhvISsNZwvmSfxjWGPDZyvO219I3OdHZxv8Ss9gVXQ
AW6+5IH1RtO+IPiep7YHMl1xhPP781tOFSxxgvOnruYoy2lzhvM3NQVWZ0W6
wPly86LOOmu4wu3zCpAOWsXhBuf3zl1gIHwLwe9vvOvIudcdzn+48tb8W7M9
4HzP3Dnh67I94fzC46JO/L5ecPs27AluK5L3hvPtvgWKb3yL4PccY79dc9YH
zv9g2PTDa54vnC9issVjWYMfnO9/cdUn5hB/OD/35oaSeYIBcP4k0YxOxiYE
32k+4+mnrxD8oC/flk6ICYTzu7J91DXPIPi+Bi1XnUyC4PyCA+KyyksRfPl5
vRNb+ILh/K9zk9dcLkXwtTOnJrx8iuC/aVzp2OAXAufzpknuubsfwQ/LeXlH
Qz8Uztc6MFvr6zQEP+7+SsEO9jA4X9ZnluqcAgTfpuXZpbJHCH7zvUlq9kHh
iPTZpri8YxeC3/6T++AM7Qg433XXDXatqQi+neSTH///I/gA0zg6Rg==
                    "]], 
                    
                    LineBox[{{1.630176947226682, 0.056917820410309045`}, {
                    1.6301769472266825`, 0.056917820410308795`}}]}, 
                    Annotation[#, "Charting`Private`Tag$5401#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0.056917820410308795`}, 
                  BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
                  DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 100.}, {0.056917820410308906`, 
                   0.056917820410308934`}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Prolog -> {
                    RGBColor[
                    NCache[{
                    Rational[223, 255], 
                    Rational[72, 85], 
                    Rational[40, 51]}, {0.8745098039215686, 
                    0.8470588235294118, 0.7843137254901961}]], 
                    RectangleBox[
                    Scaled[{0, 0}], 
                    Scaled[{1, 1}]]}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic]},
         "SummaryPanel"],
        DynamicModuleValues:>{}], "]"}],
      InterpolatingFunction[{{0., 100.}}, {
       5, 7, 1, {247}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
        False}, CompressedData["
1:eJxF1Xk0FYgXB3AhIiSZ8X5ZnySjRSVrxvcVw0MNRSlbkixpE1p+TbL0lJYn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       "], {Developer`PackedArrayForm, CompressedData["
1:eJwl0oFGHgAAhdF/SZIkSZKkJUmSJEmSJEmSJEmSJEnSkmSSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSzMzMzOxMl/ME9/vc9KWq41MgEPgV+FgQwYQQShjhRBBJ
FNHEEEsc8SSQSBLJpJBKGulkkEkW2eSQSx75FFBIEcWUUEoZ5VRQSRXV1FBL
HfU00EgTzbTQShvtdNBJF9308JVe+uhngEGGGGaEUcYYZ4JJpphmhlnmmGeB
RZZYZoVV1lhng0222GaHXfbY54BDjjjmhFPOOOeCS6645oZb7rjngUeeeOaF
V9545xvf+cHPwMfnv/nDXwJCCCKYEEIJI5wIIokimhhiiSOeBBJJIpkUUkkj
nQwyySKbHHLJI58CCimimBJKKaOcCiqpopoaaqmjngYaaaKZFlppo53/kXfS
RTc9fKWXPvoZYJAhhhlhlDHGmWCSKaaZYZY55llgkSWWWWGVNdbZYJMtttlh
lz32OeCQI4454ZQzzrngkiuuueGWO+554JEnnnnhlTfe+QfPCnps
        "], CompressedData["
1:eJxF0Hk81Nv/wHE7aUgiJHt2rriJqM5QaFG2bIWokNwsKRTZKuQK2aqLoqzZ
xpos8/5Ys2Yf+y7hxkSylPh++N3fvfPHzOP5eJ3zPueMyBVnQ1taGhqa+a2v
7c9X9M/v0ee6L2c2N6mIxs/E7e6aB4jFDJZvmzTvGLkaBCrVcYe3LXw11mHl
GdjPTJlsbNnHa9ByNQmmApoEfm35edKi0FIamFn8KhnC7d9gPMY6VQMXdPa+
jsNdefPM5fOD7bCsLcymghuTejTjqNYHEjNCv5E2qMi6WSyiSHsUXvoMxR1Z
pCKSqv7T3ME1cGPc4FTpo6LgKhmlF9qMWGpRb4ptIRUx69ZSeoTYMKthBVqv
h/j5ak9o7iJOTK9Ck0PiDBU921cxJVbIjQXOjJ+QnJtHLCJzM7vW+LAw89ZY
Lb95tOuHwNjTQQFMRyI88DvDPJobWqgVyBPGSDz8d156zyElU7bUKG1RjOGY
wt346S8ojXrlEzNJDCvZ1xSnceYLauyZmCuYP4B94K+JQG5/o5zq9ZTZUxKY
/rLFrz0Rs0img1EqyEYSYxn2UiS+mUG9yzM+BWpSmILRGbJC7jRq5TAdyKJI
YedSg8VVij8jA6eXo0Mq0thyoEPq09IptLHDKPmbtTQWWriqb0X+hAaDm6eo
F6QxiUy5uXnPSaR+yS3kyU8pTPKVm8zSkQnUAibUbBMp7PBefmsaxnGUdtE4
Zc1ZEss/NC8kOjSKhBbtdQ8YSmA0p9ziSI9HEF+XWUo6izgWt9Lex+U9hKa/
tITYvxLDdFQZ6gnRA2hpoIJfUVQU21SJ493R2YcI7BMhWvHC2AtFJZ5rR3rR
W2aRgVIFQWwudtrdv46CTEo4Q8PU+bG3erf4dKu6Eb2qpzofgQ+LYSk8YdHZ
hbS+JCc+Wt6LXaTjUYlf7US0J3wj0za4sJHn+3dQDnaiJxNBNSKSezAbOnlB
uNeBDJd6fXxdd2N187ct6Lrb0USIR1NO+S7s/cbawqnj7WiPBiluvJ+AzZ4H
1l3lbcjnCvtdAUtWjF3AT51dqw0NH8vyZ+FjwZYyBz/fJbWioeqzCYU7mbDH
F/J3a8x8RA3ufRX1igzYxNeswASljygfWC0zg+iw1zvY7w2FtKCnBBHWlB20
WIEZk+Gtr82IUZbHcdV+E9gmhwPCjZpRdwybdXPDOgjf3z/gW92EElhfikx5
/YBM/wnWkuNNSDbpHbvVnVUoMfJ42lfdiJTaFXctZC9DzvFMjVyDRuSYGvKI
VfA7PJq4lyn9uQE90O/ZVU/+Bqo/7yeX+TQg6izX6gHvRYhKYmrF9jegrMby
CcxmAWLbofMPrB5F6DDZrjt8BXuzgUMcDvWo2z7gYIsQFZj1nMhce+vRvKwV
96WXczByJUX3R90HZHNbr3H/qS/Q2sARlG39AUVlRAyTcmdhxdmDfmazDhmy
PmyMPjcDm3wnT6++qUO7abxF7+ydhr7BL590devQw44DTtK0n+GUtSXBY7UW
iez8y8+UaQoWrdedhdJrka10CqOE8CdQHBeJ6ThfizaUxYpipSZh8FXHiYi1
GrT4t76disYEjBqNB/Gn16B8o2lRXrtxkDayi9W6WIMcufr7H0WPAexkE57Z
VYOuMI65NDSOQkmMyK2p+mrEcTV0eoN5FHZcPaoi/Kgazf+t+eXjs2HwL1X7
8UKzGp0ezeGgFRsCbp3gVCJ9NQqmVZ01Jw/ANY6sffN1VUhqJkO417EfLP80
Mvd4UoU8z5071i7fByEkKm2WSRUiqT9ZBKZeOBnVrWwiWoWkpZMt2NYoUNaZ
mOJIrURfS20vidBTwHhKgy6UXIn49CpJD2W7IbMW0bmGV6JTcFEvyq0LcoLq
vrfbVKKSA6qLrIOd8N05UNNWuRKtGp+O+XmtEwLv754Y21GJaJgcZihsnfBU
yLOSZgRDSURi8Z3uDlgra2X2KcQQb6RrtmhpB9whjwYFBmAoWJLmxKnyDtiv
Gr5wSR9DHG0ZHKkjHWDJv1CQKYAhojpRPFOoE9aUnmpf7gJEdZuWifLohPjg
tBILR0B+x5xs48c7QV70Fd3yJhn5/eKrlbHogogG/gKFMDLSr3LQ8ZnsAm/3
4ztt+ciIpkgm2t+tG2YnuD54JVUgl9ZDC46MFGjvSdx7U6IC0YQXZtM9o4DX
iKaVZno5gpMuP+PFe+BRh+FlTslyNDpV+Sdtbg+4cd8OIdWUIVe1SXfJ3b2w
2bZkUG1dhmgzTpd0O/XCXLGjpNXPUkRMzksO+9ALU26aBrHRpUik+pj4/L4+
oJxc8Q+QK0V+PVI8qdf7YKMkf12z5T0Kf61MnMnog2kGX0O+m++RUOOjqd+m
+qBs12FLXsJ7pKCfam8q0A9s5QrXjN6WIP03EcPaev3wIDKZc1inBCW6fQyY
8OoHQaXU9Wdv3yHikBez67t+yBZYOcZPeIffV091ZrIfmCWet5T/UYzaGdLt
sugHwLVRTJLSXIQO+hOdWzkHoOCZp8MHuSKkH0aAFY4BKC4N2TyYW4j0Xwe+
OU03AE1NMT3rioXIT9aA23KqH0YSXkiLNBYgYfE3t3yr+4EYXfx84koBilAU
IRlH90P3UvaMx3o+coHJ9ucm/XBp1jbVMAN3dM4AHU8/3MliriaY5iORqn0f
Tjfg/0f8g+Qexny0sHnx4Y0bfeB2NzGbWpSH9DWavW8u94LXMeEPr+zzEMmS
LZvjei+kup1l1ubPQ22L4fdcSnqAranWxLydhDisL/wgD1Og4h59oQbuiNVU
h5u4R+ojd8vgbiPIuwriVi9zc+bcWp/H79Y6RIEXpqktP9pI6KvvLWc/3JVv
ZOQmcNtwKdop4tZOo8wU4MY8b56KGqTA5ecN6Q+3uybX9wEKWKXQOxjjJhZn
NZjgHhMvVrz/kYRyVR0IYt0U6OZcvZfSTEI0ynx+Ux8pMHfMV+tjIwmh3Ku8
SfUU+KFOH7lST0J+TaP1hlUUqI4VFsgrxvffsZTV86eAENOnxMRk3CU1JnFH
KXCtJVG2IZKEEr9iT5iWukH9hs2ivD9+/89kHpu0bqAy0+t3OJOQhmWg032T
bsgtvqrArIe/l7rPODS7C5bPe3CFHcXPk7mg9vNEFxxmNZ90lyGhEZs/F3y6
OkGP4FXlsp+E2qV13/F6dsIX06uT2ez4+5RyDDd4OmHucdTMQVoSEh5ge4cK
O+CBq3fN6udcFB7GrrGq2wF7u1ee29bnIl89Ge/ahnZwXzgjUZ6BO8I3ZFyj
Hbjd3ysyhOYi/d79FR1FbSDL8O3hSedc5EJ1q1aUaINZucSqAKNcRMxV6Lgh
2QpDxC5bdYVcNBbSFTYT0QKth50C2jjxrsu4TkbN8IT3gULeSg4avd13HeYb
gaj0g3NwKAdZX5LKMExsAH1Lg4fnavFu8F6z3KQeeE7El29m5yCbiaxUBq4P
kJZZwnstOgfR/OnkQUirhYdZ6vFXvHMQZvP4JfOpGhAUvqQ3a5uD/LtyV+JX
q0DJqv31tD4+zznpty/vK8HT1ZDxzLEclMhHgBehGNg5J9/4IZOD6M7wehWO
kSFV76pjBDc+jzDS/kqrHEYdzbOWaXMQ0dK6LXfkPRyW2NnH9DUb0fDq5Z7N
fgeSx9PfxY9kI1ptJrnzmUXQcsPcLbYN72MUHx1KASy7j0BXVTbyp2KKeTL5
4HJk+W1zcTYiHuoxfVNMAqtI3oulmfj64ZVMs5oc0EpXWwxO2ppvaythnAWi
St+uiz/PRn716yEJ+96CNi3jVZ9w/LyBiC42jnSQNrPkfBiEzx8X+iyjmAoK
3D5d4/fx/cSTIlzf3sCYLEvbkTv4/kNlYaTFJIjNHLzndBN3eVdgu1QiDAvr
WDrY4es9jVwuCCbAsNxfedzW+HwWjOBO/AtsP64RbC7i3f37/ms5z4CrupBb
3Rj3OnNjxuUYEF/9pRGjn402m+gERnSjYGd57yOHs3jflcMqTvsU0gfCFvq1
cdddfnf65xNg3PHjOEUTt2aCaoNrCERf2yw8g3AzlXlWGQfB256zIxfUcV9f
dSodeQCvC8gy31W27IFdpPrBol8kE7cyfl5cwq+kEW/In9hpkaSE9+ia0NhX
nmAn9dK4RgH3wd2F85luoOa8Hn9PHn8Pkef2L2dnUG4weJIqi3eWRFEvMQco
6d+UPyiDu+0IMYX/GiSn7C1hkMbdS+cUw20N5CE71kVJ3BxaplebzODnxonz
gltuu6rqI2AEyeu2u70k8PsIqQkneJ6DSBZjtV/iePeLkuR9rw1Cr+R+i9+y
8J1G7yAN+Ls4hc5zy8RbpvVyCFZfLvaabhk70+/zXh0EmaaPqW+ZxoVRKkMV
zPKPNotsW/T8r3llaPIdvbNz24+eVT3+HdpuUsNXDmztlw8k2SvCpQpWyifc
m74Ve5roFMBAylmkZKvT7J1bVxYHJcIz7PlW3xSVihIQAOphe80H213K3oWy
B+R+L0m8ve3ypUbCTvhNpLfLYduhr+o/0kKXZkzJlW1/oWY6rpCvW3TutMJN
S5PO0Nc8Tx4s1Fq9uN3NKhTOTZKlPjoGmOHe+KO8zGCcQpa/GXjAFLf16ZEB
e9cm8gPnw2YmuK/kkb+dTMPIn4NlBo1xn/8U4cq2UkCm35PqseWneZ8LpE+/
Ju97J3RyyweFmLzNB0PJjBa/y2/5GYuK8qrDLXL9eV6JLatTV0R+MpmT37Tk
iG05bRGsJ38RySw0j0W3XMqP5O+yM5AHjdy2nVp4e34p80NFQILrtovrfLNv
fTWtYP3r/+x/MHyu5ch0Of0/blk/WzSsZ/avC9k1tO0G9h+l+8cegUP+h+9J
/dsP1LLGndUT/LeHfDpEvMcjXf7/1jFSSJPq4v23v5B7/Ja9/T9ff0twXWr5
z+PB8j/7Gv+zc7R5sJGx4NH/AWruxvo=
        "]}, {Automatic}],
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}], ",", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], "\[Rule]", 
     InterpretationBox[
      RowBox[{
       TagBox["InterpolatingFunction",
        "SummaryHead"], "[", 
       DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
        "Ready"}, 
        TemplateBox[{
          PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SummaryBoxOpener"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                  "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQHfBf+NPP8/oOn/3j00MqW+wjDhSa7Phm4PAfyg99
tPzrl9lGDv+g/I89cQEvLEzgfJ7UFoFvP0zh/NBi4xaO2eZw/XLrA2NNEyzh
/NbiD+clZK3hfMk8iW8Me2zgfN1p6xuZ6+zgfItf6Qmsgg5w8yUPrDea9gXB
9zy1PZDpiiOc35/fcqpgiROcP3U1R1lOmzOcv6kpsDor0gXhvnlRZ501XB0Y
AiB8rwDpoFUcbnB+79wFBsK33BwYofz+xruOnHvd4fyHK2/NvzXbw4EJyvfM
nRO+LtsTzi88LurE7+sF52/YE9xWJO8N59t9CxTf+BbB7znGfrvmrA+c/8Gw
6YfXPF84X8Rki8eyBj843//iqk/MIf5w9+Te3FAyTzAAzp8kmtHJ2ITgO81n
PP30FYIf9OXb0gkxgXB+V7aPuuaZQLj/fQ1arjqZBMH5BQfEZZWXIvjy83on
tvAFw/lf5yavuVyK4GtnTk14+RTBf9O40rHBLwQe/rxpknvu7kfww3Je3tHQ
D4XztQ7M1vo6DcGPu79SsIM9DM6X9ZmlOqcgDB6/Ni3PLpU9QvCb701Ssw8K
R6TPNsXlHbsQ/Paf3AdnaEfAzXPddYNdayqCbyf55Mf//xFw9wMAZ6NU9w==

                    "]], 
                    
                    LineBox[{{1.6301769472383651`, 0.00999704304187079}, {
                    1.6301769472383651`, 0.009997043041870745}}]}, 
                    Annotation[#, "Charting`Private`Tag$5467#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0.009997043041870745}, 
                  BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
                  DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 100.}, {0.009997043041870757, 
                   0.009997043041870778}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Prolog -> {
                    RGBColor[
                    NCache[{
                    Rational[223, 255], 
                    Rational[72, 85], 
                    Rational[40, 51]}, {0.8745098039215686, 
                    0.8470588235294118, 0.7843137254901961}]], 
                    RectangleBox[
                    Scaled[{0, 0}], 
                    Scaled[{1, 1}]]}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SummaryBoxCloser"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                  "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQHfBf+NPP8/oOn/3j00MqW+wjDhSa7Phm4PAfyg99
tPzrl9lGDv+g/I89cQEvLEzgfJ7UFoFvP0zh/NBi4xaO2eZw/XLrA2NNEyzh
/NbiD+clZK3hfMk8iW8Me2zgfN1p6xuZ6+zgfItf6Qmsgg5w8yUPrDea9gXB
9zy1PZDpiiOc35/fcqpgiROcP3U1R1lOmzOcv6kpsDor0gXhvnlRZ501XB0Y
AiB8rwDpoFUcbnB+79wFBsK33BwYofz+xruOnHvd4fyHK2/NvzXbw4EJyvfM
nRO+LtsTzi88LurE7+sF52/YE9xWJO8N59t9CxTf+BbB7znGfrvmrA+c/8Gw
6YfXPF84X8Rki8eyBj843//iqk/MIf5w9+Te3FAyTzAAzp8kmtHJ2ITgO81n
PP30FYIf9OXb0gkxgXB+V7aPuuaZQLj/fQ1arjqZBMH5BQfEZZWXIvjy83on
tvAFw/lf5yavuVyK4GtnTk14+RTBf9O40rHBLwQe/rxpknvu7kfww3Je3tHQ
D4XztQ7M1vo6DcGPu79SsIM9DM6X9ZmlOqcgDB6/Ni3PLpU9QvCb701Ssw8K
R6TPNsXlHbsQ/Paf3AdnaEfAzXPddYNdayqCbyf55Mf//xFw9wMAZ6NU9w==

                    "]], 
                    
                    LineBox[{{1.6301769472383651`, 0.00999704304187079}, {
                    1.6301769472383651`, 0.009997043041870745}}]}, 
                    Annotation[#, "Charting`Private`Tag$5467#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0.009997043041870745}, 
                  BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
                  DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 100.}, {0.009997043041870757, 
                   0.009997043041870778}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Prolog -> {
                    RGBColor[
                    NCache[{
                    Rational[223, 255], 
                    Rational[72, 85], 
                    Rational[40, 51]}, {0.8745098039215686, 
                    0.8470588235294118, 0.7843137254901961}]], 
                    RectangleBox[
                    Scaled[{0, 0}], 
                    Scaled[{1, 1}]]}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic]},
         "SummaryPanel"],
        DynamicModuleValues:>{}], "]"}],
      InterpolatingFunction[{{0., 100.}}, {
       5, 7, 1, {247}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
        False}, CompressedData["
1:eJxF1Xk0FYgXB3AhIiSZ8X5ZnySjRSVrxvcVw0MNRSlbkixpE1p+TbL0lJYn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       "], {Developer`PackedArrayForm, CompressedData["
1:eJwl0oFGHgAAhdF/SZIkSZKkJUmSJEmSJEmSJEmSJEnSkmSSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSzMzMzOxMl/ME9/vc9KWq41MgEPgV+FgQwYQQShjhRBBJ
FNHEEEsc8SSQSBLJpJBKGulkkEkW2eSQSx75FFBIEcWUUEoZ5VRQSRXV1FBL
HfU00EgTzbTQShvtdNBJF9308JVe+uhngEGGGGaEUcYYZ4JJpphmhlnmmGeB
RZZYZoVV1lhng0222GaHXfbY54BDjjjmhFPOOOeCS6645oZb7rjngUeeeOaF
V9545xvf+cHPwMfnv/nDXwJCCCKYEEIJI5wIIokimhhiiSOeBBJJIpkUUkkj
nQwyySKbHHLJI58CCimimBJKKaOcCiqpopoaaqmjngYaaaKZFlppo53/kXfS
RTc9fKWXPvoZYJAhhhlhlDHGmWCSKaaZYZY55llgkSWWWWGVNdbZYJMtttlh
lz32OeCQI4454ZQzzrngkiuuueGWO+554JEnnnnhlTfe+QfPCnps
        "], CompressedData["
1:eJxF0Xk0lV3/BnAzmY8xM9FgfMgxPeR7h4qUJDJEpEHmsRLKIbNMpWQIlTE9
EpGic28iMoQ0UEIalKljHuKc3+F93t+7/9hrfdb13ddee205V1+r04wMDAxT
69vGokBq3eUaOzEiliKcI32Tbn+r8OnHdAcH/QQVRgpMxCmKE8SJmFDbcKwd
EwV6ZL6bvaJbXfnmxyhmCvgEGKpHSBCxsUMsuo9YKNDRsKtTV5KIlbR67fDl
p0BsCdKwkSdiv81vaGtIUiCGp4fDRomI0ewnDy9up8AHZU13XQ0ixrQ85N6g
SYGqlHR3mg4Rq1Zujwy8T4EoMlsGfo6IyXG+9ffZMg37Do/UN5UQMbGWxeCg
7Glgtg00s+shYg4Vyh5mwjOQz3AW1f0mYhGb0iIqU2YgryY1XpFFC7Nrl6M8
0JyFi+GRKsb8WphpywGzFx9m4TBmpHiKSwtruNbaHhA6Bw+fzppNzhMx0CHE
60vPQ1dbVa9WNxGzONstk4/Pg5tHk1NKFhGLzV3N3+q8ACNPKpvMbIjYmStP
H2tsX4QsfmyQ/EMTc/kQJxsytghI+xk7i4smdk+hxk+gZAlcKnceGWvYiZU0
mCyJOC+DSVnUQTeenZixKH9AOe8KDJ82mso11sCyFjOWuGpW4BhzS9b4aXUs
wdPI2N/6D1hmq5q+GlfDlHocV/sFV2Gix4qR1VwFq32Z3f2gYRU4ZqeqVkMV
sVRVh9FhxzX45CvqHxS/DdO/3v6q5tsa3HIftTkcLo8ZaGaSyHZUuPIkW1Tb
QxZTyHNp+lhLBf7Sz/yM5eJYiPJsDsZKg6wZWZYzBULY/Ql5qUBDGgSxsvJ5
3ObBsk1sT+ufpsHqnOp9QiQT5my4P+52CA0sTyvjeWoUsFiiXVsKpwFDQun1
LM4qeHOy0fRgGA2mzcoa3fN/4XdjzGUN/GjQcxJz8mhfxn8EVMu7O9L7Kjdd
YRpiQg+DJDODd9PgBbvNLw4bDlTp1arALUuDq6UsDuP7eZBzgbY7WqLCpwdl
f9AIP3ovtKKQ/ZoKJWj6gnSHALrUa6Silk+FZRk5r/dXhBBHAv/QmDcVYr62
cm/nEUEaj6Ta/9alwl87bIJ8PEWRYGPc5XDaGliK75cTuLsZdUQnJws0rUGV
S5C252Mx1CJ1vWVPzBrUCmrpPSkUR2qu6fWJsAaLBZo+lUkSiLprgZq3sAqf
hPN+LltLogyLJJHeslW4YimCKdEkUaJeX6yX8yponNTJSkmRQoszd4vKCKsQ
YRbbvXWTNMoOrTrV2vgH1Mh9gVk+0qivoNhW0vcP/JzM1R1rlkZD1YyBmeJ/
oNxZoEaJWwZlB+W7eDavgButTjnMWAbdNXlyrNZ3BVKitm566i2Dki81f78j
tgIW+f+IXroqg0TMrM7uebEMLJ0tbip3ZNAuxi2PbQ4uw1ZnI16ThzIoyMrW
8MCHJfAYOefsSvfgqWEJ+xNLUMw9Qbh5TwbhDcJhheOLoA8TTHFJMsjfVIlm
fX4RWEsdApN9ZFAeu2R7DOMisG0f+VG/Twa1vSg8mh2yAKPZYdumCDJoJN1I
qmxuHu7WSr1o65VGsruva/f5zsOjMysO6snS6MMQ4fjuiTm4uc/mae9uabRz
X2Y4k8ccxEnZOlj8lkIidTWbtX7NwlslSdntGVJI7EZnMMV9FjqWBgif9KRQ
dYAM8ebPGfjkx9E49lYS2TjNNLC7z0BFyQOPq56SyGfpZbnt+DTkKB/4aUaV
QK52PAI3fadBXFrhfRX9/758zvPpnqfAk6SQyRPiEkjUpfo64TIFUiirozMF
4sj4l2dKEBsFApqNggRUxBExPd5hRe43iDI7gFOlGDrOj8Ex/Slw9Y7KitIV
Q3Lzu2c22U9CjI1Rlg6+GdHEPMOoIROwRz6HXXbfZuStbsupfGcc8qZTige7
RZETedU8rH0MFlgd/DmcRNFDxplf/cu/IILkeFRhQgTtG+jCutl/geawUORl
TxHkmEqZZZf4CTz13//RoQgjFSmLMRPNUdBQrNDoChFGaYsh3nstf4B6qUDg
HS5h5OblW9jq/x1Kudirft4VQmSXjpXojG/QV9PIgWNCSP9xvZDss6/QWZLh
qDYiiLiv30woHh6BAXliTEiCIFLq837dwzkCpT80Ot31BBF+qXmfre4XYHqu
/u3BlACSajLUmDs7DAoVWkYjpQLI6GrrjTe6Q+DOmRaR5SGARmYk2p9wDsLv
hXiFIkMBlB/s23lsaABE7zl1mAoLoMYai5c3aj7Bje1JmaZTBARBtg+x1I8Q
fHl84uwrAjpiEETS9+qH4oZ9JzyKCOgcyf9V5+k+yJubZdoaR0CXnR2YJU58
gO96XPoMngTkOucxIXj8PQwaPlpqtiAgmr4f6YHjOzC+5c66S5OAMt+8Vhlw
fAuhbYK7d2wmoPH0xYrbbW+gOUZOMmaSH11K8em2NuiBaEkvI+1GfjRk2alk
fKoLqgPeG7xN50cCKMsuza4Doma2y907yY9eRb07EXr0FVjx6dsdV6E78ryo
BGMLGExZe3nN8yFuXoLohaom+Epj/N0UyYegJVzj9+tGmLI4b3JNkA+ZW+e8
KJtGEEeNXM1I40VtruJH5/TIEPBj7gHbIg9aJpP91kzrYPzNl7+TXXiQDJa7
hp2tBTd8W5pHOTeSGvaK/JhVDQ7PixsH+riQwd6WY63fKoHTMnZXyTtOtNsy
2EHTvAK+cR5ZPJmxCSUcfXj/amkZ8FAC0ta4OdD7QYMBPqFiiIndwqq/hQ2N
/FP+9Y5AMYz+I5cfL8eGMl7mLWgSiuHWl5R7H2TZ0LUFfuGXfMWQzJuStZXu
UC5msOMtBo006ehAGTbE3Hs+aIy7GKjNu042SLOhwLxTC7ycxRA9EzjrKMWG
BKRdizTZi4EyMXh4SYIN8ZLPRdmxFMNRk4uXr4uzIW2901K9o0WQn7sr6hY3
G5Kv6nzj3F4ELHxvqfFUViR+fvg5tbwI5liLPrpRWNEQI/PSw2tFoB/jybJz
hBUFPj1keSe0ECZcZ7M7DrEiBZ9JI0WvAhC70vWPZzUL+j1rc6zi1D2YMXPj
/iTAgvbIb8PunL4LM4GHWf64MaNniZXJbr53oGfUM+jlYyZUG32EWcUxD2SP
ni+1NWZEZxmUtnifvw0JDhN1NS4MKJFPTf7Z/Wwwt1fGtcap+PcXM3+UrbKA
ODBjPe+1huM/xMzfc2aC13VzQ4vRP3gr68FNzO8yQJ0nl1fRcQVP4nn8+FvF
TSjmae2q7lzCmT+66IqevAEUQpmLw7cFvFvU7fDSX+mQI7VwIYU6h8cd/xC8
U/Q6FDBUVJyRm8Vdjm++prj5Ggzvae5aODyNPy5IPvNHIw368yzKJJR+48p/
DNPuS6WCH3mRMFY9hg/1NTMKVibDT7nR4ee2o7in1xH18GNJEJt4ZIFq8g2P
iUgq7995FUzFdPI+kr7g074qr001E8Fv2COSU3QQJ71VBRa7BMhn6ztj39yP
F+iNfd9LigdSwpp+XMA7/N2N0MXRjjiQFfDjw3p68IL5L+yTOnFAqtPdUpfZ
iStYu/eL1ceCy+gT+4a8Vrzo9EGzBetYwJqSzdcSmvBJM9EWRI0BWWLScq5W
A95/K7hnS2EMoK0LLMW1dXiqTkLObccYIA2+dLmaVIP/pbpae0AuBiLU+8eI
yZU4xIcz6VKigUFYJNTyezn+2jxHVKaF7quyTpbs93GdlNjggwXREOFyoSlN
rQjPX/y7tSWWnn/+ZKOx6x6uaCgSPuUTDaTOMlPH9/l4RH78q8320cCYkSzx
rvo23pnyNfjFHrp3dIz7n8nCuw6kv4kl0s9LtD4Zz8rABac/XBPaGg20Q5TJ
Hbo38A5hPZ8JAXpulzybkHQNr8mp76Ey0e3UcsnpSCpewld6bHouChgG+Mk2
X67iF6TtM8J+0v3xeJx5cTy+eesVc7fPdDvwT/YOxOCFf4cevtJLt6tZQJd3
FD50c/Lk/Ta6/+bsPWQeiSv691rVN9Kd3kU86E7C5Wls40tP6Z6Iip+uDcMD
ihNZDlTSLXQ/567aRfx11Dxvahnd2Lc+ssR5vP9ERHFhId0cag0RPoG4cljQ
C/48uismPluE+uGtP7ofhGTSfTa3/ybVE0+3XkurS6dbNwO9aXfDUz1mDCpT
173f7KvhKXxavciemkh3bfImvS0u+Nc3+rcM4+imtF13fWqPVxT0HdgdTTdD
SnNCnDXO1qg9+zmS7u5WuUoPS1y17QbfPIluWQ91HdiP16ZlmWmF0006mqGk
YoKriy7zfb607meSGYKArxg+UukNW3+P7682UV1cX4lJh3XdpLszSck7ce0L
ATVuoev3sQfukFfBu8envVXXTXp54pmNIi7ck8m0HBIFjCTVo8TcbfiBYK8z
bSHrubkEiV0BT+wcF7mzboane4e65HDSx6HWsA1H1BS1yOCfmFY8HTds+Gib
hSTeTbHKhA0bCEtqieGkRJLt/MV17/aP1ybgL6Pr/RrpptFmtfFsdrz/rWps
3obBnFOZAeeTK0mO3Zh3bK+yWiBrGpfeObfhEt/gukkyu0bjgPuG1R8fmhkh
x5VcKnelm5Ghwu9B/Duy6uLY6+Mb+XCHB/dL8sPjqzkOdKtGWdzrSHxNvri7
8LUt3S3xXqJqY8/Ip3jT9h+le9xi1WLLp0Ly8IGyeBu6id6/zPMjs8iLVh6/
rem2jo8qeKSbSB7135u77ouTZ/UiOi+QOU4qXFy3neXK3crtLmQLdxvvdR/T
GA161G5CHr540n3dWMYqbt6mTOa2j3Zb91nTv6QHDlOeC0q7btjKuqYkaFfV
83Ib5w2jfUPnvgUaP+ex/I/z+bpnUsp66xn+tVuuz/NRpz31tEP/McMzfx7F
UK566r+2RM4LGcFc9Yz/zpdeyFoytZY3YPrXB8fKsLw5DoP/5iHhg/vHg7j+
v/8S1yDZie7/9mPJxce7A//XX395StE48H/zPxnGjLRs5A3+D9tscUI=
        "]}, {Automatic}],
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8792278448331833`*^9, 3.879227966824821*^9, 3.879229056436378*^9, 
   3.8792308969119377`*^9, 3.879230982023519*^9, {3.879231193783807*^9, 
   3.879231221809194*^9}, 3.879231307502205*^9, 3.8792374639208193`*^9, 
   3.879238035952795*^9, 3.879238148586606*^9, {3.879238220956773*^9, 
   3.879238246027216*^9}, 3.8957247471261683`*^9, 3.895724783131473*^9, 
   3.895730254014431*^9, 3.8957306127083807`*^9, 3.895731418607053*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"f00dcf9d-4740-442e-bd5c-a3879c3c045f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ssNF", "[", "s_", "]"}], ":=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "==", "0"}], "&"}], "/@", 
         "odesNF"}], ")"}], "/.", 
       RowBox[{"rateeqsNF", "[", "s", "]"}]}], "/.", "parmNF"}], "/.", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"e", "[", "i", "]"}], "->", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "[", "i", "]"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "[", "i", "]"}], "[", "100", "]"}], "/.", 
           RowBox[{"tsolNF", "[", "s", "]"}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.8792270721482677`*^9, 3.879227127348626*^9}, {
  3.879227378214761*^9, 3.879227505288492*^9}, {3.8792275392745247`*^9, 
  3.879227548336884*^9}, {3.879227820363254*^9, 3.879227826923032*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"e2804fa2-9ba6-4cd4-ab1e-3c32d53ba946"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ssNF", "[", "1", "]"}]], "Input",
 CellChangeTimes->{{3.879227850515739*^9, 3.8792278530337067`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"8194e1e5-80ec-4836-81e5-1d3dbde71469"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "\[Rule]", 
    "0.06160989814715274`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}], "\[Rule]", 
    "0.05691782041030892`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], "\[Rule]", 
    "0.009997043041870768`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8792278538938217`*^9, 3.879227968553739*^9, 3.879229059642989*^9, 
   3.879230898786212*^9, 3.879230983585125*^9, {3.879231195349057*^9, 
   3.879231223234692*^9}, 3.8792313087710037`*^9, 3.8792374639727907`*^9, 
   3.879238038417383*^9, 3.879238150437379*^9, {3.879238222670683*^9, 
   3.87923824608363*^9}, 3.895724750039247*^9, 3.895724783164434*^9, 
   3.895730257544232*^9, 3.8957306142675858`*^9, 3.8957314193680973`*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"043577fc-7a2e-43d2-997b-c57f38a12088"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"optNF", "[", "s_", "]"}], ":=", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"e", "[", "i", "]"}], 
            RowBox[{"v", "[", "i", "]"}]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"3", "+", "1"}]}], "}"}]}], "]"}], "/.", 
         RowBox[{"rateeqsNF", "[", "s", "]"}]}], "/.", "parmNF"}], "}"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "[", "t", "]"}], ">", "0"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"1", "==", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"rateeqsNF", "[", "s", "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ")"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"3", "+", "1"}]}], "}"}]}], "]"}], "/.", "parmNF"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"e", "[", "i", "]"}], ">", "0"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"3", "+", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "[", "i", "]"}], "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "[", "i", "]"}], "[", "t", "]"}], "/.", 
           RowBox[{"ssNF", "[", "s", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"e", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"3", "+", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", 
    RowBox[{"MaxIterations", "\[Rule]", "Infinity"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.879227566098934*^9, 3.879227655218539*^9}, {
  3.8792277051700974`*^9, 3.8792277062910233`*^9}, {3.8792278630766706`*^9, 
  3.879227889244727*^9}, {3.879229923078229*^9, 3.879229969506916*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"d8d146f4-4eed-4918-9866-93177a847149"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"optNF", "[", "0.1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"optNF", "[", "0.5", "]"}], "\[IndentingNewLine]", 
 RowBox[{"optNF", "[", "1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"optNF", "[", "2", "]"}]}], "Input",
 CellChangeTimes->{{3.879227894483926*^9, 3.879227896010769*^9}, {
  3.879227971316143*^9, 3.8792279714350433`*^9}, {3.879228980149165*^9, 
  3.879228999119529*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"2c7b3bc7-190a-428e-b01f-65a8bafafef5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1001.5313098256499`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "\[Rule]", 
      "0.028557933990356908`"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}], "\[Rule]", 
      "0.06578090174805665`"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], "\[Rule]", 
      "0.04164005317310502`"}], ",", 
     RowBox[{
      RowBox[{"e", "[", "1", "]"}], "\[Rule]", "1000.7318078776555`"}], ",", 
     RowBox[{
      RowBox[{"e", "[", "2", "]"}], "\[Rule]", "0.49788289895407306`"}], ",", 
     
     RowBox[{
      RowBox[{"e", "[", "3", "]"}], "\[Rule]", "0.17760369298992035`"}], ",", 
     
     RowBox[{
      RowBox[{"e", "[", "4", "]"}], "\[Rule]", "0.1240153125738064`"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8792278969774723`*^9, 3.879227971828912*^9, {3.879228981065*^9, 
   3.879228999605113*^9}, 3.879229061634231*^9, 3.8792299315800877`*^9, {
   3.8792299654170628`*^9, 3.879229978072356*^9}, 3.879230902158492*^9, 
   3.879230987477531*^9, {3.8792311975522823`*^9, 3.879231224817931*^9}, 
   3.879231310292383*^9, 3.879237464357086*^9, 3.879238040164404*^9, 
   3.879238152956431*^9, {3.879238225244627*^9, 3.879238246303071*^9}, 
   3.895724751931073*^9, 3.895724783325494*^9, 3.895730262583016*^9, 
   3.8957306165893517`*^9, 3.895731420772727*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"3ee7ed5a-5a30-450c-a214-cca3cd43fe67"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.8750243651606624`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "\[Rule]", 
      "1.6558663376716525`"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}], "\[Rule]", 
      "1.7624437898667358`"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], "\[Rule]", 
      "0.17157698225805978`"}], ",", 
     RowBox[{
      RowBox[{"e", "[", "1", "]"}], "\[Rule]", "1.7140193249069697`"}], ",", 
     RowBox[{
      RowBox[{"e", "[", "2", "]"}], "\[Rule]", "0.029861074321186454`"}], ",", 
     RowBox[{
      RowBox[{"e", "[", "3", "]"}], "\[Rule]", "0.025315678321230287`"}], ",", 
     RowBox[{
      RowBox[{"e", "[", "4", "]"}], "\[Rule]", "0.1058282876108111`"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8792278969774723`*^9, 3.879227971828912*^9, {3.879228981065*^9, 
   3.879228999605113*^9}, 3.879229061634231*^9, 3.8792299315800877`*^9, {
   3.8792299654170628`*^9, 3.879229978072356*^9}, 3.879230902158492*^9, 
   3.879230987477531*^9, {3.8792311975522823`*^9, 3.879231224817931*^9}, 
   3.879231310292383*^9, 3.879237464357086*^9, 3.879238040164404*^9, 
   3.879238152956431*^9, {3.879238225244627*^9, 3.879238246303071*^9}, 
   3.895724751931073*^9, 3.895724783325494*^9, 3.895730262583016*^9, 
   3.8957306165893517`*^9, 3.8957314208088284`*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"c97d11f0-af88-4d33-a4b1-ccbcff9d1f52"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.3528156598735048`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "\[Rule]", 
      "6.73186777914235`"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}], "\[Rule]", 
      "6.241232797380766`"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], "\[Rule]", 
      "0.2988978935913924`"}], ",", 
     RowBox[{
      RowBox[{"e", "[", "1", "]"}], "\[Rule]", "0.20409625672019627`"}], ",", 
     
     RowBox[{
      RowBox[{"e", "[", "2", "]"}], "\[Rule]", "0.022877676831484513`"}], ",", 
     RowBox[{
      RowBox[{"e", "[", "3", "]"}], "\[Rule]", "0.0224961013663552`"}], ",", 
     RowBox[{
      RowBox[{"e", "[", "4", "]"}], "\[Rule]", "0.10334562407359296`"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8792278969774723`*^9, 3.879227971828912*^9, {3.879228981065*^9, 
   3.879228999605113*^9}, 3.879229061634231*^9, 3.8792299315800877`*^9, {
   3.8792299654170628`*^9, 3.879229978072356*^9}, 3.879230902158492*^9, 
   3.879230987477531*^9, {3.8792311975522823`*^9, 3.879231224817931*^9}, 
   3.879231310292383*^9, 3.879237464357086*^9, 3.879238040164404*^9, 
   3.879238152956431*^9, {3.879238225244627*^9, 3.879238246303071*^9}, 
   3.895724751931073*^9, 3.895724783325494*^9, 3.895730262583016*^9, 
   3.8957306165893517`*^9, 3.895731420840128*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"c334cab0-abe2-46e6-8471-8c43c3a8cd66"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.2542328407053618`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "\[Rule]", 
      "12.83886674209495`"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}], "\[Rule]", 
      "11.594196161712528`"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], "\[Rule]", 
      "0.5184447400532052`"}], ",", 
     RowBox[{
      RowBox[{"e", "[", "1", "]"}], "\[Rule]", "0.10849352232519938`"}], ",", 
     
     RowBox[{
      RowBox[{"e", "[", "2", "]"}], "\[Rule]", "0.021775913063818486`"}], ",", 
     RowBox[{
      RowBox[{"e", "[", "3", "]"}], "\[Rule]", "0.02203455788437604`"}], ",", 
     
     RowBox[{
      RowBox[{"e", "[", "4", "]"}], "\[Rule]", "0.10192884580426319`"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8792278969774723`*^9, 3.879227971828912*^9, {3.879228981065*^9, 
   3.879228999605113*^9}, 3.879229061634231*^9, 3.8792299315800877`*^9, {
   3.8792299654170628`*^9, 3.879229978072356*^9}, 3.879230902158492*^9, 
   3.879230987477531*^9, {3.8792311975522823`*^9, 3.879231224817931*^9}, 
   3.879231310292383*^9, 3.879237464357086*^9, 3.879238040164404*^9, 
   3.879238152956431*^9, {3.879238225244627*^9, 3.879238246303071*^9}, 
   3.895724751931073*^9, 3.895724783325494*^9, 3.895730262583016*^9, 
   3.8957306165893517`*^9, 3.8957314208740997`*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"05b41b79-fc0f-4150-af6e-30b84d04fa0a"]
}, Open  ]],

Cell["\[LineSeparator]Numerical check of optimality", "Text",
 CellChangeTimes->{{3.8792279783630447`*^9, 3.879227985306899*^9}, 
   3.879229063480908*^9, 3.879230991107699*^9, 
   3.895730618436285*^9},ExpressionUUID->"288e9349-d2a1-4dc9-a9db-\
2d4b7435d0c6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"odesNF", "/.", 
      RowBox[{"rateeqsNF", "[", "1", "]"}]}], ")"}], "/.", "parmNF"}], "/.", 
   RowBox[{
    RowBox[{"optNF", "[", "1", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"steady", " ", "state"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"e", "[", "i", "]"}], 
       RowBox[{"v", "[", "i", "]"}]], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"3", "+", "1"}]}], "}"}]}], "]"}], "/.", 
    RowBox[{"rateeqsNF", "[", "2", "]"}]}], "/.", "parmNF"}], " ", 
  RowBox[{"(*", " ", "objective", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"%", ",", 
      RowBox[{
       RowBox[{"x", "[", "i", "]"}], "[", "t", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], "/.", 
  RowBox[{
   RowBox[{"optNF", "[", "2", "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"optimality", " ", "of", " ", "derivative"}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.879227670178331*^9, 3.879227710961175*^9}, {
  3.8792279031319838`*^9, 3.879227914282872*^9}, {3.879227991029426*^9, 
  3.8792280675005617`*^9}},
 CellLabel->
  "In[386]:=",ExpressionUUID->"c20e1035-a829-450a-b051-b4d9d45fd4c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"x", "[", "1", "]"}], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
    "6.365755367276904`*^-9"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"x", "[", "2", "]"}], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
    "2.0732635386266907`*^-8"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"x", "[", "3", "]"}], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
    RowBox[{"-", "2.707241597565968`*^-8"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8792276690053883`*^9, 3.8792277151370497`*^9}, {
   3.879227906883808*^9, 3.879227914763023*^9}, {3.879227973550992*^9, 
   3.879228020500709*^9}, 3.879228068103819*^9, 3.8792290645592012`*^9, 
   3.879230905298705*^9, 3.879230992227309*^9, {3.879231199984434*^9, 
   3.8792312273528957`*^9}, 3.879231312165497*^9, 3.8792374648080187`*^9, 
   3.879238042425523*^9, 3.879238246641479*^9, {3.895724755282209*^9, 
   3.895724783552185*^9}, 3.895730619928503*^9},
 CellLabel->
  "Out[386]=",ExpressionUUID->"1c0ce27f-e6ad-4d49-b33c-21b1542af992"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"1", "+", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "+", 
    RowBox[{
     RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}]}], 
   RowBox[{"100", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "-", 
      RowBox[{
       FractionBox["1", "10"], " ", 
       RowBox[{
        RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}]}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"1", "+", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "+", 
    RowBox[{
     RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}]}], 
   RowBox[{"100", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}], "-", 
      RowBox[{
       FractionBox["1", "10"], " ", 
       RowBox[{
        RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}]}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"0.01`", "\[VeryThinSpace]", "+", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}]}], 
   RowBox[{"10", " ", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"2", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "10000"]}], ")"}], 
     "4"], "+", 
    FractionBox[
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], "4"]}], 
     RowBox[{"1", "+", 
      RowBox[{"0.001`", " ", 
       SuperscriptBox[
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], "4"]}]}]]}], 
   RowBox[{"20", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{
       FractionBox["1", "800"], " ", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"2", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], "10000"]}], ")"}], 
     "3"]}]]}]], "Output",
 CellChangeTimes->{{3.8792276690053883`*^9, 3.8792277151370497`*^9}, {
   3.879227906883808*^9, 3.879227914763023*^9}, {3.879227973550992*^9, 
   3.879228020500709*^9}, 3.879228068103819*^9, 3.8792290645592012`*^9, 
   3.879230905298705*^9, 3.879230992227309*^9, {3.879231199984434*^9, 
   3.8792312273528957`*^9}, 3.879231312165497*^9, 3.8792374648080187`*^9, 
   3.879238042425523*^9, 3.879238246641479*^9, {3.895724755282209*^9, 
   3.895724783552185*^9}, 3.895730619931773*^9},
 CellLabel->
  "Out[387]=",ExpressionUUID->"253798bd-c6cb-4892-b3e6-aeb1f840e396"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6.562744896132511`*^-9", ",", "7.763942845616725`*^-9", ",", 
   "1.7657649090119243`*^-7"}], "}"}]], "Output",
 CellChangeTimes->{{3.8792276690053883`*^9, 3.8792277151370497`*^9}, {
   3.879227906883808*^9, 3.879227914763023*^9}, {3.879227973550992*^9, 
   3.879228020500709*^9}, 3.879228068103819*^9, 3.8792290645592012`*^9, 
   3.879230905298705*^9, 3.879230992227309*^9, {3.879231199984434*^9, 
   3.8792312273528957`*^9}, 3.879231312165497*^9, 3.8792374648080187`*^9, 
   3.879238042425523*^9, 3.879238246641479*^9, {3.895724755282209*^9, 
   3.895724783552185*^9}, 3.895730619967194*^9},
 CellLabel->
  "Out[388]=",ExpressionUUID->"4c865464-accf-45b7-bd66-6951d9081f82"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ss123", "[", 
   RowBox[{"x3_", ",", "s_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"v", "[", "2", "]"}], "/.", 
      RowBox[{"rateeqsNF", "[", "s", "]"}]}], "/.", "parmNF"}], "/.", 
    RowBox[{
     RowBox[{"optNF", "[", "s", "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", 
       RowBox[{
        RowBox[{"-", "4"}], ";;", 
        RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "==", "0"}], "&"}], "/@", 
          RowBox[{"odesNF", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "/.", 
         RowBox[{"rateeqsNF", "[", "s", "]"}]}], "/.", "parmNF"}], "/.", 
       RowBox[{
        RowBox[{"optNF", "[", "s", "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", 
          RowBox[{
           RowBox[{"-", "4"}], ";;", 
           RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], "->", "x3"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], "[", "t", "]"}], ",", "1"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "2", "]"}], "[", "t", "]"}], ",", "1"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"MaxIterations", "\[Rule]", "Infinity"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.87922808761425*^9, 3.879228233619566*^9}, {
  3.879228266948955*^9, 3.8792283379072638`*^9}, {3.87922840043253*^9, 
  3.8792284052358522`*^9}, {3.879228669828018*^9, 3.879228681842409*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"7ab3d236-254d-476c-a9da-177cf0efc660"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"S", "=", "0.1"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pl01", "=", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x3", ",", 
         RowBox[{"ss123", "[", 
          RowBox[{"x3", ",", "S"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], ",", 
     
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"v", "[", "4", "]"}], "/.", 
        RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
      RowBox[{
       RowBox[{"optNF", "[", "S", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", 
         RowBox[{
          RowBox[{"-", "4"}], ";;", 
          RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", "0", ",", "10"}], 
     "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"%%", ",", "%", ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*FractionBox[\(X3\), \(Ki\)]\)\>\"", ",", 
       "\"\<Supply and Demand Rates\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{"Dashed", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"S", "=", "0.5"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pl05", "=", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x3", ",", 
         RowBox[{"ss123", "[", 
          RowBox[{"x3", ",", "S"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], ",", 
     
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"v", "[", "4", "]"}], "/.", 
        RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
      RowBox[{
       RowBox[{"optNF", "[", "S", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", 
         RowBox[{
          RowBox[{"-", "4"}], ";;", 
          RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", "0", ",", "10"}], 
     "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"%%", ",", "%", ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*FractionBox[\(X3\), \(Ki\)]\)\>\"", ",", 
       "\"\<Supply and Demand Rates\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{"Dashed", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"S", "=", "1"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pl1", "=", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x3", ",", 
         RowBox[{"ss123", "[", 
          RowBox[{"x3", ",", "S"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], ",", 
     
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"v", "[", "4", "]"}], "/.", 
        RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
      RowBox[{
       RowBox[{"optNF", "[", "S", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", 
         RowBox[{
          RowBox[{"-", "4"}], ";;", 
          RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", "0", ",", "10"}], 
     "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"%%", ",", "%", ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*FractionBox[\(X3\), \(Ki\)]\)\>\"", ",", 
       "\"\<Supply and Demand Rates\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{"Dashed", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"S", "=", "2"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pl2", "=", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x3", ",", 
         RowBox[{"ss123", "[", 
          RowBox[{"x3", ",", "S"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], ",", 
     
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"v", "[", "4", "]"}], "/.", 
        RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
      RowBox[{
       RowBox[{"optNF", "[", "S", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", 
         RowBox[{
          RowBox[{"-", "4"}], ";;", 
          RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", "0", ",", "10"}], 
     "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"%%", ",", "%", ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*FractionBox[\(X3\), \(Ki\)]\)\>\"", ",", 
       "\"\<Supply and Demand Rates\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{"Dashed", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"S", "=", "5"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pl5", "=", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x3", ",", 
         RowBox[{"ss123", "[", 
          RowBox[{"x3", ",", "S"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], ",", 
     
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"v", "[", "4", "]"}], "/.", 
        RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
      RowBox[{
       RowBox[{"optNF", "[", "S", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", 
         RowBox[{
          RowBox[{"-", "4"}], ";;", 
          RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", "0", ",", "10"}], 
     "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"%%", ",", "%", ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*FractionBox[\(X3\), \(Ki\)]\)\>\"", ",", 
       "\"\<Supply and Demand Rates\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{"Dashed", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"S", "=", "10"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pl10", "=", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x3", ",", 
         RowBox[{"ss123", "[", 
          RowBox[{"x3", ",", "S"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], ",", 
     
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"v", "[", "4", "]"}], "/.", 
        RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
      RowBox[{
       RowBox[{"optNF", "[", "S", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", 
         RowBox[{
          RowBox[{"-", "4"}], ";;", 
          RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", "0", ",", "10"}], 
     "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%%", ",", "%", ",", 
   RowBox[{"Frame", "->", "True"}], ",", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(X3\), \(Ki\)]\)\>\"", ",", 
      "\"\<Supply and Demand Rates\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"10", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.879228235156035*^9, 3.879228236977769*^9}, {
   3.8792283432029676`*^9, 3.879228638513461*^9}, {3.879228689723728*^9, 
   3.879228724817815*^9}, {3.879228790482745*^9, 3.879228837929943*^9}, {
   3.8792291296810513`*^9, 3.879229227859268*^9}, 3.879229303455061*^9, {
   3.879229460253148*^9, 3.87922948650961*^9}, {3.879229541264056*^9, 
   3.879229569191702*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"ec3c1606-4d91-4fcf-9a11-30f7adefabe0"],

Cell[BoxData["0.1`"], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, {
   3.8957247581580257`*^9, 3.895724783615486*^9}},
 CellLabel->"Out[19]=",ExpressionUUID->"c761ad9b-52c3-49c6-a113-476827222eed"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zm1MUmEUB/CLsKhJSApCJCJgLxuyZtiaa/mcVrPaXOQFjcAhWgTFjBRb
70vaGG02FrbZTKMPIfYpP9igjVzrxZGFK5hbs1WrrJYzwrJsDqZFnf7b3bNn
9/x/55E1O2hLDkVR6j9f9vyfe/0/QnnUDLnak80oOamK3u3+nsL7BPEscDQC
dYpUqLOZJOvT7vAV3Rf8P0VGa96FCkKfyD9thqRGKocCrLc4P0sc1zYdGX0z
TqwHs5kjG2vbvM86n2B/ntgM5lNDeffJWCybDBEFNFy9K4QeBZP8newDvbdw
ngHVjB7b8mP96DOhXSqlv/30Y58Fns+eGCPVjfuWQP2GdS9yrD70lkIuu3KA
R3WitwzKbA0+tdmNXi4EowzPiSoXehy45N2TeK85gx4Xbge5jeHrx9HjgXjC
7x9htuM8D1x1FpVe3Yr+ClgzHOgVzLVgPx96oxVj0/bDuK8AqrjiUnuXFT0+
KJu07ldbLejxoeaQxult2I+eAHYTp4YTa0KvEG5WK1vKzpnRE4KIFrAb4yb0
RGD6+vC5J9OAnggudFjtfQ4jeitBFnk9MCIxoCeGZPli+FFGj94qkLfE15pY
evSKIAnR5inVXvSKYLZjWJB21qMngaPBwbOKRB16xRBfdPkj2+vQk4J3tfDO
8GMdeiUgAdWOoFGH8yUwb1f6jGkt+iXQta91szioJX/rahn8ckZiFoMW98kg
P6XckinUoicHhak4+fQljZ4cxieGXNMBGj05iBLl2y630/geBTxQtg0Kd9Ho
KeB8yM38KKPRK4UPlTcunl6oJb8B5b1Jbg==
       "]]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1nc4l98bB3ArJSFUP5XZJ8keqTS4H0mppJKVRCQyKipEipKvZISQ7JXM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        "]]},
      Annotation[#, "Charting`Private`Tag$55631#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Epilog->{
    Dashing[{Small, Small}], 
    LineBox[{{0, 1}, {10, 1}}]},
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*FractionBox[\\(X3\\), \\(Ki\\)]\\)\"", TraditionalForm], 
    FormBox["\"Supply and Demand Rates\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, All}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, {
   3.8957247581580257`*^9, 3.895724787733499*^9}},
 CellLabel->"Out[22]=",ExpressionUUID->"f4f0254c-29b9-4421-8802-dd86692c4b7a"],

Cell[BoxData["0.5`"], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, {
   3.8957247581580257`*^9, 3.895724787739193*^9}},
 CellLabel->"Out[23]=",ExpressionUUID->"841cca27-8200-4e80-8707-ac5f47a95316"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zm1IU1EYB/BNpVZLnWVp6WwvUfZBKmbWPp0nrLS00N07W8pMNzVq6Vow
THpxDhSsoZJB2sY0QkWM1Aj6kLWVZC23cgu1/JDbNGyhbC5YFLOX1dMfLofD
ff6/5/AVakllFIPBEP35Iuf/WD5Oud5GB8jtzkhshL7ZeFb2w4/3D4T1QCf+
fMRPMkWRzJEw3eyfNy3ifx9xenOnJ8QL5J8WIMNOsSHJ5Mb5r6Rd8Yv5zjtJ
TldFEiKxnkNyZqwd+9/J/oE38oPc58RhjyRMpjSZz96HHqHHAMqfETpODeE8
EyTKb/HWL73oR8OtmvFX7uvd2I8Bl3D28kBTB+5bBfGyzoc7zTfQY8FiYeuA
d96A3hoYrG5hZXua0GNDsDVkdWv16K2DNH3z4O6Cq+jFgXrH0s+5vDr0OHCA
f/8pS63FeQ6o6ELpguoC+gngmE80Gtjnsb8eAkGfgnHsHO7bAOb6o3vD5Ax6
iTCT03e35UUVeonQkdDWsPykAr2NoK3uM6cmKNHbBF3sEcXwvXL0kmBCMjra
oC9DLxkuzg45ouNPoZcMl0wrwdVVcvQ2w52e9P6CcAl6W0AUN/Hy01gxeikw
3brHGRo5iV4q6IxjbYppGXqpUF+5XFvCkaHHhcdqXz5feQK9NFBXtDhejxeh
txXsvdbilJwi9HjQU0PZyl1SnOfBWs6SqFQlRZ8HuqhsUQZHSv7WRXzol2zP
2WehcR8f0jVljcJaGj0BeCzWGXsWjZ4AjId30eIVCj0BXMufjGm3UfgeIcgM
3CyBkUJPCNxSRXeuhkJvG0g9zLoreRT5Df1BVh0=
       "]]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1Wk4VW0XB3BTvUkplAeZDykapHo0sbZkDEWkJDITSUohzYQnCkkiyZgh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        "]]},
      Annotation[#, "Charting`Private`Tag$93556#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Epilog->{
    Dashing[{Small, Small}], 
    LineBox[{{0, 1}, {10, 1}}]},
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*FractionBox[\\(X3\\), \\(Ki\\)]\\)\"", TraditionalForm], 
    FormBox["\"Supply and Demand Rates\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, All}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, 
   3.8957247581580257`*^9, 3.895724791704389*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"753aac97-aa04-4d54-8f89-ef150db2b1c3"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, 
   3.8957247581580257`*^9, 3.895724791709597*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"a157eb70-2954-416a-ba21-fda6bbe2a7c4"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 28, 1, 21008643813971916746, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.879238278771265*^9, {3.8957247657704077`*^9, 3.895724791862382*^9}},
 CellLabel->
  "During evaluation of \
In[19]:=",ExpressionUUID->"7761f8aa-6c1f-4449-ade6-283237730fa4"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zmtIU2EYB/Cj1ko2crfM5cptOoMymC38YI33Ec0QljWLeelinU3nFrWm
LW2GaEmLJYGVDbVYW1MryholIcwKdR+kNbspDSNKm9A+6CDIMo1aPf7h8PJy
nv/vecW0sagilqIo+d8vei5F4tZ/4SZESEd7NCPEWSPgZDKX7kHC9PTYBoZm
yVZ5NFOE3ZvBmS6fwf9fiTS/ZSH9V5j81yJkaGpUEu8N4fw34guW35iI/0R0
ldF8J+otfMc1wzj2f5KCwwHf5ccB8tIfzQIxDtsnywQ+9CjIuzURaTQP4HwM
ZLJl0sTYPvTjINf7wH3ydi/2l0F4v/BKw2Q37mOAavNDd4nZid5KGHzReLNP
1olePJiSi3pm29rQY4Jy8FD2THUreizY6cq17va0oLcKiuyFxYofVvTYoFPw
9Rf3NuM8G+TXWc/S6pvQ54DOX7Dpfm0D9rmwcby0x/TZgvt48LrO63Uv1qLH
h64utbLYbUaPD3uytXGOJzXorYZA5j7mW1E1eokgPsdY7AycQG8NHKhv5m7Q
GdFLAnvOG80l2zH0kiBcRqmpuaPoCSDv7PKMOocBvbVwYag/v/W0Hr1k4Lpi
/JEzVegJ4V62j/XOpUNPCB0KxVx/qBK9dfBo4b1DlFOJ3nrwdvvHVJ4K9FJg
WmDlbZNXoCcCW+N2XuGwFudF8Fumjq2iteiLIOQ0vBpgasm/ulwMw6csZv9T
De4TQ0l7lUpp0aAngaujH+bTFRr0JCAd+Th/nKFBTwKC9LmE0jEa35MKM+wV
d7Pu0Oilwq4dKUdMTTR6aXA++DzLepAmfwCuvkyN
       "]]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1Xk41UsYB3D7TZYrbkL2Q9KCpCuS91eSrVQSEopEKkIhkjaFLCFFluwK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        "]]},
      Annotation[#, "Charting`Private`Tag$132320#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Epilog->{
    Dashing[{Small, Small}], 
    LineBox[{{0, 1}, {10, 1}}]},
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*FractionBox[\\(X3\\), \\(Ki\\)]\\)\"", TraditionalForm], 
    FormBox["\"Supply and Demand Rates\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, All}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, 
   3.8957247581580257`*^9, 3.895724794945117*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"b4268ae6-4e02-4907-85e6-1e38bb0a8798"],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, 
   3.8957247581580257`*^9, 3.895724794952668*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"baead82a-1d43-436f-9e17-ae657477bd58"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zm1Ik1EUB/C5IjTL2TSdutyLyw8mKc3AkXUPCRklKoYWSyLFmRARrCVu
rLRm5Yeao724ueam6BTDdFS20GIwPxjLolWSL4milJvTKZoZjczV8Q8Pl8vz
P79zOWVXC0VUCoXC3/yC51Ziel9OT0YskSZDMG+I+PVy/N3dW/dRoikXJ8tC
l0gGP5gZUk/n/BHN+/G/hyw5zP0ihZ/81zZ7V7yCsEeL2F8hRtf5L+6Aj1yq
CGaNUPTcIZvei/O/SKBE+3NM950Mvw0mQNinpVR39ix6FKj+xMj0rU5hPwQ+
HisO8Y6Oo78N5DkLjiLLCM5vh6rcOW5uvhv37YDY+8oRa/cweqEwrzDLBGlD
6IUBxZlXe3nSiV440M7YC4/KHejtghO8h7+/dfSjFwHhlQNfPVUv0IsEXkWK
g8p7hv1IuCb2tXrkNvT3gH+nSnKj7wnO08HDLXHWZj/GfVHA6pFJUiSd6EXD
RvO7Sn6yFb1osJt6GemkDb29MNhWX9De1YpeDKiuF5cazrWgFwu3xlM5t7Ms
6DEgS5gj8eub0WPAeke1KyPEhF4cuBt+DB5pN6IXD3H5i9PTsib0EiBQQxOv
SA3oMUG6bH7qNOrRY4Jyf5lyYqwRvX3QtZ6X5jjUiF4i0EtPHbebdeixIJ2x
auhJ1KHHhueqA1NR3Vrss8FG09e8OqlFnw2ZH1yiCb+G/Bvnc0D2oE81Z9Hg
Pg7cE9TptUINely46WXphhI06HHhvbXA2zCjRo8LG3c665g2Nb4nCc6S8gsD
CjV6SZC6Jl74LFSjxwPTwaKLs4fV5C8WjGDi
       "]]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1Xk0VlsYB2BTKqJQEjJ9IkMo4SLeI1QoytgVKomiJFGRyr1yEQpJ5ilD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        "]]},
      Annotation[#, "Charting`Private`Tag$170895#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Epilog->{
    Dashing[{Small, Small}], 
    LineBox[{{0, 1}, {10, 1}}]},
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*FractionBox[\\(X3\\), \\(Ki\\)]\\)\"", TraditionalForm], 
    FormBox["\"Supply and Demand Rates\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, All}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, 
   3.8957247581580257`*^9, 3.8957247984857073`*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"d69f7c93-e069-4b00-8b70-78d17362e72f"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, 
   3.8957247581580257`*^9, 3.8957247984911127`*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"66b0868b-df31-4003-a987-24ff189b1311"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zltMkmEYB3BAQ6xMM6QPMgN1a2qbohZ5Ue+zsS466JZho6A2S8DphdNq
2SK6gI1p67ComWXQac2stSSxC91qLKY12FwHJ6dEUBJFYTkNl52oh//27d27
7/n/nldwoqlawaDRaGV/v/iZiF2uHzyYGiW3O+N5R0hOSZuJlbg7SbckVP05
JUrKy+IJkGuy0j29zMT/ENHM7sy3JUfJfy1Khvdxgy30xPwCOfJU1zb8PUJU
yniWyOMF49blqQj2l4le1JpmeB8hDns8K+TAmE/JeBBBjwZem+qHuD4xT4ex
wYH9Z7kR9JNAFmadu2qex34yVHU87/4onMd9TBBVqE9mdsyhx4JAV9cVUyCM
Xiok+ec15bwwemtgZMgY6989i95a+NTrGAnWzKC3Doqyb9bG6kLoZUDK4d9F
Bc3TOJ8Blgzv3uMXv6K/HrTRtGqnIYj9TIhSDaLV5inctwE6Tx0q1Hgm0WPD
GWnsXpA9iR4bdCUF5UJ5AL0sqOsTv+k2+9HjAG2a08yl/OhtBKv+gmjh0gR6
FFhUS79UaRPoUbDj7rFW3R0felwYOTojFW/3occD2eXCLNHLcfQ2wa4Gahs7
fRy9bKh/1SMWqr+glw1mzlCPNeZFbzNUqc2PBFovejngVBmeOLhe9LbADQtz
tHHAgx4fvtVoS21KD87zQW7MrHzL86DPh37+/fMto27yr14mAJP9GX3xlhv3
CWBuxUHaa93o5cJrJ2OVvtiNXi4wFxXpEoYbvVzQShatjU4XvicPKisUlLTP
hV4efHj40/riugu9fGgqNrdzT7vIH9E9Yc8=
       "]]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1Xc81d8fB3A7sinFV9ZNRovopxTvjyTRUEaKlr0iKlt7IK6VZGQmpZJk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        "]]},
      Annotation[#, "Charting`Private`Tag$209216#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Epilog->{
    Dashing[{Small, Small}], 
    LineBox[{{0, 1}, {10, 1}}]},
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*FractionBox[\\(X3\\), \\(Ki\\)]\\)\"", TraditionalForm], 
    FormBox["\"Supply and Demand Rates\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, All}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, 
   3.8957247581580257`*^9, 3.89572480218217*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"83f6b39f-1bce-42ca-9dac-0e5d87b18ec7"],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, 
   3.8957247581580257`*^9, 3.895724802188532*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"661e57c7-cfee-4603-a7ec-4c94646cf6e2"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 40, 2, 21008643813971916746, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.879238278771265*^9, 3.8957247657704077`*^9, 
  3.895724802894206*^9},
 CellLabel->
  "During evaluation of \
In[19]:=",ExpressionUUID->"c40de7aa-8dd7-4f0a-89fe-97ec22066e0c"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 40, 3, 21008643813971916746, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.879238278771265*^9, 3.8957247657704077`*^9, 
  3.895724802965762*^9},
 CellLabel->
  "During evaluation of \
In[19]:=",ExpressionUUID->"5fa70c10-6a1f-48ec-9e30-aad18d6da6f0"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 40, 4, 21008643813971916746, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.879238278771265*^9, 3.8957247657704077`*^9, 
  3.895724803119471*^9},
 CellLabel->
  "During evaluation of \
In[19]:=",ExpressionUUID->"cd794393-09e2-4a7b-87c9-00093e21d89b"],

Cell[BoxData[
 TemplateBox[{
  "General", "stop", 
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"FindRoot\\\", \
\\\"::\\\", \\\"lstol\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"", 2, 40, 5, 21008643813971916746, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.879238278771265*^9, 3.8957247657704077`*^9, 
  3.895724803125433*^9},
 CellLabel->
  "During evaluation of \
In[19]:=",ExpressionUUID->"bc160a65-ca85-4c0d-be11-84a727e621f8"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zl9I01EUB/Cpczo03a+tubZVblorBrqarpDBPSMQSSyqWW8VbWtklBAS
ZFK+jMK2mDbpj9lDGREzM3DUYFoRWoIjkrmciAm9NOK33y+Hs9GMtrrnC5fL
4Z7zOVdzuv2II18gEBizJ3dj9IJ2na6IJ/fv5TJN/D71c78I6xgxv9aP1Gbr
OmMu30iJoSY5UojvcZK2MC5ttv6v8eSGnQS6hdifJCeUfPV4AU+cZ3JJkYG5
PTMf83E+TWyuW/l9eTwJz+SSIYmXQY9QgJ4AvG8k16QZjvbngYmJOZg1jvoF
EPxT3h3mOTovBCbjckviHN0nguKfzvnHXznqFcPJY95ZawQ9MVy0Rh6mp9Ar
gdjZ0YZLr9ArhUjonOPdE/TKYMevvU3fe9GTQGClLlXehf0SMH9JHuiwo8/A
+cXORnszzm+EDY8+3TTvxn1SWC+r4E/J0ZOBP1pbavqdoJ4M3M96bquWE9Tb
BF1tcz+ckwnqyWF0qX+fw5+gXgUc9WyfPdSXoJ4Crs4HU62d6CkgOOS7cNeG
3mYA+3pUfxA9JTCh7hZlA3oquLy/1eLQoaeGiZ5+UiRHTw0Oo21wtRC9LWC1
HuY0ayz1tsLb0GrjlThLvW1gKKs3cYss9SpB49I+aPuM/ZUgEz21LEyx1K8E
T0DVoh9nyb9xowbCM4yveYyl+zSgMOTN7hpGTwv8ZHg6MISeFuwrNceXB9HT
QnRJ0zFwB/9TBTs/TNQv9KJXBYsG6XuvG71qeCEWN41dZ8lfiYhh3A==
       "]]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1Xk81NsbB3B7icTkp7jZmiRrihaF51uypK4kUq5SkqWy1E3WNiVkl2TJ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        "]]},
      Annotation[#, "Charting`Private`Tag$247553#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.9184304088564803},
  DisplayFunction->Identity,
  Epilog->{
    Dashing[{Small, Small}], 
    LineBox[{{0, 1}, {10, 1}}]},
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*FractionBox[\\(X3\\), \\(Ki\\)]\\)\"", TraditionalForm], 
    FormBox["\"Supply and Demand Rates\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, All}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.879228371267179*^9, 3.879228427331534*^9}, {
   3.8792284658090487`*^9, 3.87922848684146*^9}, {3.879228524931322*^9, 
   3.879228596671907*^9}, 3.8792286455282516`*^9, {3.879228697143714*^9, 
   3.879228725246089*^9}, 3.87922880164113*^9, 3.8792288382408657`*^9, 
   3.879229069200389*^9, 3.879229132946341*^9, 3.8792292030443163`*^9, 
   3.8792292618432827`*^9, 3.87922933045129*^9, 3.879229487057263*^9, 
   3.8792295696934757`*^9, 3.879230908340723*^9, 3.879230994289961*^9, {
   3.879231202440772*^9, 3.879231229104011*^9}, 3.8792313142223577`*^9, 
   3.87923746492303*^9, 3.879238046201539*^9, 3.8792382467531147`*^9, 
   3.8957247581580257`*^9, 3.895724805796418*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"5ed29e6c-f278-4ec3-9ef0-8629abc38af5"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"plA", "=", 
    RowBox[{"ListLinePlot", "[", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x3", ",", 
            RowBox[{"ss123", "[", 
             RowBox[{"x3", ",", "0.1"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x3", ",", 
            RowBox[{"ss123", "[", 
             RowBox[{"x3", ",", "0.2"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x3", ",", 
            RowBox[{"ss123", "[", 
             RowBox[{"x3", ",", "1"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x3", ",", 
            RowBox[{"ss123", "[", 
             RowBox[{"x3", ",", "2"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x3", ",", 
            RowBox[{"ss123", "[", 
             RowBox[{"x3", ",", "5"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x3", ",", 
            RowBox[{"ss123", "[", 
             RowBox[{"x3", ",", "10"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}]}], 
       "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotMarkers", "->", "None"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plB", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v", "[", "4", "]"}], "/.", 
           RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
         RowBox[{
          RowBox[{"optNF", "[", "0.1", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", 
            RowBox[{
             RowBox[{"-", "4"}], ";;", 
             RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v", "[", "4", "]"}], "/.", 
           RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
         RowBox[{
          RowBox[{"optNF", "[", "0.5", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", 
            RowBox[{
             RowBox[{"-", "4"}], ";;", 
             RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v", "[", "4", "]"}], "/.", 
           RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
         RowBox[{
          RowBox[{"optNF", "[", "1", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", 
            RowBox[{
             RowBox[{"-", "4"}], ";;", 
             RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v", "[", "4", "]"}], "/.", 
           RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
         RowBox[{
          RowBox[{"optNF", "[", "2", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", 
            RowBox[{
             RowBox[{"-", "4"}], ";;", 
             RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v", "[", "4", "]"}], "/.", 
           RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
         RowBox[{
          RowBox[{"optNF", "[", "5", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", 
            RowBox[{
             RowBox[{"-", "4"}], ";;", 
             RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v", "[", "4", "]"}], "/.", 
           RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
         RowBox[{
          RowBox[{"optNF", "[", "10", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", 
            RowBox[{
             RowBox[{"-", "4"}], ";;", 
             RowBox[{"-", "1"}]}]}], "]"}], "]"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", "0", ",", "10"}], 
      "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8957304758404207`*^9, 3.895730526744892*^9}, {
  3.8957305611609993`*^9, 3.895730567963171*^9}, {3.8957306321864557`*^9, 
  3.895730633839156*^9}, {3.895730689108461*^9, 3.8957307034207373`*^9}, {
  3.895730737528673*^9, 3.8957307450195932`*^9}, {3.895730776225114*^9, 
  3.895730779909896*^9}},ExpressionUUID->"d0a560fc-c34b-412a-b2ff-\
c96a8354f854"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plA", ",", "plB", ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1.3"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"Thickness", "[", "0.05", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.895730784005084*^9, 3.895730843515346*^9}},
 CellLabel->
  "In[406]:=",ExpressionUUID->"74c307d1-1ebb-4c48-9566-88474225c619"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.55, 1, 0.7], PointSize[
       NCache[
        Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
      StyleBox[LineBox[CompressedData["
1:eJw1zm1MUmEUB/CLsKhJSApCJCJgLxuyZtiaa/mcVrPaXOQFjcAhWgTFjBRb
70vaGG02FrbZTKMPIfYpP9igjVzrxZGFK5hbs1WrrJYzwrJsDqZFnf7b3bNn
9/x/55E1O2hLDkVR6j9f9vyfe/0/QnnUDLnak80oOamK3u3+nsL7BPEscDQC
dYpUqLOZJOvT7vAV3Rf8P0VGa96FCkKfyD9thqRGKocCrLc4P0sc1zYdGX0z
TqwHs5kjG2vbvM86n2B/ntgM5lNDeffJWCybDBEFNFy9K4QeBZP8newDvbdw
ngHVjB7b8mP96DOhXSqlv/30Y58Fns+eGCPVjfuWQP2GdS9yrD70lkIuu3KA
R3WitwzKbA0+tdmNXi4EowzPiSoXehy45N2TeK85gx4Xbge5jeHrx9HjgXjC
7x9htuM8D1x1FpVe3Yr+ClgzHOgVzLVgPx96oxVj0/bDuK8AqrjiUnuXFT0+
KJu07ldbLejxoeaQxult2I+eAHYTp4YTa0KvEG5WK1vKzpnRE4KIFrAb4yb0
RGD6+vC5J9OAnggudFjtfQ4jeitBFnk9MCIxoCeGZPli+FFGj94qkLfE15pY
evSKIAnR5inVXvSKYLZjWJB21qMngaPBwbOKRB16xRBfdPkj2+vQk4J3tfDO
8GMdeiUgAdWOoFGH8yUwb1f6jGkt+iXQta91szioJX/rahn8ckZiFoMW98kg
P6XckinUoicHhak4+fQljZ4cxieGXNMBGj05iBLl2y630/geBTxQtg0Kd9Ho
KeB8yM38KKPRK4UPlTcunl6oJb8B5b1Jbg==
        "]],
       FontSize->14]}, 
     {Hue[0.06, 1, 0.9], PointSize[
       NCache[
        Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
      StyleBox[LineBox[CompressedData["
1:eJw1zm1IU2EUB/Bbt7S5JdPN3HzJbYpoSAZbBPXhORMyKwq5m5tphWtuyzRN
Gq7yJVY6hZy0D1EqGGXWwFCnud7AKNFKNoy5BNmXVcxQB7qJgmVQq9MfLg8P
9/x/5xGfq2F0WymKkv75Iuf/zIfiso5QK6SrM5KPxJMs+8VaXcb7HPHbZ2fE
smUik0byjehazUMOdRD/LxDtUHL9u9fz5J+2QmIEB8fEbD/OrxJWrrxgYsFL
DPpI1smNw7zzi91T2N8gtaEm11LSW+J2RbJJ3FkVnq+3nehRYAiniQ44BnB+
CxRe8c6MNPehT4PqUaVkkXMf+9uAc9Npy6Pu4r4oCKd2rMiNNvR2gLV7X9DL
v4UeC3LGEstdl1rQY4NA5Kn5cdyMHgfy7TY30TegFwt0ddkHy7AJPS48mFwT
fOYZcZ4LjfZ8Jchr0Y8DDm1aaIitxn48TJ2ISe00X8B9PGjcOKoP9BnQ40PU
6rHv7QodenywRleMv6/SopcA7dejS7k+DXq7wDreEs61lqGXCO3sy/JXS2fR
E8D6tas9DQln0BNAtscyqG0tRU8Is/pMZYesBL0k8Ac2J0fjT6GXDHuz1zLv
CYvRS4FmU++T1jw1eimgKbw4zG9ToZcKvlIF7QoUobcb5hT0S7q4CL000BQM
9o/4lOiJoOtLkkpVrcR5ETy2PDz5aacSfRHU6c3Tp18oyN+6VAzyykM5TVUK
3CcGXu1PdShLgZ4EBjLueHuDDHoSsD5/1tbvZNCTAMfIFoKFwfekw3RNfd1o
CYNeOux5ur/cJGXQywBHz5uJ7VyG/Abdckoq
        "]],
       FontSize->14]}, 
     {Hue[0.25, 1, 0.55], PointSize[
       NCache[
        Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
      StyleBox[LineBox[CompressedData["
1:eJw1zmtIU2EYB/Cj1ko2crfM5cptOoMymC38YI33Ec0QljWLeelinU3nFrWm
LW2GaEmLJYGVDbVYW1MryholIcwKdR+kNbspDSNKm9A+6CDIMo1aPf7h8PJy
nv/vecW0sagilqIo+d8vei5F4tZ/4SZESEd7NCPEWSPgZDKX7kHC9PTYBoZm
yVZ5NFOE3ZvBmS6fwf9fiTS/ZSH9V5j81yJkaGpUEu8N4fw34guW35iI/0R0
ldF8J+otfMc1wzj2f5KCwwHf5ccB8tIfzQIxDtsnywQ+9CjIuzURaTQP4HwM
ZLJl0sTYPvTjINf7wH3ydi/2l0F4v/BKw2Q37mOAavNDd4nZid5KGHzReLNP
1olePJiSi3pm29rQY4Jy8FD2THUreizY6cq17va0oLcKiuyFxYofVvTYoFPw
9Rf3NuM8G+TXWc/S6pvQ54DOX7Dpfm0D9rmwcby0x/TZgvt48LrO63Uv1qLH
h64utbLYbUaPD3uytXGOJzXorYZA5j7mW1E1eokgPsdY7AycQG8NHKhv5m7Q
GdFLAnvOG80l2zH0kiBcRqmpuaPoCSDv7PKMOocBvbVwYag/v/W0Hr1k4Lpi
/JEzVegJ4V62j/XOpUNPCB0KxVx/qBK9dfBo4b1DlFOJ3nrwdvvHVJ4K9FJg
WmDlbZNXoCcCW+N2XuGwFudF8Fumjq2iteiLIOQ0vBpgasm/ulwMw6csZv9T
De4TQ0l7lUpp0aAngaujH+bTFRr0JCAd+Th/nKFBTwKC9LmE0jEa35MKM+wV
d7Pu0Oilwq4dKUdMTTR6aXA++DzLepAmfwCuvkyN
        "]],
       FontSize->14]}, 
     {Hue[0.11, 0.9, 0.85], PointSize[
       NCache[
        Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
      StyleBox[LineBox[CompressedData["
1:eJw1zm1Ik1EUB/C5IjTL2TSdutyLyw8mKc3AkXUPCRklKoYWSyLFmRARrCVu
rLRm5Yeao724ueam6BTDdFS20GIwPxjLolWSL4milJvTKZoZjczV8Q8Pl8vz
P79zOWVXC0VUCoXC3/yC51Ziel9OT0YskSZDMG+I+PVy/N3dW/dRoikXJ8tC
l0gGP5gZUk/n/BHN+/G/hyw5zP0ihZ/81zZ7V7yCsEeL2F8hRtf5L+6Aj1yq
CGaNUPTcIZvei/O/SKBE+3NM950Mvw0mQNinpVR39ix6FKj+xMj0rU5hPwQ+
HisO8Y6Oo78N5DkLjiLLCM5vh6rcOW5uvhv37YDY+8oRa/cweqEwrzDLBGlD
6IUBxZlXe3nSiV440M7YC4/KHejtghO8h7+/dfSjFwHhlQNfPVUv0IsEXkWK
g8p7hv1IuCb2tXrkNvT3gH+nSnKj7wnO08HDLXHWZj/GfVHA6pFJUiSd6EXD
RvO7Sn6yFb1osJt6GemkDb29MNhWX9De1YpeDKiuF5cazrWgFwu3xlM5t7Ms
6DEgS5gj8eub0WPAeke1KyPEhF4cuBt+DB5pN6IXD3H5i9PTsib0EiBQQxOv
SA3oMUG6bH7qNOrRY4Jyf5lyYqwRvX3QtZ6X5jjUiF4i0EtPHbebdeixIJ2x
auhJ1KHHhueqA1NR3Vrss8FG09e8OqlFnw2ZH1yiCb+G/Bvnc0D2oE81Z9Hg
Pg7cE9TptUINely46WXphhI06HHhvbXA2zCjRo8LG3c665g2Nb4nCc6S8gsD
CjV6SZC6Jl74LFSjxwPTwaKLs4fV5C8WjGDi
        "]],
       FontSize->14]}, 
     {Hue[0.5, 1, 0.5], PointSize[
       NCache[
        Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
      StyleBox[LineBox[CompressedData["
1:eJw1zltMkmEYB3BAQ6xMM6QPMgN1a2qbohZ5Ue+zsS466JZho6A2S8DphdNq
2SK6gI1p67ComWXQac2stSSxC91qLKY12FwHJ6dEUBJFYTkNl52oh//27d27
7/n/nldwoqlawaDRaGV/v/iZiF2uHzyYGiW3O+N5R0hOSZuJlbg7SbckVP05
JUrKy+IJkGuy0j29zMT/ENHM7sy3JUfJfy1Khvdxgy30xPwCOfJU1zb8PUJU
yniWyOMF49blqQj2l4le1JpmeB8hDns8K+TAmE/JeBBBjwZem+qHuD4xT4ex
wYH9Z7kR9JNAFmadu2qex34yVHU87/4onMd9TBBVqE9mdsyhx4JAV9cVUyCM
Xiok+ec15bwwemtgZMgY6989i95a+NTrGAnWzKC3Doqyb9bG6kLoZUDK4d9F
Bc3TOJ8Blgzv3uMXv6K/HrTRtGqnIYj9TIhSDaLV5inctwE6Tx0q1Hgm0WPD
GWnsXpA9iR4bdCUF5UJ5AL0sqOsTv+k2+9HjAG2a08yl/OhtBKv+gmjh0gR6
FFhUS79UaRPoUbDj7rFW3R0felwYOTojFW/3occD2eXCLNHLcfQ2wa4Gahs7
fRy9bKh/1SMWqr+glw1mzlCPNeZFbzNUqc2PBFovejngVBmeOLhe9LbADQtz
tHHAgx4fvtVoS21KD87zQW7MrHzL86DPh37+/fMto27yr14mAJP9GX3xlhv3
CWBuxUHaa93o5cJrJ2OVvtiNXi4wFxXpEoYbvVzQShatjU4XvicPKisUlLTP
hV4efHj40/riugu9fGgqNrdzT7vIH9E9Yc8=
        "]],
       FontSize->14]}, 
     {Hue[0.2, 1, 0.7], PointSize[
       NCache[
        Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
      StyleBox[LineBox[CompressedData["
1:eJw1zl9I01EUB/Cpczo03a+tubZVblorBrqarpDBPSMQSSyqWW8VbWtklBAS
ZFK+jMK2mDbpj9lDGREzM3DUYFoRWoIjkrmciAm9NOK33y+Hs9GMtrrnC5fL
4Z7zOVdzuv2II18gEBizJ3dj9IJ2na6IJ/fv5TJN/D71c78I6xgxv9aP1Gbr
OmMu30iJoSY5UojvcZK2MC5ttv6v8eSGnQS6hdifJCeUfPV4AU+cZ3JJkYG5
PTMf83E+TWyuW/l9eTwJz+SSIYmXQY9QgJ4AvG8k16QZjvbngYmJOZg1jvoF
EPxT3h3mOTovBCbjckviHN0nguKfzvnHXznqFcPJY95ZawQ9MVy0Rh6mp9Ar
gdjZ0YZLr9ArhUjonOPdE/TKYMevvU3fe9GTQGClLlXehf0SMH9JHuiwo8/A
+cXORnszzm+EDY8+3TTvxn1SWC+r4E/J0ZOBP1pbavqdoJ4M3M96bquWE9Tb
BF1tcz+ckwnqyWF0qX+fw5+gXgUc9WyfPdSXoJ4Crs4HU62d6CkgOOS7cNeG
3mYA+3pUfxA9JTCh7hZlA3oquLy/1eLQoaeGiZ5+UiRHTw0Oo21wtRC9LWC1
HuY0ayz1tsLb0GrjlThLvW1gKKs3cYss9SpB49I+aPuM/ZUgEz21LEyx1K8E
T0DVoh9nyb9xowbCM4yveYyl+zSgMOTN7hpGTwv8ZHg6MISeFuwrNceXB9HT
QnRJ0zFwB/9TBTs/TNQv9KJXBYsG6XuvG71qeCEWN41dZ8lfiYhh3A==
        "]],
       FontSize->14]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {Hue[0.55, 1, 0.7], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nc4l98bB3ArJSFUP5XZJ8keqTS4H0mppJKVRCQyKipEipKvZISQ7JXM
REYkWdm7jGzZ8zOOT/gQv9Mfz/Vcr+v88ZzrPvf73I+YxV3dmyxMTEwL+Pn3
jnliwa5o6acm8D7sW4UvQ63qh6i2oagNJAfGkk8ltMN6damXqKgriO/4OPc/
2QHgDin4uLn7GZQyWq5dZhuBmLIAkQ2ivsC0vaSUq38MZMiWgevWr2CluWTM
aMMk9HPHrq12hcByrt+gScEU7E3hOMRYCQND88+By3wzYK/qdHtR5C1QXzu4
ZCjOwqefQ8kLGtGQsuHB1rdic8Cw0+6jWsdBXeXYqMHcHMQz9/kuaiZA09X8
70+j5+FkU7D4n65EOJQakleoTIbJiNPlCzbJsC+snK5cTAZ/y78maOUdbC2D
k0ICFFBQ+LREDXgPNkOb3NK0KfBj5VYoRSQNAqs3/Sh7RAHnGmEFck46mOS3
7FVKocCu1z8b5jQyQYd9zvhdIwVKTV9az3ZkwUYBb+VkMgUspAjWGetsSEsq
KovnoQLLilvLgvtHOO95m2DIUOHnkL7QgmYOGHDIDzJpUeFhJmcRrSsXKnlr
DXY/pMLZkHF2WvwnkHfpQpEBVBB8WK5HtckDSx2+G4kJVJi/Fp1IUcoH1dJC
skEeFco0XCjklXxQmrIU+fWdCiGSumrkqgK47WF3V7OTCpY8sv7zAYVw3peJ
kjdGhY29vyXmRIqgpuKqP2KmQXfZV6fZySKgKxuUTnDTID0lonImpxjOVWtT
JHfTQOeejtm0RgkoLnKUNCvSQNRIMmtqy1doVRjZf+Y4DWiqbCuTHV/BPj7/
lfopGoRzFIdPWH+DZC0Hk1YjGuS5nL13X6AMbL9blzub0yB6+vBO5F4G6gcD
tb/Y0OBOK581TbMcong6sw670oAvupaF2lUBfW0dFkGhNFjhLkhzOF4Jc2vJ
Qt8iaTD6NOkiJb4S/I09bXLjaVBg/SSWbFMF9bv1olEGDeJ67DTvNlfB5nUX
y9M5NHhx/srsvNJ3GAsmXtoV0MD4gPLR+ZXvoNG5JVSujAYaKWLDt69Xg2mF
5mhbFQ1kdvK8mKuqhlcH1Bx16miwtjbVMRtQA8HztVE9bTRIqI9znBGpg8qj
Af72wzRYiMiXGvSvg1OCDx7rjdHglHXDSPtyHRQgXmWhKRrMsi7qF/+oB+/M
jXEGFBqoqOoc9fVphITCoEj/vzTw47RE7guNIHe38E0sE4KBX66ZDuZN8Kdg
oCKSFcFz53fCRsea4dnEUxl9DgSt2assEuQWyFwofT7Jj4APOEy55FqBx1L6
pcUOBMf2hR71sWwF8vHVwkYBBIELacitrRUUjdf67wshUA7uuGmR0QZGJR0c
gvsQmD68fqJvuA0qY8+q79uPwMdsRthAoB12WHZH7ZVC0CPL3H3Gux3qfy/r
rMsi8KiXOato9gNm7BybDh1EkJpTuC8j7Ac0RWdcnz2EoD3iBKt44w9Q3iDf
FaGCYK+1UYnAkZ/QGRfm13UMQT3rczkm/g6IcWjWQOoIFqa5Od3OdACp/sMR
aw0EQu1vJ5BHBzQk7ub4eRKBQ3x2/MRsBxiYlrK+PY1gh2ovX0t1J5zQLkzt
0EZA7LUia/3tBPNaj+LtOghsOKkNFQe6oKX//faLFxCU/GL3Lojvgl8n1tTz
LiGwcFZajHHrhtjwbWZqBgg+ZPv22sv1wKgNccnJFME037T/WfMeKEkR9bhi
hkDC+aza/tAekBmQMjp6HUH8cc6EkeUeGFA106eZIwip87cy/t4L+y8MWqje
ROA88op62qQflpvU3M/bIcg9RUkUf9UPgcbGLGz2CMhpF/VYK/pB63G0+Gfs
Ww68haUSA2AvPnRv5x0Exn9D3A+iAbhf1GRR7oAgjrPBi1dzCFrF3vhmOyFQ
U31k4mk6BDE24T0nnRH03ZE+SHYZgkxheetubIF2v/HG9CHgLZ/VZbggCI7Q
PvNi6zB4X8nWknJD4CXezL3eOwwGXJQK4gmCPYZPJm7Th4Fyaa/MV+yyF3Jl
fdy/QfYrs6qKB4LVmUDHYvXfkL6vzU7KE4FT7oWfTu9/g575YvD6UwTW0PZ2
9t4ICLWkaTl6I2BK/FPc6zcCit/rHnVjR7AJ9tUnj0DfBdEstf8Q1NZZCad1
jsBBuxs7N/kg2K+3mnjz6Ch84Jx2f/UCweQticwB5jEY6ec1ve+HwLNBu6lp
1xikDzzlbcQWkLs3X3JgDESk7RZJ/gi0UIlC1M0xuK5fdLMNO+2xbr5h3Ris
cyzuIAUisA15XNoaNA6znrYrSUEIWOiJg9/SxmFGv5KDih1pWMuUXTEO66ux
jqrBuD8F+TUCFsYhi+WYwU9s6fepNWeMJsDHNjaDEYJg9suP1gqRSZj9W60g
HYbgzpjkSN6HKehyCbwv8RbBkOmvTeV1U3D4Wu6hW9iXu1/INY1OwQt7xQep
2CoNE65ju6ZxndMtJSIRsOa827rDZxp+OzGfFonC9XIXU3Mxm4H9/GJXlqIR
lPPvfHtk6xyUP5HtMorH+Q2oLdWUngOlo2Ghftgp7A9HL52ag8NSavSv2P7L
nfK27nPQGKGZLJaAwGAwtDpycg4qIlh+jmJPp29dWCmbB8s3TKeuJiHYLPZc
YlCFAnIR2crcKfh8jgfLP9GkQL+d3EVl7P+MYg8L6VJg5s4FRWNslqDPp6/a
UcBLKeDUO2zG2qx1VwwF8o4rN6i8RzDTp5/awkKFHC7ZdP1UhPchIVnWSIX1
e8MDNukIXuYpK5r9ooL+3eEwX2ytVvUja3gu7XvmL5qGXbXR5MzxdSp05+nn
TmCXOAfZfMZzZ1HxbZtFBoIsveW0j+E0YNyYPXspE99vWxukEnAuK2P/GPN+
QFB0WChfB+dIOEnCSg571PQurD7COSod1zqHfSyLX8/wDT4XfbPw59iTZ0we
czUjSDRWMaZja3jNtbgeWwCVrNT6lmwES3QeJ90ddFDxrzhvm4OAJGSxvk6i
Q3jpYP8zbJ2Teb5ZinRw9/TWicJ+F2IUu+k8HbyuXm1vwNaVT6gp9aKDYHuS
rXQu3v8tpV3SVDpQ22/wjGFb9Op9Y238A2Ta5yiNPHweUcO3HX/9geY0Xk0j
7FzjO4KD43/gfKxxpz02a4+PazHzIuTFWOaEYSd3Fx9wPLwIFPeu8+PY4x2i
qQOJi6Aes3rCKx/3f+tsUJHrEmRax+3JKsDzIsgVJHyWwKrw/rZv2MUX2OdD
Q5cgWrmJ1orN2SJyziF7CejcgU4L2JlNuhskxvB6V2b40UIE8/WfXUMvLoP5
4zzzSmzH788t7kowQLqHabjmM6776Cn2PwcYcNHnV0AndgMLR7o7wQDTlmqZ
MWxxIoDqe4UBdYJy6ixFCH4Vh3km+zGghfNi9TFs9Y8psb/IDJg6fkc3E5s3
qrZH4/MK6F/xInsVI8hx2HJZ4MxfWL7tUbW1BPdXJL9rlsFfMJXichPCHq/a
FXfCEq9vnyVJYe/aKTlj7/EX/LP79TSwn5drepXn/4VbjLOyTtgGfB6fbPes
gbdG3fdObMYnKv/XlTUwFMlcCf6KIOGR3bSCIRPRM2VjOlOKQKGMY8nnGhMh
9rx/cgG7jC11w+ANJmJPwZLdGvZQwKhogAMT8SD/tAnvN1yP+GuGU75MRPxu
pfFD2JFVF6oSSpiIjeumKZ7YIVzKsXx7mInrnT+5ecoQPItbvbQwy0zEvZ/h
3VmO79MfQ0SJGyvBlTLDM1qBYN8Dq4d6UhsI33iG6Msq3N/0NwacX9kJSeVX
eb3fEZwds30c4riJKP3cmS9Qg/tzNEhaWHgzYWZbUi1Ri/NfaeFZm8VJcO3K
FNxYh0COt1NIw4yLoKT5vR7A3gx08z7ETXyS0XgYUo/g9Jzx4h79rUS3v02D
egOC7gpLZmMZXoL9mji9Dzv/RZWpKJ2X2BRMTrreiMBqg9NQczMfobQtZeMI
9o17j/K3RPITXNWKobpNCOStpZu1zbcRtTUOzwuxW/hkOJ2ObCceOu9KF8Q5
/PLhWZQM6w4i0/kq7wPsR8xSFxv7dxBk+QzmRuzNfW5ad/L+R5B7i+UFWxCM
pYiFxrkLEGTp5Y0W2KH7d7IV6e8k7O69m0zFDoq0qjEX3UXkJ26dG8c2Dr3W
vGViF8HJpiIv2orzffLdclzpbuJxrGuuMfbI2ImHFT6CxKjG/+QCsRNVFXc3
mQsRmha2vyuws7ydeK1lhYmBaFdbKraP/o1zrHRhQudAVKFgG4KDfQlpPk0i
xHbTrjNnsCMko7KazokS1789anLA9igLiDhXJEokHNzi/Rb7/G79d/V7xYg3
H094f8NWv1NzlddXjOiM9tEbxo4TtNjbSBcj+DbrXGZrx/9Tle/Dda7uIUhW
1r4k7CDZCqn20j2EM1NKD4Fthdja6qRIhOQ290tm2BY5NFHfVyQi2qT2lRu2
/bPLq2eDSYScNZX9EbbT5byuLa9JhBbfhif//ILuFBgUTiL4zWft3LE/HFle
eRNDIhyefjn1BHu5fL0zJYNEiNVfX3r67/vtWwKqakjExOL8OV/syKTbt/6r
IxHHeVzK/jnpQbOGVgOJEHk0rfwSu2BHEKOhmUS8sHot5IfdZ8x/60cHiTAX
n5/zx5YY2anxe4RE2G5qfBmErZDnJpw8RiJ4ljjX/vmod+/yzQkSceH1Ycdg
bG2JmI9T0yRi7+9LhiHY9+xEhalUEqHg8npPKLb78afLuYhEdF1RDPtnb67f
Px/QScQU35eNYdgR2Ul+S0skIlQoZPafEz3ZrIsZJKLOddA0HDvj0s0T7qsk
IrlcoO2f8/ZUC6mtkYi7DFWNN9ilaN8yHgjEfckL+f/8f4S58SY=
        "]]},
      Annotation[#, "Charting`Private`Tag$1851257#1"]& ], 
     TagBox[
      {Hue[0.06, 1, 0.9], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1Wk4VW0XB3BTvUkplAeZDykapHo0sbZkDEWkJDITSUohzYQnCkkiyZgh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        "]]},
      Annotation[#, "Charting`Private`Tag$1851257#2"]& ], 
     TagBox[
      {Hue[0.25, 1, 0.55], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1Xk41UsYB3D7TZYrbkL2Q9KCpCuS91eSrVQSEopEKkIhkjaFLCFFluwK
SQrhStayr9kJ2Q/n/MZysoU7/THPPJ/5Z+aZ+c77StlcN7rEwsTENI/HnznO
x4Zjj22gpuU2VU4XsV+alW2Sx0wlHSBo8tmJcu4mWP9a8lBS0hPOC4jdCJLt
Bt7w/Pcbux7AhVXejo6cAYgrDZZglwwA659hOUr7f8Iu0jZk3f4phHkuVTux
jUA/76u1353hEMOzxqLjOAoyaZz/Lq88h5qt1zVrno7BtYNujgsSL2Hhhn/I
B59x+Ph9MGVeKxZ+CsmtJh2dgOWrx/pm7OPBfUwn7SqagATmvoAF7URguuQZ
aPtgEo40hMn+6kwC/+8CLBrMVJiI0imbd0gB1zeHIz2dqRBku2oxt5IKRDjc
bGulgpLSx8WZ4NfA/aTho/2OKWhbuRyBJNLBTf9a7/CtKXD/Jq5E5mTA44nl
5IQvUyDy7HsdTestdKF/pvLWp6DE6on9dHsWNOtaHuFUnwabHQTrlH02vPRt
qza7Pg0sK15N897vYdPVcjWthGn4PnhGbF47B+gupIphwzTcestVONv5AVRd
Pql5idFAP3yMYzbhI3AKeA0YHqKB6K0y4xmHXLj/hBry3oYGdMvYJKScB7Kw
0bn/Pg1KtTwQuZIH2WRjPlc8DcLljTTJynxoj/3w40oRDWz/3h1ED/4EX4NN
smS+0+Cv3p9yNIlCEO2YSFZlpUNX6We36YlCGFN2iWkUokNGWlTFVE4RGDQk
TGjspoOhq+F5qlYxOAbMKS0b0UHSTD5rkvszoE75IWdbOsweZFuZaP8MDwqo
fbxudHjBWfRi3P4LED+et/1+RodcD33XG0KlwEgO87BPokMsVVV4zrsU+g5y
cyi+p4NTM7/9rHYZhMrKG6zV0IE/tpplprMcXrhRN4cv0GGFNz/dWaMCAlL7
5geYSRi5n3wSJVTAjROZVbVcJOTb+7wiHSqhodntS5A4CfE9V7WvN1aCeQh3
nqMcCf7Hz07Tlatg/WrD0XVFEsz3qqjTV6rg8m49oyMECVppUkOOF75CIcG+
c12HhF3Cf/vTKr9CaZWAg+cJEtbWJtung78Bs6G9SYElCYm18S5TEjWgCq+e
ZHqQMB+Vt2MgqAYuxiqIKPiQcNS+brh1qQYyHdbjvH1JmGZdOFPUVguZW80W
HoeSsP+goXqAXz383cgSEZhGQiCX7Zz3fD2ki30OTs8k4Ue351tn6waYVH4o
n/yeBF/3VHGzA41geYdvl2IRCc3Zv1nkyCZY8Ai0baojgR84rXgUmsHyGvsW
1ETCgW0R6n62zVAQpWDzq42EkPn0Oa+WZvAX3B//qZcElbD2SzaZLcDVaKQm
SyXB6taFw31DLcDB9jkikEaC3/kpcROhVtCgZe74gUjo2c3cpfeoFRaDU97o
L5Bwt3aX/p7zbXBv9vnYG2YEb3I+bct83gZG3r6Bm1kRtEYdZpWtbwPpJL8o
LzYEMvZmxUJq30EzqrBL4S8Etay+CkwC7WCxtQhpcyOYp/Jyeem1Qx4fffw2
DwKx1pfjc3fboSCwYjKTF4FzQnbC+HQ7nLiLCpf5EAge7OVv+toByV7V06ab
ERAydqTuagdYOzFSbQQROHDN1JXv7YTZet3Yy1sQFHdzPMpP6ATiXnKpnTAC
G3flhTivLniXuHm3ohiCd9kBvdcUemDK/VH8XzIIqPzUIH3rHmB971dVhS3n
rq+5PaIHFm26ZO7LIkjQ4EocXuqBS15l9eQ2BOE1QXbmVb3w4bCS6Tt5BO7D
T2d0LPrhuJp86X8KCD4cRUmyT/uhSeVyz2lFBGT6SWPW8n7g045bmMS+7Lzp
U4ncDzihe9qGbw8C89Vw731zP0DxNlo7uhdBPFfdw03agxBllltto4pA8+Bt
i3tWg8B1tvDfAew+p537SI9B6Egp2Wm+H4FQa+BYfcYgsJyHKgM1BGFRx/T8
+YbgsX+HnfgBBA9lG3nXe4eghNXK/bEmAmlTn3FHxhA8YScodOxSf4XSPt6f
YGakmGMMCH5PhbgUHfoJAtwJD8QJBG4fTnx3e/0TjrgaeKQeQmAPLS+nXYfB
56W5mu8RBExJv4p6A4dBfE5JrQc7ik20rzZlGEI27LNR1EZQXWMnnt4xDHnz
6hqd2NuNfyddUh+Bp0YStmI6CCYuy739wTwKNrut5h/pIbhXd6yhQWQU4n1k
B5qwhRRc6cV7RyH22mtxYX0EunPFSjGXRoGliz81HTv9jlGeac0oxFR946kw
QHAl/E5Jc+gYbNX4Idl9HAELI2ngS/oY+HlcMRU2RBBtWs2UXT4GbP+qsZ7F
rhUV0AqeH4POqudlHdg7X7/5pmc2DreHbm6oP4Fg+r+25nKJCegODpSKP4XA
aVR+OPfdJPg8UjGbMUYwaNW9oaxmEmRytpyUO4PgdJe/QsPIJLwwiO2ywN5f
N+45KkKFwryhhK/YrDmpfIJ+uA/pRio/N8H35S2l6XF+CjL6xq5KmCEoExB+
qcZHg29xIt9JcwQqwdUl2jtp8EzqqajIOQRpHLdGTh2lwRB/0ZYj2EFLHYpX
vGnA3ustH4ltMhDxNXqCBmth/7SoWeB8Z/DNr5TS4UPchR4XSwQbpXzlBnBu
2rRjE3LO4/fRCFP0we9yaKecTQv2Y7NXqmJGCJZjeOcQNktogc65q/jfOmf7
Kl7A62vT9p1xCDLYBW9kYE/1nXnTxDIDmkZ6nZHWCOqj5ORL62egS4XD7PRF
BE9yVfac756BT6/bqhyxdZsPqa2NzoBxQTavP3blXxZ6Gusz4NjzTbkYu9g9
1KFgzyyo9+fXS9siyDJeSn//YhZK06ceT2KH8NXtSLwwB1aJipNWdggKVcXy
DJ3mYP3lNjEP7BGr6/D79hwkmDsoPsU+kCVgbBo5B456VLIEe0LP4g5P4xyE
eJlNiNoj0HpIa/I8MA8Xe++iVuxFxt9uRoIMqOxi2yDvgIAiZrO+TmGA9z9b
7h3ENjySG5C1hwEGXqj/FHZquNmrDccZ4HGyzMAL20gx8VvJQwbUHj/AqMHO
uqwssnOGAZEhLOm2V3A96jX+wlr/CyybdKr98b1ujBlydOn+BcKx3EzR2B/M
nUQHxn5B27FKSiY2a4+fZxHzAuS3Rio2YKd0Fe11UV2AUpUQC75rCMbaJd/8
SFqAC93vtz/DvtI8HVrouQjKYxU2gY4I+EM9Qc5vERhWyCQau+gEBz0iYhGk
dg+pp2NzNUkYOGcvghu/Z+tX7LcNRuxyo4vgnGaixeyEgF5b4BlxcgnYNv13
6Aa2S5WvzXW5ZUjnVDc5dh2B+MhRjl97l+E8gxpqhl3HwpnhTSxD4iWWUlts
WSJ4JuDsMvRHpa14Y3cXPb+XErgMYvQA6lvsQ+/TXnWTyzC2zS93ozOCTTHV
PVoFK9C2f9i6BDvHmfu0kN4qTLqu8nO64nxFC3hmmazCy8/aGQLYY5Ui8Ydt
V8H/Q4uqOLaIsPzUtburcEaUum8vtm+Z9sOyvFVokQ35YoFtwn/34xXpNSjf
PiDwDnv544zA55U18Cymbda/gSDx9lWqkikT4dA2OO5wE4FSKeeinyUTwVqn
2euCXcr2hn3gIhMxUH6n2hN7MHhEMtiZiZAcKQoNwBZPsDSdDGAiqsbnu95g
R1eeqEwsZiIiTCwNx7DDeVRe8UszE8ZKscsWbggexP8+NT/NTKh3RL5Wd8f1
tG2QKPZiJc6o35Yt9ECw7abdLeMd7ES29ny/kCfONyPShOszByETP7Nb2QuB
/uiVO+EuGwhTP6uz6rdxPkdCd4qLbySKTj3SEPXG/7/C5l51FhexrEuc7cBW
2NQhpnWeh5gRrhoLuIPzBwzrvjleooyzr0nCB4EOzXxB+gwfwX33JDUHu6vc
ltl81yaC3hqjuvcugjz/SitJxiZC0rBxLgHbjt1tsLGRn7hluTWW5x6Ci663
87ijBYi1UvGwK9iK9jsbj1n/Q5wLePquBLuJfxeXm9pmIvL7w0X++wj+e/cg
ZherIOGV5Nl4Dvs2846T9f2CxPDBNMFU7I19XrpOuVuIhUvx4+PYo2lSEfHe
QkTb77Kt0g8QRGwXZis8I0xUz8MuS+zQaLtv1pIiRNLPgJ5QbPMIy0bucRFC
5E5sWCn24pHUpfiSrYRE0hHjGezh0cO3yv1EibdqBw6IPkSQdHDP1gZrMeLz
5+ptuthZj9w22e8WJ7SCbtKcsP3OXDRgZYgT9Bp21mfY+/oS0/0aJIgHyg/k
CrCj5GOyGgwkiSHOXZu7se+WBkcZFEoSumnXWVewj289k1orI0UE6Wq+E/HF
+Xf6dm5TgBTx9DTZ8y92vKiNTD1DiihYC2QzxpapeP3C8Jw08TGfzuGEHbq7
fEdriTTxQvuo22Nsuzm2lpodFKLY+WhXPLZNzqxkwFMK0TspH5SPfe3B6d/6
YRTiaoY7+cdup3M7uZ9RCNeYHKNP2P4Mt5DQFxSCR3pWqAD7ndrSSmQchdiu
8yqlEHupbL0jLZNCrAm9Lij+s38rd3DlNwoxUh7TVo4dnex4+XENhbhc+Eml
Ajv5ZqOWbh22e/nzP84XDF2ua6QQO0xSTCux+8wFLre1U4joXdE9Vdhyw8Ja
P4cpxJCCUX81tlKul3jKKIU4kW1xsAZb/VHv0qVxClGhaRL3x8fk4t5PUilE
ZqygZS2261VJ8ZkZChHQUt9bh+2tcX/pwxyFOKZz8kA99iOen99vMihEGVke
/cdR2cmBi4sU4j7V7WwDdtI9NvuiZQqRrJ1f8MeZpy4d9v6Nzzs6uqURO1f6
q5jmGoXwaWDz+OOSuW1LuCEQHKwCHX/8P58Ix6M=
        "]]},
      Annotation[#, "Charting`Private`Tag$1851257#3"]& ], 
     TagBox[
      {Hue[0.11, 0.9, 0.85], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1Xk0VlsYB2BTKqJQEjJ9IkMo4SLeI1QoytgVKomiJFGRyr1yEQpJ5ilD
RIYQikyZpwwZC5l9wznmz3x3f5y117P2Wnvv9e7ffo+o7R3j60wMDAwL6Psz
xj2xZT1qF6gZa8fP0NW2qFnTKXLWQuQmSHGM9TUktMJWbbmPiIgH7PA9/9ag
pRc4w4py2Xr/hQ7tZ9tiTg5BXEWw8DaRACg9dSYI6CMgi9u92HJ4CVv/VdnL
lY/CT874zfWeMIgNYlPfKzYO4mk7lVfXXkN+tct0NDYBtzTcby8LR8HstQ+V
GrKT8LFrOGVBOxY6nN4/cZmdhFWns4OzDglAt1vXH4+cgkTGwYBl3SToTc0e
+3l4GnRaQg8t9SSDj8JTRXrqNExFnq5cuJkC6d4hV3N4ZiDIbsNqfi0V/jOi
8OS6zYCCwkf6bHA6iLo3L+1pmoHOtRvhhHAGFH/XyfLgI8P9OiEFPC8TzHqv
KWrakIH/VVcTVTsLuJTDXrnGkaHc5rkDpTsbvseWqa38IIOtNMZMdsiBV2zl
acHsFGBa82xb8MoF2yNFTs3qFOgaNju4oJsHnHsfG6veoMDDLPaSuZ58GDHw
XDH4RAH9sAnWucSP8Erz6VByPwUEH1aazt4sgC+1zx1erlGAZh2bTBwrBEd/
zyFDfipUaD8g8LVCMOFmK+NVoUKYlLEmXlMEIYa7u/cZU8Fu95EgWvAn2Ncd
aunuRIXtA78lqcIlcC69V2A0igq9FWXulKkSCL2vZyiXQ4XMtMhqcl4pFK8H
TJpWU8HQ1fDyjPYXkDykURY8RQWRi1LZ07vKoAS7QapbocKcBsvaVHcZ7I1I
a5Fmo0HEztKISYevwLuKq2QdpkHBA33Xe3wV8LXwkfaYMg1iZ1QOzHtVgP6H
IfdHOjRwbud2mNOtBHMhfwnCmgbcsfVMsz1V0Fpbvj76nAZrnEUZLieqIbp4
PY/jNQ3G/nl7nkishgdupQXd8TQocngSj9+sgVv32vrM8miQ0O+ke6e1BsTC
rNP2l9LA/9zfFNqxb9DFWXgosIoGlorH1Whr34Bu0b7/TQcNtNNER25fqYWt
9qI25X4ayB7Y7U+tqYWszsy2iBEabG5Od1OC62DInF72FqdBUmPCXbJwAyio
xw+p78RhIbJQeiioAaS9TCLSd+NwyqFptGOlATwuzS4P7cOBwrxsVtrZCDF6
WbsrRHH4S8NQLcCvGfjq79o/UMEhkN1u3muhGaQXqh19TuDwq88jy+VqCzj6
Voc4aeHw7H6q0EX1VnistsL1Qx+H9px1Jkm8DXqy0pz/ssKBG3bacMi1w22l
2BT9KzioS4Sr+dm1gzsrue2kHQ4vFjLmPb+3w0kst3vKCYfjod3Xbd9/h/BT
S80kTxxsHl45OTjyHXg/dqo+eYyD32WykDlfB0icjpL45o1D/xHGXj3fDjAB
6QMCfjg8bZTVP3q5E4R8TLfTw3B4l/dJ4v3rTohJLL1Q9xqHjsiTzIeaO8Hc
IyLJLxIHcYeLX/hUuwDfZJH8GYdDI/MzOQaebnh7yyd2Mh3Vb4aT3VOvG167
A7tBJg4HO6Im5592A7cKV0lyFg4uiTmJk5Ru4BF3l1DIw4FXY4C7rfYHaJ1x
nWkqwQETt8fPbPyAS8mpu/o/43CTfbapSrEHXFhCG3+V4fClj9W3KLEHyvcG
87ZU4mB7/9hynGcv+Jcw2mo34PAhJ2Dgllw/RBeYqNX8wGGGeyZI/2o/2L3L
NlLvxUHyvr7m4fB+eEcXIWf14ZB4gj1pdKUfmHytj3gP4hDWEGRv+W0AhOvY
t6ZHcLg/+nL2tNVPwCPvWY6Qccg/RSQfevkTjGRNrnFQccAzzpsyV/0EvjEe
byUaDjdcuD6VS/6CievLJz0JHCw3wryU5n9Bygz/fM8CDgnsTT5cusMQUsGZ
O7eOg6bGIytvm2F4x/VJbGoDh0FnGSX8wTCIHy7K7t/Ega8jcKI5cxjUit0S
LzEQEBp5Vs9/zwi4Cl4blGQiwOdQK+fWwAjshGvLPtsIELN4Mnl7cQRecTr9
NYNc4S9XMcj5G0RV7tgYsRKwTn5xt1TrN4QdjXDi3U6Ae75Rl3v6b7jfJMcS
uYMAB/geRXEdBfJc+Mdb7AQwJC+VDgSOgsZMlG8lciSL4GBjyihUBZT77NtF
QH2DvVDGj1EYiczZ8xn5sOl68nW1MejZR/m6zkHA1A3JrF+M4+DWc37Qag8B
3k1nW1r4x0FxNbs6FZlPzpX2RXEccluFmGjIZ+a/KMRcHwcfinGwFxcBGY+N
Cy0axkHV2pE/jJsAx7DH5e0hE7AqJTGQuJcApsXkoa8ZExBcZK4wjBxtUc+Q
UzUBQrm560L7CGgU5NEOXpgAN4YKxhhkmfR3dXoXJyFQq50cxEsA5XNne5Xw
FETWRsf9zUeA87jUaMGHaXhce0M2UYCAYZu+HZUN09D2esy+G9mk11+uZWwa
mj74K7IJEvBX06THOP8MTI+/8HdFZs5L3cPrNwOtcoa6mgdRvbxENR9cJkNX
Gff+aiECKnkORKnuoYLCjrX4AFECjgfXl+vKUIGtlM3kI3Ia68OxC6eoELF/
uHQQOWjlh7yjFxUEpg9kyIkRYD4UXhuN+nbLQt++NuSZzD0LaxU0kM9m72US
J4BN9Jnk0F8EVA+8KlGTQPdzIlT+iS4B/F3v2S2R/7sYr3LQmIBwtqYjHshM
IcWnLzkRoHyre7QIeXWT4tATh9bxahFTkCSAPGj2ro1pFtL9funyHyagOVJS
qqJ5Fkr2C+W3SRHwvOD40ct9s0AplK6eRj7TrqW6OT4L45F1OczSBNRst9I7
sTULpgK/BVWQv9wPuVl8dA6ifn42jEXONl3JyI2YA6h/anRFhoAXe5qkk67M
Q7621at2WQJKVA4WGjrPwxNdW9cp5DGbO7D+aB7ML0orMBwhQD2bx9TizTyU
4Xv15JGn9Kwec7TOg4VS8XIgsrYPtc1DfQGyUln/ATkC6Iu73Y15F+HE4aXJ
EHkCSAdtt7ZIi2Alc4wvFdlQpyAg++gi+FwOlStBTg27GL/j3CLYSD7lHEE2
lk+qK/dZBNsn1xPlFdD5bxzjl5ldhKQeDaV6ZNsB06/MzUsw6HnWZOooqmPM
yO27fUswx5FiuIKcb+ksODSB5kePK7MdQ3np9/MoZVyGQ5OBjTLIKb2lindV
lkGHXMHujDzRLfLuV/IyRNT07cKRHdspISUedLAMrh4aVSSAO8QDJP3oEDXl
ljCHXGrESgsPp0NxKMmI8TgB7G3CBi45dPiRMvxECDmrxXib5Dgd6p+liF1E
pjUWe4SfX4F+bXpIPfLdb89s70iuwrR/3Pt4JQKExk6xLimugonctc+ZyE1M
OzO9sFVo5ij+WoR8CAueDfh7FST+Pp/WitxX+to7JXAVrINXKRvIWrlp8X34
Ktj3tN22VCaAK6a+X7t4DbZ7R6SwqxCQ57LLhE9vA9oCDrZcQLltjubxyDbf
AGMvNbBCnqjhTzhptwHbdMrS7ZH5D0iRbz3dAHs+KatHyM8qdX0qCzfg3to2
0xRkc+6nHx3FNsHVbPr5AvLqx1mesrVN+N1z7+YLVQKSHjnNKFgwYIF39fQy
1QhQqNhJ97NmwEClQiQfuYLl3bahawxY6sMjcyXIw8FjIsEuDJjVie0+DchC
idYW0wEMmCzvQ+sp5Ogao5qkLwwYOUh+TVydgDCO4/HcYoyYbscsazTyvwnr
FxYojBhL71yG2wnUTzuHsS+ezFh+94NpqgYBEm72D02lt2HaL0LazgDK9+Ib
c/YyVuyj1GkdG4wA/XHHx2F3d2B2km/abbVQPsdCZISE2LB7rmvRWifR+6+2
9a7PZse8ngRKryDLcf04qH2ZAzuVOqOVqY3yB4tXB+c5MfuGUUFNHQJOUy2X
xcz2YPuXI5RbkXur7BgtZbkw8n6+8nOoTxT619iILHJh02syKyXI9tvch1tb
ubHXxWLih04RcM31UeGuaB6sOGG6wxtZ3kGm9ezVvdgik0RDJ3Ibtyy7u+o+
TCBXjyxxmoDPH/6NkWXmxWLaEyudkR8xSp9v/smLbUzG7fiEzDboeca5YD/G
HMCH05HH00TDE7z4sJcvlsyPnUF96vABlhKzA9jNGOnIW8gh0fZ1V0X4MbLl
3tAEZMtw69Zdk/yYzKe8xFZkuk7qSkK5AGbkq1q8iTw6fvJhlZ8glsWQsENK
j4BkjaMCLVcPYmKDOyxNkbN93bkcjghh62nxkZ7IfmbXDJgXhTCD80Hy8chK
g0kZfi3CGOvFD9+rkCOlYrJbDESwcyt1BqPITyuCIw1KRDB6x1IViz4B5wTM
UhvFRbFQ4+RNErKWc90lrgBRzFjKtR6QEwRtxZsXRTGuzcJAK2Tx6vQIw0ti
mMzP9mP3kUOOVEl3lIthqeGOBi+Q7edZvjdIk7AFHWOzdGTbvDmRgJckTLzQ
v6QM+da/Juv6oSQsbemhQDmyu0lBz65XJEwk3eLxH/svur8IiSBhow7D2Ffk
D6ora2/iSJgvRbiuAnmlcutH2nsSliRwqb36z/4du4Jr6kjYP76/uxuQo9/e
vvFfAwnjzs5QakR+69aqfaaJhL3qufz6j4t4Q1abWkmYy+ko0ybkQUueG53d
JOzrHq2OZmTJ0QPav0dJ2E2lG41tyAoFnkIp4yQsLk1Uqh1ZzXdg5fokCTtr
2+j3x2cl43KnZ0hYY+O0zndkVycRodlZEhY7cKW8A9nrxD8r+fMkbK/ga8FO
ZF+O311uiyRMpbHY848jc94G0ukkbNW7VbkLOdmbxaF0lYQZh1WE//H7C9dP
eq2TsAax5Lk/LhCrPai5ScI+Kd87341cPi+xgn4I2L0OxQ9//D9r4rz5
        "]]},
      Annotation[#, "Charting`Private`Tag$1851257#4"]& ], 
     TagBox[
      {Hue[0.5, 1, 0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1Xc81d8fB3A7sinFV9ZNRovopxTvjyTRUEaKlr0iKlt7IK6VZGQmpZJk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        "]]},
      Annotation[#, "Charting`Private`Tag$1851257#5"]& ], 
     TagBox[
      {Hue[0.2, 1, 0.7], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1Xk81NsbB3B7icTkp7jZmiRrihaF51uypK4kUq5SkqWy1E3WNiVkl2TJ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        "]]},
      Annotation[#, "Charting`Private`Tag$1851257#6"]& ]}, {}}},
  PlotStyle -> Thickness[0.05],
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 14, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameStyle->Directive[
    GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Prolog->{
    RGBColor[
     NCache[{
       Rational[223, 255], 
       Rational[72, 85], 
       Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
      0.7843137254901961}]], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.895730787800516*^9, 3.895730807536088*^9}, {
  3.89573083879393*^9, 3.895730844142931*^9}},
 CellLabel->
  "Out[406]=",ExpressionUUID->"fc9d51d7-3c13-421b-befe-921e623f606b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"pl", "[", "S_", "]"}], ":=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListLinePlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x3", ",", 
            RowBox[{"ss123", "[", 
             RowBox[{"x3", ",", "S"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x3", ",", "0", ",", "10", ",", "0.2"}], "}"}]}], "]"}], 
        "]"}], ",", 
       RowBox[{"PlotMarkers", "->", "None"}], ",", 
       RowBox[{"PlotRange", "->", "All"}], ",", 
       RowBox[{"PlotStyle", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
          RowBox[{
           RowBox[{"ColorData", "[", 
            RowBox[{"68", ",", "\"\<ColorList\>\""}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "->", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(x\), \(3\)]\)\>\"", ",", "\"\<Rates\>\""}],
          "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v", "[", "4", "]"}], "/.", 
           RowBox[{"rateeqsNF", "[", "S", "]"}]}], "/.", "parmNF"}], "/.", 
         RowBox[{
          RowBox[{"optNF", "[", "S", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", 
            RowBox[{
             RowBox[{"-", "4"}], ";;", 
             RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", "0", ",", 
         "10"}], "}"}], ",", 
       RowBox[{"PlotRange", "->", "All"}], ",", 
       RowBox[{"PlotStyle", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
          RowBox[{
           RowBox[{"ColorData", "[", 
            RowBox[{"68", ",", "\"\<ColorList\>\""}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "->", "300"}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "14", ",", 
        RowBox[{"Thickness", "\[Rule]", "0.0025"}], ",", 
        RowBox[{"PlotTheme", "\[Rule]", "\"\<Marketing\>\""}]}], "]"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"LineLegend", "[", 
       RowBox[{
        RowBox[{"{", "\"\<\!\(\*SubscriptBox[\(v\), \(demand\)]\)\>\"", "}"}],
         ",", 
        RowBox[{"LegendLayout", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Row\>\"", ",", "1"}], "}"}]}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "12"}]}], "}"}]}]}], "]"}]}]}], 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"pl1", "=", 
  RowBox[{"pl", "[", "0.1", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"pl2", "=", 
  RowBox[{"pl", "[", "0.2", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"pl3", "=", 
  RowBox[{"pl", "[", "0.5", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"pl4", "=", 
  RowBox[{"pl", "[", "1", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"pl5", "=", 
  RowBox[{"pl", "[", "2", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"pl6", "=", 
  RowBox[{"pl", "[", "5", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"pl7", "=", 
  RowBox[{"pl", "[", "10", "]"}]}]}], "Input",
 CellChangeTimes->{{3.89573149904875*^9, 3.895731522911241*^9}, {
  3.895731574616633*^9, 3.895731611672673*^9}, {3.8957316417729673`*^9, 
  3.895732006931911*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"9cb2131e-3615-41c9-a901-b537e09703ea"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.55, 1, 0.7], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], Thickness[0.01], 
      StyleBox[LineBox[CompressedData["
1:eJw1zm1MUmEUB/CLsKhJSApCJCJgLxuyZtiaa/mcVrPaXOQFjcAhWgTFjBRb
70vaGG02FrbZTKMPIfYpP9igjVzrxZGFK5hbs1WrrJYzwrJsDqZFnf7b3bNn
9/x/55E1O2hLDkVR6j9f9vyfe/0/QnnUDLnak80oOamK3u3+nsL7BPEscDQC
dYpUqLOZJOvT7vAV3Rf8P0VGa96FCkKfyD9thqRGKocCrLc4P0sc1zYdGX0z
TqwHs5kjG2vbvM86n2B/ntgM5lNDeffJWCybDBEFNFy9K4QeBZP8newDvbdw
ngHVjB7b8mP96DOhXSqlv/30Y58Fns+eGCPVjfuWQP2GdS9yrD70lkIuu3KA
R3WitwzKbA0+tdmNXi4EowzPiSoXehy45N2TeK85gx4Xbge5jeHrx9HjgXjC
7x9htuM8D1x1FpVe3Yr+ClgzHOgVzLVgPx96oxVj0/bDuK8AqrjiUnuXFT0+
KJu07ldbLejxoeaQxult2I+eAHYTp4YTa0KvEG5WK1vKzpnRE4KIFrAb4yb0
RGD6+vC5J9OAnggudFjtfQ4jeitBFnk9MCIxoCeGZPli+FFGj94qkLfE15pY
evSKIAnR5inVXvSKYLZjWJB21qMngaPBwbOKRB16xRBfdPkj2+vQk4J3tfDO
8GMdeiUgAdWOoFGH8yUwb1f6jGkt+iXQta91szioJX/rahn8ckZiFoMW98kg
P6XckinUoicHhak4+fQljZ4cxieGXNMBGj05iBLl2y630/geBTxQtg0Kd9Ho
KeB8yM38KKPRK4UPlTcunl6oJb8B5b1Jbg==
        "]],
       FontSize->16]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {Hue[0.06, 1, 0.9], Thickness[0.01], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nc4l98bB3ArJSFUP5XZJ8keqTS4H0mppJKVRCQyKipEipKvZISQ7JXM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        "]]},
      Annotation[#, "Charting`Private`Tag$1390669#1"]& ]}, {}}},
  PlotLegends -> 
  LineLegend[{"\!\(\*SubscriptBox[\(v\), \(demand\)]\)"}, 
    LegendLayout -> {"Row", 1}, 
    LabelStyle -> {FontFamily -> "Helvetica", FontSize -> 12}],
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Rates\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"\\!\\(\\*SubscriptBox[\\(x\\), \\(3\\)]\\)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Directive[
    GrayLevel[0], 14, Thickness -> 0.0025, PlotTheme -> "Marketing"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->300,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Prolog->{
    RGBColor[
     NCache[{
       Rational[223, 255], 
       Rational[72, 85], 
       Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
      0.7843137254901961}]], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.895731561981327*^9, 3.89573156573564*^9}, {
   3.8957316006818523`*^9, 3.8957316158186626`*^9}, 3.895731655855467*^9, {
   3.895731686826784*^9, 3.895731713617676*^9}, {3.895731789787189*^9, 
   3.89573191821651*^9}, 3.895732012115732*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"6ed2296b-2c48-4d2e-b273-dcd9118b78dc"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.55, 1, 0.7], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], Thickness[0.01], 
      StyleBox[LineBox[CompressedData["
1:eJw1zm1IU2EUB/Bbt7S5JdPN3HzJbYpoSAZbBPXhORMyKwq5m5tphWtuyzRN
Gq7yJVY6hZy0D1EqGGXWwFCnud7AKNFKNoy5BNmXVcxQB7qJgmVQq9MfLg8P
9/x/5xGfq2F0WymKkv75Iuf/zIfiso5QK6SrM5KPxJMs+8VaXcb7HPHbZ2fE
smUik0byjehazUMOdRD/LxDtUHL9u9fz5J+2QmIEB8fEbD/OrxJWrrxgYsFL
DPpI1smNw7zzi91T2N8gtaEm11LSW+J2RbJJ3FkVnq+3nehRYAiniQ44BnB+
CxRe8c6MNPehT4PqUaVkkXMf+9uAc9Npy6Pu4r4oCKd2rMiNNvR2gLV7X9DL
v4UeC3LGEstdl1rQY4NA5Kn5cdyMHgfy7TY30TegFwt0ddkHy7AJPS48mFwT
fOYZcZ4LjfZ8Jchr0Y8DDm1aaIitxn48TJ2ISe00X8B9PGjcOKoP9BnQ40PU
6rHv7QodenywRleMv6/SopcA7dejS7k+DXq7wDreEs61lqGXCO3sy/JXS2fR
E8D6tas9DQln0BNAtscyqG0tRU8Is/pMZYesBL0k8Ac2J0fjT6GXDHuz1zLv
CYvRS4FmU++T1jw1eimgKbw4zG9ToZcKvlIF7QoUobcb5hT0S7q4CL000BQM
9o/4lOiJoOtLkkpVrcR5ETy2PDz5aacSfRHU6c3Tp18oyN+6VAzyykM5TVUK
3CcGXu1PdShLgZ4EBjLueHuDDHoSsD5/1tbvZNCTAMfIFoKFwfekw3RNfd1o
CYNeOux5ur/cJGXQywBHz5uJ7VyG/Abdckoq
        "]],
       FontSize->16]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {Hue[0.06, 1, 0.9], Thickness[0.01], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1mk4VV0UB3BTXiIZGpD5xo1Uit5SsY68MlSIRCpFckUTIkklEjIkJBpM
IZREKEMylczCNc/zfO92XfPw7j6c5zy//eWcs/b6r32krW4aXWFjYWGZwdff
+9sHVpx7rf3Vx+TihDdxz6uXNkidMJW6CrNP/2h5ddfB2q8CLympuyAjVL/5
xel24AvJ/ry+xRN4U4+6HVTthbeFgZLrpPygSUiOrlrdD4o066A1yjMoNd2Z
cLNoEDr5olaXm0NA+ElF2VvdYdieyP3v4tILsKxe1TX3HoFras7X5yQjYTOv
XT2b3yh8aeyJn9F8A/qVolsMrcZg0f5EB6JEwzvHj/uaRcchhrXDb04rFmqV
G5Xu54zDf9XPZWeb44BuNO9spjkBIxHaRTNX40FSnpcT8icgwHrlPGMpAfhB
yohEngQlpS/zKPA9qICTr9GTSWhYsg2jSyaD0cVd96LbJ8GlTEKJlp4CL20+
1HvsmALR0MbKSc2P0Jyrkit3YwoKLJ5SJqipoNUpmfU0dQqsFAj2cUoajEu4
WtwbngK2JbfaGffPsDWumkgQo0Fjj4n4jFY68KQYhEWepIHrR56c6eYM4H82
NZAXTwO9kCHO6ZgvEK4tvDW1kgZirkWn0dVMCKWs9MzQaDB14U0cfV8WKNJV
bMe56FCoeYdOW8qCbAp5+JcwHULkjdRppdkg09CRm0img/XGXQFTgV/B0Nkl
PHY/Hf5p7yNPSuaA7D9Fp/41oENL4XfniZEcIEWc/I3M6ZCSGFEynp4LSvLb
uHht6KDvqH9xTDMfOnS75YPc6CBlJp86yvsd1k/mR/M8psO0GsfSCPU7sLpE
GgkF0iGcOzd8mPIDGn8UiPS9pUPmHT1HJ+FCkOcaSfmaQIc3YwdEGO6FIFL8
7I1KKh1u1AlSprWKwOjOnPThPDoIvvnNhpqL4WqTavxaAx2W+LKTbx0pgRyN
VrHIVjoMPHpnSI8pgSXvc0XLXXT83Q+iaFdL4UP5NfXdo3SIbrPXullTCjJ+
++1Yp+jge/LsxNS+n6AQFOWQPE0Hc2WVQ1NLP4Etp7DWY4kOmonSvdcv/QLv
y6PkzDU6KIps9J0s/QUHNGKsS9kRrK6OUicCy6BnW7CKJw+C2Ipoh3HJcrDY
gog3IghmIrIUugPKofSR4aCsOIJjlMr++oVyWB9wQiNUCsEE+5xJbkMF1Lp8
0ZQgIziopn/Iz6cKBgJCDDYrI/DnsWa4z1TBHardrs79CLpa7368ZVkNn0J5
dZ4fRPDYJUHC7HANXNgaTSlSQ1CXtsxGptXC/WitmybaCASB22LD7joIDN+T
EqqL4LBc2CEf6zqgasz4lxxHEDSTzHD7UweNfQYXFg0QqDynXrH68AdGPZye
/jFFYOF66WhH7x8wEwnzTDmLwOfiuMQZ4XowMduX73oOQdsu1hZd73owFnS1
mrVA8LBCUW/vxQbY6F+f+PAKgqT0r3IfXjSA4h/pWR4KgvqIo+yyVQ1wJiyb
I9gWwXaKWb6waiOIVWhbedgjqGB/vJtFiAqWPzXecTng+o3x8bjpYm/U8T7r
iEC8PnKY8ZAKYl53J985IbgVkxYzPEGFta/zPHIuCLaotQvW/mqCOrOdmgNu
CIjtNjSdlSYIzWmV5XRHcJUHVRYrNwP/haZ2mfsI8ls5vbNjmkHLQOLkyYcI
rFz2zb11a4Fvll71V70QfErza7+2uw1spFyc2p4iGBMcC9CzbIOkUwliyf4I
yC566jvC2oAryr7odgCCmCM8sf0LbXBi8DrBHoQgpDzAxvxnO1jdXqlaDUbg
0v8MaZ/vBM2yJB/3cAQZx+hxss86oYaq0yz9EgEt2fA0e3EnJIWkrJRi294S
+FpA7oKKUd8FjkgE5ish7vsZXdBk7FRx7TWCaJ5KLwGtHvA6dXOsPxqButq9
8x4WPZDnFS9nH4Og48bO/bQ7PaC0IFZOxxau9x+qSumBRfHIC3OxCJ5HnND1
5e+FZP/Gx9PvEHjJ1vCttffC7CFBg8T3CGRMHwxfZ/aCqWfh8pYkBIW+uws7
+PqAbTbY8Qn28niQQ65GH5izv6mwTEbgnGHQ6Py+D45Vv8hY/wEBBf5ETjj2
w23+1aPynxCwxM3mtvv3g1/Rx9wn2BEcYh0V8f1w5FGvTj/273IbieSmfqiP
ssmOTEOw4/Ry3JVDAzAUwr13+TOCEVvyxy7WQTB35Tvx6gsCj8oT1dWig5Dx
YlPcGLbwbsepfOVBcKhiqh3KRKDDyFd6fWUQxBX0TzVjJ983yjItH4Tec6vy
3NkI7ELuF9QFD0HFKm/UyW8I2Jhx3T+Sh0BBV9w2FPuV6W+WtOIhkCm9/LoF
u0JMSDNwZggUv8pqWeYg2Pk+qUzXbBie5/1osc/Fec5rqCuWHIFQ1fZHlHwE
Nwbl+zM/jcKmEv9A9kIEPRatXEXlo5BC3bdfHdu4xXd39cAo9DyoveyKfbBy
+O6g6BhMaX87N47Nnp7Av8VnDMyYiZ2VRbhe7tLqdy6OAxyZMHItQVAkJBKp
yj8Jgd039Xx+4fwG/i7Q2jkJs6u96lnYiZyuA6eOTYLVpdPdfdgBC0177Nwn
QeJNFVmtDMGZ7rBfr0Ym4UG9OW0SeyyFf2apcAq+pD4S0ChHsF76Mbn7IB3+
rc9rzqjE+3Pk+Z4HWnQooKmdo2I/MYs6IG5EhyOn+pPnsNmCv2mfs6fD+TK3
lMNVCBZXJyjNeM4nmRdpFWGPd5gk1bIhaIm30i6pRlAVQZYvxOuR5ZHHE2oR
PM1U2XuxFYHcUcRRjK1Tp6G6OohzLSgT3oVd+s953SNr+L3jLDS21uH8ugRf
/bZ3Gv9/qJY+wU49vZD8OXwadGqMCi3+4PnGX6kQe4kB1g81ns3UI8g5IJ6l
f4MBv12PdfI1IBiwuAnL9xgwPpPMKY99OFXotOlLBnh25k+cxx7RPX9/Qw0D
hpIP8JVga3pN1t49PAOaVtsGfRsRzDM3OhttYcIaNT59mYqAJG61tkZiQlNq
MV2wCYH+f5l+qXuZoPbjkpA8dkKIWRTXSSbYec+xm2Ab7YktK/BigoQ2JeID
dqrtPtGdiAmXWc7lGTfjedR++gd71SwYq/08+LwF78fr3usOrbNgV6VPe4ed
YX5DrHtoFn7c3xCcjc3e5nM3l3UOZDuKgtux41tylR0OzEFBkHDodlzXIapU
UlfcHLRYLOZmYNvVTQTn3J2H4D0XvArb8HkRfBfIPvOg7r5QUoeda8A5FRY2
D+vV0XQPNk+t5PFbafNgEHRFjLUdwcdqo3XkwXm4P3M7hsCeqvh2N8xwAcIb
ubzzsR1+Pra6SV4EZoi9U1IHAomBY5yzyougGr/4PQu7ko07xZ1YhOxzU0vF
2LJEIPI7uwiBB48bdWK35r7wiPdfBMeMMjuBTgQanxOjWmmLULC1/OwdbIHX
v9s0vy1BEdU39lAXgvRbvMbCuivQfe3g+rhu3F+vhO6mnlmBiHWMgFTsoVLR
6KPWK5DUKrwuB1tURH782sMVuGfeQ63Fflyk5VWUtQITHPTFZewzgg+/2Mms
Qlaz9kWTHtzPX5DQ96VV2PHv08lV7Nh79mNKpiyEysjq9wN9CJQKued9LrAQ
15liVgR2IUfSuu7LLMQmWuiaDnZP4IBU4C0WQur4BzlzbImYC6ajfixE2TNj
OXfsV6UGpbH5LASvLMd0AXbIBpUoQRlWYox6ZwL6EXhGL5+amWAlKAmPWpUG
8Dxt6CHy3diJjX1+QXU4J3K3bVxPK6wjEkM21+sP4/5mvjzD852TsMwceeYx
gkBv0O5+iAMXkfBc4GP0KO7PgeCdEhLrCX/lYcUXYzj/JVYev1N5CFXbTU4X
xxHsFmgS17y4gbDhUY2QmcD9B0zLDgYfwc016/0TW3vSfE7GhJ8w9LpuaD2J
c11szWquKECUi6i20LGzfEstpJgCxC4W2jbbKQQ265x7amoEidgNFcpd2Jcd
72XxvhIiROaMDmvSEOyh7Kw5YbmJUJj7mhiFXSuoyOOsupmo53twdBE775Pn
a0X2LcTuvCR7XTqCe6wKhlWdW4iXekz+SOz1HW46NzK3EoeLT6X1Yg8mSodF
uwsTV4UuISmEIGyHCEeOiQjx2nNCxhI7+JVNmaWUKMFEkvqR2OZhF2p4h0UJ
p85p+Wrs+f8SFqILthFtcy93sE0j6B886lrsI0bwMAzKlbDj1PZuq7YUJ7hZ
CO9L2KnezgKUXRKEZet08lNsH5PLx9mZEsTDb19607H3d8Qm+1RLEr99hqAN
O0L+dWr1cSliKvAl9yr2w8LAiOM5UsS+PwpjMgwEJ7eZJFRslyZK1eZOa2Fr
3Cg7J+AnTeRtZJ25jB0tZrW9iilNKMtPJnhhby95H65/ToYonvAei8YO3lWs
UF8gQ5z5b+VOLrYNg+NPuQKJqFQ5v7EJ2yp9WsrvGYn4YcjIm8K+5mm8rPec
RPBEdJNp2M7Gmc28oSSi3etb6F/7Mp2DgsOxLyjZ07E/qS4svXxLIhI+HhSZ
xl4oWmtK/EAiqlQ/OzD/Pr+eN7C0jER8oFpsWsZ+9e667ZNyErExZvT+X7+7
XaOpU0ki2DMsh/86e0vwYmUNiXhUKJK7gt1hLmTbQCURTYIpFmvY5H4Rzb5+
EjHfZRDPNoPzlukmET9IIhac0nnZsQ95ty9cGSYRVtEszn99gvz28+gYiRiq
omhxYDvaS0kgRCKi15sPrsN2P/JoIYNBIjradpzkxPbe0Nd4m0kijtkOZv51
RNo7//l5EjFSTX78D3acBwcld5FE5KWljv/1h1NXjrovk4hZS2ljLuxMmV/i
6qsk4sqoZ+5fFzDkFvCBQNTq1UtzY/8PwGAPKA==
        "]]},
      Annotation[#, "Charting`Private`Tag$1428578#1"]& ]}, {}}},
  PlotLegends -> 
  LineLegend[{"\!\(\*SubscriptBox[\(v\), \(demand\)]\)"}, 
    LegendLayout -> {"Row", 1}, 
    LabelStyle -> {FontFamily -> "Helvetica", FontSize -> 12}],
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Rates\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"\\!\\(\\*SubscriptBox[\\(x\\), \\(3\\)]\\)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Directive[
    GrayLevel[0], 14, Thickness -> 0.0025, PlotTheme -> "Marketing"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->300,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Prolog->{
    RGBColor[
     NCache[{
       Rational[223, 255], 
       Rational[72, 85], 
       Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
      0.7843137254901961}]], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.895731561981327*^9, 3.89573156573564*^9}, {
   3.8957316006818523`*^9, 3.8957316158186626`*^9}, 3.895731655855467*^9, {
   3.895731686826784*^9, 3.895731713617676*^9}, {3.895731789787189*^9, 
   3.89573191821651*^9}, 3.8957320160610933`*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"17d34e63-f123-4418-bcdc-18a71a28da3d"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.55, 1, 0.7], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], Thickness[0.01], 
      StyleBox[LineBox[CompressedData["
1:eJw1zm1IU1EYB/BNpVZLnWVp6WwvUfZBKmbWPp0nrLS00N07W8pMNzVq6Vow
THpxDhSsoZJB2sY0QkWM1Aj6kLWVZC23cgu1/JDbNGyhbC5YFLOX1dMfLofD
ff6/5/AVakllFIPBEP35Iuf/WD5Oud5GB8jtzkhshL7ZeFb2w4/3D4T1QCf+
fMRPMkWRzJEw3eyfNy3ifx9xenOnJ8QL5J8WIMNOsSHJ5Mb5r6Rd8Yv5zjtJ
TldFEiKxnkNyZqwd+9/J/oE38oPc58RhjyRMpjSZz96HHqHHAMqfETpODeE8
EyTKb/HWL73oR8OtmvFX7uvd2I8Bl3D28kBTB+5bBfGyzoc7zTfQY8FiYeuA
d96A3hoYrG5hZXua0GNDsDVkdWv16K2DNH3z4O6Cq+jFgXrH0s+5vDr0OHCA
f/8pS63FeQ6o6ELpguoC+gngmE80Gtjnsb8eAkGfgnHsHO7bAOb6o3vD5Ax6
iTCT03e35UUVeonQkdDWsPykAr2NoK3uM6cmKNHbBF3sEcXwvXL0kmBCMjra
oC9DLxkuzg45ouNPoZcMl0wrwdVVcvQ2w52e9P6CcAl6W0AUN/Hy01gxeikw
3brHGRo5iV4q6IxjbYppGXqpUF+5XFvCkaHHhcdqXz5feQK9NFBXtDhejxeh
txXsvdbilJwi9HjQU0PZyl1SnOfBWs6SqFQlRZ8HuqhsUQZHSv7WRXzol2zP
2WehcR8f0jVljcJaGj0BeCzWGXsWjZ4AjId30eIVCj0BXMufjGm3UfgeIcgM
3CyBkUJPCNxSRXeuhkJvG0g9zLoreRT5Df1BVh0=
        "]],
       FontSize->16]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {Hue[0.06, 1, 0.9], Thickness[0.01], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1Wk4VW0XB3BTvUkplAeZDykapHo0sbZkDEWkJDITSUohzYQnCkkiyZgh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        "]]},
      Annotation[#, "Charting`Private`Tag$1466487#1"]& ]}, {}}},
  PlotLegends -> 
  LineLegend[{"\!\(\*SubscriptBox[\(v\), \(demand\)]\)"}, 
    LegendLayout -> {"Row", 1}, 
    LabelStyle -> {FontFamily -> "Helvetica", FontSize -> 12}],
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Rates\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"\\!\\(\\*SubscriptBox[\\(x\\), \\(3\\)]\\)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Directive[
    GrayLevel[0], 14, Thickness -> 0.0025, PlotTheme -> "Marketing"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->300,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Prolog->{
    RGBColor[
     NCache[{
       Rational[223, 255], 
       Rational[72, 85], 
       Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
      0.7843137254901961}]], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.895731561981327*^9, 3.89573156573564*^9}, {
   3.8957316006818523`*^9, 3.8957316158186626`*^9}, 3.895731655855467*^9, {
   3.895731686826784*^9, 3.895731713617676*^9}, {3.895731789787189*^9, 
   3.89573191821651*^9}, 3.8957320197719507`*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"302689d6-951f-443b-b683-5b1b5c9b3d89"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 43, 34, 21008687316917034379, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.895732020899403*^9},
 CellLabel->
  "During evaluation of \
In[39]:=",ExpressionUUID->"6313fd47-90a7-476a-a9b0-68e36db5e657"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.55, 1, 0.7], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], Thickness[0.01], 
      StyleBox[LineBox[CompressedData["
1:eJw1zmtIU2EYB/Cj1ko2crfM5cptOoMymC38YI33Ec0QljWLeelinU3nFrWm
LW2GaEmLJYGVDbVYW1MryholIcwKdR+kNbspDSNKm9A+6CDIMo1aPf7h8PJy
nv/vecW0sagilqIo+d8vei5F4tZ/4SZESEd7NCPEWSPgZDKX7kHC9PTYBoZm
yVZ5NFOE3ZvBmS6fwf9fiTS/ZSH9V5j81yJkaGpUEu8N4fw34guW35iI/0R0
ldF8J+otfMc1wzj2f5KCwwHf5ccB8tIfzQIxDtsnywQ+9CjIuzURaTQP4HwM
ZLJl0sTYPvTjINf7wH3ydi/2l0F4v/BKw2Q37mOAavNDd4nZid5KGHzReLNP
1olePJiSi3pm29rQY4Jy8FD2THUreizY6cq17va0oLcKiuyFxYofVvTYoFPw
9Rf3NuM8G+TXWc/S6pvQ54DOX7Dpfm0D9rmwcby0x/TZgvt48LrO63Uv1qLH
h64utbLYbUaPD3uytXGOJzXorYZA5j7mW1E1eokgPsdY7AycQG8NHKhv5m7Q
GdFLAnvOG80l2zH0kiBcRqmpuaPoCSDv7PKMOocBvbVwYag/v/W0Hr1k4Lpi
/JEzVegJ4V62j/XOpUNPCB0KxVx/qBK9dfBo4b1DlFOJ3nrwdvvHVJ4K9FJg
WmDlbZNXoCcCW+N2XuGwFudF8Fumjq2iteiLIOQ0vBpgasm/ulwMw6csZv9T
De4TQ0l7lUpp0aAngaujH+bTFRr0JCAd+Th/nKFBTwKC9LmE0jEa35MKM+wV
d7Pu0Oilwq4dKUdMTTR6aXA++DzLepAmfwCuvkyN
        "]],
       FontSize->16]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {Hue[0.06, 1, 0.9], Thickness[0.01], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1Xk41UsYB3D7TZYrbkL2Q9KCpCuS91eSrVQSEopEKkIhkjaFLCFFluwK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        "]]},
      Annotation[#, "Charting`Private`Tag$1517426#1"]& ]}, {}}},
  PlotLegends -> 
  LineLegend[{"\!\(\*SubscriptBox[\(v\), \(demand\)]\)"}, 
    LegendLayout -> {"Row", 1}, 
    LabelStyle -> {FontFamily -> "Helvetica", FontSize -> 12}],
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Rates\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"\\!\\(\\*SubscriptBox[\\(x\\), \\(3\\)]\\)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Directive[
    GrayLevel[0], 14, Thickness -> 0.0025, PlotTheme -> "Marketing"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->300,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Prolog->{
    RGBColor[
     NCache[{
       Rational[223, 255], 
       Rational[72, 85], 
       Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
      0.7843137254901961}]], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.895731561981327*^9, 3.89573156573564*^9}, {
   3.8957316006818523`*^9, 3.8957316158186626`*^9}, 3.895731655855467*^9, {
   3.895731686826784*^9, 3.895731713617676*^9}, {3.895731789787189*^9, 
   3.89573191821651*^9}, 3.895732023848996*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"5e981133-6ce3-4a9f-b887-b2bdd5e1ab3a"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.55, 1, 0.7], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], Thickness[0.01], 
      StyleBox[LineBox[CompressedData["
1:eJw1zm1Ik1EUB/C5IjTL2TSdutyLyw8mKc3AkXUPCRklKoYWSyLFmRARrCVu
rLRm5Yeao724ueam6BTDdFS20GIwPxjLolWSL4milJvTKZoZjczV8Q8Pl8vz
P79zOWVXC0VUCoXC3/yC51Ziel9OT0YskSZDMG+I+PVy/N3dW/dRoikXJ8tC
l0gGP5gZUk/n/BHN+/G/hyw5zP0ihZ/81zZ7V7yCsEeL2F8hRtf5L+6Aj1yq
CGaNUPTcIZvei/O/SKBE+3NM950Mvw0mQNinpVR39ix6FKj+xMj0rU5hPwQ+
HisO8Y6Oo78N5DkLjiLLCM5vh6rcOW5uvhv37YDY+8oRa/cweqEwrzDLBGlD
6IUBxZlXe3nSiV440M7YC4/KHejtghO8h7+/dfSjFwHhlQNfPVUv0IsEXkWK
g8p7hv1IuCb2tXrkNvT3gH+nSnKj7wnO08HDLXHWZj/GfVHA6pFJUiSd6EXD
RvO7Sn6yFb1osJt6GemkDb29MNhWX9De1YpeDKiuF5cazrWgFwu3xlM5t7Ms
6DEgS5gj8eub0WPAeke1KyPEhF4cuBt+DB5pN6IXD3H5i9PTsib0EiBQQxOv
SA3oMUG6bH7qNOrRY4Jyf5lyYqwRvX3QtZ6X5jjUiF4i0EtPHbebdeixIJ2x
auhJ1KHHhueqA1NR3Vrss8FG09e8OqlFnw2ZH1yiCb+G/Bvnc0D2oE81Z9Hg
Pg7cE9TptUINely46WXphhI06HHhvbXA2zCjRo8LG3c665g2Nb4nCc6S8gsD
CjV6SZC6Jl74LFSjxwPTwaKLs4fV5C8WjGDi
        "]],
       FontSize->16]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {Hue[0.06, 1, 0.9], Thickness[0.01], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1Xk0VlsYB2BTKqJQEjJ9IkMo4SLeI1QoytgVKomiJFGRyr1yEQpJ5ilD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        "]]},
      Annotation[#, "Charting`Private`Tag$1555747#1"]& ]}, {}}},
  PlotLegends -> 
  LineLegend[{"\!\(\*SubscriptBox[\(v\), \(demand\)]\)"}, 
    LegendLayout -> {"Row", 1}, 
    LabelStyle -> {FontFamily -> "Helvetica", FontSize -> 12}],
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Rates\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"\\!\\(\\*SubscriptBox[\\(x\\), \\(3\\)]\\)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Directive[
    GrayLevel[0], 14, Thickness -> 0.0025, PlotTheme -> "Marketing"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->300,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Prolog->{
    RGBColor[
     NCache[{
       Rational[223, 255], 
       Rational[72, 85], 
       Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
      0.7843137254901961}]], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.895731561981327*^9, 3.89573156573564*^9}, {
   3.8957316006818523`*^9, 3.8957316158186626`*^9}, 3.895731655855467*^9, {
   3.895731686826784*^9, 3.895731713617676*^9}, {3.895731789787189*^9, 
   3.89573191821651*^9}, 3.895732027215928*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"3c0c9677-7b33-49b9-871e-82ef1817bd4c"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.55, 1, 0.7], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], Thickness[0.01], 
      StyleBox[LineBox[CompressedData["
1:eJw1zltMkmEYB3BAQ6xMM6QPMgN1a2qbohZ5Ue+zsS466JZho6A2S8DphdNq
2SK6gI1p67ComWXQac2stSSxC91qLKY12FwHJ6dEUBJFYTkNl52oh//27d27
7/n/nldwoqlawaDRaGV/v/iZiF2uHzyYGiW3O+N5R0hOSZuJlbg7SbckVP05
JUrKy+IJkGuy0j29zMT/ENHM7sy3JUfJfy1Khvdxgy30xPwCOfJU1zb8PUJU
yniWyOMF49blqQj2l4le1JpmeB8hDns8K+TAmE/JeBBBjwZem+qHuD4xT4ex
wYH9Z7kR9JNAFmadu2qex34yVHU87/4onMd9TBBVqE9mdsyhx4JAV9cVUyCM
Xiok+ec15bwwemtgZMgY6989i95a+NTrGAnWzKC3Doqyb9bG6kLoZUDK4d9F
Bc3TOJ8Blgzv3uMXv6K/HrTRtGqnIYj9TIhSDaLV5inctwE6Tx0q1Hgm0WPD
GWnsXpA9iR4bdCUF5UJ5AL0sqOsTv+k2+9HjAG2a08yl/OhtBKv+gmjh0gR6
FFhUS79UaRPoUbDj7rFW3R0felwYOTojFW/3occD2eXCLNHLcfQ2wa4Gahs7
fRy9bKh/1SMWqr+glw1mzlCPNeZFbzNUqc2PBFovejngVBmeOLhe9LbADQtz
tHHAgx4fvtVoS21KD87zQW7MrHzL86DPh37+/fMto27yr14mAJP9GX3xlhv3
CWBuxUHaa93o5cJrJ2OVvtiNXi4wFxXpEoYbvVzQShatjU4XvicPKisUlLTP
hV4efHj40/riugu9fGgqNrdzT7vIH9E9Yc8=
        "]],
       FontSize->16]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {Hue[0.06, 1, 0.9], Thickness[0.01], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1Xc81d8fB3A7sinFV9ZNRovopxTvjyTRUEaKlr0iKlt7IK6VZGQmpZJk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        "]]},
      Annotation[#, "Charting`Private`Tag$1594068#1"]& ]}, {}}},
  PlotLegends -> 
  LineLegend[{"\!\(\*SubscriptBox[\(v\), \(demand\)]\)"}, 
    LegendLayout -> {"Row", 1}, 
    LabelStyle -> {FontFamily -> "Helvetica", FontSize -> 12}],
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Rates\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"\\!\\(\\*SubscriptBox[\\(x\\), \\(3\\)]\\)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Directive[
    GrayLevel[0], 14, Thickness -> 0.0025, PlotTheme -> "Marketing"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->300,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Prolog->{
    RGBColor[
     NCache[{
       Rational[223, 255], 
       Rational[72, 85], 
       Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
      0.7843137254901961}]], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.895731561981327*^9, 3.89573156573564*^9}, {
   3.8957316006818523`*^9, 3.8957316158186626`*^9}, 3.895731655855467*^9, {
   3.895731686826784*^9, 3.895731713617676*^9}, {3.895731789787189*^9, 
   3.89573191821651*^9}, 3.895732030651688*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"37bc674d-b28b-47e6-9e3c-5c139842b569"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 46, 35, 21008687316917034379, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8957320323624153`*^9},
 CellLabel->
  "During evaluation of \
In[39]:=",ExpressionUUID->"c75ec6d0-f0ef-4715-9ea7-614790a4f141"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 46, 36, 21008687316917034379, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.89573203343204*^9},
 CellLabel->
  "During evaluation of \
In[39]:=",ExpressionUUID->"1a418e66-f4ce-4a33-9855-dd2e27f64d65"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 46, 37, 21008687316917034379, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.895732034565793*^9},
 CellLabel->
  "During evaluation of \
In[39]:=",ExpressionUUID->"59644c87-6253-471c-a00a-1fe236b9a0c5"],

Cell[BoxData[
 TemplateBox[{
  "General", "stop", 
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"FindRoot\\\", \
\\\"::\\\", \\\"lstol\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"", 2, 46, 38, 21008687316917034379, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.895732035566786*^9},
 CellLabel->
  "During evaluation of \
In[39]:=",ExpressionUUID->"b4ecc4c2-9819-4e55-9489-63a26cff4431"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.55, 1, 0.7], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], Thickness[0.01], 
      StyleBox[LineBox[CompressedData["
1:eJw1zl9I01EUB/Cpczo03a+tubZVblorBrqarpDBPSMQSSyqWW8VbWtklBAS
ZFK+jMK2mDbpj9lDGREzM3DUYFoRWoIjkrmciAm9NOK33y+Hs9GMtrrnC5fL
4Z7zOVdzuv2II18gEBizJ3dj9IJ2na6IJ/fv5TJN/D71c78I6xgxv9aP1Gbr
OmMu30iJoSY5UojvcZK2MC5ttv6v8eSGnQS6hdifJCeUfPV4AU+cZ3JJkYG5
PTMf83E+TWyuW/l9eTwJz+SSIYmXQY9QgJ4AvG8k16QZjvbngYmJOZg1jvoF
EPxT3h3mOTovBCbjckviHN0nguKfzvnHXznqFcPJY95ZawQ9MVy0Rh6mp9Ar
gdjZ0YZLr9ArhUjonOPdE/TKYMevvU3fe9GTQGClLlXehf0SMH9JHuiwo8/A
+cXORnszzm+EDY8+3TTvxn1SWC+r4E/J0ZOBP1pbavqdoJ4M3M96bquWE9Tb
BF1tcz+ckwnqyWF0qX+fw5+gXgUc9WyfPdSXoJ4Crs4HU62d6CkgOOS7cNeG
3mYA+3pUfxA9JTCh7hZlA3oquLy/1eLQoaeGiZ5+UiRHTw0Oo21wtRC9LWC1
HuY0ayz1tsLb0GrjlThLvW1gKKs3cYss9SpB49I+aPuM/ZUgEz21LEyx1K8E
T0DVoh9nyb9xowbCM4yveYyl+zSgMOTN7hpGTwv8ZHg6MISeFuwrNceXB9HT
QnRJ0zFwB/9TBTs/TNQv9KJXBYsG6XuvG71qeCEWN41dZ8lfiYhh3A==
        "]],
       FontSize->16]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {Hue[0.06, 1, 0.9], Thickness[0.01], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1Xk81NsbB3B7icTkp7jZmiRrihaF51uypK4kUq5SkqWy1E3WNiVkl2TJ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        "]]},
      Annotation[#, "Charting`Private`Tag$1678274#1"]& ]}, {}}},
  PlotLegends -> 
  LineLegend[{"\!\(\*SubscriptBox[\(v\), \(demand\)]\)"}, 
    LegendLayout -> {"Row", 1}, 
    LabelStyle -> {FontFamily -> "Helvetica", FontSize -> 12}],
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.9184304088564803},
  BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Rates\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"\\!\\(\\*SubscriptBox[\\(x\\), \\(3\\)]\\)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Directive[
    GrayLevel[0], 14, Thickness -> 0.0025, PlotTheme -> "Marketing"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->300,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{
    RGBColor[
     NCache[{
       Rational[223, 255], 
       Rational[72, 85], 
       Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
      0.7843137254901961}]], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.895731561981327*^9, 3.89573156573564*^9}, {
   3.8957316006818523`*^9, 3.8957316158186626`*^9}, 3.895731655855467*^9, {
   3.895731686826784*^9, 3.895731713617676*^9}, {3.895731789787189*^9, 
   3.89573191821651*^9}, 3.8957320380207253`*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"112fa7f8-fdf8-4ad2-b78e-c6066f787348"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ColorData", "[", 
  RowBox[{"68", ",", "\"\<ColorList\>\""}], "]"}]], "Input",
 CellLabel->"In[25]:=",ExpressionUUID->"d9f3db8a-0b24-4fb0-9895-7a30ef9440bf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[<|"color" -> Hue[0.55, 1, 0.7]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.06, 1, 0.9]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.25, 1, 0.55]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.11, 0.9, 0.85]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.5, 1, 0.5]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.2, 1, 0.7]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.08, 1, 0.7]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.5, 0.8, 0.75]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.45, 1, 0.5]|>,
    "HueColorSwatchTemplate"], ",", 
   TemplateBox[<|"color" -> Hue[0.6, 0.5, 0.9]|>,
    "HueColorSwatchTemplate"]}], "}"}]], "Output",
 CellChangeTimes->{3.8957316263820267`*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"3ea0270f-6bc7-41ca-be22-147192c3df6c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
  "pl01", ",", "pl05", ",", "pl1", ",", "pl2", ",", "pl5", ",", "pl10", ",", 
   RowBox[{"Frame", "->", "True"}], ",", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(X3\), \(Ki\)]\)\>\"", ",", 
      "\"\<Supply and Demand Rates\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"10", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.879229571045106*^9, 3.879229584466722*^9}, {
  3.879229632776881*^9, 3.879229636783909*^9}, {3.895730320831451*^9, 
  3.895730432776062*^9}, {3.8957305575887747`*^9, 3.8957305583547773`*^9}, {
  3.895730654946197*^9, 3.8957306552793694`*^9}},
 CellLabel->
  "In[399]:=",ExpressionUUID->"43d6ac62-b3f1-4717-8423-18b34bf6582c"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zm1MUmEUB/CLsKhJSApCJCJgLxuyZtiaa/mcVrPaXOQFjcAhWgTFjBRb
70vaGG02FrbZTKMPIfYpP9igjVzrxZGFK5hbs1WrrJYzwrJsDqZFnf7b3bNn
9/x/55E1O2hLDkVR6j9f9vyfe/0/QnnUDLnak80oOamK3u3+nsL7BPEscDQC
dYpUqLOZJOvT7vAV3Rf8P0VGa96FCkKfyD9thqRGKocCrLc4P0sc1zYdGX0z
TqwHs5kjG2vbvM86n2B/ntgM5lNDeffJWCybDBEFNFy9K4QeBZP8newDvbdw
ngHVjB7b8mP96DOhXSqlv/30Y58Fns+eGCPVjfuWQP2GdS9yrD70lkIuu3KA
R3WitwzKbA0+tdmNXi4EowzPiSoXehy45N2TeK85gx4Xbge5jeHrx9HjgXjC
7x9htuM8D1x1FpVe3Yr+ClgzHOgVzLVgPx96oxVj0/bDuK8AqrjiUnuXFT0+
KJu07ldbLejxoeaQxult2I+eAHYTp4YTa0KvEG5WK1vKzpnRE4KIFrAb4yb0
RGD6+vC5J9OAnggudFjtfQ4jeitBFnk9MCIxoCeGZPli+FFGj94qkLfE15pY
evSKIAnR5inVXvSKYLZjWJB21qMngaPBwbOKRB16xRBfdPkj2+vQk4J3tfDO
8GMdeiUgAdWOoFGH8yUwb1f6jGkt+iXQta91szioJX/rahn8ckZiFoMW98kg
P6XckinUoicHhak4+fQljZ4cxieGXNMBGj05iBLl2y630/geBTxQtg0Kd9Ho
KeB8yM38KKPRK4UPlTcunl6oJb8B5b1Jbg==
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zm1IU1EYB/BNpVZLnWVp6WwvUfZBKmbWPp0nrLS00N07W8pMNzVq6Vow
THpxDhSsoZJB2sY0QkWM1Aj6kLWVZC23cgu1/JDbNGyhbC5YFLOX1dMfLofD
ff6/5/AVakllFIPBEP35Iuf/WD5Oud5GB8jtzkhshL7ZeFb2w4/3D4T1QCf+
fMRPMkWRzJEw3eyfNy3ifx9xenOnJ8QL5J8WIMNOsSHJ5Mb5r6Rd8Yv5zjtJ
TldFEiKxnkNyZqwd+9/J/oE38oPc58RhjyRMpjSZz96HHqHHAMqfETpODeE8
EyTKb/HWL73oR8OtmvFX7uvd2I8Bl3D28kBTB+5bBfGyzoc7zTfQY8FiYeuA
d96A3hoYrG5hZXua0GNDsDVkdWv16K2DNH3z4O6Cq+jFgXrH0s+5vDr0OHCA
f/8pS63FeQ6o6ELpguoC+gngmE80Gtjnsb8eAkGfgnHsHO7bAOb6o3vD5Ax6
iTCT03e35UUVeonQkdDWsPykAr2NoK3uM6cmKNHbBF3sEcXwvXL0kmBCMjra
oC9DLxkuzg45ouNPoZcMl0wrwdVVcvQ2w52e9P6CcAl6W0AUN/Hy01gxeikw
3brHGRo5iV4q6IxjbYppGXqpUF+5XFvCkaHHhcdqXz5feQK9NFBXtDhejxeh
txXsvdbilJwi9HjQU0PZyl1SnOfBWs6SqFQlRZ8HuqhsUQZHSv7WRXzol2zP
2WehcR8f0jVljcJaGj0BeCzWGXsWjZ4AjId30eIVCj0BXMufjGm3UfgeIcgM
3CyBkUJPCNxSRXeuhkJvG0g9zLoreRT5Df1BVh0=
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zmtIU2EYB/Cj1ko2crfM5cptOoMymC38YI33Ec0QljWLeelinU3nFrWm
LW2GaEmLJYGVDbVYW1MryholIcwKdR+kNbspDSNKm9A+6CDIMo1aPf7h8PJy
nv/vecW0sagilqIo+d8vei5F4tZ/4SZESEd7NCPEWSPgZDKX7kHC9PTYBoZm
yVZ5NFOE3ZvBmS6fwf9fiTS/ZSH9V5j81yJkaGpUEu8N4fw34guW35iI/0R0
ldF8J+otfMc1wzj2f5KCwwHf5ccB8tIfzQIxDtsnywQ+9CjIuzURaTQP4HwM
ZLJl0sTYPvTjINf7wH3ydi/2l0F4v/BKw2Q37mOAavNDd4nZid5KGHzReLNP
1olePJiSi3pm29rQY4Jy8FD2THUreizY6cq17va0oLcKiuyFxYofVvTYoFPw
9Rf3NuM8G+TXWc/S6pvQ54DOX7Dpfm0D9rmwcby0x/TZgvt48LrO63Uv1qLH
h64utbLYbUaPD3uytXGOJzXorYZA5j7mW1E1eokgPsdY7AycQG8NHKhv5m7Q
GdFLAnvOG80l2zH0kiBcRqmpuaPoCSDv7PKMOocBvbVwYag/v/W0Hr1k4Lpi
/JEzVegJ4V62j/XOpUNPCB0KxVx/qBK9dfBo4b1DlFOJ3nrwdvvHVJ4K9FJg
WmDlbZNXoCcCW+N2XuGwFudF8Fumjq2iteiLIOQ0vBpgasm/ulwMw6csZv9T
De4TQ0l7lUpp0aAngaujH+bTFRr0JCAd+Th/nKFBTwKC9LmE0jEa35MKM+wV
d7Pu0Oilwq4dKUdMTTR6aXA++DzLepAmfwCuvkyN
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zm1Ik1EUB/C5IjTL2TSdutyLyw8mKc3AkXUPCRklKoYWSyLFmRARrCVu
rLRm5Yeao724ueam6BTDdFS20GIwPxjLolWSL4milJvTKZoZjczV8Q8Pl8vz
P79zOWVXC0VUCoXC3/yC51Ziel9OT0YskSZDMG+I+PVy/N3dW/dRoikXJ8tC
l0gGP5gZUk/n/BHN+/G/hyw5zP0ihZ/81zZ7V7yCsEeL2F8hRtf5L+6Aj1yq
CGaNUPTcIZvei/O/SKBE+3NM950Mvw0mQNinpVR39ix6FKj+xMj0rU5hPwQ+
HisO8Y6Oo78N5DkLjiLLCM5vh6rcOW5uvhv37YDY+8oRa/cweqEwrzDLBGlD
6IUBxZlXe3nSiV440M7YC4/KHejtghO8h7+/dfSjFwHhlQNfPVUv0IsEXkWK
g8p7hv1IuCb2tXrkNvT3gH+nSnKj7wnO08HDLXHWZj/GfVHA6pFJUiSd6EXD
RvO7Sn6yFb1osJt6GemkDb29MNhWX9De1YpeDKiuF5cazrWgFwu3xlM5t7Ms
6DEgS5gj8eub0WPAeke1KyPEhF4cuBt+DB5pN6IXD3H5i9PTsib0EiBQQxOv
SA3oMUG6bH7qNOrRY4Jyf5lyYqwRvX3QtZ6X5jjUiF4i0EtPHbebdeixIJ2x
auhJ1KHHhueqA1NR3Vrss8FG09e8OqlFnw2ZH1yiCb+G/Bvnc0D2oE81Z9Hg
Pg7cE9TptUINely46WXphhI06HHhvbXA2zCjRo8LG3c665g2Nb4nCc6S8gsD
CjV6SZC6Jl74LFSjxwPTwaKLs4fV5C8WjGDi
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zltMkmEYB3BAQ6xMM6QPMgN1a2qbohZ5Ue+zsS466JZho6A2S8DphdNq
2SK6gI1p67ComWXQac2stSSxC91qLKY12FwHJ6dEUBJFYTkNl52oh//27d27
7/n/nldwoqlawaDRaGV/v/iZiF2uHzyYGiW3O+N5R0hOSZuJlbg7SbckVP05
JUrKy+IJkGuy0j29zMT/ENHM7sy3JUfJfy1Khvdxgy30xPwCOfJU1zb8PUJU
yniWyOMF49blqQj2l4le1JpmeB8hDns8K+TAmE/JeBBBjwZem+qHuD4xT4ex
wYH9Z7kR9JNAFmadu2qex34yVHU87/4onMd9TBBVqE9mdsyhx4JAV9cVUyCM
Xiok+ec15bwwemtgZMgY6989i95a+NTrGAnWzKC3Doqyb9bG6kLoZUDK4d9F
Bc3TOJ8Blgzv3uMXv6K/HrTRtGqnIYj9TIhSDaLV5inctwE6Tx0q1Hgm0WPD
GWnsXpA9iR4bdCUF5UJ5AL0sqOsTv+k2+9HjAG2a08yl/OhtBKv+gmjh0gR6
FFhUS79UaRPoUbDj7rFW3R0felwYOTojFW/3occD2eXCLNHLcfQ2wa4Gahs7
fRy9bKh/1SMWqr+glw1mzlCPNeZFbzNUqc2PBFovejngVBmeOLhe9LbADQtz
tHHAgx4fvtVoS21KD87zQW7MrHzL86DPh37+/fMto27yr14mAJP9GX3xlhv3
CWBuxUHaa93o5cJrJ2OVvtiNXi4wFxXpEoYbvVzQShatjU4XvicPKisUlLTP
hV4efHj40/riugu9fGgqNrdzT7vIH9E9Yc8=
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw1zl9I01EUB/Cpczo03a+tubZVblorBrqarpDBPSMQSSyqWW8VbWtklBAS
ZFK+jMK2mDbpj9lDGREzM3DUYFoRWoIjkrmciAm9NOK33y+Hs9GMtrrnC5fL
4Z7zOVdzuv2II18gEBizJ3dj9IJ2na6IJ/fv5TJN/D71c78I6xgxv9aP1Gbr
OmMu30iJoSY5UojvcZK2MC5ttv6v8eSGnQS6hdifJCeUfPV4AU+cZ3JJkYG5
PTMf83E+TWyuW/l9eTwJz+SSIYmXQY9QgJ4AvG8k16QZjvbngYmJOZg1jvoF
EPxT3h3mOTovBCbjckviHN0nguKfzvnHXznqFcPJY95ZawQ9MVy0Rh6mp9Ar
gdjZ0YZLr9ArhUjonOPdE/TKYMevvU3fe9GTQGClLlXehf0SMH9JHuiwo8/A
+cXORnszzm+EDY8+3TTvxn1SWC+r4E/J0ZOBP1pbavqdoJ4M3M96bquWE9Tb
BF1tcz+ckwnqyWF0qX+fw5+gXgUc9WyfPdSXoJ4Crs4HU62d6CkgOOS7cNeG
3mYA+3pUfxA9JTCh7hZlA3oquLy/1eLQoaeGiZ5+UiRHTw0Oo21wtRC9LWC1
HuY0ayz1tsLb0GrjlThLvW1gKKs3cYss9SpB49I+aPuM/ZUgEz21LEyx1K8E
T0DVoh9nyb9xowbCM4yveYyl+zSgMOTN7hpGTwv8ZHg6MISeFuwrNceXB9HT
QnRJ0zFwB/9TBTs/TNQv9KJXBYsG6XuvG71qeCEWN41dZ8lfiYhh3A==
       "]]}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Epilog->{
    Dashing[{Small, Small}], 
    LineBox[{{0, 1}, {10, 1}}]},
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*FractionBox[\\(X3\\), \\(Ki\\)]\\)\"", TraditionalForm], 
    FormBox["\"Supply and Demand Rates\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, All}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.895730349621996*^9, {3.895730394733761*^9, 3.8957304205027447`*^9}, 
   3.8957307674085417`*^9},
 CellLabel->
  "Out[399]=",ExpressionUUID->"5cbb829b-d088-4396-bb0c-bdcc4983ab87"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"OptAsFcOfS", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"s", "->", "sv"}], ",", 
        RowBox[{
         RowBox[{"optNF", "[", "sv", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "//", "Flatten"}], ",", 
     RowBox[{"{", 
      RowBox[{"sv", ",", 
       RowBox[{"{", 
        RowBox[{
        "0.1", ",", "0.2", ",", "0.3", ",", "0.4", ",", "0.6", ",", "0.8", 
         ",", "1.2", ",", "1.6", ",", "2", ",", "3", ",", "4", ",", "5"}], 
        "}"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.879229502043573*^9, 3.879229507554291*^9}, {
   3.8792296533571577`*^9, 3.879229770861815*^9}, {3.879229883819592*^9, 
   3.879229892937167*^9}, {3.879229991955608*^9, 3.879229993561421*^9}, {
   3.8792300321309032`*^9, 3.879230042621307*^9}, {3.879230082451847*^9, 
   3.879230152888659*^9}, {3.879230277897236*^9, 3.87923029694271*^9}, {
   3.879230371633835*^9, 3.879230385335096*^9}, 3.8792376227733717`*^9},
 CellLabel->"In[47]:=",ExpressionUUID->"0c4bba6d-ec33-41cd-8362-a3bad96cbb1a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLogPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"s", ",", 
          RowBox[{"e", "[", "j", "]"}]}], "}"}], "/.", 
        RowBox[{"OptAsFcOfS", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "3"}]], ",", "All"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Joined", "->", "True"}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", " ", "Small"}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<S\>\"", ",", "\"\<Enzyme Concentrations\>\""}], "}"}]}], 
   ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ToString", "[", 
       RowBox[{"e", "[", "i", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.879229773575637*^9, 3.879229876099622*^9}, {
  3.879230004978367*^9, 3.879230038461244*^9}, {3.879230159111088*^9, 
  3.8792302536050177`*^9}, {3.879230285809657*^9, 3.879230305326322*^9}, {
  3.879230436531337*^9, 3.8792304390248404`*^9}, {3.895732023386898*^9, 
  3.895732028686948*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"70e85901-3820-4755-b9b8-cb485aaaf13f"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[{{0.1, 6.908486819218974}, {0.2, 4.138599365170667}, {0.3, 
         2.5249068889591233`}, {0.4, 1.393547098082103}, {
         0.6, -0.1264587880607584}, {0.8, -1.0503659753542178`}, {
         1.2, -1.8867968615142061`}, {1.6, -2.138205453777385}, {
         2., -2.2210648098557577`}, {3., -2.2729883153516455`}, {
         4., -2.2837408325476725`}, {5., -2.2876772697755134`}}]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        LineBox[{{0.1, -0.6973903722703585}, {0.2, -2.2282349293266828`}, {
         0.3, -2.941312091177423}, {0.4, -3.3109541478308158`}, {
         0.6, -3.624576170667134}, {0.8, -3.733192691477546}, {
         1.2, -3.7987509996779867`}, {1.6, -3.8178442148956386`}, {
         2., -3.826950825374416}, {3., -3.8385360351815843`}, {
         4., -3.8448687723522283`}, {5., -3.8491013097205213`}}]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        LineBox[{{0.1, -1.7282006547780926`}, {0.2, -2.94625626582938}, {
         0.3, -3.3862447985014974`}, {0.4, -3.580476123570525}, {
         0.6, -3.727874527623202}, {0.8, -3.7754601924670137`}, {
         1.2, -3.803342816224513}, {1.6, -3.81134515436792}, {
         2., -3.815143245133813}, {3., -3.8199576962976654`}, {
         4., -3.8225811771100764`}, {5., -3.824331366081727}}]}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.922526, 0.385626, 0.209179], 
         AbsoluteThickness[1.6]], 
        LineBox[{{0.1, -2.0873502325027387`}, {0.2, -2.186402358819036}, {
         0.3, -2.218111249924057}, {0.4, -2.2351431398047503`}, {
         0.6, -2.2534705823659014`}, {0.8, -2.2633824927869104`}, {
         1.2, -2.2740634896616716`}, {1.6, -2.279827831782265}, {
         2., -2.283480299281376}, {3., -2.288668528276747}, {
         4., -2.291455742054714}, {5., -2.2932168799648194`}}]}}, {{
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               DiskBox[{0, 0}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[7]], {{{0.1, 6.908486819218974}}, {{0.2, 
         4.138599365170667}}, {{0.3, 2.5249068889591233`}}, {{0.4, 
         1.393547098082103}}, {{0.6, -0.1264587880607584}}, {{
         0.8, -1.0503659753542178`}}, {{1.2, -1.8867968615142061`}}, {{
         1.6, -2.138205453777385}}, {{2., -2.2210648098557577`}}, {{
         3., -2.2729883153516455`}}, {{4., -2.2837408325476725`}}, {{
         5., -2.2876772697755134`}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.880722, 0.611041, 0.142051], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[7]], {{{0.1, -0.6973903722703585}}, {{
         0.2, -2.2282349293266828`}}, {{0.3, -2.941312091177423}}, {{
         0.4, -3.3109541478308158`}}, {{0.6, -3.624576170667134}}, {{
         0.8, -3.733192691477546}}, {{1.2, -3.7987509996779867`}}, {{
         1.6, -3.8178442148956386`}}, {{2., -3.826950825374416}}, {{
         3., -3.8385360351815843`}}, {{4., -3.8448687723522283`}}, {{
         5., -3.8491013097205213`}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.560181, 0.691569, 0.194885], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[7]], {{{0.1, -1.7282006547780926`}}, {{
         0.2, -2.94625626582938}}, {{0.3, -3.3862447985014974`}}, {{
         0.4, -3.580476123570525}}, {{0.6, -3.727874527623202}}, {{
         0.8, -3.7754601924670137`}}, {{1.2, -3.803342816224513}}, {{
         1.6, -3.81134515436792}}, {{2., -3.815143245133813}}, {{
         3., -3.8199576962976654`}}, {{4., -3.8225811771100764`}}, {{
         5., -3.824331366081727}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.922526, 0.385626, 0.209179], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[
                
                NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                  1, 1 - 3^Rational[1, 2]}}, {{0, 
                  1}, {-1, -0.7320508075688772}, {
                  1, -0.7320508075688772}}]]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.922526, 0.385626, 0.209179], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[7]], {{{0.1, -2.0873502325027387`}}, {{
         0.2, -2.186402358819036}}, {{0.3, -2.218111249924057}}, {{
         0.4, -2.2351431398047503`}}, {{0.6, -2.2534705823659014`}}, {{
         0.8, -2.2633824927869104`}}, {{1.2, -2.2740634896616716`}}, {{
         1.6, -2.279827831782265}}, {{2., -2.283480299281376}}, {{
         3., -2.288668528276747}}, {{4., -2.291455742054714}}, {{
         5., -2.2932168799648194`}}}]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, GridLines -> {None, None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, -6.907755278982122}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Enzyme Concentrations\"", HoldForm], TraditionalForm], 
        None}, {
        FormBox[
         TagBox["\"S\"", HoldForm], TraditionalForm], None}}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
         15.954589770191003`, RotateLabel -> 0], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
       "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
       Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
       True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 5.}, {-6.907755278982137, 6.908486819218974}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 
        Scaled[0.05]}}, Ticks -> {Automatic, 
       Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
        15.954589770191003`, RotateLabel -> 0]}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"e[1]\"", "\"e[2]\"", "\"e[3]\"", "\"e[4]\""}, 
      "PointLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 7}, {20, 7}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 7}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.032857142857142835`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 7}, {20, 7}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 7}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.032857142857142835`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 7}, {20, 7}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 7}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.032857142857142835`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 7}, {20, 7}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[
                    
                    NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                    1, 1 - 3^Rational[1, 2]}}, {{0, 
                    1}, {-1, -0.7320508075688772}, {
                    1, -0.7320508075688772}}]]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 7}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.032857142857142835`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.560181, 0.691569, 0.194885]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.922526, 0.385626, 0.209179]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}], ",", 
                    RowBox[{"Offset", "[", "7", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], ",", 
                    RowBox[{"Offset", "[", "7", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], ",", 
                    RowBox[{"Offset", "[", "7", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[
                    
                    NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                    1, 1 - 3^Rational[1, 2]}}, {{0, 
                    1}, {-1, -0.7320508075688772}, {
                    1, -0.7320508075688772}}]]}], ",", 
                    RowBox[{"Offset", "[", "7", "]"}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.8792298096375093`*^9, 3.87922987661869*^9}, 
   3.879229907292766*^9, {3.879230034724079*^9, 3.879230039008909*^9}, {
   3.879230116032549*^9, 3.87923030614062*^9}, 3.879230388021247*^9, 
   3.8792304395123262`*^9, 3.879230967863961*^9, 3.8792310599276648`*^9, 
   3.8792312929406643`*^9, 3.879231383387169*^9, 3.87923753192516*^9, 
   3.8792376257101192`*^9, {3.8792381038056793`*^9, 3.8792381082448187`*^9}, 
   3.879238161382279*^9, 3.879238315242689*^9, 3.895724806415938*^9, 
   3.895730767961441*^9, 3.8957320391064262`*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"f4fda830-2746-4c7c-b626-0bb7ec093e24"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLogPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{
         RowBox[{"e", "[", "1", "]"}], "+", 
         RowBox[{"e", "[", "2", "]"}], "+", 
         RowBox[{"e", "[", "3", "]"}], "+", 
         RowBox[{"e", "[", "4", "]"}]}]}], "}"}], "/.", 
      RowBox[{"OptAsFcOfS", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "2"}]], ",", "All"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Joined", "->", "True"}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", " ", "Small"}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<S\>\"", ",", "\"\<Et\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.879231584072034*^9, 3.8792316203326178`*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"454949f6-90f8-4bd4-b455-296a9c385ac1"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      LineBox[{{0.1, 6.909285417505041}, {0.2, 4.142936194402106}, {0.3, 
       2.540434274381977}, {0.4, 1.4351885676943528`}, {0.6, 
       0.036282562232168365`}, {0.8, -0.6918465985170269}, {
       1.2, -1.206828350074969}, {1.6, -1.3308160686708417`}, {
       2., -1.3695047425845117`}, {3., -1.3948947771637938`}, {
       4., -1.4012783535805697`}, {5., -1.4041525903116847`}}]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
       FormBox[
        StyleBox[
         GraphicsBox[
          {EdgeForm[None], DiskBox[{0, 0}]}],
         StripOnInput->False,
         GraphicsBoxOptions->{DefaultBaseStyle->Directive[
           PointSize[0.012833333333333334`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]]}],
        TraditionalForm], {0., 0.}, Automatic, Offset[7]], {{{0.1, 
      6.909285417505041}}, {{0.2, 4.142936194402106}}, {{0.3, 
      2.540434274381977}}, {{0.4, 1.4351885676943528`}}, {{0.6, 
      0.036282562232168365`}}, {{0.8, -0.6918465985170269}}, {{
      1.2, -1.206828350074969}}, {{1.6, -1.3308160686708417`}}, {{
      2., -1.3695047425845117`}}, {{3., -1.3948947771637938`}}, {{
      4., -1.4012783535805697`}}, {{5., -1.4041525903116847`}}}]}}, {{}, {}}},
  
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, -4.605170185988081},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Et\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"S\"", HoldForm], TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{
      Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
       15.954589770191003`, RotateLabel -> 0], 
      Charting`ScaledFrameTicks[{Log, Exp}]}, {
     Automatic, Automatic}}, {{{{-4.605170185988091, 
        FormBox[
         TagBox[
          InterpretationBox[
           StyleBox["\"0.01\"", ShowStringCharacters -> False], 
           0.01`15.954589770191003, AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
        0.}}, {-2.3025850929940455`, 
        FormBox[
         TagBox[
          InterpretationBox[
           StyleBox["\"0.10\"", ShowStringCharacters -> False], 
           0.1`15.954589770191003, AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 0.}}, {0., 
        FormBox["1", TraditionalForm], {0.01, 0.}}, {2.302585092994046, 
        FormBox["10", TraditionalForm], {0.01, 0.}}, {4.605170185988092, 
        FormBox["100", TraditionalForm], {0.01, 0.}}, {6.907755278982137, 
        FormBox["1000", TraditionalForm], {0.01, 0.}}, {-6.907755278982137, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-6.214608098422191, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.809142990314028, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.521460917862246, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.298317366548036, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.115995809754082, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4.961845129926823, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4.8283137373023015`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4.710530701645918, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-3.912023005428146, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-3.506557897319982, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-3.2188758248682006`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-2.995732273553991, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-2.8134107167600364`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-2.659260036932778, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-2.5257286443082556`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-2.4079456086518722`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-1.6094379124341003`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-1.2039728043259361`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.916290731874155, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.6931471805599453, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.5108256237659907, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.35667494393873245`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.2231435513142097, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.10536051565782628`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.6931471805599453, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.0986122886681098`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.3862943611198906`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.6094379124341003`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.791759469228055, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.9459101490553132`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.0794415416798357`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.1972245773362196`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.995732273553991, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.4011973816621555`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.6888794541139363`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.912023005428146, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.0943445622221, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.248495242049359, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.382026634673881, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.499809670330265, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.298317366548036, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.703782474656201, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.991464547107982, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.214608098422191, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.396929655216146, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.551080335043404, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.684611727667927, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.802394763324311, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       7.600902459542082, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.006367567650246, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.294049640102028, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.517193191416238, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.699514748210191, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.85366542803745, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.987196820661973, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       9.104979856318357, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       9.210340371976184, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       9.615805480084347, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       9.903487552536127, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}}, {{-4.605170185988091, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-2.3025850929940455`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {0., 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       2.302585092994046, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       4.605170185988092, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       6.907755278982137, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-6.907755278982137, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-6.214608098422191, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.809142990314028, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.521460917862246, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.298317366548036, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.115995809754082, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4.961845129926823, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4.8283137373023015`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4.710530701645918, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-3.912023005428146, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-3.506557897319982, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-3.2188758248682006`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-2.995732273553991, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-2.8134107167600364`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-2.659260036932778, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-2.5257286443082556`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-2.4079456086518722`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-1.6094379124341003`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-1.2039728043259361`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.916290731874155, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.6931471805599453, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.5108256237659907, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.35667494393873245`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.2231435513142097, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.10536051565782628`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.6931471805599453, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.0986122886681098`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.3862943611198906`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.6094379124341003`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.791759469228055, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.9459101490553132`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.0794415416798357`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.1972245773362196`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.995732273553991, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.4011973816621555`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.6888794541139363`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.912023005428146, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.0943445622221, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.248495242049359, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.382026634673881, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.499809670330265, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.298317366548036, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.703782474656201, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.991464547107982, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.214608098422191, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.396929655216146, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.551080335043404, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.684611727667927, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.802394763324311, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       7.600902459542082, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.006367567650246, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.294049640102028, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.517193191416238, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.699514748210191, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.85366542803745, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8.987196820661973, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       9.104979856318357, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       9.210340371976184, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       9.615805480084347, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       9.903487552536127, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}, {
     Automatic, Automatic}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 5.}, {-4.605170185988092, 6.909285417505041}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 
     Scaled[0.05]}},
  Ticks->{Automatic, 
    Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
     15.954589770191003`, RotateLabel -> 0]}]], "Output",
 CellChangeTimes->{{3.879231595127707*^9, 3.87923162069022*^9}, 
   3.879237532410981*^9, 3.879237627142829*^9, 3.879238110510725*^9, 
   3.879238163382321*^9, 3.879238315829156*^9, 3.895724806581604*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"8353dec1-2288-4bb3-a4b6-21210c68cf90"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"e", "[", "1", "]"}], "+", 
           RowBox[{"e", "[", "2", "]"}], "+", 
           RowBox[{"e", "[", "3", "]"}], "+", 
           RowBox[{"e", "[", "4", "]"}]}], ")"}]}]}], "}"}], "/.", 
      RowBox[{"OptAsFcOfS", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Joined", "->", "True"}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", " ", "Small"}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<S\>\"", ",", "\"\<\!\(\*FractionBox[\(J\), \(Et\)]\)\>\""}],
      "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.879230319958708*^9, 3.879230398887143*^9}, {
  3.8792304458499937`*^9, 3.879230446169324*^9}, {3.879231148422792*^9, 
  3.879231158736329*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"1f5ed924-6208-4fe5-8cc2-e18994ac0ac0"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      LineBox[{{0.1, 0.0009984710315421828}, {0.2, 0.015876167487273125`}, {
       0.3, 0.07883215756944499}, {0.4, 0.23807046738266505`}, {0.6, 
       0.9643677610740531}, {0.8, 1.9974005266947346`}, {1.2, 
       3.342865422344405}, {1.6, 3.784130237990117}, {2., 
       3.9334021664075562`}, {3., 4.0345500235001746`}, {4., 
       4.060387261133913}, {5., 4.072074563333087}}]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
       FormBox[
        StyleBox[
         GraphicsBox[
          {EdgeForm[None], DiskBox[{0, 0}]}],
         StripOnInput->False,
         GraphicsBoxOptions->{DefaultBaseStyle->Directive[
           PointSize[0.012833333333333334`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]]}],
        TraditionalForm], {0., 0.}, Automatic, Offset[7]], {{{0.1, 
      0.0009984710315421828}}, {{0.2, 0.015876167487273125`}}, {{0.3, 
      0.07883215756944499}}, {{0.4, 0.23807046738266505`}}, {{0.6, 
      0.9643677610740531}}, {{0.8, 1.9974005266947346`}}, {{1.2, 
      3.342865422344405}}, {{1.6, 3.784130237990117}}, {{2., 
      3.9334021664075562`}}, {{3., 4.0345500235001746`}}, {{4., 
      4.060387261133913}}, {{5., 4.072074563333087}}}]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"\\!\\(\\*FractionBox[\\(J\\), \\(Et\\)]\\)\"", HoldForm], 
      TraditionalForm], None}, {
     FormBox[
      TagBox["\"S\"", HoldForm], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 5.}, {0., 4.072074563333087}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.879230359908236*^9, 3.8792303995442877`*^9}, 
   3.8792304464791813`*^9, 3.879230970412017*^9, 3.8792310621258593`*^9, {
   3.8792311490209017`*^9, 3.879231159290628*^9}, 3.879231295589489*^9, 
   3.879231385637307*^9, 3.8792375326832027`*^9, 3.8792376291697683`*^9, 
   3.8792381126719007`*^9, 3.8792381655801563`*^9, 3.879238316120451*^9, 
   3.895724806672463*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"44f4d1e3-f994-431a-8fe7-8615ec640507"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"s", ",", 
          FractionBox[
           RowBox[{"e", "[", "j", "]"}], 
           RowBox[{
            RowBox[{"e", "[", "1", "]"}], "+", 
            RowBox[{"e", "[", "2", "]"}], "+", 
            RowBox[{"e", "[", "3", "]"}], "+", 
            RowBox[{"e", "[", "4", "]"}]}]]}], "}"}], "/.", 
        RowBox[{"OptAsFcOfS", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Joined", "->", "True"}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", " ", "Small"}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<S\>\"", ",", 
      "\"\<Protein i synthesis rate = e[i] \!\(\*FractionBox[\(J\), \(Et\)]\) \
(J=1) = \!\(\*SubsuperscriptBox[\(C\), \(i\), \(J\)]\)\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ToString", "[", 
       RowBox[{"e", "[", "i", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.8792314169044523`*^9, 3.8792314972331953`*^9}, {
  3.879231540130826*^9, 3.879231552057055*^9}, {3.879231632238455*^9, 
  3.879231651669552*^9}, {3.8792384611810913`*^9, 3.879238485525858*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"71515a90-3aae-42ad-b1d2-a17416253cb9"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[{{0.1, 0.9992017205086762}, {0.2, 0.9956725612326021}, {0.3, 
         0.9845925428994007}, {0.4, 0.9592136261625783}, {0.6, 
         0.8498109633477415}, {0.8, 0.6987100869158265}, {1.2, 
         0.5066329452567027}, {1.6, 0.4460209365589628}, {2., 
         0.42674865575512577`}, {3., 0.4155744337265715}, {4., 
         0.4137627740348938}, {5., 0.41332350834620435`}}]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        LineBox[{{0.1, 0.0004971216517058858}, {0.2, 
         0.0017101552489503257`}, {0.3, 0.004162054878210083}, {0.4, 
         0.008685131698287994}, {0.6, 0.025710424856247808`}, {0.8, 
         0.04777054260434695}, {1.2, 0.07487594140506311}, {1.6, 
         0.08315672936218552}, {2., 0.08565342362072624}, {3., 
         0.08684405343446577}, {4., 0.08684846863290513}, {5., 
         0.08673058238323199}}]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        LineBox[{{0.1, 0.0001773321425453469}, {0.2, 0.0008340706389333042}, {
         0.3, 0.0026673252895529605`}, {0.4, 0.006633221527153254}, {0.6, 
         0.023187148683263378`}, {0.8, 0.04579347826554847}, {1.2, 
         0.07453291298289803}, {1.6, 0.08369892996843174}, {2., 
         0.08667077771823742}, {3., 0.08847255225060129}, {4., 
         0.08880584371663225}, {5., 0.08890572184966888}}]}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.922526, 0.385626, 0.209179], 
         AbsoluteThickness[1.6]], 
        LineBox[{{0.1, 0.0001238256970725947}, {0.2, 
         0.0017832128795142836`}, {0.3, 0.00857807693283636}, {0.4, 
         0.025468020611980342`}, {0.6, 0.10129146311274737`}, {0.8, 
         0.20772589221427817`}, {1.2, 0.3439582003553361}, {1.6, 
         0.38712340411041996`}, {2., 0.4009271429059106}, {3., 
         0.4091089605883615}, {4., 0.41058291361556876`}, {5., 
         0.41104018742089476`}}]}}, {{
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               DiskBox[{0, 0}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[7]], {{{0.1, 0.9992017205086762}}, {{0.2, 
         0.9956725612326021}}, {{0.3, 0.9845925428994007}}, {{0.4, 
         0.9592136261625783}}, {{0.6, 0.8498109633477415}}, {{0.8, 
         0.6987100869158265}}, {{1.2, 0.5066329452567027}}, {{1.6, 
         0.4460209365589628}}, {{2., 0.42674865575512577`}}, {{3., 
         0.4155744337265715}}, {{4., 0.4137627740348938}}, {{5., 
         0.41332350834620435`}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.880722, 0.611041, 0.142051], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[7]], {{{0.1, 0.0004971216517058858}}, {{0.2, 
         0.0017101552489503257`}}, {{0.3, 0.004162054878210083}}, {{0.4, 
         0.008685131698287994}}, {{0.6, 0.025710424856247808`}}, {{0.8, 
         0.04777054260434695}}, {{1.2, 0.07487594140506311}}, {{1.6, 
         0.08315672936218552}}, {{2., 0.08565342362072624}}, {{3., 
         0.08684405343446577}}, {{4., 0.08684846863290513}}, {{5., 
         0.08673058238323199}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.560181, 0.691569, 0.194885], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[7]], {{{0.1, 0.0001773321425453469}}, {{0.2, 
         0.0008340706389333042}}, {{0.3, 0.0026673252895529605`}}, {{0.4, 
         0.006633221527153254}}, {{0.6, 0.023187148683263378`}}, {{0.8, 
         0.04579347826554847}}, {{1.2, 0.07453291298289803}}, {{1.6, 
         0.08369892996843174}}, {{2., 0.08667077771823742}}, {{3., 
         0.08847255225060129}}, {{4., 0.08880584371663225}}, {{5., 
         0.08890572184966888}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.922526, 0.385626, 0.209179], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[
                
                NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                  1, 1 - 3^Rational[1, 2]}}, {{0, 
                  1}, {-1, -0.7320508075688772}, {
                  1, -0.7320508075688772}}]]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.922526, 0.385626, 0.209179], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[7]], {{{0.1, 0.0001238256970725947}}, {{0.2, 
         0.0017832128795142836`}}, {{0.3, 0.00857807693283636}}, {{0.4, 
         0.025468020611980342`}}, {{0.6, 0.10129146311274737`}}, {{0.8, 
         0.20772589221427817`}}, {{1.2, 0.3439582003553361}}, {{1.6, 
         0.38712340411041996`}}, {{2., 0.4009271429059106}}, {{3., 
         0.4091089605883615}}, {{4., 0.41058291361556876`}}, {{5., 
         0.41104018742089476`}}}]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         TagBox[
         "\"Protein i synthesis rate = e[i] \\!\\(\\*FractionBox[\\(J\\), \
\\(Et\\)]\\) (J=1) = \\!\\(\\*SubsuperscriptBox[\\(C\\), \\(i\\), \\(J\\)]\\)\
\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox["\"S\"", HoldForm], TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
       "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
       Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
       True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 5.}, {0., 0.9992017205086762}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{0, 0}, {0, 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"e[1]\"", "\"e[2]\"", "\"e[3]\"", "\"e[4]\""}, 
      "PointLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 7}, {20, 7}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 7}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.032857142857142835`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 7}, {20, 7}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 7}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.032857142857142835`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 7}, {20, 7}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 7}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.032857142857142835`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 7}, {20, 7}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[
                    
                    NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                    1, 1 - 3^Rational[1, 2]}}, {{0, 
                    1}, {-1, -0.7320508075688772}, {
                    1, -0.7320508075688772}}]]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 7}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.032857142857142835`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.560181, 0.691569, 0.194885]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.922526, 0.385626, 0.209179]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}], ",", 
                    RowBox[{"Offset", "[", "7", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], ",", 
                    RowBox[{"Offset", "[", "7", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], ",", 
                    RowBox[{"Offset", "[", "7", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[
                    
                    NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                    1, 1 - 3^Rational[1, 2]}}, {{0, 
                    1}, {-1, -0.7320508075688772}, {
                    1, -0.7320508075688772}}]]}], ",", 
                    RowBox[{"Offset", "[", "7", "]"}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.879231418533464*^9, 3.8792314268103533`*^9}, {
   3.8792314584729767`*^9, 3.879231498510495*^9}, 3.8792315528927307`*^9, {
   3.879231639279179*^9, 3.879231652028054*^9}, 3.879237532778778*^9, 
   3.879237630794209*^9, 3.8792381146472197`*^9, 3.879238167762589*^9, 
   3.879238316282185*^9, {3.8792384677144833`*^9, 3.8792384880179253`*^9}, 
   3.895724806719267*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"1fdf1049-69e6-4241-88f7-ba9244474bba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pl8", "=", 
  RowBox[{"ListLogPlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", 
           RowBox[{"e", "[", "j", "]"}]}], "}"}], "/.", 
         RowBox[{"OptAsFcOfS", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["10", 
          RowBox[{"-", "2"}]], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["10", 
          RowBox[{"-", "2"}]], ",", "All"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Joined", "->", "True"}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", " ", "Medium"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SubscriptBox[\(X\), \(3, ss\)]\)(s)\>\"", ",", 
       "\"\<Enzyme concentrations(s)\>\""}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"PointLegend", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"ToString", "[", 
         RowBox[{"e", "[", "i", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], "]"}]}], ",", 
    RowBox[{"ImageSize", "->", "400"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.879237474503941*^9, 3.879237488267232*^9}, {
  3.879237642012959*^9, 3.879237775786139*^9}, {3.895732073870043*^9, 
  3.89573218065351*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"fe353c92-a262-4bc7-a4b5-bab2f8f00306"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         AbsoluteThickness[1.6], FontSize -> 16, FontColor -> GrayLevel[0], 
         Hue[0.55, 1, 0.7]], 
        LineBox[{{0.04164005317310502, 6.908486819218974}, {
         0.08116810605298104, 4.138599365170667}, {0.1134502261533149, 
         2.5249068889591233`}, {0.14333185514096528`, 1.393547098082103}, {
         0.19864670873030996`, -0.1264587880607584}, {
         0.2501177865536414, -1.0503659753542178`}, {
         0.34563518761558676`, -1.8867968615142061`}, {
         0.43443914088318875`, -2.138205453777385}, {
         0.5184447400532052, -2.2210648098557577`}, {
         0.7135796793437875, -2.2729883153516455`}, {
         0.893534151929105, -2.2837408325476725`}, {
         1.0624470288897117`, -2.2876772697755134`}}]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         AbsoluteThickness[1.6], FontSize -> 16, FontColor -> GrayLevel[0], 
         Hue[0.06, 1, 0.9]], 
        LineBox[{{0.04164005317310502, -0.6973903722703585}, {
         0.08116810605298104, -2.2282349293266828`}, {
         0.1134502261533149, -2.941312091177423}, {
         0.14333185514096528`, -3.3109541478308158`}, {
         0.19864670873030996`, -3.624576170667134}, {
         0.2501177865536414, -3.733192691477546}, {
         0.34563518761558676`, -3.7987509996779867`}, {
         0.43443914088318875`, -3.8178442148956386`}, {
         0.5184447400532052, -3.826950825374416}, {
         0.7135796793437875, -3.8385360351815843`}, {
         0.893534151929105, -3.8448687723522283`}, {
         1.0624470288897117`, -3.8491013097205213`}}]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         AbsoluteThickness[1.6], FontSize -> 16, FontColor -> GrayLevel[0], 
         Hue[0.25, 1, 0.55]], 
        LineBox[{{0.04164005317310502, -1.7282006547780926`}, {
         0.08116810605298104, -2.94625626582938}, {
         0.1134502261533149, -3.3862447985014974`}, {
         0.14333185514096528`, -3.580476123570525}, {
         0.19864670873030996`, -3.727874527623202}, {
         0.2501177865536414, -3.7754601924670137`}, {
         0.34563518761558676`, -3.803342816224513}, {
         0.43443914088318875`, -3.81134515436792}, {
         0.5184447400532052, -3.815143245133813}, {
         0.7135796793437875, -3.8199576962976654`}, {
         0.893534151929105, -3.8225811771100764`}, {
         1.0624470288897117`, -3.824331366081727}}]}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         AbsoluteThickness[1.6], FontSize -> 16, FontColor -> GrayLevel[0], 
         Hue[0.11, 0.9, 0.85]], 
        LineBox[{{0.04164005317310502, -2.0873502325027387`}, {
         0.08116810605298104, -2.186402358819036}, {
         0.1134502261533149, -2.218111249924057}, {
         0.14333185514096528`, -2.2351431398047503`}, {
         0.19864670873030996`, -2.2534705823659014`}, {
         0.2501177865536414, -2.2633824927869104`}, {
         0.34563518761558676`, -2.2740634896616716`}, {
         0.43443914088318875`, -2.279827831782265}, {
         0.5184447400532052, -2.283480299281376}, {
         0.7135796793437875, -2.288668528276747}, {
         0.893534151929105, -2.291455742054714}, {
         1.0624470288897117`, -2.2932168799648194`}}]}}, {{
        Directive[
         PointSize[0.012833333333333334`], 
         AbsoluteThickness[1.6], FontSize -> 16, FontColor -> GrayLevel[0], 
         Hue[0.55, 1, 0.7]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               DiskBox[{0, 0}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                 GrayLevel[0], 
                 Hue[0.55, 1, 0.7]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[10]], {{{0.04164005317310502, 6.908486819218974}}, {{
         0.08116810605298104, 4.138599365170667}}, {{0.1134502261533149, 
         2.5249068889591233`}}, {{0.14333185514096528`, 
         1.393547098082103}}, {{
         0.19864670873030996`, -0.1264587880607584}}, {{
         0.2501177865536414, -1.0503659753542178`}}, {{
         0.34563518761558676`, -1.8867968615142061`}}, {{
         0.43443914088318875`, -2.138205453777385}}, {{
         0.5184447400532052, -2.2210648098557577`}}, {{
         0.7135796793437875, -2.2729883153516455`}}, {{
         0.893534151929105, -2.2837408325476725`}}, {{
         1.0624470288897117`, -2.2876772697755134`}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         AbsoluteThickness[1.6], FontSize -> 16, FontColor -> GrayLevel[0], 
         Hue[0.06, 1, 0.9]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                 GrayLevel[0], 
                 Hue[0.06, 1, 0.9]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[10]], {{{0.04164005317310502, -0.6973903722703585}}, {{
         0.08116810605298104, -2.2282349293266828`}}, {{
         0.1134502261533149, -2.941312091177423}}, {{
         0.14333185514096528`, -3.3109541478308158`}}, {{
         0.19864670873030996`, -3.624576170667134}}, {{
         0.2501177865536414, -3.733192691477546}}, {{
         0.34563518761558676`, -3.7987509996779867`}}, {{
         0.43443914088318875`, -3.8178442148956386`}}, {{
         0.5184447400532052, -3.826950825374416}}, {{
         0.7135796793437875, -3.8385360351815843`}}, {{
         0.893534151929105, -3.8448687723522283`}}, {{
         1.0624470288897117`, -3.8491013097205213`}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         AbsoluteThickness[1.6], FontSize -> 16, FontColor -> GrayLevel[0], 
         Hue[0.25, 1, 0.55]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                 GrayLevel[0], 
                 Hue[0.25, 1, 0.55]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[10]], {{{0.04164005317310502, -1.7282006547780926`}}, {{
         0.08116810605298104, -2.94625626582938}}, {{
         0.1134502261533149, -3.3862447985014974`}}, {{
         0.14333185514096528`, -3.580476123570525}}, {{
         0.19864670873030996`, -3.727874527623202}}, {{
         0.2501177865536414, -3.7754601924670137`}}, {{
         0.34563518761558676`, -3.803342816224513}}, {{
         0.43443914088318875`, -3.81134515436792}}, {{
         0.5184447400532052, -3.815143245133813}}, {{
         0.7135796793437875, -3.8199576962976654`}}, {{
         0.893534151929105, -3.8225811771100764`}}, {{
         1.0624470288897117`, -3.824331366081727}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         AbsoluteThickness[1.6], FontSize -> 16, FontColor -> GrayLevel[0], 
         Hue[0.11, 0.9, 0.85]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[
                
                NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                  1, 1 - 3^Rational[1, 2]}}, {{0, 
                  1}, {-1, -0.7320508075688772}, {
                  1, -0.7320508075688772}}]]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                 GrayLevel[0], 
                 Hue[0.11, 0.9, 0.85]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[10]], {{{0.04164005317310502, -2.0873502325027387`}}, {{
         0.08116810605298104, -2.186402358819036}}, {{
         0.1134502261533149, -2.218111249924057}}, {{
         0.14333185514096528`, -2.2351431398047503`}}, {{
         0.19864670873030996`, -2.2534705823659014`}}, {{
         0.2501177865536414, -2.2633824927869104`}}, {{
         0.34563518761558676`, -2.2740634896616716`}}, {{
         0.43443914088318875`, -2.279827831782265}}, {{
         0.5184447400532052, -2.283480299281376}}, {{
         0.7135796793437875, -2.288668528276747}}, {{
         0.893534151929105, -2.291455742054714}}, {{
         1.0624470288897117`, -2.2932168799648194`}}}]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, GridLines -> {None, None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True}, 
     AxesLabel -> {None, None}, 
     AxesOrigin -> {0.010000000000000023`, -4.605170185988081}, 
     BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Enzyme concentrations(s)\"", HoldForm], TraditionalForm], 
        None}, {
        FormBox[
         TagBox[
         "\"\\!\\(\\*SubscriptBox[\\(X\\), \\(3, ss\\)]\\)(s)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> Directive[
       GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"], 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
         15.954589770191003`, RotateLabel -> 0], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 400, 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
       "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
       Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
       True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0.01, 1.}, {-4.605170185988092, 6.908486819218974}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 
        Scaled[0.05]}}, Prolog -> {
       RGBColor[
        NCache[{
          Rational[223, 255], 
          Rational[72, 85], 
          Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
         0.7843137254901961}]], 
       RectangleBox[
        Scaled[{0, 0}], 
        Scaled[{1, 1}]]}, Ticks -> {Automatic, 
       Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
        15.954589770191003`, RotateLabel -> 0]}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"e[1]\"", "\"e[2]\"", "\"e[3]\"", "\"e[4]\""}, 
      "PointLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.55, 1, 0.7]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.55, 1, 0.7]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.55, 1, 0.7]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 10},
                     PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.06, 1, 0.9]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.06, 1, 0.9]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.06, 1, 0.9]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 10},
                     PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.25, 1, 0.55]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.25, 1, 0.55]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.25, 1, 0.55]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 10},
                     PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.11, 0.9, 0.85]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.11, 0.9, 0.85]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[
                    
                    NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                    1, 1 - 3^Rational[1, 2]}}, {{0, 
                    1}, {-1, -0.7320508075688772}, {
                    1, -0.7320508075688772}}]]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.11, 0.9, 0.85]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 10},
                     PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.55, 1, 0.7]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.06, 1, 0.9]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.25, 1, 0.55]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.11, 0.9, 0.85]|>, 
                    "HueColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}], ",", 
                    RowBox[{"Offset", "[", "10", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], ",", 
                    RowBox[{"Offset", "[", "10", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], ",", 
                    RowBox[{"Offset", "[", "10", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[
                    
                    NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                    1, 1 - 3^Rational[1, 2]}}, {{0, 
                    1}, {-1, -0.7320508075688772}, {
                    1, -0.7320508075688772}}]]}], ",", 
                    RowBox[{"Offset", "[", "10", "]"}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.879237536353243*^9, 3.87923763208431*^9, {3.879237665215837*^9, 
   3.8792377762336483`*^9}, 3.879238117419043*^9, 3.879238170239407*^9, 
   3.8792383164344*^9, 3.8957248067872877`*^9, {3.895732047078991*^9, 
   3.895732181267082*^9}},
 CellLabel->"Out[62]=",ExpressionUUID->"b0c23f2a-0d07-4362-9801-20a7a754cd89"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_1.pdf\>\"", ",", "pl1"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_2.pdf\>\"", ",", "pl2"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_3.pdf\>\"", ",", "pl3"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_4.pdf\>\"", ",", "pl4"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_5.pdf\>\"", ",", "pl5"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_6.pdf\>\"", ",", "pl6"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_7.pdf\>\"", ",", "pl7"}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_8.pdf\>\"", ",", "pl8"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.895732196367669*^9, 3.895732272524953*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"857b21f7-5d8b-45c2-b7a0-66e1b71567a9"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_1.pdf\"\>"], "Output",
 CellChangeTimes->{{3.895732263625119*^9, 3.895732273890815*^9}},
 CellLabel->"Out[72]=",ExpressionUUID->"5d8b0d2b-820c-4953-b4ac-aabd80f2d68c"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_2.pdf\"\>"], "Output",
 CellChangeTimes->{{3.895732263625119*^9, 3.895732274043357*^9}},
 CellLabel->"Out[73]=",ExpressionUUID->"2820d5c4-3f95-46ca-9064-e5fdd405f605"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_3.pdf\"\>"], "Output",
 CellChangeTimes->{{3.895732263625119*^9, 3.895732274210783*^9}},
 CellLabel->"Out[74]=",ExpressionUUID->"87a9033b-9f41-47ae-a958-e6c3d707afec"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_4.pdf\"\>"], "Output",
 CellChangeTimes->{{3.895732263625119*^9, 3.8957322743834743`*^9}},
 CellLabel->"Out[75]=",ExpressionUUID->"b96dbcef-74a9-4dea-bfa5-512b3e9093d0"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_5.pdf\"\>"], "Output",
 CellChangeTimes->{{3.895732263625119*^9, 3.895732274563964*^9}},
 CellLabel->"Out[76]=",ExpressionUUID->"4997247f-b515-4f39-9a44-f56fc3bdeca8"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_6.pdf\"\>"], "Output",
 CellChangeTimes->{{3.895732263625119*^9, 3.8957322747335577`*^9}},
 CellLabel->"Out[77]=",ExpressionUUID->"5285f63d-6c9e-4b93-b8c1-44bab30faff9"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_7.pdf\"\>"], "Output",
 CellChangeTimes->{{3.895732263625119*^9, 3.895732274915387*^9}},
 CellLabel->"Out[78]=",ExpressionUUID->"409a924b-8721-4d5f-8e58-080dcde921f1"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/neg_feedb_optimisation_8.pdf\"\>"], "Output",
 CellChangeTimes->{{3.895732263625119*^9, 3.895732275215324*^9}},
 CellLabel->"Out[79]=",ExpressionUUID->"1e844f7c-0572-4e3a-a13f-2228b604fb74"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
From the last plot we conclude that the feedback metabolite should inhibit \
the synthesis of all the enzymes via  gene expression regulation, from this \
we deduce the desired gene expression control mechanism that achieves \
optimality of enzyme concentrations. \
\>", "Subsubsection",
 CellChangeTimes->{{3.8792379537588253`*^9, 3.879238004204666*^9}, {
  3.879238274845107*^9, 3.879238300112103*^9}, {3.895725008629634*^9, 
  3.8957250396421623`*^9}},ExpressionUUID->"48a62d00-3120-4933-a602-\
e4c0ea0fb3d6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLogPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}]}], "}"}], "/.", 
      RowBox[{"OptAsFcOfS", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "2"}]], ",", "5.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0.2", " ", 
         SuperscriptBox["10", 
          RowBox[{"-", "1"}]]}], ",", "All"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Joined", "->", "True"}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", " ", "Small"}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<S\>\"", ",", "\"\<\!\(\*SubscriptBox[\(X\), \(3, ss\)]\)(s)\>\""}], 
     "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ToString", "[", 
       RowBox[{"e", "[", "i", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.8792377974503393`*^9, 3.8792378658869534`*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"a8b5e200-3695-4bb2-82d0-65f376107482"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[{{0.1, -3.178692758264402}, {0.2, -2.5112328915725506`}, {
         0.3, -2.1763910743398958`}, {0.4, -1.9425926719858273`}, {
         0.6, -1.616227365042473}, {0.8, -1.3858233258598536`}, {
         1.2, -1.0623714312178125`}, {1.6, -0.8336994110992142}, {
         2., -0.6569218335530789}, {3., -0.33746117437769685`}, {
         4., -0.11257072247282422`}, {5., 0.06057476541100059}}]}}, {{
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               DiskBox[{0, 0}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[7]], {{{0.1, -3.178692758264402}}, {{
         0.2, -2.5112328915725506`}}, {{0.3, -2.1763910743398958`}}, {{
         0.4, -1.9425926719858273`}}, {{0.6, -1.616227365042473}}, {{
         0.8, -1.3858233258598536`}}, {{1.2, -1.0623714312178125`}}, {{
         1.6, -0.8336994110992142}}, {{2., -0.6569218335530789}}, {{
         3., -0.33746117437769685`}}, {{4., -0.11257072247282422`}}, {{5., 
         0.06057476541100059}}}]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, GridLines -> {None, None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, 
     AxesOrigin -> {0.010000000000000023`, -3.912023005428137}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox[
         "\"\\!\\(\\*SubscriptBox[\\(X\\), \\(3, ss\\)]\\)(s)\"", HoldForm], 
         TraditionalForm], None}, {
        FormBox[
         TagBox["\"S\"", HoldForm], TraditionalForm], None}}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
         15.954589770191003`, RotateLabel -> 0], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
       "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
       Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
       True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0.01, 5.5}, {-3.912023005428146, 0.06057476541100059}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 
        Scaled[0.05]}}, Ticks -> {Automatic, 
       Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
        15.954589770191003`, RotateLabel -> 0]}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"e[1]\"", "\"e[2]\"", "\"e[3]\"", "\"e[4]\""}, 
      "PointLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 7}, {20, 7}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {20, 7}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.032857142857142835`] -> 
                    Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"Directive", "[", 
               RowBox[{
                 RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                 ",", 
                 
                 TemplateBox[<|
                  "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                  "RGBColorSwatchTemplate"], ",", 
                 RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"{", 
                 RowBox[{
                   GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}], ",", 
                   RowBox[{"Offset", "[", "7", "]"}]}], "}"}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", "True", "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.879237815345854*^9, 3.879237866206277*^9}, 
   3.8792381210383*^9, 3.8792383166663647`*^9, 3.895724806902608*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"ccd003d7-ca53-47d1-9c4d-6ec6f23527c7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"e", "[", "1", "]"}], "+", 
           RowBox[{"e", "[", "2", "]"}], "+", 
           RowBox[{"e", "[", "3", "]"}], "+", 
           RowBox[{"e", "[", "4", "]"}]}], ")"}]}]}], "}"}], "/.", 
      RowBox[{"OptAsFcOfS", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Joined", "->", "True"}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", " ", "Small"}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(X\), \(3, ss\)]\)(S)\>\"", ",", 
      "\"\<\!\(\*FractionBox[\(J\), \(Et\)]\)(S)\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.879237892380127*^9, 3.8792379428713083`*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"69e01af2-f147-430e-b86d-e916959da81e"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      LineBox[{{0.04164005317310502, 0.0009984710315421828}, {
       0.08116810605298104, 0.015876167487273125`}, {0.1134502261533149, 
       0.07883215756944499}, {0.14333185514096528`, 0.23807046738266505`}, {
       0.19864670873030996`, 0.9643677610740531}, {0.2501177865536414, 
       1.9974005266947346`}, {0.34563518761558676`, 3.342865422344405}, {
       0.43443914088318875`, 3.784130237990117}, {0.5184447400532052, 
       3.9334021664075562`}, {0.7135796793437875, 4.0345500235001746`}, {
       0.893534151929105, 4.060387261133913}, {1.0624470288897117`, 
       4.072074563333087}}]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
       FormBox[
        StyleBox[
         GraphicsBox[
          {EdgeForm[None], DiskBox[{0, 0}]}],
         StripOnInput->False,
         GraphicsBoxOptions->{DefaultBaseStyle->Directive[
           PointSize[0.012833333333333334`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]]}],
        TraditionalForm], {0., 0.}, Automatic, Offset[7]], {{{
      0.04164005317310502, 0.0009984710315421828}}, {{0.08116810605298104, 
      0.015876167487273125`}}, {{0.1134502261533149, 0.07883215756944499}}, {{
      0.14333185514096528`, 0.23807046738266505`}}, {{0.19864670873030996`, 
      0.9643677610740531}}, {{0.2501177865536414, 1.9974005266947346`}}, {{
      0.34563518761558676`, 3.342865422344405}}, {{0.43443914088318875`, 
      3.784130237990117}}, {{0.5184447400532052, 3.9334021664075562`}}, {{
      0.7135796793437875, 4.0345500235001746`}}, {{0.893534151929105, 
      4.060387261133913}}, {{1.0624470288897117`, 
      4.072074563333087}}}]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"\\!\\(\\*FractionBox[\\(J\\), \\(Et\\)]\\)(S)\"", HoldForm], 
      TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*SubscriptBox[\\(X\\), \\(3, ss\\)]\\)(S)\"", HoldForm], 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 1.}, {0., 4.072074563333087}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.879237895935375*^9, {3.879237938901127*^9, 3.879237943276775*^9}, 
   3.8792381232763033`*^9, 3.8792383169019527`*^9, 3.895724806978454*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"6936baf3-f25b-44b0-a992-fa56ebf7d136"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Determining the optimal input-output relationship of the gene expression \
control\
\>", "Subsubsection",
 CellChangeTimes->{{3.8957250603657417`*^9, 
  3.8957250995407047`*^9}},ExpressionUUID->"3418d523-a4b7-459f-b9f8-\
9cfd25cfc615"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", 
          RowBox[{"e", "[", "j", "]"}]}], "}"}], "/.", 
        RowBox[{"OptAsFcOfS", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", 
         RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "2"}]], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "5"}]], ",", "All"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", " ", "Medium"}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(X\), \(3, ss\)]\)(s)\>\"", ",", 
      "\"\<Enzyme concentrations(s)\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ToString", "[", 
       RowBox[{"e", "[", "i", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.895725106987389*^9, 3.895725366788577*^9}, {
  3.895725984772481*^9, 3.895725990301244*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"863faac2-2438-4817-99f3-eacdbf3622f6"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               DiskBox[{0, 0}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[10]], {{{0.08116810605298104, 62.71491920394308}}, {{
         0.1134502261533149, 12.489732277491598`}}, {{0.14333185514096528`, 
         4.029116407037486}}, {{0.19864670873030996`, 0.8812104651873417}}, {{
         0.2501177865536414, 0.3498097039515857}}, {{0.34563518761558676`, 
         0.15155648859516244`}}, {{0.43443914088318875`, 
         0.11786616963687276`}}, {{0.5184447400532052, 
         0.10849352232519938`}}, {{0.7135796793437875, 
         0.10300391154055882`}}, {{0.893534151929105, 
         0.10190229340817739`}}, {{1.0624470288897117`, 
         0.10150194990729482`}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.880722, 0.611041, 0.142051], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[10]], {{{0.08116810605298104, 0.10771839301400947`}}, {{
         0.1134502261533149, 0.05279640956856518}}, {{0.14333185514096528`, 
         0.036481348542605485`}}, {{0.19864670873030996`, 
         0.026660394399345255`}}, {{0.2501177865536414, 
         0.02391635626701113}}, {{0.34563518761558676`, 
         0.022398730413906824`}}, {{0.43443914088318875`, 
         0.021975123511169887`}}, {{0.5184447400532052, 
         0.021775913063818486`}}, {{0.7135796793437875, 
         0.021525090264991734`}}, {{0.893534151929105, 
         0.02138920823248067}}, {{1.0624470288897117`, 
         0.021298868926467058`}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.560181, 0.691569, 0.194885], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[10]], {{{0.08116810605298104, 0.052536019136981485`}}, {{
         0.1134502261533149, 0.033835497743459}}, {{0.14333185514096528`, 
         0.027862429137383415`}}, {{0.19864670873030996`, 
         0.024043886180349878`}}, {{0.2501177865536414, 
         0.022926537594003125`}}, {{0.34563518761558676`, 
         0.022296115328096847`}}, {{0.43443914088318875`, 
         0.022118406266293612`}}, {{0.5184447400532052, 
         0.02203455788437604}}, {{0.7135796793437875, 
         0.02192872854104481}}, {{0.893534151929105, 
         0.021871274340426367`}}, {{1.0624470288897117`, 
         0.021833028955368025`}}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.922526, 0.385626, 0.209179], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[
                
                NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                  1, 1 - 3^Rational[1, 2]}}, {{0, 
                  1}, {-1, -0.7320508075688772}, {
                  1, -0.7320508075688772}}]]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.012833333333333334`], 
                 RGBColor[0.922526, 0.385626, 0.209179], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[10]], {{{0.08116810605298104, 0.11232011006080451`}}, {{
         0.1134502261533149, 0.10881443813433297`}}, {{0.14333185514096528`, 
         0.10697681611656625`}}, {{0.19864670873030996`, 
         0.10503406190179482`}}, {{0.2501177865536414, 
         0.10399811627066083`}}, {{0.34563518761558676`, 
         0.1028932238959571}}, {{0.43443914088318875`, 0.102301818321146}}, {{
         0.5184447400532052, 0.10192884580426319`}}, {{0.7135796793437875, 
         0.10140138508765817`}}, {{0.893534151929105, 
         0.10111915125576185`}}, {{1.0624470288897117`, 
         0.1009412232089505}}}]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, 
     AxesOrigin -> {0.010000000000000023`, 0.000010000000000000023`}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Enzyme concentrations(s)\"", HoldForm], TraditionalForm], 
        None}, {
        FormBox[
         TagBox[
         "\"\\!\\(\\*SubscriptBox[\\(X\\), \\(3, ss\\)]\\)(s)\"", HoldForm], 
         TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
       "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
       Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
       True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0.01, 1.}, {0.00001, 62.71491920394308}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"e[1]\"", "\"e[2]\"", "\"e[3]\"", "\"e[4]\""}, 
      "PointLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 10},
                     PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 10},
                     PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 10},
                     PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[
                    
                    NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                    1, 1 - 3^Rational[1, 2]}}, {{0, 
                    1}, {-1, -0.7320508075688772}, {
                    1, -0.7320508075688772}}]]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 10},
                     PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.560181, 0.691569, 0.194885]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.922526, 0.385626, 0.209179]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}], ",", 
                    RowBox[{"Offset", "[", "10", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], ",", 
                    RowBox[{"Offset", "[", "10", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], ",", 
                    RowBox[{"Offset", "[", "10", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[
                    
                    NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                    1, 1 - 3^Rational[1, 2]}}, {{0, 
                    1}, {-1, -0.7320508075688772}, {
                    1, -0.7320508075688772}}]]}], ",", 
                    RowBox[{"Offset", "[", "10", "]"}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False", ",", "False", ",", "False"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.895725102830845*^9, 3.895725128632807*^9}, {
   3.895725174224221*^9, 3.895725367150846*^9}, 3.895725990800605*^9},
 CellLabel->
  "Out[208]=",ExpressionUUID->"6c546184-b8ff-4f7d-9f84-d41318edae2c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["fit1"], "Input",
 CellChangeTimes->{{3.895798462239297*^9, 3.895798462868404*^9}},
 CellLabel->
  "In[255]:=",ExpressionUUID->"e9fda079-3da5-4347-9bba-0f47aa46e552"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "2.209415581011128`*^-6"}], ",", 
   RowBox[{"b", "\[Rule]", "1444.965099435338`"}], ",", 
   RowBox[{"c", "\[Rule]", "136280.67574149257`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.16058981372845205`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.89579846362469*^9},
 CellLabel->
  "Out[255]=",ExpressionUUID->"e3cc09d1-8dfe-4c5d-9bb0-cdb434053b75"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "+", 
   FractionBox["b", 
    RowBox[{"1", "+", 
     RowBox[{"c", " ", 
      FractionBox[
       RowBox[{" ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["x", "d"], ")"}], "4"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          FractionBox["x", "d"]}], ")"}], "4"]]}]}]]}], "/.", 
  RowBox[{"d", "->", 
   RowBox[{"fit1", "[", 
    RowBox[{"[", "4", "]"}], "]"}]}]}]], "Input",
 CellLabel->
  "In[264]:=",ExpressionUUID->"278e7fc8-1c48-4cd5-881e-526d88d21def"],

Cell[BoxData[
 RowBox[{"a", "+", 
  FractionBox["b", 
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{"c", " ", 
      SuperscriptBox["x", "4"]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["x", 
          RowBox[{"d", "\[Rule]", "0.16058981372845205`"}]]}], ")"}], "4"], 
      " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "\[Rule]", "0.16058981372845205`"}], ")"}], 
       "4"]}]]}]]}]], "Output",
 CellChangeTimes->{3.8957984829448977`*^9},
 CellLabel->
  "Out[264]=",ExpressionUUID->"184602eb-3035-480b-b653-230aed5d2a2c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", 
       RowBox[{"e", "[", "1", "]"}]}], "}"}], "/.", 
     RowBox[{"OptAsFcOfS", "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"fit1", "=", 
  RowBox[{"FindFit", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "+", 
       FractionBox["b", 
        RowBox[{"1", "+", 
         RowBox[{"2", 
          FractionBox[
           RowBox[{" ", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox["x", "d"], ")"}], "4"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", 
              FractionBox["x", "d"]}], ")"}], "4"]]}], "+", 
         RowBox[{"c", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{" ", 
              SuperscriptBox[
               RowBox[{"(", 
                FractionBox["x", "d"], ")"}], "4"]}], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", 
                FractionBox["x", "d"]}], ")"}], "4"]], ")"}], "2"]}]}]]}], 
      ",", 
      RowBox[{"a", ">", "0"}], ",", 
      RowBox[{"b", ">", "0"}], ",", 
      RowBox[{"c", ">", "0"}], ",", 
      RowBox[{"d", ">", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "0.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", "0.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"c", ",", "0.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", "01"}], "}"}]}], "}"}], ",", "x", ",", 
    RowBox[{"MaxIterations", "->", "Infinity"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", 
       RowBox[{"e", "[", "2", "]"}]}], "}"}], "/.", 
     RowBox[{"OptAsFcOfS", "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"fit2", "=", 
  RowBox[{"FindFit", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "+", 
        FractionBox["b", 
         RowBox[{"1", "+", 
          RowBox[{"c", " ", 
           FractionBox[
            RowBox[{" ", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox["x", "d"], ")"}], "4"]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", 
               FractionBox["x", "d"]}], ")"}], "4"]]}]}]]}], "/.", 
       RowBox[{"fit1", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], ",", 
      RowBox[{"a", ">", "0"}], ",", 
      RowBox[{"b", ">", "0"}], ",", 
      RowBox[{"c", ">", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "0.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", "0.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"c", ",", "0.1"}], "}"}]}], "}"}], ",", "x", ",", 
    RowBox[{"MaxIterations", "->", "Infinity"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", 
       RowBox[{"e", "[", "3", "]"}]}], "}"}], "/.", 
     RowBox[{"OptAsFcOfS", "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fit3", "=", 
   RowBox[{"FindFit", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "+", 
         FractionBox["b", 
          RowBox[{"1", "+", 
           RowBox[{"c", " ", 
            FractionBox[
             RowBox[{" ", 
              SuperscriptBox[
               RowBox[{"(", 
                FractionBox["x", "d"], ")"}], "4"]}], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", 
                FractionBox["x", "d"]}], ")"}], "4"]]}]}]]}], "/.", 
        RowBox[{"fit1", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], ",", 
       RowBox[{"a", ">", "0"}], ",", 
       RowBox[{"b", ">", "0"}], ",", 
       RowBox[{"c", ">", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", "0.1"}], "}"}]}], "}"}], ",", "x", ",", 
     RowBox[{"MaxIterations", "->", "Infinity"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8957253829233427`*^9, 3.8957254676880608`*^9}, {
  3.895725498932987*^9, 3.8957259301730967`*^9}, {3.8957260033416767`*^9, 
  3.8957261557731524`*^9}, {3.8957262106875753`*^9, 3.895726219068468*^9}, {
  3.8957262620527487`*^9, 3.895726300565221*^9}, {3.895726365806877*^9, 
  3.8957263805791693`*^9}, {3.895733586802679*^9, 3.895733607008862*^9}, {
  3.8957336389709387`*^9, 3.8957336940406017`*^9}, {3.895733754163579*^9, 
  3.895733781050609*^9}, {3.89573381118786*^9, 3.895733837187562*^9}, {
  3.895733878604463*^9, 3.895733894946546*^9}, {3.895797498378018*^9, 
  3.895797595485608*^9}, {3.895797645966599*^9, 3.895797724557762*^9}, {
  3.895797785755679*^9, 3.8957977944649353`*^9}, {3.8957984452734137`*^9, 
  3.895798534023383*^9}, {3.895798572828397*^9, 3.8957985731687117`*^9}},
 CellLabel->
  "In[299]:=",ExpressionUUID->"979e8476-2445-4be2-a0e6-88b8f2ed4749"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "2.209415581011128`*^-6"}], ",", 
   RowBox[{"b", "\[Rule]", "1444.965099435338`"}], ",", 
   RowBox[{"c", "\[Rule]", "136280.67574149257`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.16058981372845205`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.895725373694242*^9, 3.895725389373329*^9}, {
   3.895725458588146*^9, 3.8957254681354218`*^9}, {3.895725505613398*^9, 
   3.8957256185849333`*^9}, {3.895725668202652*^9, 3.895725930715909*^9}, {
   3.895725993968767*^9, 3.895726053230473*^9}, {3.8957260860634623`*^9, 
   3.895726129778084*^9}, {3.895726199501255*^9, 3.8957262195587587`*^9}, {
   3.895726268214398*^9, 3.895726301329742*^9}, 3.8957263818687572`*^9, 
   3.8957336081118937`*^9, 3.895733640317012*^9, {3.895733671677627*^9, 
   3.895733695334858*^9}, {3.895733767049074*^9, 3.895733781382841*^9}, {
   3.895733826194628*^9, 3.895733837563692*^9}, {3.8957338795867167`*^9, 
   3.8957338952510567`*^9}, 3.8957975972605143`*^9, {3.895797647368141*^9, 
   3.895797691853654*^9}, 3.895797725637211*^9, 3.8957978191826277`*^9, {
   3.8957984581486807`*^9, 3.8957985345064774`*^9}, 3.89579857390127*^9},
 CellLabel->
  "Out[300]=",ExpressionUUID->"68447c70-a01c-404e-b851-0a12d8ef38a8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "0.020426511891907632`"}], ",", 
   RowBox[{"b", "\[Rule]", "10.887186206741836`"}], ",", 
   RowBox[{"c", "\[Rule]", "12067.7033390882`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.895725373694242*^9, 3.895725389373329*^9}, {
   3.895725458588146*^9, 3.8957254681354218`*^9}, {3.895725505613398*^9, 
   3.8957256185849333`*^9}, {3.895725668202652*^9, 3.895725930715909*^9}, {
   3.895725993968767*^9, 3.895726053230473*^9}, {3.8957260860634623`*^9, 
   3.895726129778084*^9}, {3.895726199501255*^9, 3.8957262195587587`*^9}, {
   3.895726268214398*^9, 3.895726301329742*^9}, 3.8957263818687572`*^9, 
   3.8957336081118937`*^9, 3.895733640317012*^9, {3.895733671677627*^9, 
   3.895733695334858*^9}, {3.895733767049074*^9, 3.895733781382841*^9}, {
   3.895733826194628*^9, 3.895733837563692*^9}, {3.8957338795867167`*^9, 
   3.8957338952510567`*^9}, 3.8957975972605143`*^9, {3.895797647368141*^9, 
   3.895797691853654*^9}, 3.895797725637211*^9, 3.8957978191826277`*^9, {
   3.8957984581486807`*^9, 3.8957985345064774`*^9}, 3.895798573921595*^9},
 CellLabel->
  "Out[302]=",ExpressionUUID->"ddbb4766-630b-4073-8fe5-542bd76e6da6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "0.022191241383785525`"}], ",", 
   RowBox[{"b", "\[Rule]", "9.117685347800197`"}], ",", 
   RowBox[{"c", "\[Rule]", "31839.1089839179`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.895725373694242*^9, 3.895725389373329*^9}, {
   3.895725458588146*^9, 3.8957254681354218`*^9}, {3.895725505613398*^9, 
   3.8957256185849333`*^9}, {3.895725668202652*^9, 3.895725930715909*^9}, {
   3.895725993968767*^9, 3.895726053230473*^9}, {3.8957260860634623`*^9, 
   3.895726129778084*^9}, {3.895726199501255*^9, 3.8957262195587587`*^9}, {
   3.895726268214398*^9, 3.895726301329742*^9}, 3.8957263818687572`*^9, 
   3.8957336081118937`*^9, 3.895733640317012*^9, {3.895733671677627*^9, 
   3.895733695334858*^9}, {3.895733767049074*^9, 3.895733781382841*^9}, {
   3.895733826194628*^9, 3.895733837563692*^9}, {3.8957338795867167`*^9, 
   3.8957338952510567`*^9}, 3.8957975972605143`*^9, {3.895797647368141*^9, 
   3.895797691853654*^9}, 3.895797725637211*^9, 3.8957978191826277`*^9, {
   3.8957984581486807`*^9, 3.8957985345064774`*^9}, 3.8957985739248123`*^9},
 CellLabel->
  "Out[304]=",ExpressionUUID->"320db9f2-13f9-4bfb-96fb-d0fae1ad54c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListLogPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"x", "[", "3", "]"}], "[", "t", "]"}], ",", 
            RowBox[{"e", "[", "j", "]"}]}], "}"}], "/.", 
          RowBox[{"OptAsFcOfS", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "OptAsFcOfS", "]"}]}], "}"}]}], "]"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SuperscriptBox["10", 
           RowBox[{"-", "2"}]], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          SuperscriptBox["10", 
           RowBox[{"-", "5"}]], ",", "All"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotMarkers", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", " ", "Medium"}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(X\), \(3, ss\)]\)(s)\>\"", ",", 
        "\"\<Enzyme concentrations(s)\>\""}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"ToString", "[", 
         RowBox[{"e", "[", "i", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "+", 
         FractionBox["b", 
          RowBox[{"1", "+", 
           RowBox[{"2", 
            FractionBox[
             RowBox[{" ", 
              SuperscriptBox[
               RowBox[{"(", 
                FractionBox["x", "d"], ")"}], "4"]}], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", 
                FractionBox["x", "d"]}], ")"}], "4"]]}], "+", 
           RowBox[{"c", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{" ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  FractionBox["x", "d"], ")"}], "4"]}], 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  FractionBox["x", "d"]}], ")"}], "4"]], ")"}], "2"]}]}]]}], "/.",
         "fit1"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "+", 
          FractionBox["b", 
           RowBox[{"1", "+", 
            RowBox[{"c", " ", 
             FractionBox[
              RowBox[{" ", 
               SuperscriptBox[
                RowBox[{"(", 
                 FractionBox["x", "d"], ")"}], "4"]}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 FractionBox["x", "d"]}], ")"}], "4"]]}]}]]}], "/.", 
         RowBox[{"fit1", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "/.", "fit2"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "+", 
          FractionBox["b", 
           RowBox[{"1", "+", 
            RowBox[{"c", " ", 
             FractionBox[
              RowBox[{" ", 
               SuperscriptBox[
                RowBox[{"(", 
                 FractionBox["x", "d"], ")"}], "4"]}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 FractionBox["x", "d"]}], ")"}], "4"]]}]}]]}], "/.", 
         RowBox[{"fit1", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "/.", "fit3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "->", "All"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8957261634354887`*^9, 3.895726194109136*^9}, {
   3.895726230784541*^9, 3.8957263081557503`*^9}, {3.895733563080222*^9, 
   3.895733563894829*^9}, {3.8957337194713182`*^9, 3.895733745510231*^9}, {
   3.8957337996133204`*^9, 3.895733800265567*^9}, {3.895733848792348*^9, 
   3.895733849273581*^9}, {3.895797529842362*^9, 3.8957975377887363`*^9}, {
   3.895797611131583*^9, 3.895797623210281*^9}, {3.8957976546006527`*^9, 
   3.895797697857864*^9}, 3.895797741261786*^9, {3.895797802183715*^9, 
   3.895797810145442*^9}, {3.8957985421473427`*^9, 3.895798579830638*^9}},
 CellLabel->
  "In[305]:=",ExpressionUUID->"87ad0327-e3f0-4fbe-bf42-1fc6f1d00a4e"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], FontSize -> 16, FontColor -> GrayLevel[0], 
          Hue[0.55, 1, 0.7]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{
                EdgeForm[], 
                DiskBox[{0, 0}]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                  GrayLevel[0], 
                  Hue[0.55, 1, 0.7]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Offset[10]], {{{0.04164005317310502, 6.908486819218974}}, {{
          0.08116810605298104, 4.138599365170667}}, {{0.1134502261533149, 
          2.5249068889591233`}}, {{0.14333185514096528`, 
          1.393547098082103}}, {{
          0.19864670873030996`, -0.1264587880607584}}, {{
          0.2501177865536414, -1.0503659753542178`}}, {{
          0.34563518761558676`, -1.8867968615142061`}}, {{
          0.43443914088318875`, -2.138205453777385}}, {{
          0.5184447400532052, -2.2210648098557577`}}, {{
          0.7135796793437875, -2.2729883153516455`}}, {{
          0.893534151929105, -2.2837408325476725`}}, {{
          1.0624470288897117`, -2.2876772697755134`}}}]}, {
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], FontSize -> 16, FontColor -> GrayLevel[0], 
          Hue[0.06, 1, 0.9]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{
                EdgeForm[], 
                PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                  GrayLevel[0], 
                  Hue[0.06, 1, 0.9]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Offset[10]], {{{0.04164005317310502, -0.6973903722703585}}, {{
          0.08116810605298104, -2.2282349293266828`}}, {{
          0.1134502261533149, -2.941312091177423}}, {{
          0.14333185514096528`, -3.3109541478308158`}}, {{
          0.19864670873030996`, -3.624576170667134}}, {{
          0.2501177865536414, -3.733192691477546}}, {{
          0.34563518761558676`, -3.7987509996779867`}}, {{
          0.43443914088318875`, -3.8178442148956386`}}, {{
          0.5184447400532052, -3.826950825374416}}, {{
          0.7135796793437875, -3.8385360351815843`}}, {{
          0.893534151929105, -3.8448687723522283`}}, {{
          1.0624470288897117`, -3.8491013097205213`}}}]}, {
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], FontSize -> 16, FontColor -> GrayLevel[0], 
          Hue[0.25, 1, 0.55]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{
                EdgeForm[], 
                PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                  GrayLevel[0], 
                  Hue[0.25, 1, 0.55]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Offset[10]], {{{0.04164005317310502, -1.7282006547780926`}}, {{
          0.08116810605298104, -2.94625626582938}}, {{
          0.1134502261533149, -3.3862447985014974`}}, {{
          0.14333185514096528`, -3.580476123570525}}, {{
          0.19864670873030996`, -3.727874527623202}}, {{
          0.2501177865536414, -3.7754601924670137`}}, {{
          0.34563518761558676`, -3.803342816224513}}, {{
          0.43443914088318875`, -3.81134515436792}}, {{
          0.5184447400532052, -3.815143245133813}}, {{
          0.7135796793437875, -3.8199576962976654`}}, {{
          0.893534151929105, -3.8225811771100764`}}, {{
          
          1.0624470288897117`, -3.824331366081727}}}]}}}, {{}, {}}}, {{{{}, \
{}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           Hue[0.55, 1, 0.7]], 
          LineBox[CompressedData["
1:eJwd1Hk01H8XB3C7MclOYSa7VJI2ldL9SCJUthYVWRPKEpWSRJbCiIwl2XdJ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           "]]}, Annotation[#, "Charting`Private`Tag$1815198#1"]& ], 
        TagBox[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           Hue[0.06, 1, 0.9]], 
          LineBox[CompressedData["
1:eJwV1Hc4Ff4XB/DrXvMuIyorElJJviWidG6ykkpGyMiKkIb6yio7Miuy98oo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           "]]}, Annotation[#, "Charting`Private`Tag$1815198#2"]& ], 
        TagBox[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           Hue[0.25, 1, 0.55]], 
          LineBox[CompressedData["
1:eJwV1Hc01f8fB/B7ybz3c0WSmRYpsxJRel27ZJQVQkQKWSUJZRRJpIEiKzNk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           "]]}, Annotation[#, "Charting`Private`Tag$1815198#3"]& ]}}, {}}}, {
    DisplayFunction -> Identity, GridLines -> {None, None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True}, 
     AxesLabel -> {None, None}, 
     AxesOrigin -> {0.010000000000000023`, -11.512925464970204`}, 
     BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Enzyme concentrations(s)\"", HoldForm], TraditionalForm], 
        None}, {
        FormBox[
         TagBox[
         "\"\\!\\(\\*SubscriptBox[\\(X\\), \\(3, ss\\)]\\)(s)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> Directive[
       GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"], 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
         15.954589770191003`, RotateLabel -> 0], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
       "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
       Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
       True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0.01, 1.}, {-11.512925464970229`, 6.908486819218974}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 
        Scaled[0.05]}}, Prolog -> {
       RGBColor[
        NCache[{
          Rational[223, 255], 
          Rational[72, 85], 
          Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
         0.7843137254901961}]], 
       RectangleBox[
        Scaled[{0, 0}], 
        Scaled[{1, 1}]]}, Ticks -> {Automatic, 
       Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
        15.954589770191003`, RotateLabel -> 0]}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"e[1]\"", "\"e[2]\"", "\"e[3]\"", "\"e[4]\""}, 
      "PointLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.55, 1, 0.7]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.55, 1, 0.7]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 10},
                     PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.06, 1, 0.9]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.06, 1, 0.9]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 10},
                     PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.25, 1, 0.55]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], FontSize -> 16, FontColor -> 
                    GrayLevel[0], 
                    Hue[0.25, 1, 0.55]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 10},
                     PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.55, 1, 0.7]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.06, 1, 0.9]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.25, 1, 0.55]|>, 
                    "HueColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}], ",", 
                    RowBox[{"Offset", "[", "10", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], ",", 
                    RowBox[{"Offset", "[", "10", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], ",", 
                    RowBox[{"Offset", "[", "10", "]"}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.895726194573702*^9, {3.895726225097048*^9, 3.89572630860249*^9}, 
   3.89572638300786*^9, 3.895733610568166*^9, 3.895733641875752*^9, {
   3.895733673472245*^9, 3.895733696536044*^9}, {3.8957337459418983`*^9, 
   3.895733849616604*^9}, {3.895733880985943*^9, 3.8957338970831547`*^9}, {
   3.895797623752796*^9, 3.895797698288972*^9}, 3.89579774166855*^9, {
   3.895797810621426*^9, 3.895797820685713*^9}, {3.895798553123331*^9, 
   3.895798580149466*^9}},
 CellLabel->
  "Out[305]=",ExpressionUUID->"c38a3fa4-bd0c-43e4-876e-7b8b1ead2489"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1038, 847},
WindowMargins->{{201, Automatic}, {-119, Automatic}},
FrontEndVersion->"13.2 for Mac OS X ARM (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"a07548c0-724d-4339-975c-38e01b4d7c72"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 371, 6, 68, "Text",ExpressionUUID->"385965a2-6a0f-419f-95aa-530122e38a7e"],
Cell[932, 28, 3867, 96, 140, "Input",ExpressionUUID->"6a4daa6c-e4e4-4228-962e-6a0ba400b636"],
Cell[CellGroupData[{
Cell[4824, 128, 180, 3, 30, "Input",ExpressionUUID->"4ce1c051-c1eb-447d-9b12-aab51492ab3c"],
Cell[5007, 133, 1062, 24, 34, "Output",ExpressionUUID->"48363e55-e17c-404a-8f25-401031fa0652"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6106, 162, 5373, 153, 373, "Input",ExpressionUUID->"91eb1491-bcd0-43a4-83ca-d2dbdc7386d1"],
Cell[11482, 317, 1464, 35, 34, "Output",ExpressionUUID->"91d214a6-5595-44ac-8a7d-410420820050"],
Cell[12949, 354, 1008, 21, 34, "Output",ExpressionUUID->"13632d09-354c-4465-a091-7aed4b2fc3ed"],
Cell[13960, 377, 814, 14, 34, "Output",ExpressionUUID->"1898ae25-1db1-4f57-9ef6-7544c8bbc45d"]
}, Open  ]],
Cell[14789, 394, 1054, 28, 52, "Input",ExpressionUUID->"a1677eed-13ea-4187-bf42-5a4e6b0ca645"],
Cell[CellGroupData[{
Cell[15868, 426, 205, 3, 30, "Input",ExpressionUUID->"e402dedd-4043-42c8-a736-ddf35888d330"],
Cell[16076, 431, 67446, 1269, 143, "Output",ExpressionUUID->"f00dcf9d-4740-442e-bd5c-a3879c3c045f"]
}, Open  ]],
Cell[83537, 1703, 1449, 41, 52, "Input",ExpressionUUID->"e2804fa2-9ba6-4cd4-ab1e-3c32d53ba946"],
Cell[CellGroupData[{
Cell[85011, 1748, 204, 3, 30, "Input",ExpressionUUID->"8194e1e5-80ec-4836-81e5-1d3dbde71469"],
Cell[85218, 1753, 960, 22, 34, "Output",ExpressionUUID->"043577fc-7a2e-43d2-997b-c57f38a12088"]
}, Open  ]],
Cell[86193, 1778, 2530, 69, 129, "Input",ExpressionUUID->"d8d146f4-4eed-4918-9866-93177a847149"],
Cell[CellGroupData[{
Cell[88748, 1851, 486, 8, 94, "Input",ExpressionUUID->"2c7b3bc7-190a-428e-b01f-65a8bafafef5"],
Cell[89237, 1861, 1558, 37, 56, "Output",ExpressionUUID->"3ee7ed5a-5a30-450c-a214-cca3cd43fe67"],
Cell[90798, 1900, 1547, 35, 56, "Output",ExpressionUUID->"c97d11f0-af88-4d33-a4b1-ccbcff9d1f52"],
Cell[92348, 1937, 1547, 36, 56, "Output",ExpressionUUID->"c334cab0-abe2-46e6-8471-8c43c3a8cd66"],
Cell[93898, 1975, 1558, 37, 56, "Output",ExpressionUUID->"05b41b79-fc0f-4150-af6e-30b84d04fa0a"]
}, Open  ]],
Cell[95471, 2015, 260, 4, 58, "Text",ExpressionUUID->"288e9349-d2a1-4dc9-a9db-2d4b7435d0c6"],
Cell[CellGroupData[{
Cell[95756, 2023, 1504, 43, 96, "Input",ExpressionUUID->"c20e1035-a829-450a-b051-b4d9d45fd4c1"],
Cell[97263, 2068, 1216, 29, 37, "Output",ExpressionUUID->"1c0ce27f-e6ad-4d49-b33c-21b1542af992"],
Cell[98482, 2099, 2652, 80, 78, "Output",ExpressionUUID->"253798bd-c6cb-4892-b3e6-aeb1f840e396"],
Cell[101137, 2181, 719, 13, 37, "Output",ExpressionUUID->"4c865464-accf-45b7-bd66-6951d9081f82"]
}, Open  ]],
Cell[101871, 2197, 1963, 58, 73, "Input",ExpressionUUID->"7ab3d236-254d-476c-a9da-177cf0efc660"],
Cell[CellGroupData[{
Cell[103859, 2259, 13422, 408, 900, "Input",ExpressionUUID->"ec3c1606-4d91-4fcf-9a11-30f7adefabe0"],
Cell[117284, 2669, 808, 11, 34, "Output",ExpressionUUID->"c761ad9b-52c3-49c6-a113-476827222eed"],
Cell[118095, 2682, 10172, 209, 357, "Output",ExpressionUUID->"f4f0254c-29b9-4421-8802-dd86692c4b7a"],
Cell[128270, 2893, 808, 11, 34, "Output",ExpressionUUID->"841cca27-8200-4e80-8707-ac5f47a95316"],
Cell[129081, 2906, 10162, 209, 357, "Output",ExpressionUUID->"753aac97-aa04-4d54-8f89-ef150db2b1c3"],
Cell[139246, 3117, 803, 11, 34, "Output",ExpressionUUID->"a157eb70-2954-416a-ba21-fda6bbe2a7c4"],
Cell[140052, 3130, 647, 13, 48, "Message",ExpressionUUID->"7761f8aa-6c1f-4449-ade6-283237730fa4"],
Cell[140702, 3145, 10163, 209, 357, "Output",ExpressionUUID->"b4268ae6-4e02-4907-85e6-1e38bb0a8798"],
Cell[150868, 3356, 803, 11, 34, "Output",ExpressionUUID->"baead82a-1d43-436f-9e17-ae657477bd58"],
Cell[151674, 3369, 10177, 209, 357, "Output",ExpressionUUID->"d69f7c93-e069-4b00-8b70-78d17362e72f"],
Cell[161854, 3580, 805, 11, 34, "Output",ExpressionUUID->"66b0868b-df31-4003-a987-24ff189b1311"],
Cell[162662, 3593, 10183, 210, 357, "Output",ExpressionUUID->"83f6b39f-1bce-42ca-9dac-0e5d87b18ec7"],
Cell[172848, 3805, 804, 11, 34, "Output",ExpressionUUID->"661e57c7-cfee-4603-a7ec-4c94646cf6e2"],
Cell[173655, 3818, 645, 13, 48, "Message",ExpressionUUID->"c40de7aa-8dd7-4f0a-89fe-97ec22066e0c"],
Cell[174303, 3833, 645, 13, 48, "Message",ExpressionUUID->"5fa70c10-6a1f-48ec-9e30-aad18d6da6f0"],
Cell[174951, 3848, 645, 13, 48, "Message",ExpressionUUID->"cd794393-09e2-4a7b-87c9-00093e21d89b"],
Cell[175599, 3863, 502, 11, 28, "Message",ExpressionUUID->"bc160a65-ca85-4c0d-be11-84a727e621f8"],
Cell[176104, 3876, 10176, 209, 357, "Output",ExpressionUUID->"5ed29e6c-f278-4ec3-9ef0-8629abc38af5"]
}, Open  ]],
Cell[186295, 4088, 5780, 159, 304, "Input",ExpressionUUID->"d0a560fc-c34b-412a-b2ff-c96a8354f854"],
Cell[CellGroupData[{
Cell[192100, 4251, 524, 14, 30, "Input",ExpressionUUID->"74c307d1-1ebb-4c48-9566-88474225c619"],
Cell[192627, 4267, 40579, 742, 513, "Output",ExpressionUUID->"fc9d51d7-3c13-421b-befe-921e623f606b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[233243, 5014, 4164, 106, 346, "Input",ExpressionUUID->"9cb2131e-3615-41c9-a901-b537e09703ea"],
Cell[237410, 5122, 10274, 220, 313, "Output",ExpressionUUID->"6ed2296b-2c48-4d2e-b273-dcd9118b78dc"],
Cell[247687, 5344, 10264, 220, 313, "Output",ExpressionUUID->"17d34e63-f123-4418-bcdc-18a71a28da3d"],
Cell[257954, 5566, 10268, 220, 313, "Output",ExpressionUUID->"302689d6-951f-443b-b683-5b1b5c9b3d89"],
Cell[268225, 5788, 597, 12, 48, "Message",ExpressionUUID->"6313fd47-90a7-476a-a9b0-68e36db5e657"],
Cell[268825, 5802, 10266, 220, 313, "Output",ExpressionUUID->"5e981133-6ce3-4a9f-b887-b2bdd5e1ab3a"],
Cell[279094, 6024, 10278, 220, 313, "Output",ExpressionUUID->"3c0c9677-7b33-49b9-871e-82ef1817bd4c"],
Cell[289375, 6246, 10287, 221, 313, "Output",ExpressionUUID->"37bc674d-b28b-47e6-9e3c-5c139842b569"],
Cell[299665, 6469, 599, 12, 48, "Message",ExpressionUUID->"c75ec6d0-f0ef-4715-9ea7-614790a4f141"],
Cell[300267, 6483, 596, 12, 48, "Message",ExpressionUUID->"1a418e66-f4ce-4a33-9855-dd2e27f64d65"],
Cell[300866, 6497, 597, 12, 48, "Message",ExpressionUUID->"59644c87-6253-471c-a00a-1fe236b9a0c5"],
Cell[301466, 6511, 454, 10, 28, "Message",ExpressionUUID->"b4ecc4c2-9819-4e55-9489-63a26cff4431"],
Cell[301923, 6523, 10281, 220, 313, "Output",ExpressionUUID->"112fa7f8-fdf8-4ad2-b78e-c6066f787348"]
}, Open  ]],
Cell[CellGroupData[{
Cell[312241, 6748, 181, 3, 30, "Input",ExpressionUUID->"d9f3db8a-0b24-4fb0-9895-7a30ef9440bf"],
Cell[312425, 6753, 1041, 24, 34, "Output",ExpressionUUID->"3ea0270f-6bc7-41ca-be22-147192c3df6c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[313503, 6782, 1229, 33, 77, "Input",ExpressionUUID->"43d6ac62-b3f1-4717-8423-18b34bf6582c"],
Cell[314735, 6817, 9541, 210, 271, "Output",ExpressionUUID->"5cbb829b-d088-4396-bb0c-bdcc4983ab87"]
}, Open  ]],
Cell[324291, 7030, 1126, 25, 30, "Input",ExpressionUUID->"0c4bba6d-ec33-41cd-8362-a3bad96cbb1a"],
Cell[CellGroupData[{
Cell[325442, 7059, 1876, 49, 100, "Input",ExpressionUUID->"70e85901-3820-4755-b9b8-cb485aaaf13f"],
Cell[327321, 7110, 24609, 547, 209, "Output",ExpressionUUID->"f4fda830-2746-4c7c-b626-0bb7ec093e24"]
}, Open  ]],
Cell[CellGroupData[{
Cell[351967, 7662, 1374, 37, 79, "Input",ExpressionUUID->"454949f6-90f8-4bd4-b455-296a9c385ac1"],
Cell[353344, 7701, 21291, 519, 333, "Output",ExpressionUUID->"8353dec1-2288-4bb3-a4b6-21210c68cf90"]
}, Open  ]],
Cell[CellGroupData[{
Cell[374672, 8225, 1520, 40, 106, "Input",ExpressionUUID->"1f5ed924-6208-4fe5-8cc2-e18994ac0ac0"],
Cell[376195, 8267, 5141, 122, 332, "Output",ExpressionUUID->"44f4d1e3-f994-431a-8fe7-8615ec640507"]
}, Open  ]],
Cell[CellGroupData[{
Cell[381373, 8394, 2068, 54, 143, "Input",ExpressionUUID->"71515a90-3aae-42ad-b1d2-a17416253cb9"],
Cell[383444, 8450, 24202, 541, 333, "Output",ExpressionUUID->"1fdf1049-69e6-4241-88f7-ba9244474bba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[407683, 8996, 2023, 54, 102, "Input",ExpressionUUID->"fe353c92-a262-4bc7-a4b5-bab2f8f00306"],
Cell[409709, 9052, 28342, 624, 390, "Output",ExpressionUUID->"b0c23f2a-0d07-4362-9801-20a7a754cd89"]
}, Open  ]],
Cell[CellGroupData[{
Cell[438088, 9681, 2449, 51, 535, "Input",ExpressionUUID->"857b21f7-5d8b-45c2-b7a0-66e1b71567a9"],
Cell[440540, 9734, 365, 4, 56, "Output",ExpressionUUID->"5d8b0d2b-820c-4953-b4ac-aabd80f2d68c"],
Cell[440908, 9740, 365, 4, 56, "Output",ExpressionUUID->"2820d5c4-3f95-46ca-9064-e5fdd405f605"],
Cell[441276, 9746, 365, 4, 56, "Output",ExpressionUUID->"87a9033b-9f41-47ae-a958-e6c3d707afec"],
Cell[441644, 9752, 367, 4, 56, "Output",ExpressionUUID->"b96dbcef-74a9-4dea-bfa5-512b3e9093d0"],
Cell[442014, 9758, 365, 4, 56, "Output",ExpressionUUID->"4997247f-b515-4f39-9a44-f56fc3bdeca8"],
Cell[442382, 9764, 367, 4, 56, "Output",ExpressionUUID->"5285f63d-6c9e-4b93-b8c1-44bab30faff9"],
Cell[442752, 9770, 365, 4, 56, "Output",ExpressionUUID->"409a924b-8721-4d5f-8e58-080dcde921f1"],
Cell[443120, 9776, 365, 4, 56, "Output",ExpressionUUID->"1e844f7c-0572-4e3a-a13f-2228b604fb74"]
}, Open  ]],
Cell[CellGroupData[{
Cell[443522, 9785, 522, 9, 97, "Subsubsection",ExpressionUUID->"48a62d00-3120-4933-a602-e4c0ea0fb3d6"],
Cell[CellGroupData[{
Cell[444069, 9798, 1647, 47, 79, "Input",ExpressionUUID->"a8b5e200-3695-4bb2-82d0-65f376107482"],
Cell[445719, 9847, 10958, 247, 335, "Output",ExpressionUUID->"ccd003d7-ca53-47d1-9c4d-6ec6f23527c7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[456714, 10099, 1541, 41, 106, "Input",ExpressionUUID->"69e01af2-f147-430e-b86d-e916959da81e"],
Cell[458258, 10142, 5414, 127, 332, "Output",ExpressionUUID->"6936baf3-f25b-44b0-a992-fa56ebf7d136"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[463721, 10275, 245, 6, 45, "Subsubsection",ExpressionUUID->"3418d523-a4b7-459f-b9f8-9cfd25cfc615"],
Cell[CellGroupData[{
Cell[463991, 10285, 1821, 52, 102, "Input",ExpressionUUID->"863faac2-2438-4817-99f3-eacdbf3622f6"],
Cell[465815, 10339, 20714, 468, 342, "Output",ExpressionUUID->"6c546184-b8ff-4f7d-9f84-d41318edae2c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[486566, 10812, 179, 3, 30, "Input",ExpressionUUID->"e9fda079-3da5-4347-9bba-0f47aa46e552"],
Cell[486748, 10817, 412, 9, 37, "Output",ExpressionUUID->"e3cc09d1-8dfe-4c5d-9bb0-cdb434053b75"]
}, Open  ]],
Cell[CellGroupData[{
Cell[487197, 10831, 564, 19, 78, "Input",ExpressionUUID->"278e7fc8-1c48-4cd5-881e-526d88d21def"],
Cell[487764, 10852, 619, 20, 73, "Output",ExpressionUUID->"184602eb-3035-480b-b653-230aed5d2a2c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[488420, 10877, 6013, 174, 436, "Input",ExpressionUUID->"979e8476-2445-4be2-a0e6-88b8f2ed4749"],
Cell[494436, 11053, 1256, 20, 37, "Output",ExpressionUUID->"68447c70-a01c-404e-b851-0a12d8ef38a8"],
Cell[495695, 11075, 1196, 19, 34, "Output",ExpressionUUID->"ddbb4766-630b-4073-8fe5-542bd76e6da6"],
Cell[496894, 11096, 1197, 19, 34, "Output",ExpressionUUID->"320db9f2-13f9-4bfb-96fb-d0fae1ad54c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[498128, 11120, 4756, 129, 213, "Input",ExpressionUUID->"87ad0327-e3f0-4fbe-bf42-1fc6f1d00a4e"],
Cell[502887, 11251, 36619, 723, 495, "Output",ExpressionUUID->"c38a3fa4-bd0c-43e4-876e-7b8b1ead2489"]
}, Open  ]]
}, Open  ]]
}
]
*)

