(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    745786,      13457]
NotebookOptionsPosition[    741578,      13384]
NotebookOutlinePosition[    741974,      13400]
CellTagsIndexPosition[    741931,      13397]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "Plot", ",", "LogPlot", ",", "LogLinearPlot", ",", "ParametricPlot"}], 
     "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
       RowBox[{"FontColor", "\[Rule]", "Black"}]}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "18", ",", 
       RowBox[{"Thickness", "\[Rule]", "0.0025"}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Marketing\>\""}]}], "]"}]}], 
    "\[IndentingNewLine]", ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"ColorData", "[", 
      RowBox[{"68", ",", "\"\<ColorList\>\""}], "]"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Prolog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          RowBox[{
           GraphicsBox[{
             {GrayLevel[0], RectangleBox[{0, 0}]}, 
             {GrayLevel[0], RectangleBox[{1, -1}]}, 
             {RGBColor[
               Rational[223, 255], 
               Rational[72, 85], 
               Rational[40, 51]], RectangleBox[{0, -1}, {2, 1}]}},
            AspectRatio->1,
            Frame->True,
            
            FrameStyle->RGBColor[
             0.5830065359477125, 0.5647058823529412, 0.5228758169934641],
            FrameTicks->None,
            
            ImageSize->
             Dynamic[{
              Automatic, 
               1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                Magnification])}],
            PlotRangePadding->None], "\[InvisibleSpace]"}],
          "RGBColor[{223/255, 72/85, 40/51}]"],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
               Rational[223, 255], 
               Rational[72, 85], 
               Rational[40, 51]]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[{
          Rational[223, 255], 
          Rational[72, 85], 
          Rational[40, 51]}],
        Editable->False,
        Selectable->False], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"Scaled", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
         RowBox[{"Scaled", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "]"}]}], "}"}]}]}], "]"}],
   ";"}]], "Input",
 CellChangeTimes->{{3.895303568297944*^9, 3.895303600675495*^9}, {
  3.8953036370915823`*^9, 3.895303638258874*^9}},
 CellLabel->
  "In[161]:=",ExpressionUUID->"57b5339f-eb9e-4680-85c2-ef87faa235a4"],

Cell["\<\
Express AMP in terms of ATP using total adenine nucleotide pool and the \
adenylate kinase equilibrium condition.\
\>", "Text",
 CellChangeTimes->{{3.610437738848827*^9, 
  3.610437771679278*^9}},ExpressionUUID->"a8131784-628e-43fa-8d0f-\
cf5dfbaa9746"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"sol", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"At", "==", 
       RowBox[{"atp", "+", "adp", "+", "amp"}]}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"Kak", "==", 
       FractionBox[
        RowBox[{"atp", " ", "amp"}], 
        SuperscriptBox["adp", "2"]]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"amp", ",", "adp"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"At", "\[Rule]", "10"}]}], "/.", 
    RowBox[{"Kak", "\[Rule]", "0.45"}]}], "/.", 
   RowBox[{"atp", "\[Rule]", "4"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "identify", " ", "which", " ", "of", " ", "the", " ", "two", " ", 
    "solutions", " ", "is", " ", "the", " ", "physically", " ", "realistic", 
    " ", "one"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"relation", "=", 
  RowBox[{"sol", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.610437464433446*^9, 3.610437553235195*^9}, {
   3.6104375936927*^9, 3.610437659585451*^9}, 3.610437712429593*^9, {
   3.610437778024248*^9, 3.610437798233478*^9}, 3.610640039652916*^9, {
   3.610640389814621*^9, 3.6106403899410677`*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"963de64c-2295-4f65-9d47-6dcf741ea616"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"amp", "\[Rule]", 
      RowBox[{"At", "-", "atp", "+", 
       FractionBox["atp", 
        RowBox[{"2", " ", "Kak"}]], "+", 
       FractionBox[
        RowBox[{
         SqrtBox[
          RowBox[{"-", "atp"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "atp"}], "-", 
           RowBox[{"4", " ", "At", " ", "Kak"}], "+", 
           RowBox[{"4", " ", "atp", " ", "Kak"}]}]]}], 
        RowBox[{"2", " ", "Kak"}]]}]}], ",", 
     RowBox[{"adp", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "atp"}], "-", 
        RowBox[{
         SqrtBox[
          RowBox[{"-", "atp"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "atp"}], "-", 
           RowBox[{"4", " ", "At", " ", "Kak"}], "+", 
           RowBox[{"4", " ", "atp", " ", "Kak"}]}]]}]}], 
       RowBox[{"2", " ", "Kak"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"amp", "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "At"}], "-", 
         RowBox[{"2", " ", "atp"}], "+", 
         FractionBox["atp", "Kak"], "-", 
         FractionBox[
          RowBox[{
           SqrtBox[
            RowBox[{"-", "atp"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "atp"}], "-", 
             RowBox[{"4", " ", "At", " ", "Kak"}], "+", 
             RowBox[{"4", " ", "atp", " ", "Kak"}]}]]}], "Kak"]}], ")"}]}]}], 
     ",", 
     RowBox[{"adp", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "atp"}], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{"-", "atp"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "atp"}], "-", 
           RowBox[{"4", " ", "At", " ", "Kak"}], "+", 
           RowBox[{"4", " ", "atp", " ", "Kak"}]}]]}]}], 
       RowBox[{"2", " ", "Kak"}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.610437512701868*^9, 3.610437532632275*^9}, {
   3.610437596755006*^9, 3.6104376599099493`*^9}, 3.6104377133607397`*^9, 
   3.6104377994438677`*^9, 3.610638953944882*^9, {3.610640039960733*^9, 
   3.610640054537822*^9}, 3.610640390447035*^9, 3.610640428575685*^9, {
   3.610679886767651*^9, 3.610679894616439*^9}, {3.610691928136326*^9, 
   3.610691936057661*^9}, 3.61069205579084*^9, 3.610717711367118*^9, 
   3.610802502970237*^9, {3.895303119650989*^9, 3.895303145592416*^9}, {
   3.89530357400209*^9, 3.8953036020704813`*^9}, 3.895303639980939*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"164410ba-1083-4f25-b478-30387da24850"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"amp", "\[Rule]", 
      RowBox[{"1.8953848614794016`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{"adp", "\[Rule]", 
      RowBox[{"4.1046151385205984`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"amp", "\[Rule]", 
      RowBox[{"18.993504027409486`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{"adp", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "12.993504027409486`"}], "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.610437512701868*^9, 3.610437532632275*^9}, {
   3.610437596755006*^9, 3.6104376599099493`*^9}, 3.6104377133607397`*^9, 
   3.6104377994438677`*^9, 3.610638953944882*^9, {3.610640039960733*^9, 
   3.610640054537822*^9}, 3.610640390447035*^9, 3.610640428575685*^9, {
   3.610679886767651*^9, 3.610679894616439*^9}, {3.610691928136326*^9, 
   3.610691936057661*^9}, 3.61069205579084*^9, 3.610717711367118*^9, 
   3.610802502970237*^9, {3.895303119650989*^9, 3.895303145592416*^9}, {
   3.89530357400209*^9, 3.8953036020704813`*^9}, 3.895303639987392*^9},
 CellLabel->
  "Out[163]=",ExpressionUUID->"839d9b86-fdad-4898-8960-bfd418d61c29"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"amp", "\[Rule]", 
    RowBox[{"At", "-", "atp", "+", 
     FractionBox["atp", 
      RowBox[{"2", " ", "Kak"}]], "+", 
     FractionBox[
      RowBox[{
       SqrtBox[
        RowBox[{"-", "atp"}]], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "atp"}], "-", 
         RowBox[{"4", " ", "At", " ", "Kak"}], "+", 
         RowBox[{"4", " ", "atp", " ", "Kak"}]}]]}], 
      RowBox[{"2", " ", "Kak"}]]}]}], ",", 
   RowBox[{"adp", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "atp"}], "-", 
      RowBox[{
       SqrtBox[
        RowBox[{"-", "atp"}]], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "atp"}], "-", 
         RowBox[{"4", " ", "At", " ", "Kak"}], "+", 
         RowBox[{"4", " ", "atp", " ", "Kak"}]}]]}]}], 
     RowBox[{"2", " ", "Kak"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.610437512701868*^9, 3.610437532632275*^9}, {
   3.610437596755006*^9, 3.6104376599099493`*^9}, 3.6104377133607397`*^9, 
   3.6104377994438677`*^9, 3.610638953944882*^9, {3.610640039960733*^9, 
   3.610640054537822*^9}, 3.610640390447035*^9, 3.610640428575685*^9, {
   3.610679886767651*^9, 3.610679894616439*^9}, {3.610691928136326*^9, 
   3.610691936057661*^9}, 3.61069205579084*^9, 3.610717711367118*^9, 
   3.610802502970237*^9, {3.895303119650989*^9, 3.895303145592416*^9}, {
   3.89530357400209*^9, 3.8953036020704813`*^9}, 3.895303639993135*^9},
 CellLabel->
  "Out[164]=",ExpressionUUID->"e760bd4b-1a10-4e71-8f86-a1668508ad0d"]
}, Open  ]],

Cell[TextData[{
 "Adenylate kinase (AK): atp + amp <=> 2 adp\n ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Keq", "=", 
    RowBox[{"0.45", "=", 
     FractionBox[
      RowBox[{"atp", " ", "amp"}], 
      SuperscriptBox["adp", "2"]]}]}], TraditionalForm]],ExpressionUUID->
  "a862b76a-5917-4ac0-80f6-c1469b4b9151"],
 "\nAdenylate cyclase (AC): ATP <=> cAMP +PPi\n ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Keq", "=", 
    RowBox[{
     RowBox[{"65", " ", "mM"}], "=", 
     FractionBox[
      RowBox[{"cAMP", " ", "PPi"}], "ATP"]}]}], TraditionalForm]],
  ExpressionUUID->"448607a2-0668-4996-948d-1d23ea80835b"],
 " "
}], "Text",
 CellChangeTimes->{{3.610639572660284*^9, 3.610639673271036*^9}, {
   3.610639756494752*^9, 3.610639776076783*^9}, {3.610639840187298*^9, 
   3.610639848116713*^9}, {3.610639899545785*^9, 3.610639914982847*^9}, 
   3.610639966000018*^9, {3.610640012561627*^9, 
   3.6106400577510242`*^9}},ExpressionUUID->"04b8e26f-56ca-4093-8644-\
63bc032d0704"],

Cell[BoxData[
 RowBox[{
  RowBox[{"parameters", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"At", "\[Rule]", "5"}], ",", 
     RowBox[{"Kak", "\[Rule]", "0.45"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6106404037818537`*^9, 3.610640411011009*^9}, 
   3.6106934505924673`*^9},
 CellLabel->
  "In[165]:=",ExpressionUUID->"bb0a1e5f-f2ab-4b49-b512-4f73de9a1a48"],

Cell["\<\
If total adenine nucleotides (At) is below 5 mM then depending on f26bp, \
f16bp is activating or inhibiting.
So if cAMP is high then At is low and f16bp becomes inhibiting. cAMP is below \
100 \[Mu]M in yeast. So total adenine nucleotide pool is not affected. \
\>", "Text",
 CellChangeTimes->{{3.610641827779772*^9, 3.610641881362157*^9}, {
   3.6106419207565603`*^9, 3.610641966162759*^9}, {3.6106436024618187`*^9, 
   3.610643653282834*^9}, 
   3.61067831904053*^9},ExpressionUUID->"fa745040-7be1-4dfe-ac43-\
9b6203d48ab7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"amp", ",", "adp"}], "}"}], "/.", "relation"}], "/.", 
     "parameters"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"atp", ",", "0", ",", 
     RowBox[{"At", "/.", "parameters"}]}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<ATP [mM]\>\"", ",", "\"\<ADP and AMP\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Placed", "[", 
     RowBox[{
      RowBox[{"LineLegend", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<AMP\>\"", ",", "\"\<ADP\>\""}], "}"}], ",", 
        RowBox[{"LegendLayout", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Column\>\"", ",", "1"}], "}"}]}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "15"}]}], "}"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.9", ",", "0.9"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"RotateLabel", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.610600197469586*^9, 3.610600323593759*^9}},
 CellLabel->
  "In[166]:=",ExpressionUUID->"2defc8bf-f292-452b-9ed0-367ce7b4cded"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      TagBox[
       {Hue[0.55, 1, 0.7], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[CompressedData["
1:eJwV1nk0lHsYB/Cxh8HMKDfJUjcRWlTXRczzsxQNKd0Uci2TmkmJXFuWSAox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         "]]},
       Annotation[#, "Charting`Private`Tag$48658#1"]& ], 
      TagBox[
       {Hue[0.06, 1, 0.9], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[CompressedData["
1:eJwd2Hk8VdsXAPBzTZEhQ3kNQpnKmPQeitaO4iU0oCRNxqQ8Q8oURaKiKCJE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         "]]},
       Annotation[#, "Charting`Private`Tag$48658#2"]& ]}, {}}, InsetBox[
     TemplateBox[{"\"AMP\"", "\"ADP\""},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.55, 1, 0.7]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.55, 1, 0.7]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.05499999999999999] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.06, 1, 0.9]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.06, 1, 0.9]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.05499999999999999] -> 
                    Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Helvetica", FontSize -> 15}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.55, 1, 0.7]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.06, 1, 0.9]|>, 
                    "HueColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"FontFamily", "\[Rule]", "\"Helvetica\""}], ",", 
                 RowBox[{"FontSize", "\[Rule]", "15"}]}], "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"\"Column\"", ",", "1"}], "}"}]}]}], "]"}]& )], 
     Scaled[{0.9, 0.9}], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->1,
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
   DisplayFunction->Identity,
   Frame->{{True, True}, {True, True}},
   FrameLabel->{{
      FormBox[
       TagBox["\"ADP and AMP\"", HoldForm], TraditionalForm], None}, {
      FormBox[
       TagBox["\"ATP [mM]\"", HoldForm], TraditionalForm], None}},
   FrameStyle->Directive[
     GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->{{75, 10}, {80, 15}},
   ImageSize->400,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{All, All},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Prolog->{
     RGBColor[
      NCache[{
        Rational[223, 255], 
        Rational[72, 85], 
        Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
       0.7843137254901961}]], 
     RectangleBox[
      Scaled[{0, 0}], 
      Scaled[{1, 1}]]},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           Hue[0.55, 1, 0.7]], 
          Line[CompressedData["
1:eJwV1nk0lHsYB/Cxh8HMKDfJUjcRWlTXRczzsxQNKd0Uci2TmkmJXFuWSAox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           "]]}, "Charting`Private`Tag$48658#1"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           Hue[0.06, 1, 0.9]], 
          Line[CompressedData["
1:eJwd2Hk8VdsXAPBzTZEhQ3kNQpnKmPQeitaO4iU0oCRNxqQ8Q8oURaKiKCJE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           "]]}, "Charting`Private`Tag$48658#2"]}}, {}}, {
     DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
      AxesOrigin -> {0, 0}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, DisplayFunction -> Identity, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, PlotRangeClipping -> True, 
      ImagePadding -> {{75, 10}, {80, 15}}, DisplayFunction -> Identity, 
      AspectRatio -> 1, Axes -> {True, True}, AxesLabel -> {None, None}, 
      AxesOrigin -> {0, 0}, 
      BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
      DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
      FrameLabel -> {{
         HoldForm["ADP and AMP"], None}, {
         HoldForm["ATP [mM]"], None}}, FrameStyle -> Directive[
        GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"], 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], ImagePadding -> {{75, 10}, {80, 15}}, ImageSize -> 
      400, Method -> {
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{Automatic, Automatic}, {
        Automatic, Automatic}}, Prolog -> {
        RGBColor[{
          Rational[223, 255], 
          Rational[72, 85], 
          Rational[40, 51]}], 
        Rectangle[
         Scaled[{0, 0}], 
         Scaled[{1, 1}]]}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         Hue[0.55, 1, 0.7]], 
        Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         Hue[0.06, 1, 0.9]]}, {"AMP", "ADP"}, LegendMarkers -> None, 
       LabelStyle -> {FontFamily -> "Helvetica", FontSize -> 15}, 
       LegendLayout -> {"Column", 1}]], {0.9, 0.9}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.610600205234933*^9, {3.6106002423211184`*^9, 3.6106002524139833`*^9}, {
   3.610600294209866*^9, 3.610600323977846*^9}, 3.610638956465498*^9, {
   3.610640043094409*^9, 3.6106400705189962`*^9}, {3.610640393969522*^9, 
   3.610640430976296*^9}, {3.61067987927383*^9, 3.610679897209119*^9}, {
   3.610691931023911*^9, 3.61069193867218*^9}, 3.610692058464374*^9, 
   3.610693453554056*^9, 3.610717713570407*^9, 3.610802509066255*^9, {
   3.895303119793346*^9, 3.895303145867545*^9}, {3.8953035772951927`*^9, 
   3.895303605435533*^9}, 3.895303640047076*^9},
 CellLabel->
  "Out[166]=",ExpressionUUID->"a297f391-e3d4-4c74-8fdf-a8cdcaaf95a3"]
}, Open  ]],

Cell["PFK kinetics", "Text",
 CellChangeTimes->{{3.6104378241935062`*^9, 
  3.610437827054914*^9}},ExpressionUUID->"3f4f34ad-e1da-446e-bf67-\
4fe97f87aa62"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vpfk", "=", 
   RowBox[{"Vpfk", " ", 
    FractionBox[
     RowBox[{"gr", " ", "\[Lambda]1", " ", "\[Lambda]2", " ", "R"}], 
     RowBox[{
      SuperscriptBox["R", "2"], "+", 
      RowBox[{"L", " ", 
       SuperscriptBox["T", "2"]}]}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PFKrelations", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"R", "\[Rule]", 
      RowBox[{"1", "+", "\[Lambda]1", "+", "\[Lambda]2", "+", 
       RowBox[{"gr", " ", "\[Lambda]1", " ", "\[Lambda]2"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"T", "\[Rule]", 
      RowBox[{"1", "+", 
       RowBox[{"catp", " ", "\[Lambda]2"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"L", "\[Rule]", 
      RowBox[{"L0", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"ciatp", " ", 
            FractionBox["atp", "Katp"]}]}], 
          RowBox[{"1", "+", " ", 
           FractionBox["atp", "Katp"]}]], ")"}], "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"ciamp", " ", 
            FractionBox["amp", "Kamp"]}]}], 
          RowBox[{"1", "+", " ", 
           FractionBox["amp", "Kamp"]}]], ")"}], "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"cif26bp", " ", 
            FractionBox["f26bp", "Kf26bp"]}], "+", 
           RowBox[{"cif16bp", " ", 
            FractionBox["f16bp", "Kf16bp"]}]}], 
          RowBox[{"1", "+", "  ", 
           FractionBox["f26bp", "Kf26bp"], "+", 
           FractionBox["f16bp", "Kf16bp"]}]], ")"}], "2"]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PFKlambdas", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Lambda]1", "\[Rule]", " ", 
      FractionBox["f6p", "Krf6p"]}], ",", 
     RowBox[{"\[Lambda]2", "\[Rule]", 
      FractionBox["atp", "Kratp"]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PFKparm", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Vpfk", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Krf6p", "\[Rule]", "0.1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Kratp", "\[Rule]", "0.71"}], ",", 
     RowBox[{"catp", "\[Rule]", "3"}], ",", 
     RowBox[{"ciatp", "\[Rule]", "100"}], ",", 
     RowBox[{"Katp", "\[Rule]", "0.65"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Kamp", "\[Rule]", "0.0995"}], ",", 
     RowBox[{"ciamp", "\[Rule]", "0.0845"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Kf16bp", "\[Rule]", "0.111"}], ",", 
     RowBox[{"cif16bp", "\[Rule]", "0.397"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Kf26bp", "\[Rule]", 
      RowBox[{"6.82", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "4"}]]}]}], ",", 
     RowBox[{"cif26bp", "\[Rule]", "0.0174"}], ",", "\[IndentingNewLine]", 
     RowBox[{"gr", "\[Rule]", "5.12"}], ",", 
     RowBox[{"gt", "\[Rule]", "1"}], ",", 
     RowBox[{"L0", "\[Rule]", "0.66"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.610437851043413*^9, 3.6104380351464033`*^9}, {
   3.610438065662509*^9, 3.6104381165155897`*^9}, {3.6104382335331984`*^9, 
   3.610438480878167*^9}, {3.610438547958825*^9, 3.610438617408573*^9}, 
   3.610438803328314*^9, {3.610438979649111*^9, 3.610438980169176*^9}, 
   3.61044164424795*^9, {3.610441699133189*^9, 3.610441722836437*^9}, {
   3.610600525809482*^9, 3.6106005259612226`*^9}, 3.610639036182301*^9, 
   3.6106400656881943`*^9, {3.610640398431177*^9, 3.6106403994698153`*^9}, 
   3.610802497110508*^9},
 CellLabel->
  "In[167]:=",ExpressionUUID->"0c9a0ab9-bf4a-43f1-94ce-0366c5419292"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vpfknum", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"vpfk", "/.", "PFKrelations"}], "/.", "PFKlambdas"}], "/.", 
     "relation"}], "/.", "PFKparm"}], "/.", "parameters"}]}]], "Input",
 CellChangeTimes->{{3.610438484045589*^9, 3.61043852729707*^9}, {
  3.610438577715356*^9, 3.610438578987534*^9}, {3.6104386238436413`*^9, 
  3.610438640797978*^9}},
 CellLabel->
  "In[171]:=",ExpressionUUID->"ad5c91b4-46c5-4ad8-aa07-0a2558833f91"],

Cell[BoxData[
 FractionBox[
  RowBox[{"72.11267605633805`", " ", "atp", " ", "f6p", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"1.4084507042253522`", " ", "atp"}], "+", 
     RowBox[{"10.`", " ", "f6p"}], "+", 
     RowBox[{"72.11267605633805`", " ", "atp", " ", "f6p"}]}], ")"}]}], 
  RowBox[{
   FractionBox[
    RowBox[{"0.66`", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"0.8492462311557789`", " ", 
         RowBox[{"(", 
          RowBox[{"5", "+", 
           RowBox[{"1.1111111111111112`", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "9.`"}], "+", 
              RowBox[{"0.8`", " ", "atp"}]}]], " ", 
            SqrtBox[
             RowBox[{"-", "atp"}]]}], "+", 
           RowBox[{"0.11111111111111116`", " ", "atp"}]}], ")"}]}]}], ")"}], 
      "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"4.225352112676057`", " ", "atp"}]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"153.84615384615384`", " ", "atp"}]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"3.576576576576577`", " ", "f16bp"}], "+", 
        RowBox[{"25.51319648093841`", " ", "f26bp"}]}], ")"}], "2"]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"10.050251256281406`", " ", 
         RowBox[{"(", 
          RowBox[{"5", "+", 
           RowBox[{"1.1111111111111112`", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "9.`"}], "+", 
              RowBox[{"0.8`", " ", "atp"}]}]], " ", 
            SqrtBox[
             RowBox[{"-", "atp"}]]}], "+", 
           RowBox[{"0.11111111111111116`", " ", "atp"}]}], ")"}]}]}], ")"}], 
      "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"1.5384615384615383`", " ", "atp"}]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"9.00900900900901`", " ", "f16bp"}], "+", 
        RowBox[{"1466.2756598240467`", " ", "f26bp"}]}], ")"}], "2"]}]], "+", 
   
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"1.4084507042253522`", " ", "atp"}], "+", 
      RowBox[{"10.`", " ", "f6p"}], "+", 
      RowBox[{"72.11267605633805`", " ", "atp", " ", "f6p"}]}], ")"}], 
    "2"]}]]], "Output",
 CellChangeTimes->{{3.610438492228621*^9, 3.610438527818906*^9}, {
   3.610438559454644*^9, 3.6104385836965723`*^9}, {3.610438626918457*^9, 
   3.610438641261001*^9}, 3.610438826151511*^9, 3.610439006004117*^9, 
   3.610441645515864*^9, {3.610441700656803*^9, 3.6104417247944613`*^9}, 
   3.610600527123828*^9, 3.610639157746241*^9, 3.610640074734523*^9, 
   3.610640435851358*^9, 3.610691941371624*^9, 3.6106920631547327`*^9, 
   3.6106934586512012`*^9, 3.61071771693475*^9, 3.610802513905315*^9, {
   3.895303119853611*^9, 3.895303145914156*^9}, 3.895303609963269*^9, 
   3.895303640078827*^9},
 CellLabel->
  "Out[171]=",ExpressionUUID->"fb1a1024-406f-4d6b-acc7-1c222e431ef6"]
}, Open  ]],

Cell["\<\
Indeed inhibition of f16bp is negligible (so keep f16bp fixed at 0). Note \
that absence of inhibition depends on At!\
\>", "Text",
 CellChangeTimes->{{3.610438921216858*^9, 3.610438951318183*^9}, {
  3.610441734873267*^9, 
  3.6104417553301687`*^9}},ExpressionUUID->"c35ee253-ac26-4a35-8582-\
217cec0c7fc4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"vpfknum", "/.", 
      RowBox[{"atp", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}]}]}], "/.", 
     RowBox[{"f6p", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.5", ",", "1", ",", "2", ",", "3"}], "}"}]}]}], "/.", 
    RowBox[{"f26bp", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.005", ",", "0.01", ",", "0.02", ",", "0.03"}], 
      "}"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f16bp", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<F16bP [mM]\>\"", ",", 
      "\"\<\!\(\*FractionBox[SubscriptBox[\(v\), \(pfk\)], \
SubscriptBox[\(V\), \(pfk\)]]\)\>\""}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Thickness", "[", "0.001", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.610438642793728*^9, 3.610438751785471*^9}, {
   3.6104388300059223`*^9, 3.610438906366931*^9}, {3.6104389578026543`*^9, 
   3.610438986269054*^9}, 3.610439035663735*^9, {3.6104390926148853`*^9, 
   3.610439111455903*^9}, {3.610439145709334*^9, 3.610439147189123*^9}, {
   3.610439179473254*^9, 3.6104391896668997`*^9}, {3.6106402175046577`*^9, 
   3.610640255090991*^9}, {3.6106403056419287`*^9, 3.610640333959783*^9}, {
   3.610693486426168*^9, 3.610693582893341*^9}},
 CellLabel->
  "In[172]:=",ExpressionUUID->"bc857e87-179a-4ebb-b6e0-dadb01894ccc"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1Hk4VWsbBnBDSqEMp4Fj3kXJmDpSdK/sNEhCpJxwCLsoQyeKNFJySiRJ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       "]], LineBox[CompressedData["
1:eJwV0Hs4lHkUB3C5RKgHSWkyF6+aktBubRTOT2yJbmhql91ayqWSljUlEWUk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       "]], LineBox[CompressedData["
1:eJwVz3s0lHkcBnDX6jBal9UymBl+DhGRc9qtlr7fbartRhdJtKoZ16IxriuX
3VkRs5ZG6aYjqzZt20FatGojEjHNtBlpM9PWNuF9Z2tLmjIi++4fz3nO56/n
PK7C5C2xJkZGRsFM/u+qb4SzFsWULDepXeulSdFBl4q3IZy3Bwob/raXMJ7p
bjvA4+2H00+8mgnjqhulXHOeFKwsJ633inWQFJSx7x33JNiNWAjGRTpQvU+o
eMW9APP9AlINiTqYrX7q+YLbCqNlnzmrY3VQ01ed8g+3F1bIfRXzI3RQ3yBV
Jy0cgt2ZqtOjgTqIh3snn6dqYddstvQjogPRsJe2qZ6GJWOBUWaWOrBwLfB8
vOQVHPZxcm55TUOZtdy7Zvc4ZD2c/rnjEQ1C9dZ20ztvQfur2OWv2zSk3CoQ
JntOwkRXcLNdCw2NYlaow9ppEPdlzXlzjoaanESdf7gRagpvVamP0pBfPbX5
zXNjPGjJbjUppsFI9QR/zzbFhap310Q5NHikx2Vt9TbH0I6R/j4RDc/0x7dZ
Xp+F+Q6oexhNw7rhvXmHU+agmuWeN7CdhpBnsgUcjgV6RBTJu0No0N0USm7X
WSI/MMjEfDUNC20GXfi7rDCk+RehWxANFqAXaMbnIoRFJ0QtpuHLF5Hv3MKs
sTfbednXvjT82RljHOljg7xt9nX+HjQ0F3ft5OltsPzfxH1yLg1x5hlPlEpb
NJ5u/BEdaYhOzWlmVdrh5Ze9p3PsaPCLX6DcIPgYndQtpZy5NNy19bHMWGqP
1grZgco5NFyrzz/lYzoPMwPCA34zpSHH2HvTnUfzUHaEsm38QIGFJnuNqOkT
zGOXBBlPUjBc61pRneuA+mB/1gM9BRXzHc1awxxRUmwvLR6jQFYZ1yPgsbFM
HSq+/IKCyIooJWuUjQ0FG1866CiYWHnOUN3mhFtsfVd9NUKBdnhFVmeRMw4l
l3eaayk4E7TISSFwwQnf70PLHlNQV5hhE+/LwZ7td6fTNBQUhUWvN9VzkL1n
iaToIQWLNTUXihRcPE6cpTmDFJzwOlWnWM/D3dKUoXYVBd/eKD2xvpWHkvvh
F0f+oCDYKexcn7srtgcclnyqpOALUc8OG6krDlj7vZHLKah2Frrf0btiuZ8g
blUvBe43zx8L2eGGLjGN/Jlu5p9vp3d/mxveFkzVPeiiIG7c7F6vN8ECXHDo
aCcFwsbXPOkhguz9/M9/uEFBUn7o1LpygpfyhtYeYJwR2vSAdYRgJu96RDbj
Yn1GmewYwVluMXkJjOuXGt4fryI4xF80sJKxoWNmsPYiweVXpe3T7cx+P6u0
q4dgWviqEjHjyrP7Eg72Eky/390Zz/hsupK/Rk5QSUre72TcMk82KVcSnOui
Fgcz1kTaJajuE0x6K9vrzdhT68h/qiW40duh8lkbBf5N2ZyfhgmaJ9cOqxkv
K1QbYkcJapalBagYb/CsukTrCG7a3nO3g3FqIo8zNkZwELc4VjPODfzOcHmc
4JWtCtExxoVWTwfS9QSj+gtulTI+0XC2ZGKCYPP0+cxcxmckZvFXJwm+dre7
l8b44ubYFblTBK0utPokMm5y63ZZ/oHgzOpTUiHjtnEPw8wMQcW1K6MRjP8D
fv1aRA==
       "]], LineBox[CompressedData["
1:eJwV0H00lHkUB3AW1Y5hqVZJ5u2xTaZBaiuV3FvspqglZuuMbWW8lwatOVui
EGGLhBU6dk5E2dZr5JikEsnb9CJqo82Grd8TZ02avKTss3/cc8/nr+/3Xr4s
fFfgZzo6OjuY+X8XHJPNsQ845aQ3pHe3Kp6G5m6e+25eKPStm+dwlvHs3cYT
PN4R0K3WJEYwLriVxjXgpUKz+U+VtozDNikOTnDz4KrvQklpHA3dH0Kyx7il
kJPQzso9TsPcvpfCUW49eGrutfwQS8OFdmXkG24bZBm98TlzmIbyitS+MNtn
IBiTqyfCaAiGh3kjhwbBI8wtc5UfDfJh68GacgLjA6GBdhIaWPxE4QuHMTCv
q6zSbKUh3aRDdGHfOCTbLU/I3UiDrM/7pl7ne9iTHlTnZ0tDZEuiLFw4DfGf
H4+o4NNQFcH2WrztI1xVRdYtM2P6HD1Ar9ytgx+ff9VjwKIhQTnj+W5EF3vf
2/25YJaATvcANkTr4RePI6Zr3xFYFhV02FtkgCZcR5sXhMCQ9tz3hjfm4Kh4
lZQaILB9eH9sZuQ8rNOeXvuph8DOoYwVHA4LS/NmVPJOAvQdWdy9MkP0VZl5
9N8hYGvaa+nsa4RpI7OqERUBFmj9+seNsZyzbfh1NYGto9IJgcQElxwTyjN+
J/C0KUBXKjbFHmP7xupCArUpzT/ytKa449cjeUXnCQQZKAbU6vl4c2NP7LfZ
BPwPHa1l5y/Ay0mCp5fTCNgFr1C7+y1Eds6epuBkAvfniw0V67/EHButyV9x
BK6XJ5wX65nhtXKfGzPRBI7qijw6n5vhSO+LoSdRTL/+aFd5zSJccz10w7xw
AsMl/GxlzGL8W+f+xc5QAtnLzfXrJebIfnS51TOAQEZ+UKsfbwnuMrr9bJ8v
AWn2XjX71RJcLS5pqJQSmHQpnlI2WiAJGOW3SAgMDm853JS8FMfWfcfx9iRQ
uMneosvPEu3crV2vuBMoS1KYBttwcL61vYXClUCyxN9NT8vBx6sdDKJcCKzp
v1Ca3MXFfdwYTyckkGt9vqzLjYd9uv4O4Y4Ejt9Ky3Wr52FS7OQZuQOBHRaS
4nYrPq5Xe2UpvyawWd7qY5rKx/0WDzLF9gSUS2VWnVo+vubWPfjFhoDVnUs5
O30EmDygqQcRc59Nk+hRowA3hzgWWgiZ/4/rP2wTUfiby5HdHRQBWdVbXuoZ
CidipCfaeATCErxmtp+lcG2/m0sDY4VXzRN2FoWaf9RzKhinaBXpGTkUGpOU
jGzG5eunPpwroLCa1XLNl/HU7dnekisUhrnzd77nMvmP2GnNrRQetE8tsWKc
X3Qw5GQbhcWZorxFjIui1M6uHRQuNpaksRhfM8uY7lBTGP6NS/QYh0C/dEFI
dw+FDZLEoAbGwkFz55eDFNqJPVK8Ga+sieZcHKYwtdg/ayvjDUl9U4GvKNSf
O6PcwNhdWFBJaAqf/qy6wWN86ACPo9FQWNseZDhqSSDGMX6qepzCvU75ggHG
SUYvH0dpKVSe9NjYzTi3oujU5CSFbqddIusZF8bpB6umKUxoiU//g/EVz8At
MTMUvm3HMiXjGsFdS6dPFF6SxndlMm4cXzY1O0th3Srnf5MY/wcxPUpQ
       "]], LineBox[CompressedData["
1:eJwV0Hk01WkYB3B1WxxLgyZK3MVP3bpRVM6h7XmGUiFNoeYoGddeFHInWWKS
kZGohJTuWEoyWXI5U0lSk+zllmpQsmTeH9p04yLmnT+e85zP+f7zfB+B+NBO
7+kqKipOdP7fWcfEs8y9EjeYaw6WRsSx8FDOd9jN94egNZwOf+qpR1WxfP5R
ePve7fNu6qzqJN5MfgIYOa7uXUUdsF4SOMK7AJ+Ula/ZEyzIx/1SP/IKwP7r
7R9cqGe3dwuHeLdAcspsu0EsC9n10uABXh3cfLe39kgMC18yykVvTtUBd8vG
GndqW9+GnlZlHVgosgs3Uw9yRlxuy+sh+oKunR615XrHNQnxjSAdXfdXeTQL
T4onpgs/tIBEqDjw4RgL0fUmdubucih38qreFcVCUXFCe8Dyf8C67bWz8igL
vvD0wmBID6iZWxqZHmbhYN/SHlkRARX9lCBOAAtqghPCN5YfITDvu/ZXniyc
1moQZf88DKv2nimc2MOCuN35HqfxK0Qsy3m0zYmF4L9PiA8Jx6BU1h1eZsdC
aZCG0/yt32h+Kfa6Ne0bcYA1262C+2dXdH6zYuG4dGLHl8FpaJH/r2DEnAUV
eRdWhnNwsrlTaiZiYXGoT5izaCa+X+Rs+lbAQq8ifZf63VloL61yttZnwa5v
f9TZYFVczHXbukSHBcfelGVcrhqKr4yec1djgX0gjnl8Qx3DGJftmzgsLNdu
M7Rx10Suw9PBu+ME1EDh0TE8B9de9v/p7RcCm4dcR4xctDBq2G3DH0MEXtZ4
TXM10cYqtbrE4ncEyk8+3MdXaKOeSILuXQR8Zkq6mpt18Pd9gYKyVwQ8QyLK
NTLnYm6Tn2m2nMAK32XNDh7f42cVK1t5E4EWHRN1idU8tLJYKy6pJXCn6PhF
E44uphSu1DOoIRAxTfRjY6cupsW2aVlW0vs6wrcclOlh6PX8gbQKAn1XBanS
yPn4y/3nXWGlBFKXLJhxy2UB2iTruWn9SSAl06fWg6+PY3r2/cb5BFxT3Zo1
+vUxsyDXKiiHwOjGK0pp1UJsrWTTJVkEevqsw2riDTA4Mm1sKINAznrzhU0e
hlj2bmyFcSqBG3ESbV9TLib1d2k+TiYQ7+Jpz1FwMeqsouBiIgGLjuyC+CYe
PnnWIzeLJ5Cx9OKNJns+SjNiWFEsgejqpAz7W3y8Y1txlxwjsG2hy5V6YwHG
XS9+0BZO4IeDtXu0EwS4c4n5Zf4RAlIDsXGjQoAKH/+AlYcJGD/IT3PcY4Sh
070HLx2i/UxrRK1VRjhH9Z6zaQD9//CMp3UiBleabDp/0o+AuPQzPyGZwUXK
7c8svAkEHHeasDvDIK8qTyikljjJXmicYzBhh2/kfOqTCsnplDQG7QwtRONe
BIqslOPpWQx6dg6lVVMr70+1XS1kUFl9TWZPndKqkfSwlkFh+cCU2JNAZm6g
3291DL64nxnjTJ0b2myzpYHBtLDS6bbUFbopYw3NDNYI5qkvpe5wnesnf85g
i06JyQcxAWHPApvuHgZfqqqVRVCbycK5eX0Mlo0Z2AVSr4lrV3r3MziZnNq9
j9pBmFVCWAZtekv0rKlDDvC5nz4xOPwx46wqdeS6X5U3hxkMudOwesyDQJxm
97NQBYOD1zxeDlBnFOcmjo4yaGxawbRQ58TM8L09xqCRV2hDNXXhDm/ryAkG
0ydTQ29Sy4weGW6YZFDWqMfLo64aXqycmmKw9PJE/Xnq/wCT1Yvq
       "]], LineBox[CompressedData["
1:eJwV1Wk4VV0bB3BD9VQohxKS6ZAMDTRH3auUIk2GeCRzDpHwRJKSVPJyJEmG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       "]], LineBox[CompressedData["
1:eJwVz3s01HkYBnBC7boUuqEw4zeZGiR2Oyi8b6mEVhek2JSRoe2i23ShNilp
ClnZXFoJm1adoTookuSShihNWWuoNE3q+6MUqpls7Xf/eM5zPv89D1cYsypy
jJaW1lqa/zv3V+FYp40nPa+kzl/r7cZCg5yzLJizCdR2uqV61N/u1hzhcPZD
f2ajfoMrC7m1KdZ6HAkkqnidSL3FQ7z1k3U2LEqMeznPhQX5l+iMQetiODkc
Gu80l4Vxihf8AetKuDTSnO7gxEJ+c94O1loG6TV9UbGzWBjOKhc8S5bBu4Xy
ATfqJVEtykdqGeQoKv9Qz2ShX+dTUJW8GXiWhnv2U7t6+M+TJN0Ho7AIizg+
Cw9LR8fw3z0A+F2Dx2awcKjZ3tdpvRxqBYKYai4LJaUSxZbZXWBscUFz0YIF
YkqSfcO7wDnIOVNMzd/j6zkzowvWSDyCvajPuxvkK9VdsKHj8IJn5iyky5JF
IY0KCHx1vtqMeo/y1Hvvn3vAVhM/P30qC3kGLUdMFj+H+iMzG89NYiEK2rP7
dyqhYqWf2mwCC9tUs5RlJW9gb3OZNEOPBX3uUf4z10EQ1fnpvxolkGrcIsjf
MARF/C+x4z4SECoCb+vc/wjZ2x5v+OsdgR2NR4UxfA1sFztoeRMCV7cbBpj5
/Atn0tqNVCoC+XGbyZxgLSxwjrld0UsgIW905XC/NrrLWl0WPiWgJX+O1bE6
6MQrPuemIGC7W7QvUKCHqzr7f1jcSeDlSOZqg1tj0Tuno/reEwK+ql8Opu/4
Dsdv2CoLlhPwf5lmZ2Wlj2f7Cvl27QRIvTD+ntQAfYjSe8UDArNNOiy91hsh
T8ZN3ttKQB9GwruHxuOmNu/o3hYC3gMhn2yCjHF9hJzv10ygs26jdoi9CSZz
llR13SNQfrwhjDNigjGDXj5nmwiI9MTP29pM8cpriXTNXQIRO+PKDXMmYlPJ
qnRoJOAYZde2LHwSzn7C1/doIPDA1N5A7DYZl1oOvJlbT+BmScJZe50paNHz
zHl5HYE4bcGK+z1T0PjL9N6IO3Rfd+zSbWVT8cjRxtgTtQRURdyMvANmmJqU
19V8m0DGTHPdyiBzlPI0LmOp03JETeEcCwy71LN6TQ2BkIx1bYZ9Fvja6Oqi
ilsEPi+6oM6rmYYfwzotJlArVQv31SVNx7J4mxux1QQKPJymtYZb4qoP+sd7
bxKQJopNohys8HSetvNa6qSgCD+dESt02fRj5D9VBOZ25xcntVrjdf6MvkDq
rFlnpa1+HBS6+Rc8rSRwqDYly6+Sg1PfeX2MoP5pWtCFZh4XHXe53hy8QWDB
tqZQEwkXO4IFORLqvOlC3v0RLoYkt4MVNa/+4hn/UBssOpGkuXWd/nOoEzyq
scFTnlFmEdSiId12mYDBuuW9jrrUwqsfOJJTDGqtzO4rqSCwJSFg1Pc3BlUT
b+yQUosDyv42PM2gT5zp6GXq4yPi1LQzDKZ83W9STF3ipv6SmcugsY8pFFKr
73zrKLrM4GBy6IVM6rRHhikNTQySq29z46lzCrdGH5Mx+PSWyPEQdeHuNq+l
LQwqSszuHKSumJKmaWljUPC9QBVL3R0yMVr+hMEcjvYcMTVfae71QslgwvDu
h5uo55TFWv2pYvDw26OR0dTzEhXqyD4GQ4ZbNSLqZfzcK28Ig8oBfduN1Ds3
c6zev2fQhet4KIz6gPth9bUhBh+NGTtlHXWi0YvHu0cY9EqcLA2lziotPPn5
M4PxLk8Va6gL4nWjqjQMVi/L3BVMfXll5MIDowyWtx43WE1dZnPX0vMrg3bS
a4WB1DVDtupv3xh83TPJPYD6P2Ayv1M=
       "]], LineBox[CompressedData["
1:eJwVz2lQk2cUhmEiSy2CIy4oRrLwUZGIiO3QaqucQ8AFwVjEaIVRIax1wcqQ
GQXc2NGJgqQSlwyVTQUDBcEOVKgFxIbNahSxRBEQgfczjhaiBlD69seZZ65/
9xHKDmyJnGZmZraJ3v+rPiqzWhFxymsyxzbRfx0LzTpBwHbBj3CPW+X/JfVU
S0OKQHAYenIrrByo1bcVfEtBFmyRcNe8XMvCvjXy/e/55yGpdG3NMWrdRIzy
Df8aJJ7gLqrwZeGznn4XA78W8uqr9RwfFi635h9k+VqoWjVLkgYslFdk9exz
/wdCOK3Odd+wEA33z7+KG4AryePhpz1YiB10HaguHwENk+X2xJUFa2GqS+/K
N2AqduNMZ1g4PatNdDl0FKRLHo7wHVmQ9Wz9w7z9HRzPNVN7zmfh4J1U2QGX
cdjFNex/asdC5U82QQv8PsIlAdMntqU9iXuJx3YzvFTTu7xkOgvJ+ZOBY684
6PXurGWZBQtmuud4K8Ecz6ZzTlpzWFgcH3Voq8gSm7QRXbKPBF4Y87bNqLfC
oXVe2q/HCWwc3HPk7MHpqN0oa5n2noDkRfZSHs8ay4p8puaOESBNsuN/aWYg
XD2Xmf6WgLtdl6PPblsMhAmR4TUBazCG6Udn4oZeg2/JKwLrDcHvnaSzsFsT
qdpKCHQ3RnCC3exQ6zr2xGOYQE1m8y6B0Q6HixT5kpcEoizlzzs7Z2NDTZY6
9AWB8LjEGpsLc7B+IfeH6/0Elkcv7QwIm4tP5zb62PcRuDfbbYZ81TxU7pB+
Ed9L4Pfy5Itu5vYYZ7iZwHlGIJEj+r79qT1qCzcdTtHTPn3Chtjq+bgtqGWC
10NgsESozE9agBn1r/v6nhBQLnGwqJU64Owmcen5bgLZF6LuhgkWYogu1Ur+
mECwcmenzdBCrMzJ95R1EfjgW2zKb+AiV6Iq831EYGBQfKgxYxHmiW/sWfuQ
QMGaFdyOMEcUu/7GX60joEmT20Uv46H3Ac8kyQMCGdJwf3MjDwuSM2Ji7xPw
1F++ltHBx5f13NupfxNQuV7UdPgLMK8llnPjHoFjtxUq/1oBFp7xWt/dSWAT
V1rc6izE73iJtZ9Te8feDbHLEqJQnGbc3EEgf5HMud0oxDH/+OuKdgLOTVfO
SUKccJ5fdMmzNvrfskbRgwYn/CoovG4lddSoxX2tiEFJS86tk60EZJX/CrLO
MFjp19Bo0BLYlxw0uTGHwborK+1YanlQ9WObXAbbjs4LHabONMpPZ59j0MP3
3ad+6vJVpok8NYMz+wO9u6lNf051lZQxGOW+u7uROvuBjaL5LoNVO703q6gv
FO6PSdcyKC3tv/YzdWF8p8+GNgbn6Acscqlv2mePt3UyOKK2vKWg1gfPidE9
or2Rze4p1C4DDj79Awy6xjgujqX2qE7gFQ0yeF15I30v9bdpPabIIQYHI64O
xVAHuKh/HSEMGn7RlIZTx+0V8N6+pX0hzp47qJNWnzBVjTJYcFij2kadZtv/
MN7I4MQl5WQQtaqi8NSHDwzyipLuSKgLjltE140zmBJ6RBRAXRYYKU6aZNBL
13PGj7raqcXR6xODxcN5xnXUDaOLTVNTDDoqKkN8qf8DA9xhPA==
       "]], LineBox[CompressedData["
1:eJwVz3s01HkYx3HlkhgtWWpcxvB1iHTd03b3PKWLW86WS8VpWyO3JROHaie1
mZSmUmMbkVy2LNvlUMKe1W7TzSbFFKqt2Mhlrd83rTDGILPf/eM5z3n993k7
isRbIqfq6eltYvf/LzgkMlq066RnhBPxL/SlUNsi9N8qjAWZ8974bGbdQ+UR
ofA7iGu+ID3FXHA308FQKIM5r4rlEub41Sm7NQ7nISQ/bUkIc8t4jGLA4Qrw
leM3TJmntXa69jvUQDbf763Yh8LFx0WJ1KEejHPJeqE3hfLrstb4+W/gSqfL
g+F1FKKh6fz7pC6wPuR17dYaCgk9bl1V5X0gqPSN3e1JwcQx3bV92QCM5Cid
6lZQOG3+xP3iN0MwPaE/ZsdSCqLWoDv6DSPQve+z5sovKCT+kS4Su45BeVNk
tMdCChV7eIGzfT7BhNmCI2oPtudAHLdwqx6WjVRrstwoSIsmNg+/n4I1n7xn
prlQ0GvpwN8l+hjvMklzCAWX5Kj9Qe6GuPjYRt0JIYVudU6I6W0jrFAOCxrs
Kfj2fHvwh0Rj3GXj9qHfhkJAt3yuQGCCKBGcWDabAvdAdPhRmSmuG3iaW29F
Yb7FS3uvnWaYalwx6GnJ+kAd3jY0A8e/jF4zYk5hY3+oxinYHGsXi7cqZlB4
dX/XlFAPC2yX700M4lGoPl77tVBtgTrjwXsBJhSiDFM6VKqZKO63b19kTCEi
6UA1L88SGydnufsZUVgQPVflH/45Xg6qizxkQOHpTA/TlOVWmJCayMufSuG3
cukFD31rvNo+UdinR+HAFPevGv6yRt8sHz7RcWDSJvFOqJqFcSVzC5M/cdBT
6qgoSp2N08Qu0oFxDhRz+AY1wXzc9s5GsX2MA3leVF240AY1rnkruVEOQhU7
VLxeG/QPNwvO1HAwuq5EW6S0xcPVQUrBCAddPWv338+www0/bkltGebg0upF
to3h9ugVR/L3DXFQdjTFInqeAJ9v2Na2apCDjOAIP321AAO6pcEWHzlY0nbx
SkajAy7tTXd++S8HuW4Xyhr9hBio6qj89QMH39/NzPWrEeKdN50HT/VzsMk2
uOSxsyPWS1dmJ7znYE1CXZiFzBElSU3iOMpBkZ3IuUHtiO8qOreHchw4P/j5
XECYE8YdCckQ9bG+effdm5VO2GK5R5fyDwdRQwZN9e4EBefKvFN7ORBVDApl
Zwje7DiTdv5vDuKlgRO+WQQNn63Py2ZOCaz6k3eWYK+juDKL+bg65bT8HMHS
ItteGXP5cu14TgHBFd2vAyXM2nu6l6XXCMovv1kbxixv5mXW1hGcUx611545
r3h3zLF6glgQUcBnLk5WeXk/IbhD1lRrxfyLtXzsiYrgCE/PagZzW6hlTMsL
ghsqSm5N9nDg2sX36uwi2KWZatvBvLBKIviph2BDp5FPG/OKo63ayF6C5oWS
fa+Y/V0LbvRxrGdlxYtnzElxQsHHjwQ9Dbfn3GNOXZWmvTlEMDb29aPbzEfN
Op8nqwnaTa8fq2HOvV58cnSUoOaGeudN5kuHDaJvjRHkKxafLWe+tjlybeoE
wZqYtw+vMlc5PbT3nCQYZqcdK2VWDrlodTqCmfnSBcXM/wH1WGIo
       "]], LineBox[CompressedData["
1:eJwV0n001GkUB/Axg4TkpeR1zPiJCKnT2mjtvWEl5KyYtIqWQm2aytKWJJKY
amrCes1KRB2LrdhWu2SxeVcaZJdeNqnMU6k0NIh99o977vn8ce+533MuP2zf
pnA2i8Xyp/V/L0gIU1258/SXUWVTklJvAs1Snk8gbzfcHRXWFFHP3alP5vEO
g4pHQu8F6oIGsZkKTwQn01PYGdRRLrF7J81yId12gHuMWjq9K/Ot2VXwkKQF
b6aeN/jU6rVZLTRY9hgqURe1Fx4gZm3At+u/7ulF4ENOjc3jM21wRXW9pSu1
R2TH8H1FG0TPPM9cS/2KMym4JW0HpWMdO+yp17j4OotSO0ErpLVVj/pe1Qzb
auwuxI+Lqh9uIHCs3dZr5XYpbLFvcBJSV1aJBqPs/wEPaaZpsieBSOjJfRU9
DBb5gktlHgSEI9bD1ZWjoJJ8e+CaOwF1/gmrx2vewqE628WxrgTOanfYFH07
Dho3HX18kEDYYMBtTucECHkXel+6EDjw14mwfVZTcMF107BoLYFr+zX9DTZ8
AnnjzKSfE817ZI/MIZCFBX3cOuJI4HjhjN+HV0q4Tji97fpqAizpE/wjjoMl
Yw96RasIWMZEHAqwUcGD0YHg7EDgmTx7s0adKsa7qUmN7Al4jXx3NP2AGqZZ
+uoPLCfg+0yynMtVx2z/w3rl1gRkTWGJrRUa2LIxebbCioC9Tr+p2/YF2PVe
kHB+Kc0H8tChcS38MaTKpIQhsP510KS5QBvRLqEql09goHGnUpCtDs6PFxlc
NiNQk9YcwpPr4OrPH6k9NCUQoRL7pLtbF41DNm2fMiawI/pIjWaeHnq+qy9z
NSKwInJ5t0/oInSp319SYEDgrq6tRqzTYrRmW0481ifwe+XxfFuOPt78Zr2j
12ICR5Rsvu58qI+qiRXuBXr0vqE4T2H1EhT3G0jZugRGSvmZhfEGmKDY7SHW
JpC5zFC5VmCIC6WJ89gLCUjyIlpCeUbY98NG3bwFBIIyg7s1Xxihz1b1yHWa
BD66X1YU1hsjy7ncv1edwPCI66HGVBP047Q/SJ1P4JLLSuOuUFMUFHmoLFMj
UJESqxNpx8XwD+ItL1QJpAp2eHPkXDyoV2tQrULgs6Giq6ldZqgIGM0QKhPI
sc6v6PLmodap6d6vOPT/GsQ53rU87Lnx028abAIbjQWX2y34mLPhaNkjFoF1
wpatOiI+OgS7Le2ck0GhSZhFp5yPyXusV12dlYFFU1mW71ZztIwpKi/8JAOJ
XaPN/Xpz5C79XnZxRgYR48o9bTYMsm8EitOnZRB27T1PdI7BuBV+TflTMog6
7j/jdZ7BeY+WJWVTx/pXP9DMYHCQFwkZ1Gny2LOSLAaf2y2pO0Vd6aSYzi5g
sHTMre4wteLPuf7ScgbP726+F0gtua8pbm5hsGObsvsi6rzivbtOtjH4szRT
S5u6OKbbzbOD7nc89bcG9a/6kqmObgaviIv3c6iHgvR2SfsY5GidK36vkIHV
sKHb02EGs166mPRQO1THcUtGGHymtOR1J7VzyqAi/AWDMY4B9a3UPlYFv4zK
GAyumwptoI7ew+O+e8dgU/9ERRV1/BdJiuvjDJ4JGUsqp05Z8LQ3Rs5ge673
5jLqnKri0x8/Mvhmwp5VSH0pUTny1hSDE7M1fXnU5X7hrvEzDN4+ebE8i7ra
/I7pl7MMhiS9SUqnrh+3VMzN0fl/C7ecpf4PjAKDKg==
       "]], LineBox[CompressedData["
1:eJwV1nk01V0XB3AhKpLhrVAuuiRjlAZD9smQCJWIuBSRIZmejCkKlUTCg8gs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       "]], LineBox[CompressedData["
1:eJwV0ns01GkYB3ANI4cpuazKZS5+1USUzm4dFO+DdtlRNiTRjXEZu6mQSYta
YkJuU+51JsmlYo2U0iQqKbkWqi3DEZNsfuwmBoPWvvPHc57z+et7nu95WNzj
HkEUFRUVHzzKLTrDVd8cmGrv4L8YZlJJoqYe5k5v5q9oblBsS8NefN6QwGT+
jkhBNXX+TxKJHqczqMwUpO0kufoOO9SOf3SGUYDu6d2ayMLumQ/J/sK4iR7k
9FppYS+VDrHHGRKUy1kW8q2cREWtheEkowV9saEemblBoqn8u+YDaS3IefA1
/xP2T7w2WbeiBYUiq9Q32GOqM14PelqRcdPtN3ewre3cbFOS2lHYwqfRMOxX
VQsU9r8vUeJ4gvH4dRL90WrB2Xy4B41qH6wbLyORuCpFGrqxFzXeH/hbu5RE
o7qjaRz/XvR2MEFEwWaf5Nivz+5FXU1+++UlJLq6XatIpuhFNtLqr73YF1vS
gn2fSZF+nVlmGfZJWeaE84F+tNZBLQZhF2q1Jej8+AGNtuXMRhWTiIe6CsYi
ZCjuqciJco1Ex4bNZDXiz2j+nzT704Uk0mQlsgesv6AwTnXJJhGJMla0mRf5
TSLjzqFDBy6TiCvd80i1fRqVDAT5lBeQKPxZIvc4ew5ZUpf6b8snUXUYzXPV
z99QT6TRuhV5uM+YI6NW3irgGdB09GsOic4WLrhPjS0BSYzYSB1bpecDPIxW
hSsXcqK3ZpNoXWTwqT3mVKg9wzMJzSLRR3neXq16dWDljdQ/uUgizvBvpy+G
a0AQvf6AIbbbR+EGOl0T9lp1/yC4gPt7yo17UakFPPGWESr2Rp23Jk6Hl4Gi
TchIEuL7kNy/b3I5RG7KNzPEdh73nTH1WgF83xDTykwSvWsMXOJroQOltVds
ONh3k5sOMeU64CxeGz6VQaJgKv9DZ6cuBJ6YeSHCDoiIuUu7pAdC/UYHD+xN
vA2dO/31YSRrWzMN+6WuhRbf5jtIuVNBe55Oojrx2csWqgZA9TOkJmPHLDHf
3d5vAKt0T9S7YGv2Rbscq1kJ+6hpO5ZjD5exsgtjV8F8nMb93jQSZa9frSbx
Wg2BWrtelWILLwU3+zMNwSVeVz0K2zf7YCdtxBD0W2t5rtizO0oVhQ1G8Dhj
JISOLRt2PNWYZAxRj8pPTqeS6JrdZqMOfxNICmdZd2BXCvg6PEs67E6ejr+B
neQV4Koqp4OHht3Kc9hb+opuJnUwYGAvJYSLnW92ubLDlQmaRaI0R+w/Hqfn
u0qYEGZTH8fC3mXkVdq6hgXuBYhPwXY41rxfJ4UFQsGjik/n8X8ac9e0y1kw
5YwaWrDXPL2e67bfFLYb3WyvwhZaNpp3N5hCv9TeLQ87eFKtq8WcgCeDIslp
bG71V2ZKJgFnpiUPg7FDz3oucC4QwBZMeCvN96z5i5ZFQATDZjIIO1nOzxDm
ElDOmzVTWmyjmM8TEVAn3ZofgK14svi2rIKA+MWqKD9lfjctvamZAE7/KUdf
7EvFR0POtRCQk14+4INdHNnp5NJGQEAXGav0PQPhXFsnAc/URLX7sPt89UJ6
3hAwdUdi6Y3Nlq12GpIRoEJ5b7wH26omml4yTMC+7yl1nti2AqkiaISAgXpb
H6V3skW3Po8SoPHqfY4HdsQRJn1iggC9xJfa7tix2+MVtycJWGl4QrwbW7Bs
6HWknICMsbW7lM6vKk6dnSVAYC05/wv2tTg13oM5AkbKC8yUrnAPcoxdICDK
NeWFG3aN6XMT+/8IuG6QzFO6YXKdYnGRgDGNXHWl/we9Yr13
       "]], LineBox[CompressedData["
1:eJwV0HtUzHkYBvCosDVo2I1Sza9+tpQUh92zsXzfcpt0UWhjXBu60Ehja6WJ
iLbSKVPSpHYa0wVtmmHPZDe2kEjJOIR2VXSMOalvdbTTYHJpX3+85zmf/57n
dRbuWxc53szMLAjvS8oPCycs2JW9bOGWPGX6JUqa2pnAcGY3ecHnc1LRY3ca
jjHMQRLmEyROQstv5PAsmSxyeGupRyxatDRx7zveGSKb0bklBN3+IabgDa+K
9Lo8eGSHntj50m2QV0e80g5Jq9SUKFsVYsprIQd8T46/oaJEpc7qFHk9I5kV
1WtrL1ISTR6eGdivI39tzihp/52SOL27TqPqI/VbVoXbVFFi5Xzc7cUPb8jg
NkvuyvOU5Nrc81DuMJAH72xlVyopEXZuuG7e9pb0bJo60a2CEvHt48J9bqOk
w1V+ur6MksvxnPUz/T8R15o5r9OV2EcS2z8/3Az84tsEQWcpSVN8DB0ZGAev
elaHEAUlZu098HeyOTiqD9r5l1LimhCVtMHDEsq2TWoOkVPyyij7ybp+AjyP
63Q4+Bsla/R7DuWLJ8Hgtzu9FSWUBL+SznVysoLcDnVrRzEl/beER+7WWINo
5GqFO9qL+9Rx+fbJEDxmlZp0BvcRY0SXYQq02Qf7dBdRsnpQ8M4lzAYyOHfN
CPqfxl3jBJ5c6LloOXJRRkltZtM2xsiFhFGHUE90lGVij1Y7Da4XGiQXCinZ
uV9SyymeDr0D2eaL0N7Rc7WBEV+DUl4vbT5NyYNpntaJPt9ATd9QVzj6miqt
xNPcFlxTudqRAkok4zxC2rpt4XvufHUu2qormR+nmQExlTqBN1p/zrlAkTIT
dvCGMp+doqRgjp1FXZgd/CI7/2caWloc1RzB2EOAzZSoRWhBwVYtp9ceyisc
nvTnU/J+RaVJ0TAL3n7W7ChF6/R+SY0ZDrCofIWFAF22dMGs+xGOEDGcaZiG
rklP5EbPc4LKJbdXt+dRkhG2M8Dc6ATif5cskaG/61JWZdznwdqbIcUb0UXu
JTX3Axh4mJW7nUGn3sgpCqhjYIx/tk4vpSRoVlhl62xnsO2+s0GF9o1r3szN
cgb3ZZOOpqAVDsLZbUZniHzOE/LRs2+dLwze7ALnrnmL7NDSeY0ejxpcYOXi
Fv3ASfy/weJhiwcLUy+ELmxACy//x2SdZGHVXrFNAVqUtv7jmjwWmOMbw0+h
E9drOjinWFANbSrNR2caE3OlhSzkXaj2zEOrfEwfZHIW4qefWJOLNt0ce3qu
moXr/fOyM9HSR5ycpmYWrO0p7xC6uHxvzK8tLAQZuHtS0OUJ2uX8eyyciF+n
kaCv2EpH72lZiPJl/JPRXYLpMe1PWDBVDv18AO2ms1v+UseCqDVUK0bP1yQ7
VehZkGy3sf/ixemdpsheFob9XkfGowPd5Jf6+ll4/EL3KQ69P5ZxGh5mIa37
K28ROuXHo6Y/DCwoQ/Mlsej0yS8fJxhZ6OtbeHcPukhdnv3+PVrcGLEbXXbE
IvrqKAuu4WpVDLo6NNIv5SMLOQG1H6LRGpc7jss+s6D3f8z/4gaDq2lsjAVD
IKcwCv0/DX9buw==
       "]], LineBox[CompressedData["
1:eJwVz3s0FHgUwPHRjB4Mh9qkMA8/m7z13vak3y17eimrlW2P0mYSIhVRXpVs
xZyi2RrymsZjsFivVu1qSxalJqbQ60RbkVP5ZU+andVQZm9/3HPP56/7vWLJ
vu92TeJwOBtxPm/FEcnk+SGnVsgzOzRl9Yy29Yg2bBHtprOWZhxWoQ03m34S
iRJoaZDKqRitaM4QGouk1IP7OkGB3uMVFzUqzKVRATB+Dt0zHi5/J6ygbks+
HU9BT+ntdxwWNtLhBlXXFnSRWhnNhLfprPI2Bw66plbau8f9CdUxm2mudYyG
0a7ctzEDNBJejPrXMrp30GmgoeYNtXYRXj1Yw6iJ+Ljjs6/eUV/HQ8ap1Yxm
WtxxLtqhpYUR3RMFvzIq6d18ndvxH61c5GVaXsVo9I3jkn2OYzSr2eh5YyWj
9fv5/tbrPlFpVmfdiwrsSYoc8tzCgYX22xSffmE0Vflx079vjWDo8YjQA83p
eQ5XE7lgmho8GlHO6NzY0PjNzsZgLglZpShj9KXu/Pem1ybD6A5Pw0Apo+sH
Iw6fjZ4KZi3fBtmjfV/KXAQCE1CrPCWRKkaHWiUpt6pNYdzV7dXNEkbdLR/a
ef9oBrLeCa4N2oTqgvu05nBgKi8hpZjRNcOBo/YBFrA69qH7syJGH7eEGAW6
WkKXHbm3Gn0pvW27SGcJfyi8b10rZDTUOO65RjMdqHraaXf0zpikS/y8GfCg
/lxetZJRjzAXzYbgL8B3hJ+8EH13uqtp3LKZ8DRxXc5vFxj9syY135VrBVbH
XgcBOsnI2a/jqRXEZ8tb2xXY15e4dm/DLJAdSDgagB4sE8uVydbwpOVM9D8F
jMrnzeY1BswG7XvbraloWV5oe7BoDmz+fXGzCB0oD9LwX82B5N09vLZ8Rj98
U6pXNtnAoosHMiXogcFV8S1ptnDjETlogi72mm/TGWwHyogrrDqP0eoTcZZh
bgLYHr7OJRCdFrDTh6sTgO+L9BgT9OK+ooq0TiHo0l6nX85lNMcpv7rTRwTX
4i1ORqCPNmfk+DSKYH+F15k56I02AaVqBzG0anolmhxGV+5t32opFUOnrN1f
ilbaShw6dGI4uk0uBbRDa3m271Z7eNkuPTRxHv9za3HubrIH28fPQq6jQ7W8
rtvOBNR+HepktKT+vUh6hoC1utIH0HtS/T+u/5nAVKXFSoqO8294xD9HIJyb
tWQFOl0XlynLJmAeqhcvR9cs04+fVxDw5nmOLUXr/zI8LKsikLTAr87j8/1u
fkZbO4FJnGULhei8kqjwk7cJ3NKGugrQJbEa77V3CFx+cPFLO/RlK9nYHQ2B
+X4qaxt0X+CM8J4HBOrlwwYrtOPAbO/+AQL9U2beN0d7NiQKVIMErE4L75qh
vz7Rq9/1ikBk7Ro1H73BUVH3ZohA9/V3zSbomEiRYGSEwNkjpbWT0cnLj+kv
agmUxhRUGaNPmPXfj9Vhz9915Tx0Tm3JqQ8fCASaLiichC5O4YVdGSPg0XKh
wAhdtWnXquSPBE49nZfLQTfY37RbMUFA/sO9LEM2o03auXqDgUCUe9bZCfT/
bJdasg==
       "]], LineBox[CompressedData["
1:eJwV0ntUzHkYBvDpqpPQZMWoqZl+0eoqyxG7+b5Yt0orU5uNpftIN2xjWxUa
JSPDdEEiqVSSKZziRCUVXYUus5dKl2my9eOY1GxNsu27fzznOZ9z3n/ecx6u
f+TuIE0Gg8HD/N9ZJ/x1HQOTN1Se2fWavk+T+g6OmzcnhHTG5SaPomdfVJ/m
cH4jvWnJW0bQWTVicx2OiDBtV5QPo8OcBeGT5lfJomWVpwfQHZ8PpivNi8jw
SnGfDD2ne9Dqg3kF+VKnvFaDzmnOPkKbN5GncyZ/kaAnMsqt+843kfgxVvUF
9FZ+i7xd3UQew7SuGP1ea9LrcUczcWWr00VoJ2f39aKkVvJAxsoVol+Xzmha
fXxFQgWrhFHok822Lo4HOog4tznAG11SKuoOs/+LvJ1wmmKh+eTN1fdH5cRv
oPNR1j2aRChWyMtKRghvVPPcUrQ+N8Gqz0lJ1ElaVQmlNLlg2GKd4ztOGgN9
l0yU0MS/2/OpVus/pKLIQMcTfeR5gn+k1TQxPrbHoFxKk/uHDXhLdnwhT7fe
WMdB58SEjq70ZoBkeMDh5F2aCLNnPCbea4Cp959dI8U0YXT0Q+VxLVAsuNi1
B708Kjja01oHQlgVwqo7NBlSXflxbpUu3JQ+qrNHuygOxaUe0YNte5qKLxfR
xH1IYmNmpg9Tb1vXaqNH6/xPNUrngsehO+4nbtPEniljbz4wD5K1h5jKQvyP
qPx6xufDJ2qZXQR62wefSQsvQ9BtHUkbKqDJH7WBGj62TOjJLLzriy4/W7+f
o2KCZnFj1N/5NAnWEfS3tRnBeRtDuxB0wNGYcoPMheD3wMhOdYsmDnybNje/
r4Abp290Bv3KyHauYN0iUF+5FGKIflIivGarZQy3VfM35efRJEbDeldrrzH0
VfKU36D1e45vjyhbDLIWveiGXJooCrjp2bFLoHVC+CgQnf41S7vCiwXxN41W
zeTQRJIZ3ODHWQqylD71dbRP+s9tBu+Wgs7s8hcb0VPf56uzq02gxv6Z5cBN
msgVm6Jrk0xB6u7IFqFznR1NXvqxYVy0QGmDliYKmHw7M6AUl2Zk2TRJ8gpw
1VKZwWAdOzURvaYnpyjppTkcNolxcUBnrLgmfenKgd6giaz+G7i/GnGGawUH
XCDIQ4zeaeKV32zJBV2GicAZvTGiYS9TxIWKyObsiSyaZJv6W7aquLDFdHFI
IdqyrvCy+14LCBg49sEXLbGrtW6vtoD5u2d3sNHB49pvmqwpSA4Xx3Vdxz3e
/8QRXaQgdbWNMg0dJuTNuKRQIP2Y0paKFvDKfjdIo4BbuFCagj6rElyQXKbA
4Qv/0EV0yTr15ytZFFwf4g2fQ6ufzcoKiilIylgjj0dL2g3E9Q0UOIXrjUWi
M/PCD55poiCT0dgegc6Latu8vYUCPYvcsnD0Q2PJdEsbBaEaBdGh6B6fhQc7
uihobKc1+GgrOWvzoJyCJ8/DWPvRK8uOm91SUBCS0zGzD70+sVsd9I6C2k7P
/r1oN6useyOjFNCrCwp/Qh8N5ZiNjVFwIjZhrRc69rt49YNxCvofVpl4ohPn
DXZGqfDejsngoTNK85KnpiiIq9dt2oXOPaXNfzxNgWvvbekP6GKPoE2xM+hl
Qanu6DKLF+wN/1JAXf32153o6vHl6tlZCgRrbPe5of8DrGeadg==
       "]], LineBox[CompressedData["
1:eJwV1Hk01VsUB3AhDUqhhJepGwpP8yuV9imJpN5TxJOhbsqYEEJEUZKUJFMZ
Q8iQMTwJKTJHpoyZ+RHXNY9v3z/OOuuz1l5rrzPsrwT95vlr7GxsbB24WHvo
XTrXHiPvY4Vpm5IytSgorhNX1xY3heKEWKmcfylY/prvLi7uCNWtdLqDPgU8
flnv1zbdBzUDwajZyxSEFviIrRT3gmitdzdPGFEgN2r0dNn4GXQzd2RpG1PQ
xhO2tNDoB9ekfjcomlFgoWh3Y1osGDaHivV636Qg/Udn9ITSa1hdKuw4Z03B
nLl6K8M4HNTlI9RVbCk4WflccqoxCm4ZDSQ+cKBgIEilcMI0GvZI5EXecaLg
idGiHnM+BmrHAtJ1nCmomzfxHxOLh7c5ryeqXCmwLxHdPZqaAAcSNXaa36NA
+MWP8hGlRBh52eUzcZ8CugzhoIxToLTmeXTdAwrY552qJ5zfw5XSJgdZTwp+
dGqJTCingm//4hfbRxQ4JHLnjDemQUig1r6OxxSo+fVxjUekw5HB6fYVTyjY
6lCoyTDNAJdsVREhHwoKlG6Pjc5ngreAZZ30MwpWtXRJj4jlQJ1MwL/1fhQ0
FXy0Gx7IgbvZV2QTX1CQEBv0mUrNBbmVVS/v+FNwzuac4ZBSHrQ6179ZGUCB
uM7OpMF1H6HUpmasAD2uyDk/UP8RHH+tkrEPpCBgTW5Av/EnCH4651IdREHG
bTWbW4IFwKbxZqttMAWvhw4KMZ0LwDh+IYU/hALLGj7jceVCmPJI9z/5igK+
16XsjMYi6K1PrrQJpWCeJyve6uhn4DzmFDWB7rn35p+xiM9Qx+PcbRNGQZbx
3bBR02IY7f6ocC2cAt19+w//nv8C5Ze1irZHUqAUK/HrxuWvUOtz1c8HLSe0
4dFI8VfgNNf5zEQvLQ3WD/uUwBb66NvsKAoiy8KtKbFvsPeYS4dUNAUTQZky
HU++gXXgrbMe6FPG5d21s99gdQHNvAM9zDGtlVtXBruW89c8i6HgkOK5w16e
FbDTr4eqj6XAm9uI6TxRAe6Gp6e3vaWgvdkx0epKJWy5+V7JEu1hHyOqc6QK
unQrm5fRNSkL7NKj1VDz8IP1xni8D1hjsF6+BsSC7dg00Eek/A97GtVAkoHg
X77opxPxTKfvNfDGKubT2gQK9j+vv0Z/9x2ydVt0GGjXMjm1PYZ1oPZca8Q7
kYK41A9S717WgcQLbp7/0LVBJzgkK+rgzTplrUH0dmOdPEGFH5DXxWGplERB
GYeHPBt/PURLGuj/Rk8M8XA7na4H03O6qluSKRCpDe5nutZDalr8fUBbRaRE
9A/Xw4ORwCkftIBiC1/11wYw+3LzLC2FArL9+qjqYgPcaqyVVEGbcjPKi/Y1
wsXTPyzM0HnNXA+yIhphUFtMMwVNt987HerUBAvVJzr3vqcgOcWrxUL+J7w+
yGVCS6VgiG/oidqVnzC3+mmaIlraXu3YDv+fkNB0PFobHXGUO7J79ifMGKz1
eIz2+/bkuu6XFlC0/kIfRtt3P2Oo6LWBYU/IYGQaBWmnxqIkn7XBuPxHww/o
0fh/NDmK2uBkGb9/BdrEivdDvnQ7TJctHplC6y76OR9gtkOr27u3p9IpCOcu
d+dV7oToY87fW9HHFO/ouRl0AuF6Ffcb3Wope2D0dic4iaScZcugQLDWu68i
oRM4vo5x0tDPg9RPP9r4Czof3lG8jnaXrOJZbvkFkcrZ9j1oY/gePGzTDf07
crWLMylgi5rKbfFG6xlO16CDOLe2lkV3Q4WbvmMbuvTbddH4hm4wSlmWnELv
0FyIuna4B9qa0+WksjDPTKQT21f0gqw33/F7aLdy9cpK4V4QU+nZ+wQtKG/z
O29fLxQn5qwLRKsy83a/utYLfEKxjonoeJfzmdrfeuHnwTzSgDbzc8mv8e0D
8x3RhZIfMM8mozo+xfcBn8ZzrV3oEO1StpSiPvhrc139IXTZVn4ln4k+cDNT
en0GLfs2ruS0Tj8QdTkVK/Twf3U1RWIDMDdNncxCW/bu7M5IHoR/NrQc+Cub
gk6D5tWF3wYhO7dP9xj6QtMj+cqeQYjQa7p5Cn2ovN+xV3gIvDfJmF1Ec6TG
bBTwHIItVZ4xduggZ4ljtw0p2K3Grp+KLuQXClbYOAKCRvbtojk4Tz6l+cqy
I7AhLeNvSXQsl0OPxqkRcLkXlCmLfjLbsMvMeQRe6ZUYHkJf7PD/GjIwAuEV
Q7s10EMJGyfmC36DzJPz7W7otRIe0h2HxsCVffOmZnTp0ee77iqPQZppJbMN
/VAn7KDI+TGQOaNW0YVm981WuWQ+BlWnvhsPo+eWho0bQ8eg+3Gp2jKaatWK
q2ZngHCSZSUtl4KKIOmdBRUMSJhtkTRBP87Yv8ewmQEHYgYVLNCqNccVlnoZ
sPu4haoVuniV3umjywzYILKo6YDOs/c1zd4zDr6Rbn8+Qidpzsa/DxiHYKZa
byz66cZymcjLTICSKxmd6JyDIpnnLJkw7pNv24PuMbgJC3eYcFOQY/cA+kgS
v6Z2IBMux1oEjqIHTuu5rK9iwpaBFpkltJL7SLXjkQko74q1EP6PgpnJDXbn
BSbBi7su5G80TYS+vEybBHUZxbLz6HMnM7yS9kxCcW/8pBY6xk8nbPXZSeia
iiN66PO7Ikvy3SfBsH1NnAk6yWSvsCxjEsL6XIvc0PQWzU8cFVNA75HRTEav
ffXrhnXzFJj2aXCmotN0Lbd29E3BhXDj1HQ0x09Px9wV0zDLZ8ueg45uyt1n
fXAaeu5GuH1G99WLx7VHTQM5EcZoRJvVDPvmOM6Al0HO1yW09RcP+k3pOTCO
/JumnEeBaM8prql9c3DJx4dHBV3OvibBmcwBRV8xo4qWJD4Mr3/nQKDA/4s6
ujn3pVu09xxMTSWf0UQffx8b1jw6B8zLpSuvonlflf5Uyp6HQCOz467oVKt1
FwRPL4K4frNqOroihN8x6eIipKuWMTPQfcXC4SeMFiHY4VBoFlpYaCdl4boI
xTX+VA7ao1DZvTBzERa/PLAvQF/kc00327YEzw6xqVSi59IZ/B/nl6BUit7R
i468Yz60W5uNiBw8qs7/EeeoYM2Mpz4bMQhN89mELuCMW9lxlY3MvdtftRnd
6dMj7mPFRsa3XFYXRItG6GsPerGRx9I2iiLokOK/iyPz2EjM9xtMKbTf+v1h
fNtWkJofpZkK6PvhCxoTwytI0x9vS/TQbHWdJM+Jg6xZCrocjJayve6gKbOS
rOov3PMd3TMZeJH7Ixc5e6u7bxGt1mvm4me9mhDz8FHpfPxPPb6yoqJriUlO
w9AZ9NBnultpEjdpC20NMEXL8zaIKBmuJ+KLnUcfotfC5JVWJg9R2HtZLgyt
MqI7vU1rI9FPHnPPRDcVGa3QleMl1l4Xd5WhMx8VG4hP8pKJoH15LejrK+06
q6r4SHPQgOgI+qrNncx1IfyEc4aHbQG9y1i2Sv3KJjL8UshhzScKqvnkuO0U
NhOlPRYzAuj/ku+/kuMQICk8q6K3oe+skPmnok2AuE+U0eXRa1udVC0ztpA/
D64UUkD3xkr4hzsLEgFRXcsTaP8dQpw5WkLkzP7n/WfQviHXS66ICxPHWZ69
mmhdf/2qdf3CRKZ2/c9L6JmTMbPh+X+Q32d1k66iu3tPOBR5biXs3ad8zdBR
inv+qLwiQrKPXAi1Ric9sOM1/lOU3CYHGm+jPbWunuGYFCVW699GuaAPtEbG
e1aKkW5GdbA7Omjnq6TKM+IkfKaz+xHatcAn6EyOOHm246L2U/TZP7RiyrZL
kNzU1hsv0MctSy7xekkQDq+WiUB0+Fb69opJCZK+EBb9Gr3989uAc5e2EV7b
4toI1vn+LJKpzd9GPKx4C6LR15mc37/J0AineNmPODQ9dVzc6xmNaPjS7iSi
Le5fWFB7TiOT94S9Wba7kNG47gWNcAfxvGL50aTdU98AGvHd/zuX5WSF2fnA
UBqxOuk9x/Js4XJD7DsaoUwVHZNY/WvX+RSX0Ej0Rk/bZHTImxsmD7/RiOKq
7R4sv7GtUlItpxG1w/kvWM4S8J0rr6KRBJ2hNJZbdflN6upphMdbgsGydLeQ
Ulc3jZw1XXcjBb07w0k0updGAu66OLN8+EHL7LV+GhltobxZVpcOfT84RCOZ
1gUJLNuYi4syGFgvcnqAZeej92bTmDRyyzN6muUH67t+2E7SiCAscr1nvU/K
G++ZGRrxC4mVZDnKjdM4d45GamB6P8vvNK6dcF6gkaQDyidZztj2VeTYEo20
OPteYDmfKTWLAU7WCzTTWf4fwr1Yow==
       "]], LineBox[CompressedData["
1:eJwV0Hs0lHkYB/CxRKG2IRXKvLy2QVJxOl35PbosjUuIbZfSGpdx60JI0qpU
kksqxi1JwspB7FAU5W4M49bKupxkUps3lp3EyGZ/7x/Pec7nn+9z0eWecvL+
jsFg/IKL7lm/cRW3esVZqCc2mzj1UKixl7A9QvihCC8zfw72YnNtNEGcQ+pf
zPL3Yme9TGAtIWKR+ySPMMMONA89MctKR1OpAmIVdu9X3+QpViGazLPm9XVT
SGlwlD3BqkKLj4vuHcXOacsOolhC1HVo9nlwF4U+p1UYvYkXotGYK6sCsH/k
iSQ9MiEyaOw87Yn9SX7Wpbq3De1uK9/ujL3D3H5XbEw72l/DWtyG3VW68B37
n04UFRl7dr6TQlFtxpytx3uR0lrhuhjsktLYwUCTAaThl7G7VEyhcbXxeI7H
ACo8WLOzEJsdxrEwSB5AN6qV9uRi39+jkiORDSDOW2W7VOzbwngf16ZBNPkk
4X4Udpjk5rTV0WFkxY9TccTOVhFFMw+MIDWHCyNfOijEQ93pn4IlKOXvQKkd
9skxQ4mg5CN6epCwMWqnkLLuFfabHVPI8Y1pGktEocSVIqOcX6XIeqWDoW0b
hbiDzi/k27+gO9FOT2OEFApqusI9xZ5H/YFK/LetFCo7rXp47cH/0KMVF9a4
YuecDxjfcoQBDaa6Zf0tFLqcveD4+ZMcBDu35p3AZvSOwPMIeYhV28z/HntD
iE+4s9ESOGNn8/6PZgq9m0n9SaVGEdK+1ZT7YHPG/C/cDloKBteC+rWw7d8l
bdTRUQaR6SOL1034fw3ci63FKgAJWnFZ2CbMvvX7ji8H6+OEuhe2MprxGJKu
AHcrxRJTbKsJ11k9l5Xws6UVyGH313vJuRozIeihie+rRgpVXG90J2aYkPJe
JboY22dJ6IhYrAaGftLt17A9g89XqGaoQ7U9mvPE3szbKLb1WAUKcCZsP3an
mrFK6E4N0Dhg7KmP/azkcqax/GpwcL1huRT7vJyRQ/vwavAuDUukGvB+QxHW
JwVroG6H07Ju7LF83eTsyLXQiPoLqrCTDTQVqlw0wVFY+nsOdlKGT4sHoQX6
94JOxWO7Jh8Tq37Qgg3hTvnh2HP782TZtdrwIs3E3AtbMrY3vD5mHSR/sNRx
wn5gvlW7w2M9zNmc80XYxVdDmbxNOqAtnH9pgh3j4mkjP6MD4WXvSBb2tqGc
wpgOFuT3XZSuwE4zzCzusCEgIuRmFAM76mVCmk0VAaq2vEvT9RSy03bJa9PX
BXkqN0CCbXmyxY0Zqwv3FM26+rCz13H122d0YerZ9sdCbP2GAr69mx4oDrSO
12Anbao36qnVg1HvJx3l2D5ShW6hEQmV191NC7C5Zf8SsTdJqGP80HgXO/Dy
4QXOLRIeGvrzaYceFrxWvUNCTnqlL+3rM6GJSXwSFqy8l9Mu2Sn7mppFgqhY
80gmtqxusS+/iARKe5hKp+f3qCY0tpDATarXSsXOyD3he01Iwl3OxAQfOzdE
vM9aRMJZDVYd7crVSfMiMQl+fak82kOu6r69f5JQ2DcsSMFmSzT3jUpIKDlW
7ZCMvUUQofNwjIRlbi76tHddHZR5fyAhxX529g62LTvr8cdxEgRMh2zawQGE
zvQ0zh9wnryNHbnnkqxcSkKmG7ue9tXlo69CZkiYa2LwaaeV5sbNzZFQcajV
nPaDiwq86nkS/gqoZNIucvTeG7lAQql/0dgtbIFe83qLb/R9BVW0a6UbZIuL
JMgpP0qg/T8me86b
       "]], LineBox[CompressedData["
1:eJwV03s41XccB3CSy+M2R4Xjci5+7srtyVTP9P0Me4hqM5eKp9o57veYs6ek
Vi5hRkcp0mNnB9XMYhr1qKZcIrdjKLXRKsdR/Ng0TjkS+5w/Ps/7ef3zft7/
fLj8lC+j1qmoqOzBU2blSb6Ga2ThzriNoTfGRmjSOcLZvY8TR6YqHG8/Ra91
tWZzOMcIvzn53mN05f0itjqngMT+HNM+iE70FCS9Y18ikufedR3okfexpfPs
WhKa5smoQ2uOTdjOsVvIsDMkHUWLe0WpNLuHxPVP6X+Erm8oGEt0+ovYVyqc
qWGaxJChS7NpUqJh+PLeriGaJMvspU310+S3A1tXT/xBE21uju3zbfMkUuoh
rB+kSbFBn4P4qwVyZK6ncFlCE/5Y8D21/rek3T179TN06oMcfortMiktcRdX
DdCk8YhukMmuD6QopOX2JrT4eMKMyz4VWC2zic3vp0mWaCVwcVYVHj7r8dNH
q4y8gLsZapA6/Q39Qx9NbNKjjwY7qIO16M4FJ/SkvCxU53cNSEwRrBvopYm/
LP7EuVQt4IS1R8Wj904KHVksbVAb4toboGc6+KceXteB1yeWQtt6aOLEGLXw
PqwHXbssbVPR2kTOG1/Qh5InweMOaN+5sHeWIQbA22i0Q/qQJk/bI1XDNjOg
2HTWRIxuzu88xJEzoLVg6Wk0Olpd8EIiMYQIXz9rR3RE2vFm3YoN8Ei/JOpt
N02cYxwlu3kbgRmo7/sAPWi4WUewfRM0FEbUn0Pfqc+6vFnNCLK5ToNR6OOq
Dl/0PzOCVTvm9x5o7fEMv+QmY5jXXgzXRcuucktFmSbw3sv0H1kXTUrtmOtb
QpiQwzO0akULK6K7eRxTuOV24FoFOqz0oET3lSks+mQHHkMv+VxRiFrNYCzD
7ZdQtFTmdbQ9zxz+rvu60QNd5elqNsCzAI+UHzON0ddzBYyYLSwwYvLEyw9o
khcSEaAmZ4Gsihn/HO0+Lq7NG2CD+ehOzQ50uf3l6wMBHJgdqvmuFv3t/aLy
gBYOFFrbyYvRe8xCrvRaccH1iMGfAvSnyd3hjAIueBl2ex1Gi8z5Vv1yLnha
U1W+aKuOaxf3hluCf7Tdfje0cEu7w3CrJXz8osmOhY5eWD/U40CB8za1D1po
fuN/nIKzFKT/e2ZC3on/khW04l9CwdkLl4uVFgQ1PdE9T8Gk3d0dSufLBcXC
ixRY6HHPL6Lrtyvel1VSsDX3mM8CWtG2Nnq1joIQ1YjaebRwWLeos5uChBaN
TBpdUZ0Ue6aHgoNOpfZKV6dLvP36KFiBLU9m0DeNhMt9EgpOu2e5KT0etiF2
5DEFGca3pl+jbaVM7wkpBeMi/7AptEtTBqtGRoFHv1BL6R25Y4qoVxTkpEzc
lKF321b+Oj2Dexg/bVA6LYHDevOGguGTdwek6MxPTituLFBQwz6UqXSu3sSj
dDkF/lY6jkqXN1QXLi1h3+d5+RPoqlPrY24vU7A/NdRD6brAKK/MFQpOzrlM
vUQ3WXZZ7FyloLzN6ILSrQs2irU1CnxpTR+l/weMLmvA
       "]], LineBox[CompressedData["
1:eJwVz2lQk2cUBWA2kUpcwBbCEvKFN2NkEcGloxR5r9hWquiIgGgsIJFVEQpj
VJaqRRDQYilSRSiDSMFSTawaFdQiBQpiIAixWCVMHWKq+OFCYwrBhd78uHPm
+XXOFUjSNsZbmJmZrcMzZdV+ibVf3NHAI94W/Oh7LG1XMyGRTDI97bp3bhR6
qqP5EMNkUvvKRusv0VUtxfxpTBH9cUPDyBZ0ygrprnH+Kbpkc2ZNBFr9Jqns
Fb+BjnkVPgxBTx8cFj3nN1GxOP2AP7rmTnU6y++i/xTmvLZHyy8UDab4PKSZ
eZHBl9UsTaR9p0YztLT9ckdvKDpV56FVyEdozJElU8/7WTpDkCf6e9krmiM5
X3oAfWyO0rNmm576H8r9mIuWDIbfsuz+jwqgc1FDH0vT/8iTpIkm6cvgQUEg
+uJXnDDuF++o83jlYc1d3JO985lvpBkEzYwskqJzq9+Gvh41hyBxQDAXbaZ+
BDezLKH66l35rV6WztudsC/ccxpkzE9ulaAfG05usv3NGvYIFbNno9fodnxd
mm4Drl3xpddULF3/uMTLzW0GSAYUw3HoZ22Sg7dltiC39yl2RvvYDfBWxcwE
f2e5prsH/6OGWI1+FhQ4BpsXoFc/F4+7R8yBJP+tjoHov1rjzMXedlAus1li
7GbplcL2aMZgB7/knQ+8gU6YJn2kUtmD0vN6ZhZ6e0b2FU7FXFC/eu8B6IWJ
XqqQ2A/B9oLfSxt0r723rXT5R5B61suxV8nSG/LcSm9LBxi9tWyiAp1t7rmh
e8gBQse1yXHoGZqs4FSFI9TuTW/0RevqBWXVOVxoyWvgWqDL5jtZNUU4wSI/
nl/fHZaWVCR0xjLOIDptM70OLS6LUnGeOEP7vN452eiJT+uM1c0u8EGU3rAe
rdUF7WstcIXVVdccRegzK/xcemJ5oDs+sPRdF0tl+VK7xAVu0K+4ue4+uiBi
+1pLgxtw9zDLLqOXamoaCnr4YKHZEVCMLveolPWsZcC9WKfegT7QUly+tomB
jLaB05+j17lE1N0RCqDCRyYUolemdm61KxLAIe9Lj6zQ1a4SYbdBAA9kL1jt
bZYK286eWL/VHYSyn8070CULWj37m91hNOrbjAZ0gt6qr8uTwBml/ZqjaMnF
f5mi7wg0OnN0aeiU3LC3a74nwHsYmmKyNExxn3OcwMqddfpUdKFBeqzkBIE8
o9TCZPly45uTVQSO599kUtDG36cG6s8R4IqHYpJM/f2c4vZOAg5m0U+3oStq
dyUd7iLgU7Ql3eTa3apVwUoCvpWSyRj0VYeSSaWKgHFDFcdkjXhukvpPAk/b
FX5RaJHWadWwlsDYg+T9W9C+iiy3n3QE4nQBNib75w8a458QsNvEK92MDhFV
/TryjMAn0db1keiMnYzb2BiBF8p9qgh0TsA3xkt6Ap+1Xd1scv7M4Xu7DQQ8
Zllow9HlF2qPTkwQ6P+hZTwMfeagVeL1SQKLVYtzTT4XGh+U85ZAeKiCY7LC
vYMX+J6ALS/o5EZ0s36ecWqKAFk4JDD5f2owX/o=
       "]], LineBox[CompressedData["
1:eJwV0n881HccB3C6VHMKtZVL3I+vdbokPTZ7lOjzHhUjPapz1fRo+ZEfJb/K
NfnRmjGp4cR0xAzhYUbZgxWVdOzOHc7POGP9cNTq9BhxcbLZ+/54P96P53+v
1+PxYgdEHgpaYmBgwMfT/8KLAcu2nby6y5ZW5pLYryGtfax9R1inyL2ZHVUJ
6EVp03cs1gVyn2VnoXdhczrTiJVGnNS8yTj0GRdh+Cwzj5jSy8Sx6L73oTmT
zEoynczuOIdePjzKfcNsIH5R0ken0MWKomgNU04K7q439kHPiOt5T3+QE6fP
Snbz0XtD2tW9Ojl5ZSu+eAg9QZsVNPYpyFNu7+QB9HaX/U5pqR0kKTFL6Y3u
vrWwhPtPFwlq6410R3+jsPPcdqKP5Du/8HZC19xKGz5j/yepHAvOt0aHkJ68
ibNq4uNdlfmiT0Mixjep62pekcHw54FVaGN2Mvfp9kkSed29OwSdYdbOK/ab
JnsHuzI2ogOGfR7SOt6Rglh3wZNeDYn+IzkgkjtPjqnj83LRtVEmfIsv/iUq
H/8oPro4Puy1wxEDWOfsJzFGJxUtHJyZMITUWu1RWY+GGPQ9g/txNLDZ+3As
Bb0xJjjWh2cEIgZdStBj2uuH6Q+WgcIrjL/YrSGe46cTr0WvgD2xQ+WN6P1j
os3W1saQ2HU3ORb9uiXgUls1HbLdHOjOaHvzASu3EyvB4Uph5/su7Ee0/iPT
q2C5hyHnEdr9je8sR2AGD2Z480loleSkoa+dObxl/hrojq6/3PoVS2sODgXx
a8zRwUbCZ0rlasiMCssaVGpI4Nn4epP8NVD2qSW3FL01ZLNyn/+HYDFh+jYK
3bXaji7c8RE4pptJd6Lv1STdsKOtBXtV0FE6Ot6Qd6Djr7Uw8MmPLFUn5huJ
84ioWwc9j5cxKtDj5eycogQLmMsmwjh0ji1jaYOAAXcOMxy90KL8YJk/az0M
RUhsWWjfnONKk5frYeqcYuJdh4bM7S7TFTVZQr/h6M52tHrcNVaSugHEtJnw
UnSJyzbLTn8riL5U6XUBXZ0iNA/ZYg0LtCXPD6FTBYFeNK01nL5GmdqjHUeK
K1M7mdAWc/OD5WjxphvVnV4sqDX1jlG34/6a08VeDSwgmVrpA7S3paBMYcOG
rJgDFXnozyNkx8zT2LDzCa0+Fl20IcCmQ8uG8xy6TIC2aanI3X+MA9XZ9mOO
aNEWCa+3iQOZe0I916GDp5f2yHkUXFR9rXynwD3WvmWlZVJger7m4yH0mST+
gmcWBUJueYkKLeTXDZpkU3BnxS9MvS9rhRmiXAqu+gwwBtE1O3TvrxdS8NN4
86rHaN2jxYHyKgrqMkfmu9GiXpP0VhkFzmxqpA2dXxoe+r2cguPyQl+9S2OU
bh7tFFRE2gzJ0L+vFc23KynIuC0YkKJHfNeE9j2m4GeVe08rmqtmuI2qKQg9
fUrejHaoi7O+OU7BlHOph95OKcO6oJcUcLR/yx6i93ELb796TcGXZmJpE/ps
GMt6aoqCK7Lk1vvoBOdvdb9NU1BUYLVb75SVo/0xWgq2ekla7qHFt0qvzs1h
PvutLY3okktLQxrnKUjzm3XVu+pgkGvCAgX9Qe2SBnQdR2q16z8KjFyqXPVu
mt6oW1ykQDyWK7mL/h8SO6Zo
       "]], LineBox[CompressedData["
1:eJwV1Hk0lV0bBnBSXqWRJsp4zI1Kb1Rcu4QGaSBTpEQqDSgiNCpz1CskUkgR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       "]], LineBox[CompressedData["
1:eJwV03s81HkXB3AMJew+dFHEGH7WLSxSoXK+i5ZGa7XY3YeWhxoUavWk2hpq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       "]], LineBox[CompressedData["
1:eJwV0Hs4lHkUB3Ct2y5TGURuM+941TC5jF1dbOkc0bM26UnIpstmJJVb2qZt
Uay7lFVZlZrVdLGr1qhtFNsmoTRy2Wjbnkwpl+03YyiriRHZd/84z3k+f33P
+fJEieuiP9LT0wti5v8tOSgy8txWsPxRDv+RhY8Gmrqo1eHUTmhKORNgu0wD
0/fqMinqOxjjGb/jLtWApP4I15DKB8tqDxMXbw3E+Yjjx7inwHhTRvKnCzXQ
9X5H8RtuBVS5v4qf56YB4+5e/hC3FjzMV7pL7TUgbSlLGuQqoK5EHZ8+MQiy
qvzuOPenYPNkw3GsGoQYeHhKs6cPDgR6T2PsICQMuPTJZSqo+qQg86rrIJjw
svg9S97ApemNEdSwGgrNHgikW0chSFZSU1OjBlF36G391ndweNBMO56phqS7
WaJE/gSMqT+cHQ5Vw9XdrJC5X07Bet+0lh5XNUhTYtXCcD3sMFu8SWCohoyy
yeC3mhn4TNgY6N2nAr2uF/hHsj4q+HfSjjapYP7e7ftDBYa4qFN2fOiiCvq1
J9ab3jJC+a4S0aECFawa2HXgWNLHaO3//uycJBWs6S9awOGY4C3focDZG1Sg
bhSl3680RS+jmsLF/ipwZz928Pt6Jir8BSPzPFRgAtpI5egsPMy+HdRir4Iv
hiLGHMPM8GaH5SyhiQqeNGybEeHKxhsh91vtdASq85q2UFo2pg53Z9FqAtsN
xS/a282xKa/R+PlTAlF7UqpZpRb4NuuGe2IbAY+YBe2rIy0x6sqSh7p6Ah3m
rqZi7zm45ZhDrKecwE1ZxmlXfSucqu/k/fMLgZQZgrWtz6zwmWeXOlBCwESZ
HJAgt0ab15ON6ccIDJTzistS56LUOnRoKI9AsbONQW2YDU41lFux0ggUlW5v
jqRsMVgvLmrFPgIRxZvbWa9scVdYTqNRAoFx/4u6sjo7VNglsA9GE+gbWLG/
IdceZcKneS83Ezjn42nXFumA18tetkyGEajMFrNj3Djo4FOdObyGQG5YVKC+
loOS3BHJqgACC5XSitw2LlaIvkqM9CVw0uV0ZVsghcJKLz/hUgJp9UdOBtZS
qLiTIajzIhBkF3axxYmH9RZYecmdgG9C80Z2Pg/ZW7YaL3IhUGYvcmrV8tDh
hNWFTJqAU+PPJWs2OuJrlxfKKA7zn1uDoLPOEV0/o9iHbJj+Rw0eKgQ05iwW
1IgtCYiu/kvl/0Cj1KuF3zubQFxGyOSqozR6lJuz2xmLQ+R/s47TqDQIn6pl
nKcVFxaV0Bjb/+fzo4xl3rr3JyQ0Jl7bd9eXse7O9OPyyzReix2jzs1i8jtZ
R5qaaUTn5azomQRKz8fvyFHQ2NF/OySY8fm97X4BD2g0bHT+yYfxdauiiQft
zD3hlUutGCsjLHZ0/UXjt+a7TzWzCPD7bPx6+2jMfhPUI2AslCdzLgzQ2Fuh
DbVm/Hl2ty76FY3OMclt+oxX8yVXVGoaN8TNbVaaEtgTS3FGRmhc6/SjspBx
6rLvdb+NMn0ctNiZwjh7Zu+jvVoaV/bsHI9hfLLqfMH4OI2O3me4vozPpRvE
/D5BI1u774Yb48vB0StSJ2kU+vDX2TKWO95zWP6Bxohvfn1txLhudL5ueprG
Up1h0agJgf8A6DRBuA==
       "]], LineBox[CompressedData["
1:eJwVz3s0lAkYBnAiMthtspRLY8Y3sSnUtl20eN811SaxW8g5KjEaoxuR6eJa
SpotNcXmUnMciUpR7Y7tpJoVonGZtobaIl0mme+baZemicm09ts/nvOc33/P
w+GnrBVMMjMzC6Pzf0tz+FbzNx8NUvkPF3om6aBVxV4dzd4C1l276ruFOpho
kx9ks/fB2lcTW9NpS5sK3SezxbBIOt7YlKiD7YGiHaPuZXBDoVRECnSgGk8q
Hna/BLLFtku38XVg3ffa6537TagznddGbdBBZUdFqtZdAQsC1z/l/aiD+qvi
vu2+zyA258GcXj8dCOFhmS5NDfkr/Hodp+ogeXC2WlZPwuEAtaHvHy0wOIe8
XiwZhpbMEJO4SwvHp3Z6V8bp4UTaffOOy1rg90X+YdH1ERZa3JaOHNFC6r1D
/BSvTzC7Os7/olAL13faRcwI+Qxj2qLrxSFaqMzcRs2LNkPH2gUUy1sLeRWm
NR905ljgkTL6wl4LZqqXeDvDAqcciM4FPQWe6Yl7I70no0D9XaP4CQVvDCXr
bO9YodWs4EWtcgpWDW7NPpU6BT/KO/K+rKYg/I1kDovFwFmBKW3DxyigWvj7
79fZYmq5w87EPRT4Mh/P5G2yx/beDSPW8RQwwBDfr/8Cx7MGChlhFPzwLmbU
I2oqBtm8ZYQtoeCv5s3mMXOZKBYt4D3iUtBwpDWWbWCikTKmCRwoSJwseqlU
TkO3hQGyFeYUJKRlNtiVO+B9++I62xES/IRzlKvjv0K3CGOV/BUJD6bNtRX5
O+LzXVew8yEJt+rzzsy1cMJTlqq0rBYSMs29f+p67oSl/3KDimQkMPozVibL
pmNOgtwqr4aEwRpOcUXWDLz4wVc/UEZC8dfOljejnHGgZLmq9hgJkvLE9ni2
C76NXfdUsZ+EmOKNSrshFxxaJjn7s4iEsWXVxgq5K7o0vXvWvIUE9WDw3uYC
N4xSBTA8N5FwLnC+a3f8TPTlf9xoE0lCXb6IKfRh4Z9C9edJq0goiEoItTCw
MLrhNuQiCQv7Ky8VdLvjsj3X9HmLSCidfaauO5SNhw60jWb7kJDbVFgaepON
jFusGmsuCWGuUdUdXA4mbL1zkuFKwvfJ7euZYg5mHq5VkNNIqHDjc7sMHOxp
+OAayyCB23LhdPh6DzSVNPMqJ9H/fJq9H8k9cHfRwbPB4xpI1Fs+VHgT2Cb1
Gc3Ra4B//T1bfILAtZ99ikQ6DWzPizCtOklg3xCvbB1tUYTsiV0Rgc475lct
pn3EIDouOU1gTbak2ajVQL2/cbxESuAr/1C/HNrGuxOPay4TuEU+vamA0oDk
kV1hazuBv6QsbZRqNFBetSPpsILAQrXOP5d2VbqSt7KT3jMcdyeO9u9Okk+d
SgKzOEcfELT7YxySVL0EZv/dw64d0oCX2pn3Wk1gfviF3TfeamCeLIN1fpDA
3QKPb8poL83vMwqGCHy/JnIkg/ZqL+k1kiLQyexZRhDttG1s1sgIgXttYhrv
DWogK+CA8Vc9gS7cfUUXaOfbv+5JNxC46W7ITjHt0qtVR8fGCAx/bvo2jPa5
/ZbCxk8EzrAZcPOjfXmNIDjLRO9nJk9h0pZ5tM0M+pfA5eFXRt+/0YBc72mc
mCDwN8dSqof2f87qYvM=
       "]], LineBox[CompressedData["
1:eJwV0WtUjAkcBvBuQ7ogpSY1t95WTHI5WGrx/6s9VgpRw9libaOmaCZNajdF
m6LLUkbaKDqzI3Q6NKVTe5ZNqJSkSY1VtqwuBu87r11MoybUvvvhOc/5fXo+
PALxge3RFmZmZpuZ/N9l6eJpy6JOrCsmDPcyEmlo0fKDd/L3welq+dRWxlOt
jVl8/iHoke225DEuu5PPY/HzgJyQxTXIaZCuTZaN8UqgcqZ582gCDdqPsUVv
eZVAvVA1RxygYXr/sNcb3g0Yypq4YCWlQfVAKdfz2sHt+pwznVE0qKvz+qWL
/4JZiesD3ENpiIHuEjpxBCrMSuSXkYZ43cKROjUJ9X235OhDg43gmNfz1W/h
xNwIXz8XGgpmdwhV3xvAyS/k8VwLGsT9YbctH34A2/sWo1pKD/J7x8QHvCag
MFD65aBWD9cT7ELZgZ8h52DerWONelClxVFLd5rhkxWpoScr9JCp/LRtlDbH
FTNKyvYU6sFMO4gNqZbomMLR/XNED/OTJClhQhY27Er2F8bq4YXx7A7bW9PQ
36rm2w1hetik23+kUG6NTe+HNMtBD1teKLy5XBs05tLs6d56oJrFGferbHG4
eau9mq2HxQ5POAF77HHGV6swiKUHGzBGDhhmolNS9kW1gYJv3oSPeYhmo2HG
1FPuEAV9TVHm4YsccPyRo2VcFwX1uS3f8Y0OeCZku2jXbQokrORBjWYOsvWv
MxLUFOxNTKu3K3VEn94Nlc5KCpbEeGuCI53wQ6t1TaKCgq45i2yTfefioWvs
WoujFPyhzjy/yNIZZ0nuXrI4SEGauTDk4TNnVPHiPwdEUWAzkLoxvs4Foae9
Y+UOCnRXBEXKw2y0VYqLfwikoGiBq9UNkSs+4mW2sNZQoCiVtEXy52Fr9rO7
PUsoCC/arbF7NQ9HL4m0Pp4UjH992aRsdMNB7cT+YRcKRnT+KU057ji5m0P9
bkfBxbXL3DojORgxL0P23oyCquPJDjE+XOwrzbSBDyTkiPYGWRq5mB02Vsmi
SVg5oKrM6eShU60oYfUQCecWnq/qDOJjvq7zF0kvCT/dyT8XdIOPo+kR3dad
JGx2E11+4CnAhvqDQn4zCevj2yIc8gSYqbBfwLlJgtJd7PnQKEB2bZdDcQ0J
ns0VxVsiPFD6o18hWUGCwqdJ2NPogcp6ZF1QkiAxWHW3CwlUrfoiobuYBPH1
9/y8UwRaSWY1dRWQIM0M/bTpNIGcvqeya4yTQ+t67c4Q+LltMyePca4xuUBR
TOC/k0ty/BmrfU0fz5YR+Pq5Jrs+nwTT3aknV64S6Bo/teLCSWa/xy6/pY3A
CEVKoPRnEkrLZbHZ7QTufxe3L5BxeZImYGMHgQvpsZPzGf/mrJjo0BAYfK73
78E8EgbCHWO1fxL46/KKKhFjrxHXgOERAk+xHMcgl4SldancSzoCJ09vC+Ew
9jveb4p+RaDDPn7VRA4JwV5lNSRFYNZLqbyecWIcn/vuHYGy6lpPb8aH1xw1
1RoIdBNEl1ozPm4//DjJSGBBY7njy2zmn+ryE+PjBJrim2erGF/MsIq5OUHg
lrTyonTGV7dF+x/+RCD7ir37LsZ1Hq2cdZMErpOaV/gybjTMN01NEXh7U/pK
F8b/AaewUWI=
       "]], LineBox[CompressedData["
1:eJwV1Hk01V33APBriEplevIzT7fI+KT0FqV9ipIhDTK8RBGuUpIyK4XIIyWP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       "]], LineBox[CompressedData["
1:eJwV0mlY01cWBnAwgChR2UaNbAl/JDaCI60Oi8K5rVsLlBkERAFxwLJUFAuK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       "]], LineBox[CompressedData["
1:eJwVz3881HccB3A/CoV0+kXlHF9LdBqP8lhavN/DqvlRSfqhWiHulN+5dkWU
Eh6WrmUpZoZ+rIdHol02s6yQUlwhVHeaXH50389NN46uLPvsj9fj9Xj+93rZ
hcdvjjTQ09MLpPm/i9PCjdz25XoJjGcsbOCpoamTF7CNFw0HP/Jt0qinmutP
8HiHIdD0x0EP6uI7p22n83IgIdL9SZWtGmI8RbETthfhgfxzqx+4auj8IMx/
a3sNqr9s8o5erAZjeb+j2rYWCho33lIuUEPpw5JE1rYFsqV1h9JnqaHyRo48
ZvkLcP3GW5CnIyCA9oskSQlpETV3dgwSiBtwUkor34B8WU9ywlMCM+1OOv61
6i2odtSs9GsgkDf7kXPp3lFgDwdfLLpJIFy+5U/D1nHQz31xQFNGIPHeyfB4
x/ewLr3bsDOfQHWCWbDVV/+C0q7dtyqbQGnKAZXrNj1s7t/EyUslkFEyGTRG
9DGmOrfFOomAXmcf/nHEEMfETFmBkMCS5CjxFufp6BlYF2W0h8BrbcFW09tG
+KvJudG6rQT8BvYf/S7RBEuXdpTt2UBgw2vJMi53Jg5ejv7s9loCqsbwYw+u
m+LBh7He85DAck63jc8ec/Q+OtS12YP+A22YYnQWTkqzxcIVBNapQyfsQ2bj
UNVwaYQLgWcN+/RD+RwczDu0q8eRwK3spq95Wg5e8jA3G7cnEDVd1CeTWaJl
rdR7woZARFLKLbPCOfi3k9/jPGsCnwqWyQLC5mJm6HI30TwCjy35piKPeXgy
wGeFJ4dAXWVGEd9wPvZIYoTHzAmk6Dtvau2dj6e8BBNXZtB9iiPr46QL8EHz
2TcWRgQGrtjll6Ra4RxFa+9LAwL5S62n1YZY43ihWdnZKRYkhVH3w3gL0XfY
PfqnSRZC83fLzIYW4lzH3VG9Ohbe+V7WldQvQs3+BZ9MjbOgHPAWN2QtRotL
ObPjx1go83Rb1BZmg7zh9sP3NCxczxRxBC5ctL/Hd4sYYSErJMLfUMtF8ZK1
WkbNgrui9FpWmy3uaknY2api4YJT0fU2fx7KJp8E3RxmIf3O6Qv+tTz0/bk+
4fggC4GLQi4/dLBD/TbrifjXLHwRd38nJ8cOR05wRs71s1CyONyhVWuH7lVu
q8v6WHBovHp+w057NFBm6fW/pP9cGpw76u0xTdO+0qOXhajRae0tzgwq9MV9
KXIWwqv/4eWcod4kcVc9ZyEmI3jS7yyD6d+LgpTUomBpj9k5BpWPt8cpqLO1
ojzJeQbb/K0qZNSVHroPBcUMGseKXH+h1t2d6r5SwSCrFu9PpZZ0mJ1uus9g
Rye/0IK6sDxWeKqFwcaNwi4T6vJkmc/6RwyqzYs4BtQ18yXvH8kYjE8b+Hbs
GQuK0DnCzi4GtYkmZ55TOyqtffqVDLa+2n63nNpVeoR7aYBBrnbEtJh6daZc
FznEYJhxyrbz1AGOxVVvVAy+2hGjyaZOOsDjajQMrrGscY2jTl1zXHdzlEGO
eChDQJ1p3v80WctgBZp276W+cKM89907Bh1cnNKDqcuOTRP8/p7Bqyr7rgDq
iqBI79RJBld4zeKvpZbaN9t4fWSwbkx1AqjrR5fopqYY9JX/plhF/R9Lv2FQ

       "]], LineBox[CompressedData["
1:eJwV0n0w1HkYAHDCXcd2R0mKtbt+sqyX1FVXwvOgRkk64dzQ1Vkvu3ek1mC2
KK5IriNF8pLMJjW90Nvmruvaury/7Y1Umsg5bB19N2lb2aXc9/545pnPzDPP
PM8zD0+4e1vcHAMDgy00/s+VB4SfLI896tOuyRja46qGxh5uUAT3B0hbETL0
LfVss+IQl7sXBobqm5G68n4+x4SbB0UFE97m1Ineqbvec8qA/3T5q1oXNfRM
i4vfcC5CesUe8YhADZ/2DfHVnNtgu92HDc5qkLVXSV5x2mDSw9VRvlQNdVfz
+hLdn8Go0M91KVsNIuguI8nDMO58YVxiqYYklfOwvG4U1KvrAwrM1GDKy+b/
veYNhLm9aFEYqqHAvEMg+14Dvi/0l05OERD2hd0z6pyEtM53Jk2vCUiasoW7
+XpoZD++F6oicH0PK9R60wf4zHBScLefgCw9YcwjwgBNJ8JP3+ghcLBqJuQd
McSjwXMP5HYQMOgZxD/2GeGmIHVvawMBx5R4aZjABF+PKa/X3iEwoj31jdnd
T1AZejowVk4gUPXj/hOSubjT6aNj+xUCwSOFLnZ2pnhxVB99pobAWIMwq7XW
DK0Dkibdqwi4Wzxh+++ch19mV3CkpQRMQRvdr/kcl9VfspecIBCgjnxvH26O
wd7Rq51/IfD0QaxhpKsFnnyxKMPrMIFbRxp3cLUWKJAYh41lEYg3SR1UKucj
6744bns6gZjk9Fus8gVo2tVksCONwDKRizIo2hJDGy3rz0kI/DXf1Sx17UKs
CQxqvZlI4E7dwQpXIyvslUWKfMUE0g0FX3c+t8JBi0y/ihg6X/++jUnyRagp
ef9y5U4CqvO84qoMa8y78oztE0Wg2Gmx8e3wxeio4z6yiiBQWB7fEs1dgkXb
m0ojQglEFn+nZL1cgse8Zha0bSUwtb5GV6WwwYDIEB0riMCwyk/6INcW76X8
k1O7kcBZ7+U2XdFsLC95vYHZQKA2J9VC5GaH+g3a5nFfArnhMZuNtHa4rGdF
yIgPgVX9sou5XRwUeX6RfW0dgVLnitquzVwstDwkbV9DIPN+funm21zMOj8g
VqwisMUmvKbdgYcTcSsHe1cQ8E1qibLI46FLThn/Kw8CVbZCh04tD28ORhUm
uxFwaLhQEhxlj5kyb+W4gO7n9kDwUGGPqrsLT/7sRO+vMe5uEzBo7PFUYuRI
//H6W27eMQY17gunf2UIJB4MnQk8zuDw2zcDtdSpofJeVhGtH55uqKY+ok0t
KCxhsEZ65vgx6rq1uulTlQx6dpuvE1Hr/px9cv4ygwM2+5utqAsfsvIbWxi0
PjxPkWZPoLx6l/hwG+2/PqElkbo6Rem/sYPBvR0T3ULqeqtCfYeSwdh46Vgw
dX/kAnHPYwbtt8U786n5w4v9h4YZPGFbNtDLI+Ah32d3TsVgcVeCvovaM6dP
F/eSwVaH2EWN1EH8ymujYww+/9gYdo06OYFrNzHB4G8a3+dHqDO8ftLd0DCo
F3nNyaTOmTf0KEXL4C1tpFMqdenV6qNTUwzOKTWSRlOfzTIW/a5n8N9N+bII
6sshcX4ZMwyObfXs3EItt29m+3xkUCk1nfKnVmgcdbOzDMYUfXDwpP4PX2JP
Zw==
       "]], LineBox[CompressedData["
1:eJwV0Hs01GkYB3Ai1iVLLbmOGT/HZEjppKLL8zTaTagj13OkZNymRBQni9Qq
tw2xKbe1DlIrGVurLbVNLVLjFkZSbMok4Z220qxLZN/94znf8/nnOc/34QgO
e4YuUlJS8qLzf5YmC9TsQ85scemd79q4Sg7NUra7H/sARKXpXLWjXmgRn2Kz
v4dhaXY8h7r0frb5YnYm/Fiy/I0a9aHNcZFT5kVgMv+1fredHKSfhfnvzavB
eiPTJaBWHxjmys0bwC9sm2XSSjmUt5bFTJhLIL6qOSjTRg6fCm/whrIkUGc9
UHOM+rvwNlnPjARSL06/DaUmKlM+t6WtENiXvolPvWHzLqfM9Hbw/SJyneXJ
oatubhH3n8fQPFatK6Q+0Wrrah8oBaXs4KtO1nIQ1WUOHLJ7DmyDMKd7VnII
h+4ickQGxhqykdscOUSNWMvqRWOgNfzqYrSpHDQ5p7lDG97DqTIJCg3kkKPb
xivfPwnVa/m8Al05CAa876m0/wuGevUV1ppyiHlwWnCYOwtnWfdmJSpyuBat
7WW4Yx7UQ/Y19s4TKE+MGF/tp4Rr5n+XhkwRSCmb2/2JKKOTcnRL1AcCStKX
+GeCCua/4rtcniBgFRsW781bjDnqa5riRwi8VhT4at1Vw66A9IT2IQKuIweP
/xTzFYqnbdyanhHY9TrXhsXSRK2Kj1kKKYHxJsHJR7VauIxz4NWvnQTs9PrM
nAOXYKiVqElDQkATFEGDkzqo/86UP9ZEYLvcf8rCRxeTFA9ESWIC/Y0hyv62
evjZgL/TrYHAjYzmfWyFHj694s3NqycQtjjuZWfnUixRWxudV0cg+EjiDe3i
ZbhRZH9CtYbAqnCbTvegb/AXkzsT1ZcIPF5qqxXnqI+R4opRnQoCd0QpJbYq
Bnhyn677i1ICico8j/a/DVD9ZrttTBG9bzDBJap+Oerc2nvN4TyBkUuc/LIk
Q9QQlGwNyCOQv8JItcHHCI2L3vJdswnkFoc9DGIbY3bJizfnMwn45+/t1B41
Rr3XowGaaQSmt1XNlIlNsPdo/5UdKQRkI/z4xnRT7Ok7ikPJBCo225t0BJmh
5dsnKfxEArWpcXrhK1moo2TGmj5GIN0n2E1FwUKb5xDRHUvAYbC8Or3DHBXH
QxwSYwgUWpfUdrixUbtl/Vh0FIET97ML3RrYKOvnJTtGENhp4lPVasnBcVeP
Wkshga1RD/foZXIww53f5hNKoMxUYNmu4KC7RLo+QEDAsunyhV17LNC10PF0
VSDtt7KR1yO2QHZ95A6tvfT/k6rdEh6D0SuSs1z8CQiufWRnnmXQRLjpZpMf
gUMpXnOueQzqa+0vuEUd51X/VPscg8Uv8uNrqTMUcTm5FxisTLXfUkAtcpz5
XFDKYMazNX0HqWf+Wui7VMOg5JmD41Lq3B7t7OaHDAYfwNYgXwLFlZHCNAmD
SfPO7b7UlbGdzi5tDIrB+7Eb9R8GubNtnQwOQHG/A/Wg/zKh9AmDD7bfmtKg
5sqMnIdlDPp5mgmv+xBYXZ/AujjC4H2DgYTL1E6pAzOhowyGeFTm/Eztzi39
bWycwfHzng1p1Eci2KwPHxi8m7XCZA910qYfZq5PMnjHbN06D+rUJcO9sQoG
czV2en5LXVhXeWZ6msGJkAvZq6grTqqG355l0DDn0VVL6prdofykOQbDU1U6
jKjrLVrMtnyh+7nb3+lQiyetZhYWGJzffU5Xlfo/8JB6Uw==
       "]], LineBox[CompressedData["
1:eJwV1Gk0FVobB3BTSuiGXtd4DCepeDW/aeDZQoPKRURIEdFkuhFRmQqFkCJD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       "]], LineBox[CompressedData["
1:eJwV0ns01GkYB3CW2kIXlNwNP5mMoVTrUnhetELlZDVZM9a4lKEkypRI5RbW
bdg55RqyWEejWLZQaqnsIBVtOmiTSaF5S2loStm3P57znM9/z/c5X+Pgwz/t
/05BQcGPzLddeip4sfW+TKeJpQptWokYbg/QdvrSwmEJ2p0+cQbDwt32ZBrt
BPRLUv1aiUtvZRstomWAIDpMJYA4wpF/aM6oECJmjl6rOo1h4HOYcNqoFqSp
Nd02pzB8PzxGx0YtYMy+yQiJx1DRXRb92kgMNuVBV2f5GD4UNDOeZYmBG8V0
FxO78Xok/XIxGFRkyYqJpUpzrNaBblDLPl7tTGzn6LUlI60XeiyEITkxGB5c
nv+O/vY+hL++wrE8iuF0N9PTmjsAr7Kr8hKjMNRfzhiOsBqCxb82zCYdxDCl
MZXlGTQEf/oF8rjE9GOeTuuEQ7DEGk9vJS53UK2QyIeAGojwkh3AkC/OCmXf
GQbupWzrcOJjktx32/2fwtUasyxWOIYy1Z5k9R9H4Zb9CAPxMPDgYaH0iATc
rEJy/EIwRI6bS5rqJ6HzwXR4mT8GFeMU+jO7aViV/2Yobi+GnJU9jIrAGdi2
e6i21BtD8PCem0q9s1Cs8+S9zi4M0XdSgg/TPwFvFRXp4YGhIUrNR9vjC9zR
riyxdCP/jD84tcFXAa25YK5t44ohqWze+4NUETkrCBkdCIPCwCi6HqeEDB8J
REVOGMxiQmP3MBYhzt02TqIDhhey83tVbyxGynSm0Y0tGDzHDyTkRy9Bg+XX
PijYY/B6IbAwNFRB+jEjiG9L/tcZfOYfkSoaU3MromwwWKk/NnDlLkMOepvD
BzaTfCALGplZjkoiGWmNmzBsx+w5E9ZKtGLpy5S8jRiedOxTZDPV0aGvvYGZ
1hia028H0GTqKKE2Y8UfGzCELuKP9vVpII2ycX7HegwhR+Kb1Yo0kZ9XIfeT
FYb1PIu+nUGrkE9UM8uF+L4GU5VvvxqtrhQpplliaKtPKmYqaSH3CeH1MSaG
eEXG7t6nWsjliztzK7HKSJx7ZNMaVFC9wC63wDBebSwsO6mNkkcvPV9DLFyn
o9zC0kErNW0fZTIwCIpCu4Jousj3YaV8BTFb+Euf2itd1CXYc7bEHMPHbVXy
snY91PA8IGotsWTcJbYjTR9t9HZvaVuH4aKjtd69IAM0+6ZO6EUsSuWr8ywN
kWKsVxSmY0hjhexQkhkiWUo7N5/4h5GK2rR7RihFUy7bRFxgXiy6t4OGWq49
Fj0zI/2+lV2wo4WGklv9ndOJd+mxqrpNjVHQxWRjG2LnyC6OeoYxeqvSVS5d
S/qpH2zaKzNGPMtc/XJi086ac14cE2Rb0pnAIRZYdjD6202Q9GZosy5x6Izy
QzGDQuYgXTZoSvrY8J6WkUuhlxGnXIqII5J85j3zKCS5P2tbSMz3aRpU+41C
XqJCywLidBk/R3COQm/rA3TOEdfbyz+fL6WQfuOL93nE8r8XHlfXUWjT5KAo
g1jQr5Z9u4tCJh6rXU8QF1UeCjsrplB1ntgxlrgyps/VvYdC9lo1dseJ/9IS
fOrpo1D6padWfOIRtmbYwL8UuvDF1iCamC7RcR2TUGh5a4FiOPGGpjjD38cp
tNVu5CuPeEvqsHz/KwpJfd3nQ4l30kuvTE5RKJ9VNLeP+MhBmuG7dxTSBdPp
QOKTDonyxhmSr73uDZc4ddnYoxgZhf7L5+AA4oLLlZkfP367b/Nrf+KLZ5R5
rZ8opNfoP8UhrvPe73JynkK5CaJJNnGTyV0Dp68Uoh82m/Qjbp8xky8sUCg+
oWviZ+L/AWRJpAM=
       "]], LineBox[CompressedData["
1:eJwV0n1QzHkcB/CykVkxbbpSUbv9Im0PtsPRw/p8VJSeHxk1SpueKBRrunRh
lR5M5OyJmm4nXeGMnq7uxlNIOKm92/Z0aBPVcqXvSWtVW3Tf++Mzn3n985n3
e+bDE+0LT5yjp6cXROf/XZkrmue66+QGz4B0sbCYQLuSG7iNmwo1A7vvO1LP
Pmw9zuV+C4qAFXMsqSvvltjM5RZB9SVF+KciAmlCcfqEzQV47VXvW0etnE6R
jtlcgRNO/U1W1Ia9A/bE5jo8d2gy/LeAQFWHLOOdzWMwvZxZlp1PoK6+qDfN
5QVo3Cy8Z48QSAbFhdHMQXh/kZhqsgnsVTsMNtcNQ9l0Qq7bIQJsXp59//ox
KGY6d+7JIHDK+Am/aqcG+Bj6EtMJiHoj77A6P8HH5zoH01QCGQ/yRPvsdeD3
jj0/OJFA436jiCVbPsNQblvCQhHNc3jPiGCbHkpafn7WEUtAIpsJ+ziqjyMh
uQ66GAJ6yld4K5uFGl319tTtBFYcTMqK5M/Fd2xHgXIrgSFt2dYFt+fhG9/6
SGkkAX/17u++z5iPdiU9tSHhBIKHSh2trdnor9AVe4YSGLkvOvr7tQUY1JXc
nRZMwIXTs8w7biH6WPTjD4G0H2jjVZpFuF/eYTjpT8CXRE/YRhlj+VlHk4gt
BJ617dKPduLgvUWSMrkvgZbC9liuloPCYzGSrM0EkuaKX8nlJviZ26RnuYlA
QubhFqPyxejeX5g85E1gVbKjPDDeFM0nWKvavQj8YeK0QOz2FW5fLI2t2Ejg
Zp2kwollhg8NeaulSOCwPj+0s88M7VYnjeUBzafK9tvbbI5tx7LbCjYQUNfy
pLKcJWhuFHaiVkhAutLC4HqUBeZ083fc9iRQWp70KJ5riTcUsgPEg0C0dIfc
6K0lKgXowqee9KmZkrVaYZ+q1CfOncCg2iurrWApejwo6L3iRuCi0NWqK34Z
xrwf9yfrCVzLF3OSna3RLNwg1oe6ICohgKW1xuX/hHBq1hFYq6q6UtBlgyDh
fPjyDYHzDhXXugK4KL813JVKfeRuyfmA61xs7o/yka8lEGQVVdNhx8MDKxvj
PKg37n0UwynioUWh2cbf1hCQLRXZdWp5aGd5ztiZ2u7+pXPBMbboq2afaVhN
+zm38btbbTHL5WWhO3WSxkDxmM9gvyvrXuvX9B8bx7lFpxlMv7nOJIQ6TRIx
43+GQdJSZR9ELY5o/tvoLINLfwwTBlAXasWnSs8xaD4jSfWlrnObmi6rZNA9
hP8AqKfuzfbUXmVQlZhbJKAu7TYqaX/EoHfH000m1OXV6SknHjM4OvMqwZi6
+qDc2+8Jg8e3CCSLqH81K9U9kTNoNVF+h02til6conzK4BcTmZBFbT9o4T0w
yCBbGbX5oysBQXO29U9qBnvHK1LGqd3ze6cS3zL4p9/yk2PUgfaVDcMjDDbE
6itGqTP3cK0/fGAw9HJfnJo6x/PYVJOG3nvvkTdInb9w4K+DWgYPTasuv6Y+
X199cnKSwaPOb8f7qC8eNUi+oWNQsC50iYr6aliiV84Mg7fk08IX1M22D5dt
+MLgmjfDCc+oWzUrpmZnGfxln2VxD/V/UHlG1g==
       "]], LineBox[CompressedData["
1:eJwV031UzGkUB/DSGzXRVFJi5jf95hhGLJ21uxy5lyy9jFYvo91abGNUilIZ
KpFGL9rKFiUv27bVKrRNcsZLRWsrIWYW46VVlEY54rFopwzRPvvHPfd8zv3n
e+85VyCLC9w4zsTEZBWt/3vpbpnlfHnuEhtd+dCKfAJtOkYSwmyCHXe/vIDU
Y+3NexkmGZxOVikWUZdezudbMDkg+WdJ1xzqzZ6KLSP8I+DKqQ50pNZ9iCp6
zT8JCZcyR3vyCFh19YkIvwHOKIt/TKAu7yiLf8G/DgOpPG1WLgFVXU7X5rkP
4Vyf5XFJDoFIuH3kZYIeIOc0Z3w2gdj+WXq16jn4b/DpOJtBwFqQIer56jUU
6pTnhUoC++1uiMt/GIK62JhxzWkEZF3Bf5jdHIZb0ffcxLsIxF/JkMWJ3kPL
6WWTVSkE6rdygpx9PsKLrJGs6CSaZ2fM4LwQE3wsqg+w2k5AWTYa8O9LU5T/
fWXm40QCJrpevJhiho6ckIe34gnM2BaRFCy2wF98Z886FUfgqaFkjc0lS9zt
Vfd94xYCvv3Ruw7Ej0eRpTFIHUPA/2nBbB7PGseXqN90bCIw2Crbc63WBrnW
PWKHKAJzufene623xcI0z/MrI+h+YAjvHpqIwSNjF0/JCawkoSNuUjvs3RPS
+UFGoLNFbhrqzsUOL5leHk7g7L62dYyBi5xss4/D6wlEWCh6tVp7FKoCfk5a
R2BDws6znKMOONjwaTuzlsBnkbO1knBHHJ1Zc+RhGIG/7N1tFAsno869Lioz
lECTSnnM3cwJrTwXTAr8jsBOU/Hqm4+csNj+QZzdtzRfd4p3rHoKNul6r/Ss
IdBfJSgqS3XGhZvW2WqkBIpmupg3SF2w2Eo//HswgYKjEVfDmalYGRrYfSKI
QGjRWi3n2VSsGl56rT6QwLvlx41lza64wk5AIxPQ9y9LasmehhPnt+5qXU2g
wnO+qyZ8OsouJk7QfEOgNlPBjZzDQ2uPaotX/gSypRv8zAw8tJ+S2OZCvaC7
/GS2ho9tHgdli1YRODzrWK3Gj8EIxxi7rRICaZfzD/s1MOiR3AjH/AiscpUe
7xAKsCEgPe+WL4GlsVfDuDkCtOVna5ypy6bJhDcNAnxl6ioK8SEgbK0+5B/m
hhWNHhHV3nS/OS3iO81uWNL+eeXYSnr/IfPb18UsNj9foPSnltW/ZXJ+YjF3
YGlF7Qr6L8qgUd9CFvvuSB+dolYEqR9wDrLoENTkfIJ6n0Gxv+AQi5LOlIIK
atVC44eSUhbrdnTsLaE2/jl2v6qGRQXza3I6dcEdTn7bVRZr5O3lUuqjlVui
sq6zeC397UAgdeU2rZf3DRb3KmPdV1Ofcyp4f0PLYpZResGXujvUIUp3j0Wl
zxMdUIv0Ll59ehatOx+5iKnnqVN4v/WzmDdsKhdRL8rsMm58xuIDoUIlpJaI
Sk8/H2TRM9V7OZ86IYbhvXlD51XliY7UqYvTjWeGWPzi7uLLXOpM27672wws
ZpyYYTuJ+nBdZe67dyye4Q5UT6Cu2GMe2fiexbS8JoMldU3AxmWpoyxOTOnx
MqdWu7VPX/KJxTBNwAFT6uahGcaxMRajk+2ffPqawH+530gO
       "]], LineBox[CompressedData["
1:eJwV03sw1WkYB3ByWYNaR2WTzjk/fq1Tkuiyi+J51E7rli6cyCUcl4NcOnK2
QikRxy272ajGnFVRrVBiLdtS5M5RlNqlqXGYrm83KSdk3/3jnWc+M88883xn
ntdUFLcjbI6amponff/X4sMibZvQbEdxgSBLLY/A7QHG3ZuJhMtGY8xMLoHZ
tsZjDHMQ1ic8vK6iLr6Zy9diZKCaL1G8p452kMZ84p+GRJehwVHqgamIgrf8
y8B0cGw7qL8aGhEQfj00aVp751CXdMklL/mdYJ+SeV+X+kNRrcXjnE4YfaKz
QZt6s7hb2a/qhJZfzeXq1K80PgkbBrpgkbOr32QOAVsHD3tZRg8E610oH6O+
UzU9R/CmD14j92oTdUqXpatN4AB0qK8JkVBXVsmGoq3+haNRVx16sgmI4e7p
V/FK0M8sWXs4i0Ds2HJlTeVzuHLDXs6VEdA1TRM8tn0LB2PuLcjOIJBn0G1R
EjQO++y/HNY+TkA05NWk0fMRMhb+fsInjYCkNU0UJ/gMHPXTNRWpBK7t1fdc
5DIDa480rOEdpXmT9ryw9lbD0a/9tGJTCKTKp7d/eKWOzbJ0j0eHCKgNPMEb
iRpY+DLC3yeZgHlC+AEvCy0EXv+9ukQCoxOFO/X+1kanSkfG7iAB17GoQ79I
dHBL9ktpyX4CHqP5K3g8XfRPnZxj/BOBFy2iIx0Venip8IJTdQIBK84gd1Pg
XHTep+O8bh/NBxPBw+PzcJVuafw/EgI/Et9PZkIDPGW+yyByL4GHzaHqvpYc
NJhuUteJI1CbeXs3M8HBxjZft7YYAuFa0icKhSHKDOfdkkQTCIlPqtU/Mx+H
XxtK1+8hsEq8QuEevAB5lwRbDaMI9Bla6kntFmLl/sjqBxEE/qpMPWupYYT9
U2l29WICSeoW23oeGWFbValnVjjdbzjRObbmGxQzg5KIMAJjZaYF8uRFWH3J
piAolEDBMmPNeqExRmv5+7iEEMg/E94ezCzGmZNTam4iAr4FAQr9p4ux/GZS
rHcwgckfSlXyRhOUi96HC4MIKMc2HmjOWIImJlZBUYEEzjnYmPQGc1EasL1U
sptARbqUI17Jw+/ddZ/lBRDIEIa4aUzwsDVttqTWn8C64ZLLGb18tNrmGNnn
R6Bo+dmKXjcGrW1Ex2Z86f3dzC1yq2cwQXOzB596i4mwtGupKZZfaXd33UXA
KbbdjyMzRVWb8utMHwLyJaKlPROmaFU2Y9HgTWBpy8VTHn5mGEEqHb/spPlW
Nlv0N5rh6hCGuFCHj2ve7bRg8WI+k5UlpPd47T0jO8GiYmtd/5AX/Y+pntOu
P7OY5DyqeEgt9ax5oH+SxR05u7rvU2dOSPPyT7Goc2dJax91pZ1qqrCY9jtp
3WihVt2aHSwrZzH5N2FdOXV+v37u7XYWW7+7rkyiPnM+JuJ4J4umGQ+eHaA+
n6DY5NzNYoxq42sp9R9G+Z+7FXQ+/40qjnrYd37EwH3qmLMLQqkFSuNNI0oW
Y+dt8Hantq5J5F0YY/FPa0WQC7V9+pAq7CmLgSNlUZup3QXFV5+/YNGzb0UK
UsfvYXjv3rFI7qSWr6VO3nBUVT3Oom2cc50NdfrckXsJEyxyvbxarKiLqs5n
T06yuLvXcXgZ9bkjmuKGzywWb+U+/5a6fHvYxuRpFld/cPpoRl1j1sZ1/MKi
fvUVDYa6cdxcNTtL8x4J4HCp/wNqcXc/
       "]], LineBox[CompressedData["
1:eJwV1Xc41d8fAHArZSQjftmXS0oSSUP0PpGKfFtGQla4qMwQiUpCEUkSIZJR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       "]], LineBox[CompressedData["
1:eJwV0ns01GkYB3Aa2g7aGqFQzMxPTS61OWcrnPI+m0tWNinThWyNYrTKRKa1
oazbECOVItKE3E6LLrSxMVJoXHNJNShrzLYu75amWUZa+/rjOc/5/Pn9ni/T
n787YIGGhsYBcvM/96z/QtujKY6z2qfetxZj9LSH4bGPcQylLt9r+jvxXFNd
HIPxC2K+63PLJ86tF5lrM5KRa8TH0gji41sFJ6bMryGTBUOpq4l7PgdlfDAv
RUE5YnpMEUZf9Q+zsXk1mizJuGFfiFFeizh03FyKWIWn3jTlY/Qpq8rqbaoU
zQgmD9wjduW1yrvVUrR66tvhXOIJ2hSnpqcFbTdzNBYQ223d6ZAsbEPRrDSW
BfHzitkF7Ped6LWGsjQ+D6NzLTbutod6kOH46B3PmxiVVyT3H18vQxH8t+LF
NzAa0x9LdefKENOh+PyXXIzYp90d12bIUN9fWTGY+OYW3Ty5WoayaXJRO/El
aWqgT2M/4slOrEsjPi2/MLn94CBy1tKMpBOLdVvj6C5DyE/iwmJcx4iHuq5N
hMlRuImzwcFsjEIUlvLK8lGEJqzlnpkY6TDj2W/tPiA++3RLYgZGaUtbrfIO
K1EJX+eO1yWM/Pu9JbS2f1FBd32vczpGoY3x/nz2DNqcE2uYnIbR3ZN6e1Z8
/wUJw52czUWkz8jgsQ37NOCLUUVbYwpGseJZr08TmrBrY4p+yXmMNHqG4NEZ
Glw3XqBblozRmvDACG8rbaBqp/0fJmE0osrcq1u7EP7Jzjw2JsTIXfFT9KXQ
RaC0wksYxDtH0q3NzHRg4xEnSXAi6e+Jf8yzMl2wp/nIuhIwWk/vW+V0aDEY
dhpn2RHrIBV3QPk1WHJ6hyrjMdqOfaZYnKUQH+piaEv8quGopo8NHZI2RydU
x2FUlfT0R4aKDsIGzV4v4kBtwVBHhz74ik4ajMZidCQsskovexmcHxx5JiL+
hmfd4cE1gMP9qe32xJ36NroCe0PogSueI79i9Ed5bI4NzQi4l/M514gjNa12
tQ0agU3T1CsPYp2BM24hlcuB17fMZiGxooiZIY5aAQJR1mBzDEYZa421qjnG
4HslbVxInJ4d2MxlmEDQ/ud+nsQ+GX4deu9MoDEkrNCEeNq5UC2uMwXjEUun
kXMYyRXbIhqEK+GW0ZbP94nzt9qatnNXAdtJwowlLksQ0HnrzMAbtzRwiIWc
IztoKjNQRSosbYg3DuSVCtvNQRDzepEmcZZlTln7DgY8Wm+SJDtL9l0vytpR
zYCDSwIz7xH/YMopbLFgAvc3mr6I+LuQZl96MhPGJXlRwcTilf4WbSom6F04
lOhGbPGk+OpOXxb8jIOsLYnT1zVYddexIDGBflGXOFCp1SW1osAkOrZoIprs
8e5HRvIFCmhpa988Jz4eu2fW/SIFNRKfo/MW7Kl8qXeZAre9N8c6iZNUgrT0
qxTwxQFTHcTl9urPmbkU1DJe0duJ1Y/n+opuU9Ak2+8uJU7v1hM9babAwLtU
+pg4u+BEUKKUgnhXtHveBeEdTm6tFFzU+1tWT/zAKH2mtYMCiWbYhIR4wGdZ
UM8LChwMeEvriNlyY6dhOQWK2S7fGuINlWfMbikoKDa6rKgmdkjoVwe8oyCh
NpA/bw927p3RMQps81ziHhKHBTPMJicpiHH98/YD4qgtv6rvKUkez02b5p2w
eLg3XEVBfUNufRVxVkVByvQ0yf+y4EUlcX6MFq9mhoJh/rbD877tFbAtapaC
G1zl2H3iSlbTKsf/KLAreSCYd51yjXpujgI/lKox7/8Bxve/Yw==
       "]], LineBox[CompressedData["
1:eJwVzn0w1HkcB3BaYtb2sCpFa/e3vuJaCjdjJjen76fUFJarE82sqzsbVoXi
7FX0XGJJyXOcNiTFIB3NbC7JQ04eutq7urNLsu2p+DZpW1kq9+2P97zn9df7
LZTu+z5qjpmZWRDNly49Kp3rFZm5FjVZJo7VENyhZsTbmd24wDYyWUc9e7/l
FMMcwo6RQyka6tLWLIElo8ATqsI9PdSxvvK4D4KLuLuZma6mVs/E5L0VXMef
BJenYqitNCOuRKDCn79W8p5XE1z2QJkwJujGuR1dv9y/TnBdvUITu3oAS1Sx
JKiKYBl+dHE8UYdvPlGzrSoJjtev1DXWvcJec+zn6ssJZgtPuz5b8xYHITeJ
6jLB5xb2iMp+MuBNP7/c8PQSwVLNtrus3kmcVOP7n+FXghM6T0v3uU5jsT+3
Zm0JwQ37OSHL/D9hFk9b1XmR/knZ+9pzuxm0i/nFgUUEn1R+3Pp+3BwEfjEz
FoUEm6mH4fdkFpxw8/HS5BPskhR9cJvIEtgZtoN1eQS/MBaG2dyZCxEPg9nV
uQQH6PccyUmwhiqd9ZHyHIKDX2S78fls6N3TFN5wgeDX7dLjf9TaAHdLWPtQ
NsGruU8c/X6cB4fq32RaU7OxMUJrmA9nXRK6xecJ3kQkH5xCF0J8TtiBrHME
/9MWaS5x58LNtt5BbRbBTekdOxkjF9q++yFkHXW0pXy4v98WRLf9x8vOErwr
MaWJU7wI5vcssF9C7SFz6xdHLIYmmyjThUyCH9q628h9loCjp/0Ym7q57mSJ
O8sOugbeueRmEJxiLtrSO2gHrXvD6pdSs7XJm+Mbl4K1x4r4KwqC9VeFecrD
yyDJ5/1zX+q8r+wtVKH2sBvvvqVOJzi7OLorgnGAe2ILKzm1JG9HP2fUAW7U
dtrxqKc2VJqULctBuaXv2t00gnX69Qfb0ngguzHBiqMu9/Va3hfhCBKbnQ5L
qWtT5VzZKj4EvYkTPjhDcFrorkCWkQ/OMwWKE9Te2rLraX0CsOvMV3tTF60s
qe0LZKAjfPHARCrBx1qzigJVDMQK17yvpg5aHlr5wFkIifvzP8mo18V3hXMV
Qhjz/vOeG7WSJ3XuNQqBu31n6/hpgp3bqwqCw52g2Xlo5jfq7FVtosctTnAs
xXvlUepog8WjbhEClp381kZqacM7RnEeQcy0Z5ctdezJkI8BFxCIhhNGudTy
kMannFwEscWPrb443Sg/l12AIDrBsHkBdZ2PaaawFEHFeEOvDbXp3uyTqzUI
fH14AxZf9h9zsjq6ELzMP8D5cIrg4oq4mDPdCKwcrnpOUlck9ftt7qF7lwzb
jNS37LKne/oRhJ8dKzVQayWLYtR/I/APCPZ6S+2qs/cb0SHglv274xW1Z2My
/4oeQYmD8dRL6m9SNaaoUQTX3D2qR6nFrqU3Xr1GcMVsdlJPnbiX4U9MIFjR
xMkZoT787QnTTQOCGsxTPadOnTfyV5IRgdIjYHiYuqi+InNqCkGUi7nHM+ry
4xay29MIFExG2BB1zdao9Yc/ImiO9jo6SN3odN9x7WcEVe8mK7XULQYX0+ws
guk7A30a6v8BN6VcWA==
       "]], LineBox[CompressedData["
1:eJwV0H881HccB3BS1rh6dCmR3K/vPVxdElur1PJ+l1g/9IPrVPqx7vpB86Mo
TVgnsZjoQn61Sw5XN5G2a8tmVhITznLNesQ2uWSsTw86lx8p++yP9+P1eP7z
frxfb778SMDBSRYWFpvo/J+qU3JrjwNpXtstjkSsLydQZ+D5becdBvGd0Cu+
1BP1NWd4vJPwqmpxqze16k46dwovFWLGBYwXddiq6PBhbj5UHvYr/YDa8CYk
e4Crhf5mrzlO1O91dIsItwoS024/6rtOoOhBYeS/3EZYDuYfFNQVN1I7wtye
gKsvY6UoIxAMD/NfRBnhO2558slvCET0LDDqKvrAVtbUGK4lYMNPEv29fAAE
Eo7G5xqBjBlN4qJ9JpDt1ie4XyUg79j2i1Xzaxg03O221hCIvJ8kPyIaA82g
sbe3hMDNoyyJw/q30BAQI+kupvfEhfa7b7dAtpN+j15NILFw3H/ohSWey/JP
eVREwMLQhdWxVug8VLCk9woBl+OHYraJp2CGwkf6spDAM3NuoO3P1ii8lvXh
dOoNPZ99kRk5FR9GrDMxlwlsfqZcyOHYYIxwba6vikD/PXnCr+W26D82olJ8
TcCN3e7s/ek07JEJK29cov3ALOs0TUd+0tWaoQICn5CgYYF0BkqHxko8qB/X
HrAMcmVj/rMzgSfzCdxKqdvLM7PxWF9rjiGPwKEp0V16/Uxse3wv0IV6f1Tc
LVaBHUpDTPu+yiWwOHih3k82Cze/rb/+OodA60xX22jP2ViWdfHdLuqfKhIv
uVrZ4+6BkKLfLhKIsxRvbf7THlGhq/OitumMXRehm4P1O7IyddkEejT87MJ4
B5zbsnRgGXX2fMfJVVJHFMgmlt3KIqAsONQg483FCo12EVAHZe/Rs3rnop1N
+NTWTAIja0tHC2ucsNrXfuFOamPPmpjas/PQ975Y/fICAfUqD6cWmTM6n9tQ
dYq6PDmaHbyIg1OfqCMdqc9K92+0MnNw/vWu96uUBD7qLNKebeGikGt9QUKd
t+BSectGHo5VntYMnyeguJOet7GKh7xjKUM51JucpKUPhHyMPbHl8Qrq1REN
u9ipfCy5rA3szSBQOE8ubDbzUf12U8B5auG9qzmbdwnQRSGKAGrlolpxW40A
Vwpmi03p9P+myQ8bxQxKAtqK1NTym694qecZrMzMjttJHZYoGd9wgUHtjuWe
O6ijJbo/WFkMhs22HA6kTjFHZyhzGLwSZHlsG3WF5+ibXBWDs4Krw7ZQj96d
aNeUMRgqmhPsQ61sY6XXNTC4P2nJ5x7UBcXhIV82Mgg+oZ7u1MXH9d7rmhis
9ax/40b9vb1yrEnP4M3SfxJcqTuD7EIMvzO44Olf50TUIqOjd7eRwXZtWpkz
tbsullPSQ/e1Tzo6j3pFcsfowV4GK9pVS5yo/USqyr5+Bp+uhBoH6qhQHmdw
kEHdoJvBjjr+49Oj35oY3OdQlzeTOnla96PjZgZvG+P3sqnzbhSnjYww2LV1
Z/90anXC5OAfxxh8/jy+chp1mf/BNfHjDLJs6k6wqHWCemevdwxG6dxW2VLX
mFxGJyYYXNpVbWVD/R8XH1f2
       "]], LineBox[CompressedData["
1:eJwV02s41HkUwPEpsS1TUbukmjHjLxODrd22LU/5nWILaUrCRjdTLl0ol9mI
SqnclhQxTGNcMiqLLqMnk1STy7qHlp6l1ZKnyH/XpVlNbnv2xXnO83l3vi8O
V3h8p+9sBoPhhvP/lp4R6qw6lGi3XbB57HoxTaraOS6enMNE1iQ4IkHP1FTG
cDgRZEFCXk8mWvo0yUSbE0+M9L+rTkcf2yAKHDfJJIwf+VEp6PaJgLRhk1tk
YIWuJAb9RVcvjzYpJ53fPrgZgM6tlwV/MKkjISq9Azboj+Iyy55f6ojT4GKB
FXqzf0Nfm6aOVBTKbC3RQ1rj7sr2euL5A3eBOXrtBoFtfGwj4Sbw5Cz0i9LJ
2bx/WsjmP1uTmOiz9VbOq/a3E73Yqu0Dv9KkpDS+65jNH6RFWarJRvuT1syh
kD6SyHkhnosO6rfoU5QMkOfLf+o4XEQTXe4FXs/aYRJ43zVRcZsmyfoNlrkH
xsjKSf5ZbbSwa9cTrcZ/yZ1H4zX2t2gSXH1BeJz3mZQef+8bc5Mmd08w3RY7
TZGTTo3bWgqxN/Lo4EpPBrw/qQxios/LJl0/Ds2CS4m0wlNOE0b7G6g4pQX6
8hpys4Am5mF+4bsstcEhcIFg6AZN3qozPPQe60CQxP0aQTv3Hzl9NXguxE1Y
J8fm00TwNoXPZuvCs70s7448mgw+F0b/VqwHLO9W99VoG4MOlv3+eeCwxdEu
Lhf7iNqne2w+GEvbDD/k0GQL7TVu6q4PRuPlUgf0K9WhWV5WBlAd7fFlgYwm
ZXFV+zhqA1hTdlu8CO2nLXrT3LwQ+IVJ0ohsmhwMiSxjZi0CTViaIy2lyTf+
/GYXn6/gzd3hHj90y0IrPdG6ryF0jTzh1XWaPCo5L7HSMoSqe48HPdCRsyx3
NL42BN2Xth1NEryv+5RjkMII7CKmZc7ofjk3TRa1GJSdV/jtWTRJW2E8p9zd
GELjFj7ehU7J8qv14SwB3xj/y39l0sQrbW8z890SIEv4dqHoTw4FGlnlUsh+
fXDPtJgmff2bwlWxyyAnalNvKjpvw6qlTT4sMII2GwpdfFFk4G/NhpSErKCK
DJrEuh/cqqVmQ/h8V/Vu9Pfdubdim0xAtWJb1kg6TcQWkuKmrRzYvjcr5Cr6
7NMk8dZyDsz15t63Rm9b6l5Qb8aFPTsly5qu0WRjUK23QTwXHh5j6YjQsmVC
s0Y1F5gPZflGaLPnhekCb1NwZgt8VWnYZ62ybKs0BWVBZ8YJtN/YnNY6Swrk
ORKVMVp4d5QTf5kCK2F4ZH0q/uN5t0nnKxSwfNaz6tAiN0UnM5WCZB3uk1p0
nFqUnJJOAbXaRasaXbJOM5EhpcDjhkXSE7Tm2UyHvIgCsJ6SK9ApbcykqloK
hvIHRrPRWfmBAZfqKLDwVIql6PywZnvHBgoO8YvsrqMfGKZ8bmimYIc5nZCJ
7vZaFND+OwWHR0fM0tC8PmP73j4KdJ0m9sWjVypOsW/0U5DKatSJQ9te7NL4
vqPAobWi5BLahSe9MzBIgbJ6ajoGHXKUwx4ZoSD4xFTOGXTU+nOae2MUFDU0
Op1GX5zX+zJMTcHu/kejkWhxaX7ip08U1NprHCLQedFz/JWfKfCJ3vL3SXSR
q++mqEkKlh8ty/gZrTCtYdlNUzCbYb9RhK4cM9fMzFAwaDs8GIr+DyqDkXI=

       "]], LineBox[CompressedData["
1:eJwV1Gk4lVsbB3AzpTqG93glw2YnGUInTqXyfzoy5mikQpxUhgaVIkXToSNH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       "]], LineBox[CompressedData["
1:eJwV0Hs0lHsXB3AMKswrdCTX4ZHRKHKoKOxfHLlUSow6FBkxShQrlUjphlyS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       "]], LineBox[CompressedData["
1:eJwV0Xs01HkYBnBiyLVQSm7DrzXbkKgti/S+S1sR2tkx29mpNiaXRGSOqRYV
Yt1S02YljiSRylCt7NpyWZTEaEvZPWi34zvD0Ag7TS6R/e0f73nO56/nPOe1
E8R+HbZIQ0MjgL7/s/ikQMc1NGdL/PCGkdRYJbT1MP13MyMhyvTMdH20EhYe
NZ5mMr8Hr6fL2OORSihuzrVlMLMgaFSPGRSqhGgv0eEp20uw/UlHut63Suj5
cDBvwvYGmKR3ujl6K0G3f5A1ZlsPopSqkzlmSih9UhL3xrYD1DNil8O1b6C6
Jqs/2rkPdu2J/pmrGIUIeHZJKSTwLiU4/MtNoxAjX0Nqq0fA7fJb5+yLI6Bv
l8b65/MJ8JYuWyqcV8DZpZ3s0mAVBM83uQlPKEDQH9Sk1fUeAl1LrMwXKSDu
YZogljULleOneOfyh+HOEUPuSt95+Izlbfp48zCUJkaNuuzWQK/n7Dd75UOQ
WjLHeafUxPFC4yt9RUOg0fMaHyRoodqzqSWcPwQO8eHHg9gM7JduT+6zGAKZ
+uI3Bg06KJJO7lYNysFPfujEj3GL0UwcIs2okkOgTOxoY6OPvKpYr/JEOYy2
CpIfSwxwR7bxVBlHDs4mvdY++42wbST+5lmWHPRBHTKgMkYHnYo6Vy05bB/j
T9nzluIWp3zLq3/L4K+WUE2+kwlu2u+3jdMgg3uZbd8x1SZoeU30YtcVGYQz
RK+7u03Ru8gsTZEqgwPCxHuGhWZYKVoysD5SBusiHLv9Q5ZhU2VuXCJHBk9N
nQxE7sux3a9LtM1dBverU4uctMzxaF1N8EdKBoma7K+6Xpnjqyqvt57GMtAf
SNgRU7sCC/Qyy5bPEpBX2OWVJK3EMwG5x3wVBPI+tdCu51lgJkNIzb8kIC4M
bw9hrsIYrYnQ9ocE+Hn7ug2HV2FKsP+G8joC01vLZ0oaLbEiUaKrdZ0AkXsf
b8mwwgFRr4v1JQJXvVwtpSHW+K7i/KqmbAKSdJFJxFobdBa3cSdPEMjgHdip
pbZBxtyE/VgcgY0DpTcypLbIkvhy48MIFKwpkkh3MvGX1maHXXwCp5pzC3bW
M5F3WSJ5EEggwJJX/mS1HRYYW67o9yHwRUz7HpMsO0zTTGi29CBQYiVY3aW2
wzGn3nHVOgKrW6/nB+6xx72DE2d6Heh9a1vYzxvtcZb76xIPGwLhKu1nHWwK
J9Y7uHksJyC48y8z6xyFFg+cc+yNCESncuf8zlN4M7nLaMGQgIhb+6fhBQo5
rdM/9dPOVIvOivMpDDw/VZdHu9p95sPFYgpTDA556tKe+X2ht+IWhWvLNQPG
9On+54a5be0UppbqZTcsJlBYdvjgDx0UMqpm7xfSLovv9tnRSWFxJEd1jHad
uXi2s5vCvo9s4XraA3yzgz0vKYytirp9XZcAi1j4DBIKFY5Gzhd0CLjUJthc
k1NY6dt27whtj/T+mbBhCl/6Sr0Dafuzim+PjFJ4Wv+PaD3awiimzeQkhVc4
RzWSGQSSNqfM3FVRmLO18O4+2ulGgy/i1RQ28HQOedIuqCnLmZ6mcHzqjuK9
Nv3vZO2I32Yp5FuN17ygfYsT5p00R6E8PTbpLu1a+0fWWz7S+xdcA8W0G1UO
MwsLFLpzN34SQ/s/2WNFRQ==
       "]], LineBox[CompressedData["
1:eJwVz30w1AkYB/AVetn0ssQp2Rc/l8tbcdVxU56ndENI13mpIVc2rCIi2wjX
EVpLRIzXNuOluq4ijW6GLiKnvHal687tltjfb9e+uFPbJi93e7/745nvfOaZ
eb7z8PiJ30QvYjAYe+n5PyVn+Yvdogq8on1OZ37QaKFnhBtwgHsMdnsUKd6p
tWDo7cjmcs9AV2zZlr9UWpA8LOSYcsUgKnApGVdqIX6H8MQMpwrENa7i+3It
jMzHlk1zbgDHz2ifl1QLS6QTDlOcNgjdvExQ2KeFuv7aJA2nDyyYDIv2Bi00
NYul8a5/Qv6odGX/Hi0I4FmVNlkOFTz1hahpDSRQG+WtTSqw4ugKrSs0wOTl
OIx5TMO5WtGMdJsGilYPONYd0cFE0bjQdkwNfGlwp/HgB1i9JzzHL1sNSb/k
8BMd5qC9HN8bu6ih5aRZkPWef6BzvTDQ640K6tLj1JsPMPB1WLuJbYmKvruw
/73WCDXTx26x/FXAGHmDP6cZY96FQ23yZSrYkBKTGuxoivXRt16peyeB1FeE
Ln+wGCcvJGX1FkyCH3X8u0tJS1HUv6rHdt8kBJLFTmw2E+vOsveOWk2C+hE/
88nt5djitiqQQynBlfXS1vvwCtSVWLoaWpTABH2kTLcSg82DmZ05SvCZCpux
C1mNW4yHDJ6hSvijO8oozJmF7paC9ClHJdzL6/mWq2cho6qzNttECTGmwjfD
w+b4xUi1+4RMAUeT0++ZVVtgwtOGruttCtgkcBoOiFyD7Xwj/a1KBTw1d14u
9LRErX2pad5pBdxvOlfjbGyFif3zoTYHFZBu5Pj14Csr9Ha+bF3toQCmLM03
ofUT3DrK2cSyUQB1jVdWm2GNuUU24XcYCij7bK1JW8ha3J6YtcWXoqC4OuZx
JHcd+vxqcOsepCCsLGLYTLkOg+IONl+/R8HH3VdnaztsMHvM83CphAI5tSu1
W7Qej9xv7lwQUVC/w81mKNIWHQuKlRlJFNzOFbIELmyM3P3jnE8EBaKQo/7G
ejaWHLn0xNWPgq2yuhuiIQ46KS2kHtsoqNxYc3vIn4tjnWdIb3sKvn9YWOnf
xkVm0finmSwK9tqEXO2352FJf6mkw0DCzoTH4SwxD2Fy1qrzbxJq1/PtB/U8
9JH7frXwmgT7R9fLA8PtsEm/cFz2lIRil27H5x12eJbVfSizi4QYncmzPkcC
K9ZEDMXdJYHf8o4rvkhgREDji4FGEuLPBS34lRCIRp+/vUhbGNT6u1kpgSmj
estg2nl6YVFxOYHNB1mpsgYSmjxn5yskBC46kXRlqp6E2S7Dy2s3CUx0iklm
1dH9z80Kex4TOM9vdzosIaG64UTs+T4CxzPq/e1pN6QMe/sOEMi4m39KdZmE
n6yK5waGCXRfFiI9RVsWZhE78huBSV2NTHENCQ7ytd4TcgJdYgYVrVUkbG5N
YzdSBHrunMlNo/1lrnQ2Wkmg+MVSF6Qd4CC5o1ITeGV09NJAJQnJcVz227cE
TscteTBRQULG9qzZuzp6v2Z7zQ+0c1dMvEjRE3hS45eVQLuyuaHg40cCNyqm
o+bKSajPNBG0zxHI1+bwH9K+uT96V8YCgXGUVnCedqtdr63XvwTGezsIA2h3
6DbMGgz0/6nu+ea0/wOwlFmr
       "]], LineBox[CompressedData["
1:eJwVyX881Accx3E/w6Vyaebn3fE1l0t+bLPH+sHng1qiWkIeYyknP6orkav8
6AdSVEyxOkmGpVl1aZPSSibThOuRM7XdJaPv936426PopnNk3/3xfrwez8fb
lZ+2KcnEyMhoPb3/W32YP8dv+6lAp/qhFWsZWuiUctbFcHbAKQf9TKuVFma7
2go4nCw4ExTvwaNd3V7CNucUw+Cd6WuWlloQBAh3T7IrIW2nTUObuRakhtSK
1+xGsIg4qZpvrAUL2QhXy24FbC+vWz2pgdrHNelj7G4YYPI9/UY0IL5RLBN4
/wWWzuG+A2INpMDTSk3GKMT7y+zuZGlgD+k52ixWQVRFXO+BYA0wXI9xX37+
GvpVVYsTzDRQatPDq902AVuOMFwE3WPAl0U9MO39Fzw+OdAYWjwG6b8d46dx
p+Da2kP2LWFjcHOvdaT92hmIlJusZDPHoDZnl9o3xgi3j4utZFI15NdMR7zV
GGPN8atZ01VqMJIO471sUxRm2S6vTFaDR2bywSieOS7bPxO5yVsNr3TnN8+9
PweDRILhHQYVhJE7D51Nt0SrqACNcZcKNrwqW8JiMXDgbU7XtnIVqB/yj/5+
fS6Grai43Z6kAm/moEvI1nnIMJw+qvdXAQN0CfKJ+Zht2eo4zlDBGm3spFu0
DXoFrrg59UIJzzu2G8d6MdHINqkl82cl3CrqjOfomBjhZ9boU6KEZHPhsESy
EL/4lHDlJSkhMSPnlvUFW/xY+GYLJ0gJPilLJOsSFtH/0gXvWUp4stBrrnDZ
B9j63YskMCjgF3F+lZepHSot0jdayxSQY8zb2PvCDjfcvX84rlUBDHl26J7m
D3HBDsf0fZUKIBtcK2py7XF3X1BVU64CKhY7mLVGO+B0uODByXgFlF1IfpTA
ccSRPK7F5hAFxFZskVgrHHHNktuX8jwV8G7VZX1NmxN+eXbos4T5Chglgw92
nHDGZrX313/rKKgL8HPqS3BB932iWp6cguuFQmbKUhZ6mVxKVXdScCI6MdxU
x8IqLuvbPjEF/vLaxhN9bLzInGk+fZ4CkWfV9b5wDha9zT6Wl0/BkfYSUXgr
B6UuInGigIL1TtGXH7u7YkHk4L2YGAqC9jyKYxa7orPVgf41qyiocea79+pc
cau5mu/vS4H7wyvnNsS5YUqf3GDMoqBsaQevv80NTXWOqxqsKUieMHvazSPQ
Rxcl2jxFAv/mOKf4GwKDMu5Td1QkCPIjp8POEGhsv7MljbYwsvmZdTmBkpCe
Ug/aRTphadk5AkdCLn9VoSRBvExvOF9NoKG8NGavggT9r7ODDVcJzFNpxj1J
Esr6rUs6HxG4P+pidf0wCRfqd6ce7yZwWGCSF0e7PlMSEtpDYHD0PwJb2i12
ZVM9EgKbpBHxBS9JkMfapkr/ILA6lH0lcYgE7qhDyMgogblO5U8+kpPg25zN
+p4k8KHNj8uHZCQsL5TpkxQEcl77iM/RXsetblKpCSTa8sUWtDN2cVhv3hAY
89J5kfpPEnJX5ul/miDQf1dBRx3twnkjA5k6AmdPrs+Koy26UX/q3TsCNcNz
jPqek1B31Czl7hSBdqsnnhTSvhqRFJw7TeDKyoAfAmk3u3W5BL4nkC18VTT5
jIS2CQ/97CyBj/dS6U20/wN1jFAt
       "]], LineBox[CompressedData["
1:eJwV1HlUjdvjx/EGScJX5abScOo0KCRkKPLZhAZuiIab6EqjIYUiJbN0DSUh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       "]], LineBox[CompressedData["
1:eJwV0ns81PkaB3C5dCxyq2yuM/qpkVuGPXuw8nxPlFy2V4VqKWKXEWG1KNdt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       "]], LineBox[CompressedData["
1:eJwV0XtUjHkYB/DaatZWIrfVZa5vzBqEsytl6XmSxaislllHLmk05ZJyaWy6
oOSSTrbSUXKSanNLJeVSMqhRuhg7U9uyk7M1Y3T83hmXxtAQ7bt/POc5n7++
z4UvjftF9pWNjU0IU//3ov1S1pzITH9VzX3FnkoTKLt4wWt4WyHExklUecUE
Iy2KQzzePrBa882GChMU3cviOvAyYNH3vVckl00Qs1C+4wP3NBwSP3DwvmCC
rk9b8t5wL8HVz3llynMm+FqrE5q49TAytz2r8KQJStqLd9HcNmilTYJ1CSao
qs7Qxnj/AxslQg+XBSaIBvVp42496EapvwQ7mCDWME1fV/USXGr1TbUaIzjy
04X/+r6Bpp8j3XTFRjgxtkNUsskMLeL9tyTxRpBqV9+163wPG+b7hYvERtj1
IF0aJ/wIGvaIPENghJqdzqsmiz/Ds1B2aKatEUqStpPZa2zQYr7+5m4fDWnF
w6HvjLaYM7u/sVxJg01XHzYm2iErJeXy3AoapsZHJawWOeDDHyn32zk0PLfk
/+p0h4WJqZFPFUk0LDdsS8ndNQplyvZrl2Q0rHiePZ3DcUQniXLqyVAaSLP0
4MNKJ+xnlas5SIO3aw87MHw0nrWak/d40+AIloheswu6+c3rGMWlYakp7INA
MhbHcSZsixxDw5OmSNuwGa64d/KCWDtbGq4fU27kWVzR9YFgn+wdgSgHeZ9K
NQ577rZ/SRsgsHl30nXnwvHYXTfllqiXwKzo6argiAm4RH2koVRN4PG4GU5y
v4n4Ym0IX9NC4HZV2pkZdpNw7cZOU8AdAkm2opWdzyZh7vRBQ0wtAcfexGWx
dd/ixEx1+k+XCRjO8/OKkyejV1hlxpRSAnnfudnXS9xQxzk35v5pAtmFUa0R
PHeMezUnQJxLICxvg8p5wB1lCYt54kwCQ4vLrcUKD4QfzkSw0gnoDYsSmo56
YjMvoDQzhUDpwjkejyLY+Jq1OkWzl0DlYblr9EwO5oQf93m8k8BRyeYgOwsH
x+599WLKdgJze0suHX3ExcKZ7McoI1Aw7UzloyAeHi/odBkKJ3DgXlZBUD0P
U69Klv0WRiDEQ1Le7sXHRuDWLpEQCIhtXeeawUetz9sVRSsJFHtKvTotfJy1
9mKlIoiAV/OFUyvWCbBx1tnB9UuZ/WY2iTQKAVoN39T4BDL3N9ur20QUdvjq
3z/zJyCtGeRl/E6hm9jT3TyfQEzaquHlORRa3/kM9DOWr6r72/kkhZoDT2/8
yfiYRX4i+xSFhdbaDVWMq/ysn/KLKHSyVrVtZWy9P9JzvoLCuOMB7v1+TL7G
OUvZSuHBGPtCtS+BwrIdW460UdiQ6HjzHuOyeFXgsg4K178+0lPN+Mak7I8d
KgpDB/o8TzDuDRu/pesvCm+5O7YuZyzUuwXq9BSy1jRkK+cRmF2XyPnDQOGT
7hfdtYznH9ZaZQMUVvumepQxDhYWXX1JKKzI/1ydynj3dh7n7VsKB0cc3vsz
Tl6Qar1mpvCTNTfEm/Hh0brueAsz/8WMC2zGBdVlmUNDFJ5zviYd9mH+fdA+
uuEjhc03dc0044pQ2aLkYQo9vkoSahnXCVrY/l8ovB2VmNXOWGGeah0ZoVC7
qc9Sz/g/UZtZHw==
       "]], LineBox[CompressedData["
1:eJwV0H0w1AkYB/CNJXkp6k7ed9cvbS1Kc72cDs9TMimEJHO6XixWRcS0M7L0
Im87RikmVEZIjTOWOtscSoVT3raiFxNdRU5+L3e2tbLay/3uj2e+8/nv+30E
4qTdsQYcDieIvf+z/JTYeF1Mvs9Bjb+8/ikDnYP8wAj+Ecgmp7lxrOe72s7x
+SdB0DPqwWdd/rCAZ8SXwylCefWiioEEb+mxL7wyULfs7zvez8Dg18PFU7xa
2D6aainoZWDh8KiQ4TWDpWzhncAuBip7KpIpXjdsun4tg2xlQNEgH05Y8wZc
omXJn6oYiIPnZXTKGMQIVqWVyhlIHF891qSYhOaW2BtDSQyYCrKE736cgvtb
apMvhDFw3rJXVHlIAzwjdaefJwPi4T0PDPtmIPGdo6u3IwPJf2SJk4Rz8H7L
nx2xBgzcPm4eZrPjX/BT7OtYTtJQKYsnPSI4iK+pyfJnNGRW6EOn6QXYOJ6S
daeZBs7ge7yXZohTPysFFjdoWHlCkrpHZISpGY21sgIaPmpL9prdN8acsYRq
v5M07Bw/mnEp2QTtprJ/8o2hYdfHQlcnJ1P8ZZJrkRVCA9khPvOk3gxLh5NP
v/GhYY3VK0ffgxb4xeuTWuZGgyloo0Y0i3FaLzxr5kDDdibyi3O4JYqINP2M
KQ1D7TELIt2s8Nhv8aV/zVGgzOs8wNda4Wm72cBzNAUSI+l7lWopRpveS8h7
S0F0ikxpfmUZGiiMJbbPKFgb56oKjPoOTdZIhuI7KHi61M1M6vk9VuX0vfC4
S0GrIvOqm6E1uru7ZAf/SoFsgSik7601fu0KHSTLKTAdSfNPbFqOvyvn6jZe
omD8pqC4It0GZzYU1TXmUlC8ypbbHG6LZUc5UQ3pFBRekTyO4tth0Nqioq4U
CiKL96vMJ+ywSwjd4iMUzG6r0VW02aPJIaFx/kEKxsa3prbnOqD9RMCOur0U
VHmvs++PckSuj+/wgSAK6rOlVnHuTmiaatGm20ZBbnh0gKHWCW0mH9RwvCnY
MFJZm9vPw+gkm+WV6ykoXX21vj+Aj/pb62uWuFNw+mFBaUAzHxfVB6kcXSgI
sg+v6VkhwCW+JnmFjhRsSXy8z0ouQGGES3CrNQUVDuIVfVoBvtlsIMpfQsGK
jluXd+1zxk/nPyw2WcTuc28XDbQ5o+vekNhBA/b/Gu7zbhGB6rNWz/31JIhv
f+bLLxC4LWJjVOQMCQmZYfqdFwlsk3j5ImtpWNNr8yICr0mTV61knaeVni+8
TODFQIlerSVB4an7WlJO4A/c+B45a92j+Vc36whsdRd/a54moXDAvKDzMYET
T+zaHTQkXKk+djinm8C5gUkTQ9bVJ1S+/r0EMpqXuyc/k3DXunCuV0Xg336G
U0rWI5HLDg++JFD5qCo4mLVwzNZ3dIzAYq+06kw1CR5NaU43xgmUPB2yP8J6
c/awLnaCwBxlQEkw60BheeMkSaBbcEKJA+uUeL6TWk2gZ6783t0pEtK9zuru
aAh8mSkLKmedbTH64oSW7SvL+HCOdWlDdf7sLIED3g1LQ1lXneHGtcwRqPj8
tmET67rQ2K3pegKNM+xCnFg3OXc5+nwjUBQWo+GybtOs1M3PEyinWsqof0j4
DwYhW3E=
       "]], LineBox[CompressedData["
1:eJwV0Hs01AkUB3DPakudqLWNPIafTEkpm1a13BudHkisJkUlI0bRg8PmmVYe
SWI3CaXxSmsdCqM9rJRHNB4jM9JutLXGZPP7/WrElNGU/e0f93zP5697v9ec
d+qHIC0NDQ1vZv7PwrO8OeuPZjgZaYwWyp7R0C5lu/uwj4GjnedEE+PZjubz
bHYMjLqbG+UyLnyYaabLToeiuXepHYzDHKNOfDTLB2Pb8oKKQRqkn0JyFGYV
MHUx1znoKQ1zh0Y4tFkDZGVkfWmW0FDcJQgnzUQQt6s2QbeXhqm8euuXl0Tg
0hcd299Dw3Z+t0yiEsGq2RtehYwp7Y/cRmkXXDvRlLWBsYOjx+b0tB4ockj0
DOim4ckdtRbnXR/4WNTpCUU0JHbZuK73l8IeZFVCBw3Vd9KHwtY+hzLF7x3T
zTTwoT+fipABz6qtwvUuDSflq2TC6jdQJhCufF5Ew3zzZM5LBwV0ZetEu2XR
cHlxt3XxkUk4sKvmwvGzNPCG9j7Q7vkAIweNNkhCaQh/lMw7xZmBwZG3c8IP
0FBzWs972a7PoGvl4ui5k+kbFzq+zkcDucMum17Y05AkUHtNUZqYLLBTDFjS
oCF9hU2x2njMSz1xaCkNVpHB0XutddGoRd0k1qJhVHlt34L7czAiQZF8/z0F
rvLjCb+Ez0PsShbV/EOBx2j2alPT+RhfcZ7t20/BeBvv3OOqBbg/iesd3UrB
Wv1BExf/hdie/aivoZaC+aAMGJ5chOGjx7L4ZRTsoH0/WnAX42PLmxLXqxT8
2XpU09dGHw0+TxUMp1JQf6H9MFupj08KWUMtMRQE60a9EosN8Cgv4fbbUAoC
I+Lq9QqW4AM/Hb8j/hTY8leL3QOW4pRbaFWgNwV9BjYLojZ9jS0+gtKm7RT8
UZ103UbbED2IxI24hYI4TWvPnheG2PlG5W9py9w3HLvzpPAbdMmwzcglKJCX
m+cI4pdhbYhSwGJRkLOSpdPAZaHhuMNX8xZRkF0Q3BnANsKMXvdxlTYFvjmH
xHpjRmj/RSw/PEPC9LZbKkHzciQ9K8McFCTI5M7RrWnGWFdpHzz7moQSx/XL
ewNM0I57vt75BQlVKVH6/DWmuKQ8soU/QEIaN9BNW2mKn88kfKfoJsF+uLgi
rdcMbTIf56pbSchbdb2q142Nkls3xM8aSUh8mJnn1sDGnv19ZxxrSdi9nHur
y9Icf5Xyh7R+I2HryU4//XRztBCE3UspIUFgzLPsUZrjyptmKfkFJFi23c71
8LNAY8XMu4ArJGSvabWWNFsg/GjnHX2JhOBJnX6RNYHsD/zkFSkk8Gres9Oz
CLzo9NfSmLMkhCV5q11/JtAkZ1uRH+Mob+EzvSsETmypXOvE+IIy6nJ2LoGp
/SF7tRlXb1J9ulZI4Cnn/LbMBBJULbOD5ZUEHhw7va40ntkv0cts7yTwhqfe
1iexJBSUnghJFRG47br+6jrGpZFil53dBEqkOstyGd8zzJ7pFhPYGlw348d4
2HdJiPQpgX+fWyEbiyGBI2O5jMgI3MDRRA3G64SxpmVyAh1Edftl0SRsThlS
BY0R2NiyO7KDsTun8O6bcQLFBhuFlxhHhLJNJyYI1Grp2cdiHP/9T6raSQK5
JdWp6jMkpCwcGYhUEqh/NbLhJeO8O6UZ09PMfxZWcsoZl5zT4TfOEDjQahSY
zrjSK8g5Xk1gyb9hxWGMhRYdJk5fCHxtWDyyh3HzpJVqdpbAcvk9q28Z/wfz
t5PO
       "]], LineBox[CompressedData["
1:eJwV1Xk4lN0bB/BBO5WlJEXDVCpKUm9Ruk+0IPW2EFEpEQqhFNGK19ZkrSxF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       "]], LineBox[CompressedData["
1:eJwV03k41FsYB3DbqAxlKKUYM36uQZaUnovKe5CypdzIE6VGod1yZzwtRGXJ
TUNdtxB3rjZNCy20SFLZlxGjlP2apmVyJrtIdc/94zzn+fz3ft/zPeyQiN9C
VZSUlLaR8/+ddzRE3XbnKSePZVWSYF0FVEpY3gGs3TBsPr+7XUcBP6vLT7BY
h+CZS+/oBuK8itNGNFYqdLyQB7gyFLBvFX//hFE2BEedYZvPUYDk267MQSMR
fHk27jaloYAZnf0cbPQI5C4Bl8tUFJBfL4z6bFQHYYp+9bFhDKNZJRa9aXXg
+caNFkW8JrxB2jpZB3p/Xd2MhzAMqE74l0rq4dhEPO3DIAb7VT6OqSmN8G9o
amSPAsPLomkVzpdm+MWp9Gm3HEN8vaWn7TYJUMPKP5hSDIVFqZ37rDuAsovj
XW/DINeRp3lyO4Bx+/N1V2JOjKeTWWYHzIuhLe6WYPhnJT1fOtkB2T8yZzCI
z9alhQVWdcIZr2NWsS0YYqTpQ2u3dMMKe7b6djEGIb3hBMOtD0ZR9ZUttRjC
oSV7IFoKDxMrxcwnGJQujpd2npLCzbk9ovoyDFlqBl31l6UgkM2siCGurQtj
il5LYTixJbf5MQYzv+mLoY7vwLn/s05iKYaPuzg3e5RloKK7pWbiAYY9Z+PK
X2a8h5a2k7RZ9zAckJlLiws/wctbD2pqRRg02ImcXvtBEObSFdZZGATaDRb5
20egfFbATfc/MIR0+j1VbRwH5e06ot1xGKKqEkMiOFNw70vf0vRoDHciNTcu
8PgOJkm0u6W7MeQf2StfEqCE4lW8jm7gYjgunPYdHVBG1fvfdm0NJPkkfajs
sCqiEsbj3fwwmPLCDvpZ0BD9y6uGTT4Y3o2d30R/oo4ig0OrN3tg8JTtiTsb
NRPJFxrl8lZj8HmXsZjJ1EAuBUsZ+oi8z4uQhNpbdNTrd7OduxKDNeO1oes2
LcQPsfQvsif5YIzbNTIbmeaaxx9fjmEtDpww9tdG9xuDKvyXYnjzfKdyoCUD
baq8NsyzwVBysjKYNcZA8z2qfMctMYTR+H1isQ4KXnZMEGWBYUf0kRLNHF3U
V579Hsww2IQvFntz5yI/nzVHVphiaNaxpPMd5iGtG0Zq1iYYHhcev2Cpqocc
B38N4RpjOKJssaGxWw/tp+eKTrHIfF2H3Q8Uz0deKh1Nb5kYZFfZmcLYBYj/
ZogXZIgh00xf7ZG/Plrb97eNZBGGjJywGi5rIbo2a/u2gwsxBGZuFWt+WIhG
rWrMl+tj+Lr6yqSwfBF6GFn09sN8DFKZy8HnKQYo3mG2eoUehourbBc1cQ2R
57Wi64J5GG4l8RnhVky0I3bd4NG5GFL8d3ipjjGRTWaEc4IuhuVd+aKUJiO0
pEHd+aAO6aP5hVtNXiy0XslemMYg/6fidJbXIxbiNTc6ZWljWLfI/0q9CRtF
xE8/uDsHg/OBmiBGKhsZ5x3ylc0m/TcIMWkcY6Ogb+3Jc4hNXhSc8wkyRlbi
j63rtUg+q+cWreXGqKAyvDtHk+x/RK2lzoJCqoUpH7vppI93hlmp6RTqECSz
7Yj3Hd847XmGQjfSwcGWmL+xuF3zTwq1CSJ8rYlPjvEFGecotETP7oQZcaHD
5LfzeRTaauU9YEA8+ezn66s3KCQrE7bRiDNaNU9X1lAo2Vb7e7sGhpxL+3cl
11HI8vdo6hXxJZ7Y1b2BQkft3D1bie/rZUw1iCmUVbsuu5G4K1B3l+QVhXoc
ylc+I+ZI9V37pRRaHWOQfZ14SfFh5mUZheIVouoCYsekzsnQDxQysxONXib2
5uTd/iSnUGjZtK+QOHovizk0RKGc1lFGJnHsymOTd0coZF6r5XqGOEmrv403
RqEVJed5AuKsokunvn6lUAr9x5uTxBcT1MJLp8h+oIOeTHzDN9QldppCLGUO
nCAuNq42dPpBocjl76ITiMtHTCd//qSQ1XNGQRzxfyB+2bU=
       "]], LineBox[CompressedData["
1:eJwV0ns01GkYB/CRSyWK2my6MDM/azQhdbZOKp4ntNlBJbdDbcsQFo3YpI0t
JbcK41JCjp102S5EjXWolPtmGq203caeOsZU6J3Vzg4Nyr77x3Oe8/nv+33O
wxHG79gzg8Vi+dD5f1ccFhqtijjpOnXBtonvqIb2PrZ3EPsHSLS5KRtzUMN0
Z3M6m/0TFMwdqW2lrrifa23IzgHjcoEumDrOJWnvuHUpZL3LPZ1pr4a+yeji
UesroC1pLnrOV8NMxQCPWDdCXqTgczhPDZLuyoQR6wcgPWDXs4athpobOYo4
x5cwMdu9wNFMDVHQW/o+UQndDXXcA3pqEKmWK6U1QxA+I8esQUPAmHOc92rd
KMxbm3u1XUUgz0zGl4Rq4CuPeu2tFwSECv97+g/HoMuoc2OVnEBCx3FhPG8C
hvX6o++3EqjbZ+K36NtP8OpIY6ewkYAkJXbYKYiF3Ru80vRrCRyrnPL9970e
pjdJL6ovE2D1vcY7h/RR0jIuKfqFgO3+yIP+fEPclP/q2opSAoPaksA5d41w
48w+yb1CAgJVzM+FCbNwdQev0+MUga2D4hVWVsYot0ziBmcSGG4Tpv1ePQfd
B+PnrjxKwNH86TL3700xrzxd/ncK7QfasH7NXLxhXXcnKJnAFhIyzg0wwx+H
L5RdTSTwvDVCL8TeHI2M62pDRATqs9t3s7XmGO1j75UfQyDSMOl1T8983BnS
JLkeSSA8MaXepGwBZptyzrmGE1gZtaLHO+wLLDmlqDYNJfBovv2cJOeFGGP8
WtG+i8DtmmPl9voWqJwtalYEE0jR429/+JcFvtscuLQ/kObrP+Qpkn6JLVHp
LDN/AqpLnOLK1EU4dPvNuiJfAsV2lgaNAZYIayN2sLYREJdFdoWxF+P1m5cN
6r0JhBR/12PydjFe8Qs5nysg8NHjoq6yeQlm2+5TbvckoFS5HWzNWoqn5U8M
fb8hcN5l1RJ52DLcdIlj5+JBoDojyTzKwQpvJbc9D3UjkBUQ7qWvtcL3v8b0
ViKBNf2SK1lya6wI4tbJXAmcXV5eLfdiY6Cdp5jnQuDI/dyzXo1slJVuyU7Y
QMBnScDFbhsOJsu6xvqcCWwSde00z+FgavAJi9B1BCqXCm0eajl4nGWyXrGW
gE3b5TNbd3KxobxhInUN7efQyn/czEWXwqFpp6/p/TUGvQ/4DDJuzuonq+k/
1v3DzslnMLUjQFO2ikDcMb8pQQGDohObxaepk/ykz0yKGDy3fNJBTJ2tTcoT
n2HQ36chNoO6xlk3WVLBoOSkaDSeWtcy/fTSNQbHF0qtNlOLH5vktncxaBGW
bDrqRKCsam905gMGBYLe1mHqqv097p4yBptejBxUUf9mIZ6Q9TD4Zovw7Uvq
/pAF0X1/MvjHyDZ5BzVPaek+oGTwRLfx3XJqJ+khqwsqBvVm7Tp8hnp9hkK3
5y2DluGxWEDtzauoHRpmsKK3rTOTOjGWbfXhA+3vGNSfQJ268ajupobBqrHi
qjjqDNOBJ/u1DDacy4+Noj57o+rkx48MRgw0fdpFfT7NIKppgsHDq0e6gqiv
+e5xS51icGXLs8Id1FJu5zLXzwz2Rqbt9qFu1tjqpqcZfDQ5yPek/g+q01Hp

       "]], LineBox[CompressedData["
1:eJwV0Hs01GkYB/CZFZPbatRONJmLnxAqznYhy/OQPYSstpTVZTNyCakwm6iU
JanVTjVH0SJJZR2j1qjtRlHIZZwS7Ua7TtJseH+H1VSmi333j+c85/PX9/k+
UtmOb6M/43A4q+j8v4v3y4zcth717j6q9BQsY+FetyR4vWQbRIeEDRtQTzXX
/yiR7IHNKaLs8aUsFN/JFxtK8mCWY/ieDupEL/n2t+JCeK/2STpI3f0+Tjkm
rgT7VuOz2iUs8PqeOxDxdXBP8Ta5sJiFsrbSXSPiB5C02apo3I0FVU1eX+LC
pzCiibOPc2YhFh4WjiYPAu/ppbd37VhIGpo/qFa9gpBlu2t1NiyYSLMd/nYf
A39hbleKgIVjM9qdyrZMgOi2nelOCxZkfWsbDDregJDnWzvMY2HX/WzZDgc9
hB/hL6jmsHBlp9kaq5UfYVFipp9AT6AsI2HYdT0HH/oU+M2bIJBV+mH161Eu
hvHse/8aJcDpHsBb6QY476eggeGXBOxTY9LWOhliXc/LEdUAgRe6U+tMbxuh
pd4pc2YfgcCh+H0ndk3HzN9Fjh49BEJeKJxFIhOMLHQzr+0iMNwkO9BabYrc
tI8Jt9sILOT32qz43hw3WW20VdwnYAK6yP6Jz/Es1g69ukPAn0S8tQ2bgenc
Ah7/FoE/GrdyI1z42HZLPn3/NQJ1h+9tluj4GO4R9TqylkCMoXxAo7HEpMBH
AbNrCEQlZ9SZFc3EUc5je88qAotinTXBkbNw7M8OofIigS5LF1O5xxc4fVxX
d7ecwE1V1hkXAwHuk27Rhp4lkMF1Cu14JkDjxC8brv1C7+tPD0hSz0ajzF7V
N4UEhi5IlaV7rbBLGtDkVUBA6Wg97XqYNequZZkanSSgKIppiZTMwWPnntwQ
KQhEKDdpzLRzkDPQr9+YT+CdX8Vkab0QK/Xh6t1HCAwO+aY15s5F/+qVVk9z
CZzzchN2RtqgYZOnWJhDoDpHzo9dIMJLdgWBpVkEcsOiggx0Iqxwb4jyPUBg
SX9ZZW6nGHXbnE2a9xE4Pf9MdWeQBNft6BnJySCQeSf/dNB1CZpxuxwd9xBY
JQyraLOTok/WeLz2BwI+SS0b+HlS5HZGd/SnEiidK7Pr0EnRr8pyydVkAnZN
FwtCNtjiKbFBdeNO2m9Bo9Ojelu0LekyeJlE/z8x7eEDJwaNQ5K1bCIB2ZV/
JXk/M+hqrBTaJxBIzFrzIfA4g/NejHmLqOVr1E/MTjI4y8I9SkB9WCc/pihg
sKEuW2VErfKYfH+qmMFg1jJUG09g8u5U74UqBlviBuovUSsemeXfa2HwH0eX
QBfqovLtcYceMGh44tARO+ryVM2KgHYGU2XN7XOprwoU+nYNg/ElulBz6v6I
mXHdPQweDvg8ht1GwGHQesXzQZpXY3TzMrWrOl10fojBN2kVxpXUy3P6JqO1
DK70dfiujDrYofjyq2EGrT279cepkxMkovFxBpsKWwNSqPd+dXDytwnaZ3FG
SQJ1jvnzx6k6Bn8tsdBFUZ+uKT/67h2D2f7Pzq+lPndgWuwNPYMXlws+BVNX
rY723fuBQZto1/CvqdW2zTbenxi0KnOu9aKun7CfnJpisLOVZ7GU+j8FIEYh

       "]], LineBox[CompressedData["
1:eJwV0Hs01GkYB/BhUJgssS2lmeEnNom0FSo9L1blklNJHF1NuVRiiT0a2qgY
drqMKMpKFJXr6gztVKQhGoxr2w0pl0TenyyTS8q+/fGc7/n89/0+RrzQ7f7K
DAbDk9z3zPyDp2Z9ULhhcHtWi40dDTXtXHdv7iHwsFCSLSeera08zeUehyWD
juUUcWbVOY4qNwl2Ol8O/YE42D7y6ATnCpTFNux9b0tD+5eg1E+cO7D51WO7
i8RzOnrMMEcC+yWGK3tsaMiuzwr7yJGB984tQv81NIynl5l3n5VBSnK9mg/x
xsCG3rYpGRgU745yJR5mTnjdb68Hq8oReytiW3uPtUmCRsjt5+yYXE1DS8mM
stlIMxxyVpQnEp+st3C13tcOzokBeTmraCguSeoItnwNn11uJlSspCEQWq8M
h/dCX8oS6QdLGkL6l/aKiwehf/KDzRtzGjSMzph1234C61QXhYMpDee1G8yz
94/BtCc/ptmIBl7HjkfMxs9QZ7unq8+QhrAnZ3ihZtPwsZzvqqJPQ+lvLE99
l69gc3fkVoQu2Rt9ZGiFNwPdET5PSNCi4VTWzLbxYSW0V/n0OoU6DYz2t+gh
n4kMC4QmAlUaTCMConaYq6IWdUayjEFDnyJtp2aFGnqtnOYfOoPBtf/wiYth
c5Gj4fDv8gkMHn2iZWy2BjJIdi3yGcMwVM2LfVqkiVI/jFzaOILBUuf5Yqd9
8xAlMakYH8KgAQq/zjEt5MQObGQOYNiEfSeMvbSRtfP4lxc9GF5KDyr5Wuig
YwNxHq/eYChLrNnLVeigoLgutTUdGAJUI982Nc1H6trru3e/wHAgPLqMdVUX
1YRoPelox2AVuKzJ3U8PFTo8sIxrwdA830Iz0u5HdJvVnT/eiOFB8akMC+YC
lOrR1SuRYYhWMt/a2LUALTM4/svWWtKvk785RPwT6j7QImBVY+jPM0rNitFH
glaek14VhtSfDVQkXgaoObTA+NNDDKKrAXV+3IUoZfSztt59DL6pe5pYAwtR
j+6Ip/c9DJO/5k5lVS5CuvILvmFiDL39jlFSgSESWax7KS/FkGNvvUjutxid
KBVvYpZgKIqP1AlczkbiI4wVUYUYBF4H3JgKNvpafeHPufkYVndm3xHIOWhI
exUz4haG9KUZRXI3Lnp004u1MBfDyapz6W4SLsosDdTMzMGwZZFXbr2JETL9
y7dw7XUMDiF1u3SSjJDrxiB3rWsYsgx5Jo0KI2QfWyetysBgUn3rsscuY3R4
suNd3hWyb7nUvK3SGOmrh4/lpJH/j6m0yswptPRekfDkJQy80v+4SRcolGcl
/yZMwRB8ynPGNZlCTpr79p8mjvQUv2ClUCijVSrlEycqIs+LLlOosGQ26RBx
sd3Ul7RMCgXnuxlvIp56PPs8r4BCzDA9vjKxqI11rqaOQnTb7SfHL2K4euNo
UIKMQrZ5jg5hxDcimpw2N1BIpMivCCIuXyCabmiiUGnG+3+8iTt9dYPa/6XQ
7nlzJKuJzXoNnHp6KeTS+qx7NBnDCjGffbP/ex+XoEHitfEdU/4DFJr1EY6+
JXY3y/x7cIhC0usRai3E4Ue47NFRCp3V7bQrJo5ZHzd1d4z08RE/zSWOn9fz
LEJBIbnIxyeTOL3khnBykkLx4Sr8s8Q5sSqB96cppP9ek3WGuGCbv2PMDIWi
et5ciyYWG9cu3vCNQu/cT6w8Rlw5Zjo1O0uhbI2B2sPE/wM2WI5C
       "]], LineBox[CompressedData["
1:eJwV1Wk4VV0YBuAT0kDGUhQORxQipaTiXSWUSipTGkTGTyiRiJCEZEylZKYi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       "]], LineBox[CompressedData["
1:eJwVz2s41GkYx3HH7DqkIUVihr81ETa1IhfuJ3JoyGZl29RWJqcK4cJWtJVj
1jE7RWpCllY5VWxLoZVyJkalQcmwlXr+OU2MxD774r7u6/Pu99XjHvvBT0ZK
SmoPuf8//1fuMnPfFDt31/3V+c40NAlYbrtZhyHkmFfpIeKlx/VxLNYJCLYt
+dOQmP8gjSnPSoa6t4zqUicagmwjg2eZl2B6ydKixpEGwedA3gSzBHaURMT2
OdCgMDDCxswaCLPXaNVENBS05YW9Z7bCSKla1kcrGmZyqo1fpbaCeoNrzh1i
p4B2Ua+kFRrmI5p+If4gO+tVK2iD6wL9DCliK1t36+SkDojge06qW9LwpGJB
hv2xGzbF9C9utaDhdJsJx/yAANRtXl+7Z05DeUXyQJCZEOzSU3sN1tMwrjae
yvERwikXu/diYxrYURy7dTwhTBgOGTQT59soFYgkQrgZfWX+MHFWa6q/96MB
qOOZmN0yoiFKlDHpvG8IYhSdixzX0ZCn1B7HcBwGgdkdl8RvaAiAnksfwkWg
IW9S68OiIWTMSFRV/g58s783j19Ng6JePPuV1QSodC92BKnSkL6i3bjg4DTk
BnHc5b+mgTuwq0G24xNsy+wxWilLQ9ijeO4x9jwkbHroorqI4Vaosqfm9i8Q
FSgKnZNgKIg+Or5htxQK89jJY3zCEJu34DHzQRop8usnn09hkBIMo/snZVHw
5+hJmQkMhhH+x3cZyyN33FaOMIZRcfaPSnXL0EUdhZ/ocQycsSOnssK+Qg35
oZXFbzG4j2au19VVRPlH7Vuu/oth/CH3TEuZElIP99soGsVgxnim43BABW2a
T8wyEmFQBLHP4PRyZH+nh1X+GoMz9p7V91qBlm/XSts4jKG/0Vfa24SB9jHM
OcKXGKrPNe1niRlozM+3pWIIg7985HBXlxqyrwx2ix3EcCg8ulo5Vx0dNE65
ED2A4duA9V1uPitR8Wj8TLIQQ7eaiVLkFg20OZQjz3uB4V557GUT2VXI8Wre
/vv9GKKljXd2DK1CgfdaAoafk32DJ11CqlYjfYcXZhrEY8V6vLwYTbQyVEOZ
+wwDb52WXI2XFlIKqLG68RRDZq5/sw9rDVJxkpQoEHvzfu5SfrMGzTBZBqF9
GOa2FUny6rVRp6+NUCDAIBqzP96YtBY5Td3V2U58zdZcu9NHBzku1o3U9GIo
S4hkBJjqIsulxEBr4iSvQ66yYl10427328YeDBaDBSVJnUw0Pqkl70ycY3S5
rNOVhRovJAb3P8Fw+kFajmsNC0nrO9z1I96h7VXUZqCHjrg9Fku6MWwNad7L
SNZDUXo98ZeI89ZyDTrEeqjUfwPLgtjg4fWL7nv10YTzVs2BLtJn2mjcW6+P
RAp/ayUS+0/L9bQaU6i31mi3KTH31hQrOYNCcuxXvKFODEGxnguc8xTyM/rO
cpA40rPqufLvFPLAD14Iic+JI9MzL1IoM/4ss5+4fIvkczafQk0x/LJeYsk/
S8+Kb1KoQsair5k4s1c5ramZQjbViZzbxLmFwYGJrRRyDaqdriQujOhycGmn
ULO9Ab+C+K9VmfPtXRR6uSZ3opR40Fs9UPCUQosMldzrxGyRlsOIiELnvsjN
XiHeUHVS948xCqlW8QovE1snDEj83lBIvWHPzlxiNza/8t04hbzy425kE4cf
ZelOTlLI09zLJ4s4xuas5PY0hdRM01XPEyeojPRFiEmv1kJdBnFORWHK3ByF
Us9HaacRXzsjF1A7T6Faubi2FOKbHn72MQukf3PTid+Iq/Qf69gtUoijbW2U
TFw/bShZWqLQVNFofxLxf9hwxlg=
       "]], LineBox[CompressedData["
1:eJwVz3881HccB3DclcVl6Zb5kXPnK0ZXtMfWsqn3u7KSXylZPa5ULj8qP4rc
Y0k/JMKOaEliZir20M01Yks1NeRHfjS0skhybq3L5ytd51fGPvvj9Xg9nv+9
XiLpgc0hBnp6ej40/3fBcensZcHyVeI510du+LNQ3yX03ircB5sP5qUXUc80
1JwSCuOg47tA/jfUBXczbGYJ08BJXqeWUEeslEWO2VyE8lxS8m4zC13v9ma/
timFbeVlfa7Uhj0DDsSmGgoM3cwUfiwU3S+MfmXTDFnq1IZIHxaU19J6IpY+
gWKt4wnndSyEQcfFoRgVdI6m1ycBC1FqR1Wl8iVU1/96Y70rC0aiJIdnK15D
n3ix4+uPWTgzr8WpaLcWdNlKTvQSFqQ9W+5wWkfBYLd/+LADC9H3kqQHHCbB
37DihM6WhfKDPH/zDf9CprxKpRDQPfHhGpeteuhjrzTebclCYuHUprdD+rjA
pCnuqhkLel39ePsIB40eZK/cwGfBPjb08BanWejk0i18/j4Lg7oLXxn/Nhu5
rUK7IR4Lnur9x76Nfg+3l+7/fngOC76DWYsFAiMcj+mL+8SQBU2dNKGpzBhd
1itFnVwWlpo+sl67ay4G/rBDHmJA/4EuqFdrgt6tjQ++1GNhPZGM2QbMw6sN
P41ZTRPorg3Wl4hNcThh9quFUwSqUut3CnWmuCKzXyuZJBA6S9bf3j4fRx+6
vc0YJ7AnJr6Kl8fHL+ryWkdHCTiHLW73DvoAvWyV9+N1BB7MFxvLXBegkp+R
pNMSuKVMzBdzzDC5sTkx/w2BeH0nv9anZujcpK9ePkLAqPeIR1Tlh5iwTczX
DBNQl4iyC4+aY3FNnUEtSyD7IwtudYAF8ixK0jMJgay80MYgoSXCvZuex4cI
SLID23kvLHGHm8HVY68IjLsXTxTWWKGJ2NfgkIaASr3mcG3KQkx5PFyY9JLA
pZXLrNqCrNEkxONJ+j8EypJlpmFLBMg/p1ErXxBICdjjxdEJcEajvfj0bwKf
9haVprTZ4HSUYhuHOtcxv6zNS4i3o1LCQU3gxN2MXK9qIVq1+JgfGiTgYxVQ
fN9OhBvlO2wrVARWRzVuN00ToednwTlc6sKFUrtWnQhrixfxNw4QsKv7Mcd3
uy1aXvHLUDyn/5bUOnXW2OLynY4p86hDtdyOZicGwxad10X2E5CWvxGmZTJ4
nu3z6HlGICLRf8rzLINN8Tn13dQy/8rHvHMMLhgrxUfUqTrZmawcBpv3Dbp2
UCtdJ95dKGDQzLrYpZF64veZRyUKBs9Wuztfp87q5GXUNzKY/5fsoJw673Lk
3tPNDD5TJI+lUl+ObV/r0cJgFXf4+GnqX8yyJlvaGUyfbjtzkrpXwt/b9SeD
PpxbFV9TO6gs1g6oGJSo0TiY2qXyiOCKmsFDm/ovBFF/ntwzEfKCwa3m3Xa7
qL0dCn5+qWHQPeIPkFDHhAsFIyMMiu0H4vyoj7qdnKjQMqgLWjPHlzp57sDD
WB2DucGTuV7Uudcuy8fHGeyMja5eR30pgRt2c5LBskAXT3dqxaaQNUenGOyv
W9ezmrrStsF61TSDgvOVEUBdo7WfmJlh0PxO3LQb9X//I2ZJ
       "]], LineBox[CompressedData["
1:eJwVz3lM03cYBvAioMihVhA5e/BDsIeo4IwQ4X2HGhXQoXJEjHNFTq1ySI0C
2xB0QLwQCHKmQzxm0CpayXBYHV5DSjeow4OaEaA4C/0O7BALKPvujydPPv89
Dz8+bXviLBaLtYXm/677Ln72yoSTIa8DyFRrLIFHWl5ELC8Vbjn5qpTUM09U
BTzeUVi8f/jwNeq6B6e51rxiaPSLUddQS4NlBya4VRDxXmqTTa2dSikf5V4F
iyx37SrqOb39vkZuC8z1fOV6MYZA/TN5xjC3HfJ7mhOk0QQUN4p7pX6vwdB1
qCx7O4Fk6KoayRwAyR4Pl5yvCBzUCwaUindg6H9+IzWCgC3/uO9fa0Yhe5+P
1HozgTMLOoT135igc7Uk/NUGAvG9Ufct1R9gYc77nzJCCWQ8Ph6f5jsJvhd1
lwVAoCndfofL5k9wtNE/UbyW7snZb1gRy8Lq1Pu51oEE8uXT2/4dscBihUOs
aDUBlrYPW7MtUTPcwj4cQMAnK+lIlNAak05lpspXEBgcPx9jd282plitCmP7
EQjT7/u2NMMG7dP3/JMoIrB1sETE4dhi8VTckb6lBAwP4/N+u26H6kNFBbU+
BPzYPZ7r9jjgRCO/KcSb/oNxic40DysEiWs4XgQ2GuMmvKIXYMNRTsAQl8DL
tgSLODEbtZG31Z2eBO4UPfqaN87G9GP+pcPuBJKsZX0azULMsKlQmFwJ7M3M
uWNf7YjBFk6Bfi4ElieLNBESJ3yjsNHnORP4faHYTha4CG3rR/fddyLwiyK/
RmzpjPxrf58VOhLIsRBGqt8444YOw1g+m+7TZW86qFyMedJLt8fmE9Bf5pfL
c10wRdY2UjiPQPlSV6uWaFcU+cvL7B0IlFQnPZXw3DBSZHBrtiMQV75bY//W
DScODWvSbQl8XH/JLFe5o4HZNuM2l8CAPvRIW6EHhnWzPIbmELgQvNK9U+KJ
HscqlfWzCVw/IWMnL+NgX5FanGtNoDB6b7jlOAcDM/21CVYEvtDVXy3s5GLs
SMSrEEsClYKa653hPKzdGFWzahaB7x+crgxv4WHYVFaphwWBLe7Rl55587FW
J3jDZhH48uDTXexiPi7aNejOmzGC3CPeWz3Ox65CSQz/sxG8H16p2LrLCwdf
KrhBn4xQsqxN2K3ywmYfSdruaSMkmay62oUMbheWp2VNGSG+6T2v+CyDIrPV
8x8njSDN3zEddo7BjVVnltdRy3YoX9iXMXju54KTVdRF47IzJRUMysQ315dS
KwLNU+frGCwfnd9aQG3+dabnciOD95b3qpKoS7rtTz96yqBXHuO0jLq64UDK
D+0MBkRO5gqoG7I06zZ1MKhOCBpaQt3sXDLZoWEweNGHFg61Ls4xRfsng7VX
diYtoPYdcF3XP8BgbGhbt8lshBXKbM5FPYNl3ktCR6mDTvSaE98y2BQw2jRC
HeFbd/OdgUFhmapUT525n8cZG2OQnxm08wV17tpj5lsmBqN6dB1a6hMO/c+z
xhmc1g2F/EFdeaPh5MePDLaeWunTTn0hzyr57iSDCY6Z1Y+pG7clhuZOM1g/
4Tq/jVrp9cQz5DODm5cKjquoVSYf88wMg+Jyufku9X9UA1G9
       "]], LineBox[CompressedData["
1:eJwV03s01GkYB3BCF1GGcgkzv/GTqYncKrL0PNJFbsUYOtO6VoaEElsutbFJ
tKTNKV0kKp0Kbe3onFpJUozL2NJliy6HbAd5o2lyibXv/vGc53z+e77PeR5+
ZELA9mlqamoiWv/34gOR0+23HV3lWCSLubWZQEMH4xPMxIBD+Mt/KqmnHtf+
wjApMLJ3JPQqdXFdHk+LyYFxu7V4gXqnW3LcCO80WLyqaMyj7vgeXTjEuwr3
UnyIlHpGZ7dgkHcHmgZra42pS5tLdg/w5FAetiw9LpjA16Jq4btf5dDmZCqV
Uq+TtvQ8HZNDRc4R3wjqTxoj4rsdzeBvp6MrpnZ283PJyW6FYalvsCv1Xzcm
pgk+t0NsSKC5NvXPzdZe9mEdMCh2P1EWRKDqRk7nzqWv4YvDhmVNYgJSeHL6
U2IPaBsMHZ0TSCC+d3GPrKoPzjsej3ENIKDNPyR45zwEypo6r0WbCOTrtQhL
w5VQsWKy0sqPQGRn4H2N1m8wzTU/jXgT2P3oUGSCYBxE9Wvi7m4gcHOXjsh4
wySkBOwsvLae5k2L7bcLVsM/zl+5kLCWQGbJhP/XT+pofE6+MdSDgFrHe6xJ
1UCRr/L0j+4ErJKi9gUKtfD6G/HhFUDgg+pU0Ox709F/udjGzY2AV++O/b/t
nomHh4w+W/xAwO9DwRIuVxtnela/NFtJoP9h5MGmytn46rXK08OJwFLOC3OP
MF0UTrXv8VlO84Eqoks5B33zN8dkOBJYPygZsRDroVTh7HvWnsDf9dvUJdYc
LF+UvlduS6D6SEMoo+JgnGLGTP5SAlFaye8VCn3cxk60hlkT2JqYVq1zxgAb
BBkZj4UEbKVLFD4R87BiQPfUqsUE2vWtZyevnI+fHU9UlggI/FmVedZawxAT
tBz6FloRSFMXbmp9Y4hcp9uHTlrS+bpSPeNlRgi2UQHGLIHecn5hSboxXjuQ
m1TDJ1C4yETzjtgE36SWb/FhCBSciWqMYBbgUOSkySSXgKQwRKHzcQGmvAvW
qzEnMLrm8lhJrSmWSjhTUjMCPb2r99Vnm+GjzktrHEwJlLnZm7ZFmGOUNi+j
34RAZVYyR2rDxcCe8Hv3jQlki7d6a6i4qKmZvLfUiMDyrtKr2W08lNWJBImG
BIoWn61s82ZwYVduWch8en91eUXedxgc1ecOOM8j4Gsqvtxsycf+8zHBjAEB
9/jGLZwcPg607jjI6BMoMYu0bFXx8baLUMThELB8eOWk3xYLfGXT98xEj+az
qRc+rbVAPa/nIdZz6f6Vmk/kQhaP7+8NsptD7/HmFybnGItdjQPrvHTpP2aK
JryOs5jVfsFvHXWySPZS5wSL3R7VQaupj6iS8wtOsjjffULqQl21cuz7qWIW
MxzUjwmpxx5MvSi/zqIj00W0qQue6uQ1NLI4d/JnVYsOgTMX46IPy1kMqdae
1UR9MUnh4dnCYv8mpVkD9W3DgvEWBYtm6m/X1lB3SQyiO56zuH7Y6FwFtaDH
xKO7h8XYRANJHrWdLJV7qZfFzMqf9uRQu2R1jm3/yOLbWU55WdQ+guLf+/pZ
5H1TPNhPnRjLcIeHWYzxltjGU6e7ZozdUrJoB5e9d1Bn6XY/S1Kx+FHpEx1F
XXTj4tHRURbZXbfKQqnLDmpK746zeIW3q05Cfd1/++r0CTpveO7bIGqZxWPz
Vf+ymLtQfTKAulZpNTY1xaJy6zPTjdT/AcdcZWM=
       "]], LineBox[CompressedData["
1:eJwV1Hk81PkfB3DRSRfa2ZJjNG1TRHQTXp+li8puodoOopCSYlPJkU5JSqKk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       "]], LineBox[CompressedData["
1:eJwV1Gk4FHoDBXBMpFBKVBLDkND6VrdkOX8pxZVbspeUyqSiV6WyLymplCSJ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       "]], LineBox[CompressedData["
1:eJwVzXs81PkCxnG3Li+X3MpSLjN+NLGSsoVWnu+iRJezbrUJRaEixSFJSlJD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       "]], LineBox[CompressedData["
1:eJwVzWs0lAkcx/FB2mIqk8u6zsXjGI1LRG1Z+f/RtmlQki26aKZQhNzOEdot
uWa1o5BIlsLpiFKq016sSiRi8cwwxmUyZiXTRZrNKOzsi9/5ns+rH4sfsytU
k0Kh+Kr3f8t+5C91OpLrvmF/6YMgZwW09DF99jCPQe9Y7AaVgwIWW5vOMpkn
YflJrm4hRwFlzXkMbWYO7D8hevWIpYDjmxOjPjEuw06lW8f0KgX0fT5a8J5x
A6Tn+qsbp6bgK8kY+w3jIUQwjF2NKqag4nl57BSjHVCzWf+s9hTU38qRHHcY
hNCrNteVNZMQDj2XFXEyWFHfUBkc9gqi5WtkjfWTEGOYpEVzmwAdVjp7dON7
iE9cHZhP+wfO63VwKg7NwIZj4ig9AznwJbv/0ur8Fy6FmGq+MxuH2Kfp/Bj2
HAR7Z4b4esig4QQ1wNh7Hipjdo3n5oxBRUrka8c9FFSySepb4UtIK//i/1Gh
gd+WnJWVub8ESp8U/0jWwmQ/gxbxAylYJ4Ql7eZoY1ChQ/wqZymMKy/9oPvn
UrzLDvpUmj4K2+URpy7ELsMTxSHdpVUj4DcusKXTdXAiI/zv0eFheP2Ef/pZ
nS6uXRjJa183DA40kYVXyArEyMwaZdYQ6ICSNzSzEhPsew2lHyXw/ZvgT5aB
epi7b69LNk8CA4+PaATb0bBE0+Fzm2QQ7mW3HGQqaXh1rsr9SfgghGknSru6
VqNh8a6Fwg9iOByXco9aoo+iIA3RmZ/FsDbctsuHZ4B1i+Zbax3E0L3aTjdx
kyEGiYc9XbsH4Pf6tFI7LSOMTaF3XEkZgBQNzs7OYSOsNKBkHrMeAJ2h5G3R
jV9jxCivp72/H+TVrILyVGOclkkp+Rf6ocDGZMnDQBOM1ttysJzbD4KSsDYe
0xR79LP2zlL7IbjgQBd1whRdHeerqnpFMLulSlXeZIaXNaJzLxSJQCb3THqc
ZY5hv0Z2+/NEULnZyewFzwLn30Sci+SIoC4jkRZuT8dFplynQiWErMDDXC0l
HbPtDsd97BDC+qGKG1kvGDh/ajy+9ooQiteU1r3gMnG/R5FJRpwQfmrOK+Y+
ZCKryPnm0FYh+JoFVj23YmEyzdxt0kIIHtFt+2g5LPTTcDq9Q0VCuTnfqlPJ
QoG1qZ1XHwlWT2qK/PZZon5rjYFjAwkC+8ec3iZLdCd981flkxA2s6SnnUPg
Snvuy7wYEvgNH5g5vxA4yPZblupPwvG0gC/b8wlMOjXiPbuThMSAxn7qRQI/
UDkVCWpnKxPPC4oIlFcNC6J2kFC/SfX5UhmBCfctEw75kqB6tCiqriXQ82LO
d9u91f+91LyWNgJJW5939h4klFyLOprZTqBYQB+5iSRcS+jy2tZBoPVT7TFb
te8bCeY6ugi86bZgwwEShoL1j/YJCTy3Zvld9mYS2DITrzEZgekBpnetN5Hg
2JhMvy4nMFomfl+9kQTXDIkqdILA+DMHvNhq+7DLbk++JnDvuyvWNt+QEBfJ
pE9PE1jIiJVz1pOQ6nZGdWeGwB2VT5/VupCQsWKMTFASaBN5v9lO7eJb13Jn
ZwmcWxb01sGZhMrTS8J/myOwdYFidXsdCbX+oZ6pXwjkpjpFO6ndaNlq4b5A
YE+hvPOOEwlNM9aqxUUCXXjG6KL2f5yiQ10=
       "]], LineBox[CompressedData["
1:eJwVzWs0lAkcx3GFLi5F2gqZGZ6KZsoy3Van5v8v7FaoxNBhS6Zc2sots8kt
JkJtmjaLOHZiyBbGyrQn2mxFRS7l+mBGYWYojVaYZVzW2he/8z2fVz9zTvAR
v4UaGhou8/u/ObGcRbanrrEKt7g1WD1SQk0rzdmTdhoybK7cK36ohLmXVZdp
tIuQ+y2TaV2uhJyn16natBRoGzD2pIuUcHY399wE9Ta4/8ryX5yvhNbpwLQR
6j3w32/pePSGEhZL+i2HqRUQ5Z2dHHpKCbmvBaGfqHXQp7Oz/+hSJYhKUyRn
rbshSY82KGB+ggBovq0Mk8HdE10BjceHIEixUSYWfQRhRSC77KePoGOeYPn+
mxF4N7T9OKP4A6Qa1NNzT4zBp/baJ3F9g8CRuP+l2fAPBH0pMmtZPgihLxI4
wZZT8OzJxFFXlwEoC9FzW7N/FtyVKdyIPAXkRp0ZsvHUwObdXXcqx+XAE8y4
jisX4E3Zs8Klx+Sg0dqLf0ZqYgxZaPG4WQYbwv0j3OnaGD4wcO2ygwzkqgwP
3SeLkCd8mhtR1w8HFD/E/By6BC/E68d+du6Hg3I+g0LRwbj707Ej3X0wVM2J
qy3Rxc9a3gWhF/rA2rDDzN5HH98wskw5K/pAB1S+0rFlyGR0B89W9MJ3w14T
FmwDJI7ZC6xO9ELn81MLvDYZYtvovwlx+r3wMLnmOE1liGFU3lt5ynvw1+b2
NjWtwPJlXiWPVO/gZFjUQ70sIxRPxPCPnH8HXwcwmpx9V+K2Pl1dn6keeLNi
ky7X7iscHXdc4xzbA49FvOxNmqtQ7uozVGHQA1EL6IcbelbhaQNfknVHCjrS
yH1B4tXInp0sFO+QguKueZogeg2ma059WCmRQJqVsVYF2xg1cy4+So+SAD/L
/5UvzQTzHSarazdIwCvtWJPeoAkKJCUdoWQ3TDoUqAVVpuget77ULbEbZIq9
Ec+T1uKPVy+FbNnVDXm7bU0bfc1QWBxCxIx0QUki1zBgMwUVpm4mw8VdkMQ+
6aSpouDi2NqwsHNdsE2aey+pkYo+Bf3xsYwuyNyYXdLoRMPMxz1G8SOdcOnp
9UynChrSXeJHtpZ3gospu+D1OnPMPzT9S9LFTtgT9MrbMMUcTehvXdodO0Gw
lrOuQWWO2ZVXvUeXd8K66sL0g94WaLk9mM5/TwJ/83N6S5UF3pT4XukoI8F/
TKu5jk7gmahDhA6PBE7ZKC3lBoGz2tL7ep4knOW5zRy4SaAN3Yhy2IMErpuY
1LtFYOKSMtEtNgnJKm4qP53AS3aLrEzdSRDZqaczcgj8rcY7kuFKgvrZXMfd
IgJv35dnuDrN/7foXa95ReAS2ffJ5UBClvBc4JU6AlkzOdlTLBKE4U32++oJ
9H1wvn7PvP9YxZ+qbyJQaVsd93YXCVIvo8DWdgKjU1l7/rYjwVJmbN8vIzDE
T38lcysJNuJISr6CwL0OGcORW0jYmShR+w0SWH31kKyaSYKzZc7vH4cIDF/I
JDxsSQg7Q6N8+UKg2bD+eJQ1CdG74tUPxghUO3uJXmwmIVG/vy1cRWBqUV7C
8nlnlgqvTU4SaOG2LFHIICEvTiugcorAltXrS4fpJBS5+u2NniEwo4Wi2jFv
scVLM9a/BLY7qjx4G0moGtugnpsjsHJbXluDFQn/AZrpUO4=
       "]], LineBox[CompressedData["
1:eJwV1Xk01WsXB3AhDaprqAyZjyFDSnSl6PuIhOSaoqjcVMh0KUlCo+SWouuW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       "]], LineBox[CompressedData["
1:eJwV1Gk01fsaB3BT3UxlKBnabP5FoeKkAfH8inLCdU/hcM0cU5nikiNyGoyp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       "]], LineBox[CompressedData["
1:eJwV0Ws0lAkcBvDJNYw9YVmRuXhlNKl0dtl0+/8XlZKRJBtLzbi2hsqaVrKr
VDRbSiVdNWd0o5a0S+ek2CGyKlRTOMZu9n1njJHpKEuGkX33w3Oe8/v0fHi4
ol2bE00YDEYonf+79GeRxdKEY6uTRwXTDkF6aFZyNkZxdoJ27WXtTdTDzOOG
QxzOPjC55VPuv0oPpYpCtjlHCgd/KaO2+ulBvEqS9pF9ARaNl9Xv89KDciql
eIRdAa7emcvFTD1Yqkienn0fPv79qDxSOQzyJ7I9b9lt0J/bsV6wfRiq7khV
4sW9kOjy+FpoyltIhhcXhjMo0EV349TpIUjXLKBqqnRgn5kvzenSgTX3MO/N
shG4e7ncZ5qjgxNznvLlO0bh1YV1dVuODYJIteUP02fjIDO19bAyamFPy2HR
Lt4knGq0EffnauHubmaE8/ppCF4R8uqhsxbk+1OHfKIY2OTlsaa5ZgDyZMbw
f4dn4bt/eiqYwgFgKPvxYbYphr0Ia2lxGgDPzKSsLXxzjP0qitHcrgH12Lmt
NvUWSJopY1UnNbBB8/1Pp/fMxs6AnWTFZg0I1EULWSxr/LHOub7LVQNDj0QH
/qy0wU5jtaJrWA2L7brcArfbYkZ0vktvvRqsYUzYN/oZ2lzSsCLPqmGdPvqj
e+QctMwQGm6J1dDTlDAr2tsO18rflVWuU0Pt0eY4zpgdustLYvN5akgyl/R3
dNhjnsIqd9JCDfEZ+2uZFx3QJGxZ3skhCpYkL+zYKPwcZ44+p3Y8p6DT3ttG
4u+Il89+GL5TS8GDqrxL3qZO6FkQWApXKNg/i7/p2V9O+OFE2dKwfAqs+7KD
02u+wNrnJr783RRobnCLZTnO2KeIq5d9R0Gx11yz+5Fz8cH6KysLgykoupjU
KuS44CCxy6XNj4Lo4tgOptYFn7TlbfbzpGAi6LpB1uCKX1oOtLo4UkBpArKa
CubhoTR5zKA5BWWrlrq2C93wB/uGUN9xEiqPSOySF7HQdu+3bssHSSiIjA8x
HWPhbuMBDzcVCb598oqCdjYKtwYxD7WTcH7Bpcr2EA7qEv18YxtJyFUUng+5
z0HHoDaHphoSQl0jrz/x4KLjiu4oXTkJ36S3xthJuRjX42UmuEKCbJ7I49kY
F609p3cGnCHB49HNEkGMO0oz4ju3SUkoWtTEf9ngjpaCnoRPuSQkjZq9aOMT
aBbWy1q2lwTR3Q8c6UkCs0YiptLTSBDnRRg3nCIwqbdaEkxbElHTzTxDYGg4
b5xL++iY5ERRCYH13Bir12ISqvwNU+dKCVTMvpe1grahcabrxm0Cz6+Z2GeV
Su+/ZBY2txLIKFQYK1JIuHg1LSW/jcDj2ce/Pkz7amZHYPBTAnN+DcqKo33P
qWjyaQeByvBMGwfafdEOKcrXBBYOVmTlJJPAo+YGkhSBC974p21KIsGnJpt1
TUOgzTkPi4W0lx9RGRK1BLJLNNfMaW/klVbrhghMN6hH6xJJyEjlsN6/J/Cz
bb93z6eds/Kg4bdRAidD+DIG7SO25KvMMQJdq8ViVQL9z52rxyYmCBxJETif
ol12wCy5bpLA+bZvx1Np3w5PDMgxEni2MVS1lnaN+2O31Z8ItFoiaeHSbhj1
NMzMEFj7aXutMZ6E/wDhKk1f
       "]], LineBox[CompressedData["
1:eJwVzXs0lAkcxnE1qKSNkhTm4lUyJrIdKqrfT9pNqE2iVlSmXMrEZsclRESo
tKOcGlPTpNLNSampk7awIkTThkroZt7XGMxB02RGFzv7x3O+5/PXw+LGbYyY
aGBgsE6//ytO5xq77jq6UrT+XmjuWxXUtTH9NzN3g13rEfdfu1Uw/qTqEJO5
HwTUzge0LhWIawoYRsx8+JP3c3NKhwp4KxL2jjKK4ba6Puz3NhW0fY0uGmZc
gxiKEnc2qmBSV4+DilEJftq85PHbKih5Ktk3wGiCsnYRMzhbBeU387t4zp0Q
dXBtWN0sFUTBi+LBeDnsGZIPca8OQizlKJeWK4H3r9niUs9BMGFlO7xfOgyn
pu1eOKlhAI6bNbNLdqjhxTlh1ZKwAeB2baqmtXwBbm5s3cShfthXn82NcxgD
5bv7yZ9y+6HiD9NAq7XfwT11Zct5Tj+UpMb0L9psgKp5BoFymRKyJN8CPg9O
wEZDmxHPNCUYtH3Ahyk0VBLanNMuSpjPj0zexDbCS8WLG20+9gGpOR089ZEx
1ldMNptytg98qT0HTuybjMZXfKZHB/XBelLgRKebIJ/lIbe06IP+x9yDjTem
YuFzxx85nQpwNn9l6719GjrTxkYPSBRgAprwbvVPmLLkYfX2GAWsUYWM2gWZ
YXW8dfWAmwI6andNCOGYo83rDKGPoQLu5tVtY2rM0Vhx621wRy9EGiV8kMlm
oITka2eX9cLO+NS7pqKZyPHtOKTO6gWXKCeZf7gFFhhntsaF9cLzGZypCctm
oeiHi9V19174uzzrDIdmicdcPH7jWPRC6gT2hpa3ljhw5OX+Q8MUmHSn+MRK
Z6NR39V2u+cUUJdZRZI0KzRlN67bVkFB0YI5hpVBc7C4KTMt9QQFAlFkQzhz
LnrdZ/V8TKQgpChMZqqYi6w3AYnKUAq0q0t1kiprDD5WVfjBiwI5tSq5NtcG
k+YNd1x3pODCClfrZ+G2qDXLa080o+BGToJ51EI6JgXwjnfqSMgN2ulH09Ax
OKbMI5Mkwa275FruMwbSQ9+3uctIEDqeufHMj4nZEiN35wckZNQUCP0qmZjx
yyPSu5SEddZBpU/tWUhaSWemF5LgFduw1TyfhfN2JPtUZJAgseHat2hYGO+E
7Ol7SbB/fOXU+q12qEg+7LsqlATBwlp2a5UdbnhXpAnwJyFSbfiiiU2gWFBp
LPQkgVvxiZn/F4E09diCdA4JvKzAb76FBDrd5cs89U4IlL42PUkgr2HpAZ0T
CXmahOOCUwTOdRN+4etdvkz39bSYQEZN+hYemwTdP+OvLpcRuEKEr0MX6P9b
TQvqGgj8zObeWW1Pguji3ujDTQTqzqak0/S+yJd5+zQT+Mq2ZGMtQcI9S8FY
s4zAJMrMEvXuDpkZ3faSwBNv1kxZbkeCg3yOd4+cwMKtSRI3JgmLpCn0SxSB
7fdPjn1mkOCR06WLUBC4+fH5bVK9/R3Et5T9BDYKc7wW6x0fw6SPjBA4wlsT
70onIW15pu62msDELfcsRmxJyJnW087XEGgRN6nmlt7CmxeParUEllE+rov0
vnDQMOrBGIHvrruNDtmQUBYQsSrtG4FnI77X39RbavfEduUPAu+sPSeO07tK
PV83Pk5g7FHLdBe9/wPly0+e
       "]], LineBox[CompressedData["
1:eJwVzXk41Akcx/ER2mIotEoy1681OVeHdjv0/aJDJdtBNtRmitHSiMdsQgcl
JCXJlVmh6DI66EmHVBO5ZldK7RoPmX5zGikmudZOf3ye9/P668PkRG4NmUKh
UDbp9q2CI5ypC/emr3pfeDDHXL8fRO0Mb3/GPnA9tW9O8JR+mKyvPc5gHIKs
L55dQr1+ENRl0A0ZaeBZGLHYi9IPEW78/cP0fHB24jtET2igfSwse4B+Deqq
31leHtbAd529bA29BvzLrpqfVGuguKkoSk1vhIhfk+5FtWlAWJnWGeH8L7Ro
L5UbZmmAC235fdFSmPfPQc9LmzXAI+2kVUIlVGuMbJqoGjBinmB3/zwAPlcd
XjbX9cGZmc32xbsHweuuXNkV2wecTt8n+i1foEdGZXXb90HUixOcSPYoxAaV
sqZ3q+H2Aeq2Oesn4Ah/nZafr4bi+HCViz8FmRJCffMXNSQVjW8Z6tPD8A8X
hvKoaqC09+CjOH2kq2fIhS0qsI0JjfW1N0TTw+8MEtNU8EGbu9348VQc5h09
J/dWwQby98NZUdPwVvmBrYkmKvD5kOlAoxmhwYXA2sw2Jaiec469rDBGvcT4
vMqLSnA267Dx/M0EHwUMiEL3KMEItMGSQVPMWuHW99pFCes0AcMsv5koVXfa
WI8r4N2zvXoBjmbYGJZwJ7BJAdWpol0MrRn+NCpFoUABoYb8HrHYHBcdiks1
iVTAnuj4amqBBdLq461s1yjgR66D2Dt4FvaartGk2CjgL3NHY/6y71GWWxlA
G5LDQ2HSRUd9S+QvDJr+XiyHeD37zS1dlriidaXrWLkcjCRxXryq2Vhjy6ta
clwOZBkzuyhhDl7vKMuy5sghe4GVQY2fFbq8aQs6CHLILAhtCGbMxQ4DwU5k
yCEge6eYKp+LyWtln8unyOHr6isjRbXWmE75e1gglYGU9Ih9ljIPu4e2zyhq
kEGJ20Lr1mAbfJQqKlx7XQYVyXwzrhMN40KoHvVnZZDit2ejvpaGpyfvpuf/
IQNXSfG1lFY6vuCFLlsQJIM8u4sVrRsZKHq4g+G+WgZH6zLyNtYw0P25q5Od
gww2WftdaZrPxO1B1Mc+FjJw5zUEmqUxcboLq65mgoSieZz5LVom3u9pkhrK
SZj/vDzHJ5CFUpMtkzGvSMh0emb/qpaFY3WjuyW1JIQOGrQ12hNoOVPl6Hqd
BM7tz4y0swT6jr99EJ9LQkTStvEN5wiEaw4b7HTmb6t6Sz1PYIl/obQjh4RU
Lf9MZg6BdwStSxbpLFw2MpYrIHAWe9VmZTYJI08nO8puEPhxafO+HVm6/1fU
DFEDgeFd663dM0goKN0fdrKRwBmadtXH0ySUxog9vZoJXN7rIfpT53uWmaPN
YgL9zr/MHk8nQRJgEdb+hsDZTz1u3j9FAltq5dkrJTDGOOruolQSXKriaJdJ
An94E8foTSFheXLnSIicwI5pPrnndPZmC24pVQQmSNaXDJwkITqcQfv0icDI
DK5TZTIJCSsTR+4MErhg4rRil87JJr2vY7QEmrvxKkx1zqssTf/6lcBc7k5f
3gkSSo4ZcB+MEug6wF1K0/nGlhCPhHEC9ZLZLPFxEqpY9Tar/iNQxi+YfUTn
2kHbkclJAhdbPLF01vl/0mhV6g==
       "]], LineBox[CompressedData["
1:eJwV1Hk01WsXB/AjcpOUoSQ3Qw65lalLKdH3KaXIPXVlKBWRoUEaZUjDja4k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       "]], LineBox[CompressedData["
1:eJwV03s01PkbB3C3UpFNoqUw48uOhDi/zabU8wlRVFuL5cgmEzMqCoc2xqWf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       "]], LineBox[CompressedData["
1:eJwVz3s0lHkcBnCSat1yKaXmxlvRhKWtdnXU9yvSxaWQbNrdMm4V0VhOxSxS
7rEqpwbHTsOqHCK7U7vFToWymdx1xanTNKnfOzMn2SmDzb77x3Oe8/nrOY+9
IDE4epaBgUEAk/+7Ml0wxz2qcONQGHoeDtFC+wDPP4x3EIb8i6MzgrUwc19+
ksc7DiYmAT0lQVqovFPENeblw3JWr7BphxbiN6Qc/sQtg6dFBTuJnxYGpg6U
vufWwr3xdtzgo4W5Q68cNdybsCg6J0K0RgvSTomQ5j6AZ6bX7r610UJDY/5Q
vOtz2Cv1XalTaCAW+srUSUpIdbmPigINJKhWKmUN70Bf2bLwz0ANmNifcnzx
zXvIMGK5Z1troNhSwZfuH4f8fr6T6Qs1CIZ23TZ6+BGqaANfdr0ahPdOCRId
J6Ge47r2Yroamo6YhSze9i8UV1uwHoepQZoWR9zCDHAfXvLa7a6GLMl00D9q
Q2zwWjM/ylINBgMvsSXVCL9rH/yj/AMNK5Jjju3iG6N6/jZF1yANr3UXdpv+
NQcz3WxG2M00bFcd+umscB56jTTvCZPSEPi6ZBWHY4Jf891EJJ8G0ibI/Puq
KU5urltbmkKDq9Vjtvc+czT4XDhtGEGDCegihsct0ESTkGG9g4YtmvBPDqGW
eEoxyFN60vC0Ncow3NkKR+nVYldnGq7ntf/A01lh22VRUB6bhhjjlJfd3daY
m7OuttSChsiktOtm5TZ4UnzRJ96Qhi9jV3X7RyzApJj1E+t0BHqsnU1TPBZi
VIzN3Ma3BJobsiqcjWzRR8irrBghkGbI3/lwxBavBG6Ve/QTMBlO3ZogW4Sz
DhaaVXUQUF2yL5WIFmPBjMbGU06g1Mlu9s1QO8yZXtCZKyNQUh7TEcFbgheC
zoyp6giEl37fbTa6BCMXHbfrqSYw4VOjl8iX4hHWM11cBQGlatOx1lwWfhXs
l/j+HIGqDe5LuyLYeGVXb6LLaQJXs1OsYl04eLpw8I1nNoHc0Eg/Ix0HcxtZ
VbJ0AmuHpbW5XVxMt93zaPQoAfHKiqtdfjyUic619wgJZNwpEvvd5GG9en/a
0TgCAUtDazqX2aOyg2ssiibgldCx1yrfHpd0jzax9hOQsATLHurssUXVFJQZ
TmBZ2+XzgXsd8PbGRE5yKPPPpZXfL3fAo297a+t3EogZn933gE+h17y+oDo/
AoKmD7z8nymU3Tr0u9MWAvFZIdPbz1D47pfrbxYwTgmRPTE7R2Gwh5ZlyDhP
l1Jccp5Cy6nlZ5/5Emjw0E9dqKQwoKZSUsBYf3fm8aU6Csc62b6azcx+v1lR
eweFUwPqFpkPgfLqwwdyHlB4p6DJX8q4Ornbe6uCwuM1O14UMb5hWzKp6Kaw
L2+heSzj4XCbAwOPKNwjuVFgx9hRaef9Sknhjag28wxvAm6yVM6vKgrvfRzo
jGO8PntIHz1K4bUvZAXfMvZ3rLz2jlAohpfWqxknxfE4Y2MUygee+Kg2ERB5
ntD/Nk5hWUjI4n7G2eavBpN1FPb+WKaVMxY3VhdOTFCY7HSyWsy4KnN27K1J
Cp/nLM/KZlwXFL1JNE1hqV1JZBJjmcN99sbPFFr4tm7Zx1g+vkI/M0OhUtjs
6s/4P2S1T7E=
       "]], LineBox[CompressedData["
1:eJwV0Xs0lHkYB3AMsS5to1auc/EKScputWmX5wld5LIqdNJFBmOqUblMJ5dt
N7GS1MxmC2XnCHWcTqidOquVatgkjC2rOrFxRrNOfu9MShPjuu/+8Zzv+fz1
Pd/z8AWHtyWZGBkZhTP3f1YcF8zzTSwK6NhqnJOeo4PWHl7YDt5+UO9cqOEw
nnvUfJLHy4SZz1t07dk6qHhQzDXjFcLKGfm/HMZif0nKOLcM1JvLslozddAz
JSoZ5dZCVF6TcvaoDsz71B5abiMY+8hcVqXqoPKJPJVw2+GXSPHJh4k6qKsv
7BP7vILiWEezro06SIanZXTaEJh39lvkeergkGbpkKLuLRyrWRPZ/JkOLPl5
HgNrR6Go7RxvalgLZxd0eFXuG4MafytR9WMtCPqi7rM6P8HN8bj4oGtaSP0z
T3DYYxIE6ruDOwq0cPOI9Xb7kBkQzBf7ZB7QQmX2wZGVO4zQVxFiAmFayJVP
b/1IG+PGnfveLfLVglHPIDZlsTBxzYkX6Yu14J4hPBblZYYKz1xz5TQNb/QX
Y6zuzUPPLFAPvKFhi+bA9z+nWqDx+Bln204aIt5Il3E4lngklyVqU9Aw0iL4
8fENK9zbJLz8SU6DD/u5S1CcDQ4E75+OOk2DJejj+8fmozxhwm7mKA2btLHj
rtELMGDUMDcsoOGlMtE41puNxUm8XRaRNNw+1bqXp2ej2KKnmwIahGaSQZXK
FhvWqwKly2lISMu+bV2+ELMLQ+51u9CwInmZKix+Ecru7Y74OJ+GbltvK4nf
F3h/KlgomSPwR13uJW+WHb5kGQTF7wlkG3tFdv5jhy/imspshghY9mdtPqRY
jH8NeAfs7SWgucovkefYY7ro4wN2O4ESTwfTxmgHpO17lWuaCEjLhW3xPEeM
6bZRVTcQiC3Zo7IedkSRu++e+hoCE8E1BnmzE3L8Cp5/VU5gSBN4TFngjKes
o1tenSNwxd/XqSveBV/XNrFN8wncyJewk5dzcJ2NYPabbAIF0QmhLD0Hz8z2
13xIJbC6v7K2oIuLv13iDnwpIlC69NKNrlAeqoQtgwlxBH54UFwa2shDO5/6
3CUxBMKdomueuPEx2PSydnc4gfWH2naxC/kouHWffXADAbmzwK1Tz8dmq4yl
C/wJuLVcuxCxyxVLNo5OHl/N7Fuu9HrW7IquaVGZIT4EhGOmT9u9KJRtaLjT
4E5AcPMDr/Acha+ygtu6uATEudunt8goXDKhlNQzlmxXvLA+T+Gm0mkPGeNT
eslZ6QUKBbJfL0YxrvMzTF2soHDFldNVfRwChodzz69ep9C7PCVlxIXpf2Zd
3NpGIau/sdXSmUB5VYrop3YKNUXb3tJOBKoyVEGbOyi87S1jdzO+Yyed7FBR
6FgzIz7PuD92oainl8Kg1Se+c2bsMeQQpB6icFV6pdLHkcBKRRanWkOhem0o
n814XX6fIWmYwidS6ckxBwJhHhUNb0co7E0k235nnHaQx3n/nsLX1d3OgYxz
vj1huDVGYZJJcKkb43wb9d8Zegptn0YsNmdcWl9VNDFBIX/VEl6nPfPvH02T
705SaJL7rraO8fWtSYE50xTOU4R/LWOscH3kEjBLYbgHPE5n3Dzmbpibo9DO
r2V3DOP/AFJnSFk=
       "]], LineBox[CompressedData["
1:eJwVzXs0lHkcBvBhWOVSISKZi9eiMcSq3SK+v03ZZLDF6BxtysglJMqcXBIp
t0qpdSKyEqW0bi2FjCwil0YM2s20OpgTve+8WCaXlH33j+c853POc87DFpw8
EKhMo9G8qPzfBecE39geu+zEEuNX3FNJaJOweAdZxyHmuZ4pk/JKe9MFFisW
ir/apU+nkFDQnMlUZWWAwuG7uhuUwx2FJ+aZtyAxM0w0cJEEyeeQ7GnmQzB+
J870vECC2vCouZxZD0UJ4a3sJBKKugqjcGYniA99/8I5loS53FrOyJVOiN5U
IlCl7BLcPda/2AkBWusl7TEkEPR5foOkC2xFI1aulLc7ethnpPWAvaZfn9sZ
El5XLiubT/WCa8AczVVIQmIXd5/tEQncvvbynGkUCRWVGcPh1m9htdn+b8NC
SAiGvlvEqTFIWt5ISnxIiJBtHqupmISiCB/6wd0kqLMvmo9sn4ZKWcx77y0k
XF3XzSk6Ogt5WvxyMyMSBMPez+k9n0BwJqd6SoWEqBcXBSfNlyCG3slbIeVQ
HanpZeD6BeJfjl+6/lYORfFhH20O0lB4FXciu00OyYXL++cIJXRa9OApr0oO
NMl71BhHRy5NG3xqb8vBLDooxpujirhHeMUDaXIYV+T4aIi+QYxWJYkoWg77
ZKEJN6JWofEvvej8UTl4jGdZMhjq6DcVdTuGuxw+tgqSXpZroK/PaIOxDnKw
1h4ydj6ihbZxY40lFnJQB4W/dHYNkurTpP9skMNPct95E/46JJLx5F9U5fBX
yzElX642Wv149jA5R0BtepsfS6GNhgdQ/ikZAUGqwvdisQ4q7aBFMQcJCDgV
X6uZp4si9mhYe7QTsCXYUszzX4/OrDVo49QR0KvD1RDu0EMflH3T0UMCnlUk
53Pp+iitRdumLp+AeCXOzz3v9FHT1vOfhJkEqEvj9kbUbEDWPHavNJEA2X12
duFZA3TZUhSaepqAbAtDlXq+IZqUqjUnBxGQlRfU4c/aiE5yDXOrfQnwzT4s
1vywEW3lKT6HeBKwsPveYmGTEYrQFU4kOBMwJtsV05K2CZnktr0p207AXUdb
o1f+xqilMTDByYqA8hShdrAVA81U1+lITQhI4we40RUM5NKcvGPKgIBt0qKH
aa+YyDtt4FPUGgJyN+eXv3Jjob9r+ugTKgQkNmfmutWzkItE2WdwCQd3I/69
LlM22rXg+rvdDA4/RnQc0s5gI2Xp+muREzgUbhKY9ijYyG/zOT53BAfT1tKb
HodMkKvFAf3GIRyyrFo4/U0maMHw7YNSMQ5Bsyp9nRwMHS8uXzBox0FQ/S8r
4xqGZrpfe7o34RCe7LW87zqGHDvfTHAoC71q3mj+iiHt8cCUVZTTFcKrWTcx
lBeq19kqwqFix+LnnAIM6V36I86e8uKfK0P3H2FoqD8u1aKR+u/XzGzrwFCH
TtVOtQYc8opPhKR2Ysi+9M4eWT0OxdFi573dGCrZs+pAK+Un+llL3WIMPSi2
FyZSlvrqhkgGMeRAY8jm63AwHzN0Hh3D0Db/yNDJpzjY1MQxSmQY6jW9WdZB
2T5leDHwA4b8V1uS9yjzzAuqJj9iyNjpTqKA8qkwFmNmBkN3csq6h5/gcHbn
+cXHsxiilTiYN1BO0RodiFZgaGr8h9RcyrmVxZcXFjA0ujbSg0/5bpJKcMMS
hrpXyp7aUX60P3DX2WUM6dp4mupQrjFpN3b6Su2xX7Kna3FomjVbXFnBUKxf
n1ov5f8AqNWLBA==
       "]], LineBox[CompressedData["
1:eJwV1Xk0VtvjBnBD3FwpwzcJoV5RSClNGp4TDSiVKVIR1xQl3Ciiia5cKSSJ
jEnGlFKRK0nJmJJ5LF68ZxNvryHz7/z+2Ousz1pnnfXsvZ+9z3K7syYOAnx8
fI3M+P9n3CU7YS37kJ2iaddbpVd3o7RO6YCF0ik8TjlescyhG3MfiwKUlHww
SORFzsZ3I644VFFIKRizCVsWhYv0QGPI/tac0238zyHTO3NbD9oXxs9ON0bg
jeWH8oeuPTi9w+vMuOJ9eE07tjz+0IPn37pSRvQe4Du2niJDPZh0PdDGdUrA
bTbfZz8ZNnZXh68ca0xGksiPbLY9G3VTzpHDiulIXaBQ98cgG95lCuuGnmXA
/GE/NSvaC9k73yoH9bIwy9K50Ly6F3ZqlCBxyoHDVLm2l10vBKZ8P4/4PUV9
1CblQ/69+NZlvmxkzzO8b02toe714kKWaP6vxlysvpdvGPWpF4YRvcK/Ep9D
oeCr6MKuXshfeGfGPfUC3onyfh/GelGsd354aCoPISbrjy5e0Yc/Wn+oDirm
Y+HgHwfFPPrQVPyf10B/Psp2OoZbBfQhIzX6PXlWgDOZXReV7vbhoOdBG1qv
ELa33SU0XvUhSqQgqs/pLb7/iv5aOdqHF+cNPf+WKUZukqS0y7x+PKA3L+X5
FcNb/t6SVMl+uNVKOv3a8w6CPcYNQpr9kHzwSYDbWIJ9Ro8jik/2Y2rhy3T3
7e+xsUnXLeN0P3quPjw8nPge/rKHhfZf6MdLp0vxQ6dKYT0kd6LgVj+sNmjr
/Jz6AO3dRXfCX/dDL3X59zMnPyJnhdU8z5J+aCxddGOw9CNkJLxDZKv6MTvL
qR8ILYPwp6y+io5+JFUkeBDFcuyfO7ergZ+Dkeg8tc6b5UhRXarf8CcHe50q
u79OlGPgQMKeh1IcDAiOmxfUVcDM+FtMhjIHW3Yc1AkOqoLb9fOHondzECJq
z/MbqcKacVpL7QAHHc0+We621dA+mPBXpCkHgd6PFCy31aDmuIrNmC0HtTnT
AqpDnxF3pXVkoT8HkhCxFtOsxRfLnX1XAzjYphKpE2RfC/2QZWfqgzm4NZLO
8/1SC4GT7o+WR3GgHV7vYJf5BS3j1tscsjm4XKFhqGVThwdxS15uauQg7dkr
lcy7dfD87P5TtI2Dr9G6giur6pB3qiWkqosDZSfLQpmt3wD/xTwJmoMKwUBN
Pql6yBqlBRZMcSC9o1Xy88cG5I7zfnTK0aCUHYf0ZxqgYu37NEGRxilRbmXJ
hkZmXYSNjFk0CpuFr79MbITP8LR6iBoNO+/143G+TXhTcCbKdguNJznBrac1
W7BGIM2tzpgGLUnfNLRtwV2XjcbxZjRUvQ13ropsQUDRjOlJCxqJ20WTuida
YL5/o03FcRoR5TcdrT60IndkpknHiYZ3923uvuPt0MPH9ixfGrl7h5NX3m5H
3qX8bVN+NIbSD5sJlrRDf0qPo3uZhrO7xKsi1Q50Zg+kFAXQsJqJ8NvI68Cm
G1PRLjdpJIhWBkjs6ULDLkf3jAc0du64ePyKdRe0JMV+3o+n0eamvnHofBeK
hUx0AxNpyHwN6a3K6ELIzuS3Bik0wqMPGNwQ/w526pE1MZk0AlbWLJxr/Y5F
9ifiTubTcMKX+wOe3Viv+UqX+4UGX/JYQWtINyaiA1XM62hEz5Nvq0jphp2E
PyfvG41P5Y4K6Q3duP/m/Ca3RhqrzKaTHXR6UJNyWehNG41+Z9WsDn42+n+E
51X30rhSeaC6WpaNou+vJOb1M/k0PX8WbmBDvta6azOHhj6vcF2sAxtrNLgj
9wiNdH+TPItyNmSrnL/qDNNwifAvqg3rxUXTi3kSEzQERpM736b34qN+Ze6K
SRoxFp/4ckp6cQeLI7WmaFTIS+mFjjDvL9grZzBDQ/1xWpmBZR9EpN902/AT
DLypqy1R7Ifd+CJjLRECN/bq7hdPOFCQOaUetISgy7p5/rtyDgIsxw08ZAhM
m25oVvdw8KTnQ9rRpQRbKvt82LI0Att5OivlCASfPRKXDqJRIEZtSVMgiPZb
vvO8DYGXi+Yd25UE76SW3t8qPoiqrWcvF2kRaId+KtqjPohDC7zn+6wnSBW+
0GO8dxAhrYdM1m8guDnRsNbFbxCpqcobk7QJjnRGfozpH8Q1/oRQ980EdIb4
yFTxT6TbnpZr2k7w5/JA1c4tw5h3Yvex9r0En7aHr720Zxiu0tFGrvsI/rGM
37zMZBhjaZ89fzMWCHu975jrMA5XVh4XNyCYnB1waowbhttJyY5N+wlIm3na
ZwEuZu64zdkcIqiKVl1dXMWFXU3B6jUWBP++0NayaebCVijEJ4Wxfu2urbNs
LjZ2SKvLWRKU/nHcYPscF94Ouq+FjxIUeoedeq31C+sWWT9osCLINptIfxr1
C9ojFqFW1gS3xCvVkk7yYN8kcHPSniB/87K8g248+Hn6vHR2IOixPovpizxU
vE052MB4W7aUmcU9HsIexVXlOBL0Gxz3F6vhIfGGhMJxZwK9gMHPPttGEHjx
hlCsK8Hv0UVeJtKjmNrQ+OW1BwFrmd3cHGsUJUOpOdKeBAd3vwjO1hqF7Yih
7DnGjyIs4+cbjWKJ/9H7a/4mMFmbVFYUMArHXSvNY88x+Z3Xy6pzR/HGvc3D
7jyBXavZW8GqMbyd+2ie4sfsR+z3Mx7NY9hQL1bBY5xr5Sbf2TuGxiN2bF1/
pi8tQT4F/ON41nJdqotxSlPBBo/N4zDtSD8hfZmgt14prSN5HHHBv5T/vkrg
UjsQlu/zG3sbjBW51wk8PgTanVWdhHuWsqvMLQKFnr3CYxsmwSrNdTZmXCkg
kuFHTSL+7qzWv4xXUqHc4KOT2G4zuGqKcXPB3SspIZMwXdKe03KbYNfT1Pjm
oUkcW7jYOiycQCL2U4ve6yk8LJ8UbIokeOa+wFTGYAau862PsGOYPsRI+WQf
mQGRev7nklgmb6lsgq79DMp1nkToM5ZdupqcvjyDDwoBCpmMA9/tCXiXN4Pa
Y8Iabg+YPktefu6yYhYqfoqHB+KY/j3nSv03NQudp8abKhIJki660uss+Kh7
WrT6klSCdcUiv4NO8FHT/9F52xkXz0sT6vyLj7rUXsqyY9wV2qMU6s5H/RgL
yMxirJB4woITzEcdQ5Qb9ZggpvRQaVIhH6USXdBul0YQIaYdL7mCn3L9/o9G
ZAbBtYRp45EBxrNlp588IeCr66IKfQWpt+u2DJflEaicc7xgpiZE5Rj5rjMv
ZPo4eu+I6H/CVM5Y1oeodwSGbBf/CI/5VIu7QWrwR6ZPPWHqCgp/Un875J4r
q2DO63u7K5+yRalMhW81+2oINCUalunZiFEN2nZiGV+YvmDUto23kNrHX+p4
6RvBvkGr8RXm4lQw96bprkaCphJ7fisNCWrOwOjd82aCvBul1kqjElTS14iJ
slYCRyGvrpoaScpv84bLje0Ef3lezFsQI0UtfnpoU2wnwVon9ZoDtv+jVgVd
M9T+TvBZUkPUa+tiyjm4OKjmB8GbJ9diNQSlKfc1D/dp9RBc5Fc7XNUuTbXM
2rhHsZl8bb76bi+WUK5bacO2XsL8R5ZHJvjJUPI1NUa/+wgiVy2dl2++lPJ1
Gc+Q4RCExTiW2SrJUgsMp+QW0wRWkSdqFvTJUsWNT/VnGf/e/WgioUiOMvnb
LXOAEHSzdS+UBMlT2eNmV4oGCJJ3aMlV2y6jnj+Qd7g7yJy3614STmsUqIHJ
0HWmPwmCzP/aLziqQOULru0QHCLY2JaUHlStSKkLXirPZxy9Oja7er8SdSqt
aNmxYYLLxaHR+/OVqBOb6p34uQRGcuaPKpSXU4rK6Y8eMN7lVnZMIng5tfBq
ZrXKL4IEeTvlqtHlVKv4+sY8xsrvH0cdPLaCWptq77GRx8xvTYna16IVVIrF
OrNsxo68eV/K1ViUmOSdn6tHmPvg2S+l4Nssypd7w+4+49PXTKcNw1lUJyVp
GMvYy/RF44I7LOpEyG6tOMY3Rr1uhUWxqA9uKbOJjJ9snZi6F8ei9k2Y3k1j
PPFuriE1k0XtMPkn9xXjsK8LQkvLWFSyeFNWPeOYh2ec/ylnUSp62cGNjB+e
q9HTr2RRaoaajs2MX0qHTVbWsKj3mtoK7YzbrKSc6+pZ1NJi4397GKt2L9X7
0c2ijCz7THiM173wVUhhs6iJ9YFqo4x1rrdOOPSxKI5uDf844wOqcU85NJP3
qEvOJGNPVyUFLpdF5b4vFRYYJfDbfnUil8ei5NKrWwUZXxf78e3cKPN9j8Cn
Qoyjcx6G/P7NorbxTVuKME6+Ms+pYJJFzXILNUQZZxo76PpNs6g78hp8Yoxf
rPi4bOcsizpz16BuIeMinsoEc4FTvzwWp4oz/j+E1eUc
       "]], LineBox[CompressedData["
1:eJwV0Hs4lGkYBvARIqccymnEjE+NJJ2XhOfdVApJTgklNEOIlJFEREhStlQk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       "]], LineBox[CompressedData["
1:eJwVz3s0lHkYB/ARYoeKlIhmhrfcu6h1TrMHzxPbdjGiC/agLZPrRuKYk9DW
KjTHpSmKWOugpqNCl8lJRS4xSY2VshWl3NPvnVVmytA2++4fz/mezz/f73ls
hPE7IuawWCxf5v7P0t+Ec13Dsz1V3atzdc4q4UEPTxDEi4Hurm3SswVK0LY3
HufxDgPt+ibckXFpUy5XnycG+WzYC798JcR6iOK+cM+D/zpxS9FpJfTMRhdM
cqtgxXzfd1Z5SjDoG7SnufXgtztBOJmphPJHZQkfuB2Q+aa7ZkGyEmpqxX2x
q16BrnRjjipQCVHQfZ4kDoG2d3Br9XolHBhxHJLVvAc7H2VDurUS2DYn7AfW
T0L1BlrAZikhz6TTqXzvFCwev+R2dIwGYd+u+7qPP8PKNn68YRcNCW0nhPH2
M3CvTeBsUE/D9YPGOy22/Auh0euaV0hpKE/dP7EmiIWZHYErfPNpSC/7ul1F
dJD30fCy+XEaWD1v8V6KLmZV1neEJtFglxSZvMtJH++GlogkETQMqwsDjRrm
YuDow+zmn2nYOvLrkTMJhsgzudn8yoeGbcMSZw6HjbKX3CXmSMNEq/DYw2oj
/MlsIbvXjYZVpr3LvPfMw7B32gvxzjSwQR3WPzUfK+5PXw6ypWETHfzFNsAE
OU0ToxaWNLxoCdcJdjHFQkGQ4VkTGm6dfPALT22KDU03Ry2+oyFSX/RWoViI
tR4BAwd1aNiXmHrLuNgM8ySfQq/NEFgd5awQhC3CDCf/rBgVga6FLkYi/mJM
LjPmqmkCd2vSS1x0zdEt59M3j3ECqTpO/o9fm+Pw3cPPQgYJsPtTNh+QLcE5
DV3PB/oJjEhtCsrSLPD2SxdP1gsCBQ6WevUBlqj5HOny+SkBSXGkPIy3FKPG
/9I/rCAQXLBbYTy2FIdP5XR4PSIw/eNFTVmjFR7R2xs31EZgaMQruSXLGvew
W0tmmwlUeLhaPQlbhvPkRpvpBgLVGSLTqJUc7MhyHPG5QyArYJ+PrpqDjYPx
Dm/rCLj1l1dlPeGii4pb4neTQJFjSfUTHx4Sg93frK8RONqUW+RTz8OCGz0D
8qsEfK0CLj5aboPFW3KaKqoIbDggDzEV2yBLIjLvkhIosxYuf6y2QT596PKr
SgLLWy+d2xZii9/Lcktdy5n/VrY4PW20xZiHM35X/yQQOaXX3eFEYb5r8bTB
HwSE1z/xxKcorOXnm0nPE4hN3/l162kKVfPdS0sYi3bK/jbOp/DMZLTDacYn
1aI8yTkKE8W+3mmMa/ia2cJSCr0/rM/ewVjTrO2VXqEwXuy3T1vE7D81zn0g
p9DuNX9tMOPiyrjozA4KW8StH/wYVyYpvDd3Unhb1S7dyLjOXDLTqaBQv4Vv
48q4P9gsuuc5hXci2u0NGdsPWXoPDlFYl+yWWldIYI0shXNhhMJJgZvgKuMf
Mvo0EWMUbumr4lQwFtiXXns/QaFw/B95LuPE/TzOx48UxiwZc45gnOb+u+bG
FIWuC04YhjDOmDf4LElN4aFN+aP+jItqK7Onp5k+T4NL7owrjulF3ZmhMGXP
fvFaxle2R3ilfaUwNhPjHBjLbNuXeX6j8GJ45g4O48YpO41WS2HnFXf+Isb/
AW+dW+0=
       "]], LineBox[CompressedData["
1:eJwV0Hs01GkYB3AxDQnHqERuM340S0S7nNLG89TUplzOCl10ys5IoyUhdsWU
mpJUorKalKwRai3TZepQrUoX6zYdWdU2VCfpot5fNKZIsu/+8ZznfP76fp9H
INmyItbQwMAghM7/u2SHhDtnw4GA8jl15gVVLNzu5Aev4m+CnhPVLzdRj99t
2M3nb4PTli6FIuqSG3lOE/m5oOHc2/yxkoUE/7TNn5yOg7JK4BJF3TkaVzjg
dBZkAeNa2woWjLXPhcSpHi4fK1snU7JQ1lKa/NapGbpE/kXakyzUqnK1CbMf
w74gn6El+SxIoeP4u5Re6H/99UPGLhYS+9x61bVvoIGnyJFuZcFUsEf4dN4A
4LWaG70xLByybHUv+0kHIa9Wv42PZEGijbhu1PYRXJemlg8sYSH5zh7JFuFn
8Grfr7Gcy8L5JLNwm2Vj8N1Y7bU8N9onM77fe5UB+vg5/LbajgV56ZewoXcT
MFrlKd1rwYJB5zO8lmGE+x8bPhYbsjAzdWN6hPtEbNbZN6v0BF7oj62c/BcX
71xPD1zWT2B538/bjySb4Kft8/OkTwiEviiY5ehoih+ucH19Own035Ls/Ltm
MkrnLoiY1UxgNu+BgyjaHEfveyepGwiYgl7crbPApNe/Xwy7RGApifrkHGmJ
0fF2gweqCTxq3DAhyoOHnm5uxiuVBC7tu72er+ehPcfS2KqYwMaJac80Git0
ff++LeUwgZiUzEtmxVNQ4WGsuZhLwEs6SxMsnopZB2Xfi+UE7ll5TE7zm4aV
RcMX6jMIXK2Vn/AwssY/FsREPNxKIHOC+49tPdboqVYMVSTQft0ZgYnq6Wix
xm/1o1gCfZWCwlKZDU7t2sGviyZQ+I0tpz7SFq9X+feErCFQULyxScyfgaYd
ZvbZ4QSiCtdpzF7NwA5uKJiEEhheXDFS2mCHpx9xm5YEEujtW5TemGOPceN7
uqxEBJT+c+zaxQ4o/rrjyCl/AjXZaTyppyOePOd28Nw8AjmRMUFGekfMMQxT
GfgQ8O0uO5vT7oR2ylULp3gRULidqGkP4qNl9dGBEncCWTfyFEH1fPSYKVey
rgRC7CIrWlwE6PN0kmybgMDCxKa1vFwBKrwvGiY5ECi1l7i06QW4vYnt9LIl
4HKrqih0rTP+4im3iZxG7/NsdL/f4IwbDK05Z3j0/zpOR7M7g32Zs+c1mROQ
nP/Az81nsGP+TtEiUwIJ8vAvyw8zaNujbfyWOi1c/dDsKIMmLeaLGep9+rRD
BUUMJgfogjjUtX4jo8dKGNyrupp8dxKBkZvjDyqrGbz5ZHRqEHXBfbO8200M
+sq4dZEmBIrLN8ftbab5wvzkH6jLUzWiwFYGp0974TGX+rJ1wedWDYPyXwfP
2FB3R02J6+xiUFV3+LLWmICw11b0vJfB/KXlQgm1tzrD8XQfgz42rWMrqOdn
a0diX9E8vNIlog4Wlpx708+g03qy35U6JZ7vODhIHXzK9A2XgGzBrpELOgbr
w4bZf6mzzZ//k6pn0Bqnd7VQK1TlB4aHGeSVKSv/pFbu5EivfGbwYbrFkRLq
6rDYRbIvtJ9RQNYharXzXYeArwxGDHknZlE36GaOjI8zqBh7uT6J+j/AEUFM

       "]], LineBox[CompressedData["
1:eJwV0Hs0lHkYB/DJpFrUSS4ljBmvbTKknDbJxvOE7YJ0cWsVMhVKJTRbaMui
pFxLLklCSK7VqMWSW6zbKNOqs1TWJYt+b4lJpOy7fzznOZ//vt8vT+i3+5Ac
i8VyYO7/n35WOM/44GWLtxP6DaxCGhqkXDsX7mGwilF8NVpAw2xjdTiXGwQO
Bm2vuxin18ToyHOjQL98R3oh46PmomOTOqmQG6HznQtj6RefxA86+VAribmX
d5eG+d19fKJTDhPxRrRpPg2ZLRn+ozrNYOqlpczNpWEipUzwJroZ9hqUjLAZ
b/Zu7e+caobMUXHJUA4N79iTThXSFpDPPTtTzNjU3N4sKrINFlq2ZG9k/LRk
Ro7/vgPon4YsHG/TcK7F0MbYQwrVmqY7RFk0FJdEdR81+htaShuaw2/S4A3P
Ut8F9ENpcpV/dBINxwf1+8XFwxBU4ZTMj6VBgRfBf2P6AW5f0xxLiqAhdnGr
IHP/OEwfrhzwCKFB2O34mN32CdSaE4zX+tPg/yRC6MefhiBn6SOONw33Tig5
LNv2FdrH4tLEbkzfEN+RNS4stH9T2HbJgYawjJldE+/m4NJFib9QNjSwpL34
RzAbu7N3B8zfRMOKk16nHQXy6Hv/BxXb9TQMyJKdFavm4aSaS4GbEQ02g0d+
veK/AFP/MWH36tFgPxBvwOEoYMDd/rJaTRpG6oWhfxYpIrgHPvVTocFIuUvb
ymMhNtzZJripwPQDmWfP+CIs7GvNSZSjYQtxndR1WoypDqIAtWkCL+sOznE1
VMYhC6OQiTECZRcb3LkyZUz4pnEiboSAl7yoVyJZgpSy02B1H4EDASFlStdV
sDFTIsvqJrDa20Bi56mKbys96rueE+hYYqgo2qCGV5d1qOS1E6gsDkszZKuj
9afAY5wmAiFzBDvbXqmjoGLC37SGgEJP8Nbj4qW47yOv81Y5gcFcXmLGmWX4
b+nK2qwHBBJXaswtd9LAIZOC8O1FBOKvezV5cpfjDsvEqkt5BFwT3SRKQ8uR
JZLTW5BF4LN1zlRGtSZaR0TfWXuDQP+g5em6SC180O7TO5hEIMvcWLPdUxsb
MjKzbBIIFJ0XKXuv4qAzS/vp6mgCkU4HbNkyDgZ9sh22iySwriczP7JdB1+w
jUa5YQRS9NOK2m25uCuDpeX7K4FzNTEptuVc1FXNfu93msB2TaecFj0efjPt
fH03kMCm4017laN4yNn2KHS3H4EMLaFem4yHwfv1on4/QkCvPi/Jfq8uQu5N
3wteTL9VdYLOal085XzrfqiQ2X987rNmAYWWChr1G90JCO995EbFUchJ+iDd
40rgaJjDjE0ChY82meVuYSxyEL9QukrhE581wSaML8pEsfFJFD5AHl+VcfGG
qS/J6RR+rVp0reNnAlO1s125BRTeMH9bs5lxfKdSTEMThbH5484mewhczz7m
c6GZQpW2fe7fM84+KbHa2krhvPW+3qqMH6rHT7dKKDSXO3X2owuBHlcVH+lf
FLauta4pZszv17Dq66fQY2f4FT7jNeJgzu1BCu0cV4jVGZud7546NEThQ1Xf
F/KM7fjppcMjFJoNv9QdcCYQ4MvljI1RmPIQ2m8xPrPxt6n74xQ+Dhz5Esf4
/MK+5ydlFNYJ1hmeY5xSkn3582cKK3PyE9wYZ4XO9a6YptB/qrPRjnHBrkOW
Z2YovOSV9vVHxmLdRm2Lb8weYjkTA8bV4yumZmeZ/IULTixn/B9q2ojy
       "]], LineBox[CompressedData["
1:eJwV0mk41fsWB3BDg2jCTSmZdiUNyq1zkOH7kxOh3BQqiShDMqRSREcZEzJk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       "]], LineBox[CompressedData["
1:eJwV1Hk0FfgbBnDRTrI0isp2RUmkNGMpz7dMmwpjnSQGhaFkSRGVKDupJLQY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       "]], LineBox[CompressedData["
1:eJwV1Gk4FHoDBfCxpLLcLCVkmYwipAVF0flLiZI20qUUKYm0qpRuhZJEki0V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       "]], LineBox[CompressedData["
1:eJwVkHk41PsCxke0GRUpGlmGX9dISt1uRcn7vbRqeVqoLHGpkEJougnVIam0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       "]], LineBox[CompressedData["
1:eJwVkHs0lAkchllqy4zO0FUTc/lEBuFUR+zy+4VOJdfcWtXumDAsua05FVKR
aiqTymYiRyKtbKpNN5Xwjcu4jAZNhYRJrZGTltGMtNb+8Z73PH+9z3lZvPgd
Ed/p6Oh4z+X/LkznzXcIP+3asRDeBumPgqSL6RXCjAZxwkKH2RkVzDbWZDKZ
B0E4abe7VK2CwtpsxjymEM7npgiH3qsg1kWw7wvjEmwZy91sL1VB19eo3HFG
OSTu/bCQla2C73uHLMcYj2Dz5A9nO4xVUNxSlDjKkEJVNy2kesUIVN4S9sau
7YG7/oKdMdPvgQ/ySx+TlPCpObN1lj4MccNWyqrKETD96MAuSlCCAeuY5duN
47DGajIvpHsQRLRWTjF3AnL8oh2dMwaA1xv4TK9tCq6J7nJGM/shseEYL95y
GvSWThXTwvrgTgI1YMW2b5Asq/3J+moPFKfGqOxDdLBUsmOdWPMKMopm/Cc/
6uLO9PGwx/kvQadrAJ+k6OHRK8FP2qMVYJEceSCQMw/PRNulZbi/gHfqvGDK
0/lIvU26xvl0g+fwr4fOJy7Aqhd8SgK3C3ze5VibmRlg0pffd0+JOkFF8o40
36TggS0hNN9+Oaw1Upi6/2KI/nFG6Wn2cjAAdVjfxCJk7DLZP3j5+dyvoV/Y
QTRcZLWheczgObyqD9cNtTHCzD+5VhtoHXDvpORnptoIXZuMF8vtZBA5TzAg
kxmjEX3ThULfdtiblHqPmr8YdVOF4CVqAzu+tcwrbAkOHJ6RO/e3QoexDUXg
tBTlJbLaBptWeFyZUWCjtww1gkjPsvMtkKrL8Wt7swwVHYmi91NSMOhL2RpX
tRw1s3s8gqOkMFzGyi1KW4H3X5enPRtthtw1JvqPgkwwQnI6fCq2GXLyI5vC
mCuxOnz9jbpvTRCau0dG/bASaa6vxwcuNoHG45q2qIaO8TdCa87aNoFy2O1A
/YlVCBapd+ueN8JVFwd6e5gpFpCnyq8kNsLNLIER39YMxd09wjOmjXAiaO92
PbUZ+k4c8nbpaIANfcXlJ9oZWJGqpVxIbwCxVcHN9u1MFHF63uk7NsDh2mzx
9kdMdHAK5OKYBLzpQddazFkIqgf+YX9IYFNc0y4jIQvrD1YbLI+RQNEqnnmb
moWD9fX0UmsJmJPXL/rsYqPfaA2fOkFCjm09p7OGjRXHN3Ypn5IQOaEvl3II
7FT9Rl4/TgLvzj9M4VkCs64UWnoEkRCbETDjeY5Arury6thAEgQBVS+pFwh0
78jwzA0g4aRaIMq5SKD5ttcLhv1JqHTSfs0rJDDvzbngkz4kaOtmFWUVBPqt
9rBVbJnb76RmS5oIzKzTHhE5k5Bfsi/quJRA3SH21sdOJJQky9y3thJIdxtf
//dGEu4vy5lulRG4ZrffYTdHEvpCF0d1vSAw8LOxQrOOBEulifuQkkBx3JLM
WFsS7KtSzEqHCbQvUxUV2JDgnNWrjfhA4CdD6WCLNQleloW3R1QEuvTv77bi
kJAUwzT7/JlAX6+c5BELEtJ+PKr9a4JAz4f5D03mOMtwqDtZPed/isvyXE2C
+FbJaY2GwHAnDbeCIOHqEX1+9TSB8ykPHPvYJFT4R7ilzRCosKasM5zjKnaj
qeu/cz5moztcWSTUTFhoZ2cJrOR758UzSfgPMrxIhA==
       "]], LineBox[CompressedData["
1:eJwV1Gk0FXoXBvCDqFSEWyFjRxFSUbdUPH8phfLeuoZQXCehEuXFLUMUGZIh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       "]], LineBox[CompressedData["
1:eJwVzWk4FHoDBXBbmyhL0WIZTaVUltvtSovzx1UpeW8LoS7Z0lWRbkiIKBJq
KpWUvCRClFJZsibZwsxomAWjGdtIJcRY8s774Tzn+T3nw9Fx9dnvISMlJZUi
yf876YLrbCP3GNMzvIB5l2V7UcWkWB+i/IP9w1nqi4d6MFNdGkGhBELq4ErR
u44eJJXHac+iREPplk15SFEPTm73OzWmfQ81lbHCo//2gDl5PP67diZ8QtNz
maJuzOF+1h3ULkRw6pbi69+EaCsv8fvSV4gLOs/0avhCZKUnvBvIK0KIfu7J
5QwhbM7YOIss3uJiEyVP+ZUQd+YV3en1LIOhbcC6zcFCqDyokRlqrYRdo5Br
sVCIlLpk3wHtWhROZjYp7BRgJOGVXmdsLbhZbg67tgiww7NewBDXoqq07OaD
DQJ8kR2zLWLW4WGY8cZriwTYvN1mS3RUAzbI8dRogs9ofjYlo/utCedCeqU7
L39GaN363UbOTLQ0Z+yw4HThSd6b1dm3mdiVdknaoLkLjARz2VUNTFydNqVu
qO7CSk/7t0tMWpCcKh50ftGFOtlL+lKqn+B+dNtEYkwX1LZzVZqqWTglTFxg
YdaF3GfR3JP6HCh2Fcf+VcCHSEUUu9uFg7Cry8zfP+dD13+36Zp4DsQfE79b
ZvLx323zUwRiDkKbbzC8Evm4WRt7zPE9F1Ov5w0ghA9/wfWhnUfaoTdqvVXG
ko/k+fURypL2v6246FZBJ0y3Bx0Jc+Jjj9PjPylPO8HzXrfpWwAffrfBK0vu
xBJGTE9DFh/DRX9mbYrqxI0Ea6srSl1Ye39F0ZhdJyJWNS6Y4XbBW5FLey3u
gCfo976cEeBmn9EJ4z0dkEr9WcSNEcC8x8RI1qwDCXIavLo0AbZ+/VHC+6MD
NbXHtDJZAtgPa7wrWNGBNQenUj22CLGVqD9TnmxH33Hdpx3S3aj1OululNsO
r5shpc20HrhYG+yM1GyHzGhqZ1lmD8b79aN5i9qReKhG6lllDxSsQgu2K7Sj
TkPVIm6kB1cC+DTKJA/rMp58sLLvRVovY8ExNg9fipnNldp9SAsKney8y4N3
91pBfm4/wqgf7i/W4IHvxJ5bUduPrsy+ulmLeDjQdkX/o7AftCL/vVIKPGyu
7w3sXibCoOsf0oumuJDNe6ykFiXChQCX5fk8LhKCdUwDnAdQtaPU40MyFxWq
S++ZKA0iw1Cmpmo9F7/H1ZRarhvEJUXv9+2ruEiffU64b8cg3jwSys1ocREr
Zhl4BQ/i1tyFyo7KXNh1xlcn9g3ip/4I6/RPDkRZSiOT5V9RlVNJFldyIK9z
Sbdz83eExIgS+E4c1Gy7YXDB8jtckv42tnHgINL+obHm/u84OBOfVXGAAxla
wc7DJ75j9rrJgcJdHEz8+uLZmiTxnAW9X3/jYIBn+6RJZggBZw3t3eZy0JCg
u7a8YQgWddkGpm/YuJr/u5EzewhR8fzzdi/Y2NVsZvKrewibZ6we/pvDRtWc
I1bbZoZQoS7a9/YRG2/9af8UGP3AGt3zTyNpbOQcFGc+v/MDIymZ9mIvNq4p
1eulHB2G4Vc9Kz0qG4XGmq9svIeh0hgmc1aLDaGTD6aChlG9T+Ni5VI2tuao
Hjx0dxhJJRN5p5TY6LM6EqLYOIzG6zqUqek2WEQMNgVuHcGbli07h9ltGB9d
6LdfbRQxvTwlrdttcOUeLJNt+IkNoh0uK9XbIH+/65Qv+yd8zqq/CFNtwwtH
b43Onp8IeaAN/sI2yHKiAoukx2CkPjH1ZG4b0tqKNvoaj6EszOnW0YlW9Hyi
POlIHcPyyIEk945WeDV/oRUGjmPxy2TNx09a4fv+kquP7gRGjlarW1i2Qku4
Y/bPjRNIn5rfHmHeinqZeVnBZALSX+VfVKMVq0jcULTDBOT9l4bv39IKdtHt
sLSYCag5+QaFG7TC7Hn6Q/a3CazPs+s2W9YK5fs1HIuCScxT+FBrMMRC3mmF
A0usplGQblnimMZCQ6JqYI7dNEoVA/vaU1joqVqWbO4+jTXRq7+5JrOwbOna
gZOh07iXWB55JpGFSxWWERWvpnHXwTo9g8aCnUroS68Vv6B6XmXAM4SFiZdD
qiWTEn8cMd1oz0JK0AmR4SEp8nCgWO6WCgvhyVP7Rr5IE5dmJ4578idIMfnk
7XlZEsRz0Jrc/gmrzx47d1BvFrm96uiA+ecWCEfv2s0vmU0yKn2J+90W7O72
CrnpO5d8ZdxKZf2nBTZC2jotLXlSEeyRnKvcAtE717CanPlkdaTG69p2JvSV
WZoWzork7413s3WymZDHqAtveAEZMWuKcwtjYueg49gKWyWSEX2g2taOibZK
d2nH9cqkuHy0qtaQiVdXqpwoo8rkcuWnlhwlJo7N8uM3NqqQsq01lZnfGXA7
E/RKIVGVXGayWpZ8YsDAc12jtcsiEpBopin7loEmlfXz/UwWEx+hSkpJKgPF
ueH318uqEYVpDev6WAaCpPX+amhXI7HjCw898GdAnnd+l3e+OvFQvnJmjysD
3ek68cnBSwjFr2NO1F8MxK9ZKldou5Q4rz1t6m3KAC3x2AcXyjLiHRnofVWf
Acf4vxsVepcRm9N+vxjaDIz/+VicXLqcWGn/bluixICg2/xcZZQGcZznzzwl
y0DqdqPlH100iVNow8i7UTpyLvspe27QInV2xhXZ/XRE2brtkR3VImFP44rc
OujYxEvJjPqoTf4RXzMoZ9CRsPZ+zsc9FHJW3anveA0doeVxCXsKKUTh/X77
4hI69i63fVy3Uofs3aTTX/qSDjPvD4eVo3XIffFsg7YsOpI1XFc2jOqQskd5
tkkpdKx8l3HH5vAK4uFzysHpHh20DZV6jNIVJMv3nMODG3QcG5aj1+pRibVr
gn90NB2ueT8o0deppMbBx84mnI6T4Qemdt+gkr2/fjzTl9jvQH6rwi3JPufH
goUSXxn1u0a7QyX77h1pb7pIR66JePJuEpWYS70t3iexuGKGlZ5NJbJVniF2
YZJ/hkJc1QcqGXqZLe9+gY7ER6eOR9ZSSXm5QMlS4kdnGy121VPJ+gdeGqsl
fq1Gm6hvpBLBHmeLvhA6eI6qx5mfqGQ8orT5pMS6gqUWnwVU8uPSqj7/YDoM
889rpXVTybuxDHN7ibdc5oo9eqnkc6pbqonE1rpJz/tFVHLF+qLvVBAdZ05Q
tIaGqET+uaFNuMTB2y6KXwxTSVXaIYabxJcVP7ecHaWSkN9yDltKnPDsUcz4
OJXU0TtC5kqcGibnWTRBJYOkQE10no7sfR7mwVNUYiRXnF8vcf6Kak3TX1QS
UN99KEfi0uHV4pkZKlHfaSx1XeL/ARUkDqM=
       "]], LineBox[CompressedData["
1:eJwVzXk81PsCxnFbKrRIKdmGXzVI21VHC55vJKKrU7aTtBhrZEonypaW4+CU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       "]], LineBox[CompressedData["
1:eJwVx30w1HkcwHFCGSlWUcja9XXtWXRMTzTx+ZTKY65IGXSxHguJoSnUCXmo
0a5SlOQQJUcPVndSQuTysDelfotdm3Zt4mwlt2WjnPvjPe95MTlxPuEL1NTU
ds73/0tOchbah5119tdrjs6yV0B7H8NrH+Mg9Kuz07NsFTD3tDmDwTgOR09N
G2dYKaCkJc9ci5ELo9IOVTxTATFOSbFfzC9DtlPQLRZNAX0zUQUfzathZrDc
cPbDBCwSSVkK80a46nWjhFszAWVdpfH/mD+DQ/5HH+9fNQF1t3NFMWsGQdO0
sEEpHIdIeH55IkEGPdTn5DW3xuCw3ErGrxuDraPWUZHcd6DDzGS9dvgI0jtD
08Xxo3BOv5tdFjwF4mK/vKrUt8AR7Xms0fMZtLMP7BWfkUN8RyYnjvUVmnxf
rSb8Ebh7RNd3pfs3aKEZ3Iv7LoOylOhxu31quNOtMbjJUwbppbO7/51Qx3h6
3MO9fCmo9Q3jw2QNjHGVCoQ2UlidGHFsD1sLfdwdVH9WvYERZeHexY8W4gP1
HVWB696Ah/zQifPx2hie5tH9sm0YvEd41nS6Dl7wbUjtDBqG8SectL9qF2PC
BmWnodYwrKFRZi4HluA7suBDdsBr0AFliHhqKWbe3J4pa5OAqyLgi4WfPh6a
lNwrZEugvy1MPcCGhizJ8qAFvw1BQ077LwwlDXnmG+S5rCGI0EoaFggM0MpH
N+NarRhCE1IadK8sw9sikK1zEcNPkdYCr5DlGFLb1bnxjQj+NrBZnORoiJJp
E72wEyJoqksvttEwQn3vceOeH0SQos7e1TNkhNqtn2IP9gyCjjjZ7TB/Bdq5
mQ0Jjg+CvIpZUJq6EhPX92l8sxuEgh+NNRv9jLEyz09v29sB4F2J6AxhmGBO
hVxv7fUBCCjYL9AdNcGZ9ElSHjEA09sqVaXNptix8OdlLNYAyORbj7Vlr8JW
bpdZ3/t+KHeyN+0NMUMLD+cN9fx+qD2dRIu0peMig/aP39P6Idsv1FNDScfq
iys+5+3qh/XisursXnNMV79ouZ/eD0VWxbW9ngz0CaN1XJoUwq8teUWejQxM
KQz1t30ihJ2mfpVdlkzc0uQacLVQCFsOdwbScpnIfb/lYOURIZSu4lj2KJn4
3mnE0sxNCJZPblzyDrTAjfZqlV1ECDzbNvaLZgt0L2/JyFIXQsSU5vNnbIKb
B09Ftw9RwLn7iZHLJVjryKq/+YiCmHTfWY98gib5+bOm807y5Qt1LxD0zJcE
cR9SkKNMOse7RDDrjA7naBMFdY6qmcISgtQf+ie3N1Kgap2jqmoIXg5fOj3K
p4D3QjevvZNgqN1Er9PvFFypiI3KekYw7QgZq6+hoCJR4OLWTdDsPM+EPe/7
Rryv3QKCkt1fHhvdokAcsCyq7xXB7dqhyydvUMCSGbtIZQTzJSavqysosOMn
06/LCbImHQKZ8950WqQKHyVoo+moKCqnwItVcmdsnGBwTJdPThkFCdEM+uQk
QVF4GYkqpSB18ynVvSmCavnO3sPXKDi9RPoyUUnQIargnP+8i25XnJ2eJriW
67fLvYSC8jTNyAdfCdJL7j9vvUpBze7wramzBGP7mqI2zZtv8dTM+TtBa8Ng
w/piCpqnVqvm5ghquV4TWs/7PzA4Toc=
       "]], LineBox[CompressedData["
1:eJwVz3k41Akcx/GR0M6MSkrOmeHXRo7Ss6yO5fs11lGOJUmmtjLOSqwy+7Ro
XQlb7ChJ7KxkybHErtpHNpsjIuyi1G9m5BiTdfyeHE1ylLV/fJ738/rzY8iP
OBC0ikajua/s/4q+56vuDLxsF2CikyQqo6C5l+PmyzkJsf9U1fFKKFhuqU/i
cL4DG5PUtk3FFIgepbNVOGnQSlOLSi6gIMxWcGaOfRMO75gLc82hoHcxNGuK
XQq6urkmgmQK1CTDxhS7FsYrH/UfPkZBQXt+5AS7Dap32CSxGBRU3k2ThG0X
g1nW5rp3jpMQAt03J8/KINLp3XP9xAkIl2+T1VSOgb4nMzyufhzohheNB3ZN
weDjWdrcxBhkrH9qWnBiFvQDGhyvm48BX3LwL+WOd+CRpuS/K+hfiHx8kR9h
vAAxt8qQUT4K1d8wvbX3fQC6g5VJkuooFMScHrf0peH4yB1iz7HXkJi/5PV2
Ugk17cVr4trlQOsdxD+jlXGMnxe4jSuHrVHB5w+aquCFn2uF7n+MwIjixiHG
Q1Ws9Buya7Edgf3yUxeuRq7BPZ53ABtl4DEiNGOx6Kj+k5N2nacMxpv48U8q
GOhrmXl9HzUM2zX6DByOq+PnZV7Wb1KGgQ4Kf+nsWpxJn6xa3j4MzhRvzshn
PcZOGTn5PhuCl42BSjxzDcwsWwqtiB+Ce6nNxzgKDYxL01Zh2AxBsIpgsKtr
AyalRgSXTQxCwNmYe8xcTdy7aW+nWekg7Agx63Lz34gXkjsDjp4ehL83mDME
uzdhdY+aVY/ZINRVJuaZK2uhHy9Xbjk6ADFKpp4d/Vq4ePLcV6nnBoAujXYJ
r9mMmueKYvvUBkBebJiVH6uN6tHUZfuSV5BlorO61kcHle9b/pru+AqEucGt
/hxdzGbKPjRS/cDL+rqLOaqLl6w96hLz+uH9l0Xz+fV6aDU9VMx16geZnHu+
MUUfn6Q7G9otSOG27U69Tn8DNP3skl9EuRQqkgUaIRYsLIzMe6gSJIUUnwBX
ZQULE+huB9uNpGAtLShN6WSj6QOu3+t+CeRsy6vodOUgt/SFkc0tCcQ9Ss9x
reWgAcN5nfoJCbjr+RS1bzFEaxFXT0RIwD689YhGmiHe13/rEkiJIV+fv6VD
YYisRIV2T40YtjTdyfY4YoSen66xX0wQg9Ci0bSn3ggr6BdD5V5iCJ5d3d1m
SmCWyceJbLYY+NUznLQfCeR5azV7zJAQlui9tD+TQLBq0kqdJkHgXfOCeY3A
2OdNKQ1TJKQqBBnCbAKlgUXNVm9IqNw9v3hDRGD0txal+pMkzDcs9xWXE3ii
WrB5Rk6CsIeZ3txKIGV8hvc7SUJu4ZnQS20ExtFLTk29JKEwqsvB5SmB8VX8
HIsV39cSLjztIvC4o61bSR8JUp5maO9zAlWnujfm95JgLNNxGJYReJjbQ1zt
JMGyJpr1i5zA/FVKn3R3kLAnWTIfNEogHnJhrF+xm7GoamycwFwztZCMdhLO
nuawpqcJtORci77SSkLsFwnzv80SaEx75tzRQkKy+vCzKAWBmT8s7GSuOOdu
4eX371f+uw0cvdJMwu341SEPFggMHBCKOppIKPcK4sYuEZjQu3aRueIaoxYD
u48EfhQfELg3klA/u3V+eZnAntJDzIwGEv4DEd5JiQ==
       "]], LineBox[CompressedData["
1:eJwV1Xk81NsbB3BbEipL2fepXNooFaLPKZWbJEkq7SqUrtK9RGlVpCK5JVmz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       "]], LineBox[CompressedData["
1:eJwV03k41PseB3BLKdu5mK5Dlhl+ynKSnHKRzOdbXZLKSUWWSibbjcahRpaU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       "]], LineBox[CompressedData["
1:eJwVzXs0lAkcxnEal0J7Gsomw8x4Z80mSluzkfL7ydBNbdalsLVMbpWETEfY
LrZcTpFtbRcdZ1LJyqVoVLO7SZNNEm3UKKNN3vedyTDdhEZk3/3jOd/z+evh
S3Z9HzPFyMhoHbP/W7JPYrYw+oi3/4KX2brXemjq5AVs5G0DI+PkPfSAHibv
NvzM4+2FRdq06H9f6aGkMZ9rysuDfwKIhPt9ekhYLt05yj0N4rjjKUdVeuj8
FF/0llsBnuJmQnlTD+bqPqGeq4Ckle+meR3RQ+l9WfIAtwXSNwWGiAR6qLmc
p06Y3w2Nvw+aJ6wchDh4dHowhYQJla+CkzMAifRcUl7TD85+6Sn9ah1Y8A8J
X3i8hYhK51C9SAcFM1pdSiOHQCToHRVV9YNEHXyL9WAEorc+vSAT9kPy34ck
u4Rj8JDb83qu/BXUJlkFzV49AeYqpzFV0Csozdihc99ohPdM/SocRrSQJRsP
/DBojC3JJVER5Vow6uzFv9JZGPlQbe0XpQXn1Ni0YBdTTJy2YIk7RwvU8MlQ
y5tm6BOw30f6UgNr6O0/HU+eigtt9y7xK9fAeqpwnqOjBS6fclJvulsDujuS
A/eqLXHZmythX/lrYD5b5eD743ScEO0IW2SnAQsYjuoZ+gK7X/tlRr6nYaU+
fNQpZAbKxSk54a00PFVGG4e7snGJJEvbVk5DfW7TFt4wG2/H5lzqyaUh1lTa
295ujRLH99UHttGwNSWj3qrYBr0nR57YrqdhQdy89oComThtXBfRvpiGh9au
llLPWRjI3hRobE/DnzVZZ1xZtjjQrzweZEJDhrHLhgfPbZGb/0O6QE+BRU/6
qkT5l6j0X7ynuosC+iK/SJY5GzksztkbTRQUfW1nogixwwHrbLNltRQUFsc2
R/HmYOXStgiDjILwos3tVto5mPFMc7bnGAUfxWUGWYM9PnvRMd9jPwUkvSJN
mcNBCSdx0c4kCs4tX2jfFuWAioApNU5RFFQflrLj3Bwx3XPiRFYQBTkhW9ey
hh1x4EZwuMKfAlFPaUVOGxevfr6yOdWTglNzz1S3reWhV6PU/LQbBfsb80+t
VfBQWbemfjWfgnX2IWX3BXw0aEYfXZtFgU9icwQ7j48bjoa+3GRJgYwjETwY
5qPq0Haro0YUCO6Un1gf4YSsmrzG7hESCt2ULh0NTphmWlBbpychdsjkUYsL
gYOCmS58igRJ7Xte3jECv1U6lGWrSUjIChpf8wuBmkoPXSRjaZC8y+pXAq9X
eYu8GOcOSwsKTxD4Id7s+ZtuEmo8DZ9OlhCYO3vL7jDGhtuTqouVBLrwxxRu
z5j/Dqv8pmYC3x4MK+tWkVB8fmd8dguBZwj3snrG51PbfVe1EvhNyN1LhYyv
2RaOtbYT6GXj2uzPuCfcJr7zCYF2t66Lrz4hQUja+faRBBZ/Vx6Y/5gEd3m6
4wWawJjHXVXxjJceVhtitASWNtVNFzMOEJZc6dcRmFQl6R3rJCFlB8/x3TsC
jW2yW+IZZy47aKgbIpC9nQ4UMz48ve9x6jCBrNvUCy7jU5fPH/n4kcBV2GDV
1UHCuQMmcX+MEbiv47fKOsaVgTErMscJDPaYuqGAsdzproP3ZwKvCWeObWPc
MORsmJwkcCT0RoUf4/8AwhlY4Q==
       "]], LineBox[CompressedData["
1:eJwVzX881Accx3FGKvRDPxSF4ytExLaWyvX5FI9STpMfq2lad36LRHePyo+6
cJMVSYYIHZ1qRlkilJrkR7hCrOXs5PreD9yV7Mqh7Prj/Xg9nn+9zRnR3sFf
aWhoeKr3pYWnGDpOQee2TjUsM37LUkBzL4W2jxIOznpCrz6mAmZbGpMplJMw
GOy2v/6YAgofpZvNoaRBwLXwYXaMAiKprKiPZpdB2GdipRGlgN7psOx3Zjeh
xFkZ3R6ogLkDw9Zyszo4xG7h5HgpgPu0OGbUrB2uc8J2nLdWQOWttIFIh1ew
o8ipU7tFDqHQfXksVgTlb5nSNcFyOEKuFVVXyqA+8f44U1sOuuYp1kLnd/CP
ns1d3ytjkLG4w5Z7aALa3L7Zcpw6BowB34danR+AzW+iu74ahZgnKYxo6ynI
s6nJMkschaqj+j4rd30CQmGcRLMdBW784RHHfRo4FHF828yLEUgqntn735gm
Rqk4vyWnjYBG7xDej9NCTt69596uI2DFDDnhazsHd8wPkFCnZfBGmfuD3gMd
zM9oe13UIIPdZERiVsw8NIku8gyJk8GeN5l2pqa6GOCRraGgymDkMYPdVqGH
PvXJXyfPk4GDQb+J688LUPBhUUphtxR0QUkXTCzEo0GW1XpcKeyU+3+08FuM
d1jHps2jpfCyKUjTf50B5tVU7a1CKdw923yQojTAn+bX5pxZIYWQOawhPn8J
WtLKds2VSyAwNv6ufv5SZEeulu1slcD6UDs+jb4MKU1+QxOlEni2ZJ0ea9Ny
3HDx7MLA0xJoqEwqWKdliLSawS3PD0ogXtPWq3PQEIXxbUkrqBLQFcS5H6le
gdT9xiUJJhIgy8yzixNWYqjhVcJNUwLZNkbadX5GmN4RkTMhEkNmfkgrnWKM
Vj61n+raxeCfHcDXlxjjYOzQjzpVYph046mKG1dhhvMNiXuuGETk9hNNqaux
JtzR5Tu2GEqoTqu66Ca4qSTjsF2YGCo4LINQe1P8lef5INtbDKl+gR5aSlPU
qb09z2GrGDYIuDdTu8zw2FPNCIGNGPLWFlR0eVCw5bwq8tZyMZx+lJ7nUUdB
40leUJmmGDxX+fGeWprjjazBtioFCduOtB4wSDNH7hpwLBokoXg1w7JTaY49
cz8/rO8gwfLx9Zw9Byww7dvR2ZwGEjLtm2x7Gi2wfUZ00+0PEkImtLvbbQlM
3XJBaX+FBEbVe0raBQJFikknXjoJkUk+M7svEnhw40avYLVZPtV/618iMPQO
9fgatc8qWRmZOQQus78i5J0noXKTajq3kEDOxSij6+dIUP01219WTmDFVP/6
8jT1f49+enMrgZmM5IE6Dgn5pVFhv7QT6F97aFG82qVMvqt7B4G0/XwPF7Vr
DDOnOvgE4lWffxtTSBD4Lw3r7SOQResPb04mwVpk5DosItCukmrUfYYEx+o4
02skgblc774stTdzBlTBEgI3Fwgu+6pNsy68LRsh0Ebo7vKSTULsYYrp+DiB
J5k+YuFpEhJczqj+nCDwe/prkqs2Z8HwC6aSwJ6Bfnmg2nm3Ss9NThL49sm4
ofQUCSVs7dD6KQJ5gqXOv6tdvjd4e8IMgduf5dAj1a62aDHZ+pnA8PcnLjmo
3ThhpZqdJdCx4F7Xu0QS/gfcDlsH
       "]], LineBox[CompressedData["
1:eJwVx3081AccwHGPtXkqPcjjufMTkUSrFsX3O7xSeXitQpue5oozTy25xjGV
MSzq0sVR5kVzaq0zRXWr1BTydFuuSFQ6/H5359wqLuFitz8+r8/rzWAe2hGt
p6OjE6Lt/5dnMud5Hjzp6272S+jzYhU8lNCDd9G/hezKiUe+Ws+1NP5Ip6fB
JbLkQtU5FZTfL7Q3pOfD3raZHbE8FST4sBMn7Uuh2LRokfKMCiQzsbw39pdh
e2144dMCFczvlzqP2YvAfBNNvC5LBZXtFYdH7dtgPT/QOixeBcLa/P4E9+fQ
0FfMK/lMBSx4XKpMHoLqVz0bNVNjkDTiMlQvlENc4vjypY1jYMTIdn614Q1s
mJfe0MkZg1MLO1wrvxkHfoSPzVvvMWD2h93T73wP5w/9Jj2hVsLh5mzmIedp
+KePJuqqU0LddyY7Lbd+hJtugvacI0qoTI9XeOzSwdbcbudgTyVkVWi2Tyh1
sZlMPvLvxCjoSAbxDkcfqyaedAXeHgWnlJjUMFdDzBrMS8jLHIVhdUmE8d15
6J32bLgscBS2jcT9UHT4E+yxd2rQNRuF0GHuShrNCJ2XRNASexWgeMA8/uiq
MSoJ7jk/gQLczXvs/Peb4vqQBo+OZAUYgTpqYNwM92zspdgBCggci5x0CF+I
LqaBeguWKOBZ00HdSDdzDGaXFoSQcmjIe7iPrjZH5ebXQcRdOcQYsgfF4kXY
U9W+2rpIDgeS0xtMyhbjcEHevT3xcljNWikOjlqCeuI7hsLNcvh7kZsx22sp
3moSzmymy+G2MOu8m74FrrIN49R9lEG6ruuXnS8ssCz2d052nwyMBjhbkuqX
YQ1PGhJwUwYjAgavIsMSr13v4cTwZcBbYWUgCrdCs49uAtNUGXDLYlqj6NYY
LZ1/6WWkDCJ5e8UmlDW+K7nDWAky+BBQPVXRaIPGmna3pQ4yGBrxS23KtcVu
CGx+PF8GVT6eNl1RdpgWMMT1U1JwNYdtzlpFw+Vxg6yvJBTkhh8I0lfTMC1/
rKLmNgXrBiov53bZY6bnUcd7VRTwXc5f7Qqi42X3bMG6AgqO3S/kB4no+MZ2
0DI3hYIQm/DqdkcGzn4t7J3dS8EXSa27zfMZ2PfCI6JkKwUVtkzHTjUD1+qb
ztqspcDxQU1x6G4HjLeLsq2iU8Bd1eTa3eiA0oGyWwvMKIgZN3jc5kpgadEl
s7RpEph17+j5pwn0ja8Nui4jISFrp2bbGQInjtcYRGvN3lnfa3KWwOhlMy0W
Wuep2ae4xQSGMoUsDkWC0GtqpqScwPstllZ+JAlTf831CK4QSJXyvSVDJHC7
TQofthLoyFubqHlJQtnFxNif2gjkC34OrdX6YorYf0sHgay7n3oxtb5hwZ3u
EBP4sjHD5dELEgYiF8dKnhLocdYolTdAgvOQlb90iMDM6rh29+ckeNRzaL+O
EFgzWewj7SPBO6d/KpoiMOm0RHRO62Dn8j/kCgIvxH/fpXlGQnI8nfb2LYFK
hW9URy8JGZtOTF0bJxAzmmyPaZ1jKn2SoibQafG212u05tdePPnhA4HNn+/P
Keshoeq4AevPaQL3ieQHQ7W+sj3aL0NDoP+K5BA9resdWux8ZwlcM/fe98ZT
EhrHnabm5gjcJDrqFaf1f+bVYEY=
       "]], LineBox[CompressedData["
1:eJwV1Hk0VesfBnBDGlA3lCvlOBxSqFQkRc8ujVS3gbgqQqaSoUtFMkTJLYUk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       "]], LineBox[CompressedData["
1:eJwV0X04VHkbB3CvtQ+TbVgiYjguo0lKbYXk/klKklWSGuVlMKZIeFjy0spL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       "]], LineBox[CompressedData["
1:eJwVzX880wkcx3FC12mqJRS1ja9azY9yj+ucks/nuEeEelw/6OhSm5jLrzh7
5KRInK1a1ClaeezQ76LymHo4mvKzmSkpP45Tl1b7bizdrBrKfe+P9+P1eP71
duYlb4mZYWZmtpHa/y09xJvpteeYnzxbCZxcPTR3s0K3s36GRmFZe1OOHqZb
5UdYrF+BtkEOPx3WQ+l9MdOKJYLAmt5PokN6SFgnSPzAPAtWgaER/el66J6M
KxpjXgWJ97PekEQ9fDHwkj3KrAVB+9FgaZgeytqlKTqmAp7/k7qhy1UPVTdF
Awmef8Ft377Ie7WjwIeusyOpwyBW0AySiFFIUq8YllWRECy+cqXSfBSsnXPZ
z78dg3GhIdr32gicmKfklO02QGJWUNTUrhHgDWxrsOh4DznX9tR9th+BlJZc
XjJ7AhzJ3UlePTq4vY+2deGGT7CYf3W9j1QHZQfitau2m6Htym+8R+N0kCOd
2jw+Yo5frS+5c22NDsy6X2B9hgU6nFdxzek6WJYWm76NY4U265euznijhVfG
4vDZ92Yif17fLVWTFoLVew+eSpmFUZ7iFsYfWtj0qtCNwbDG8/YljxVZWtA2
8bIfVs5G1dunocpoLXjSe5YE7LJBjwt3+ccDtWANRu6gYQ4GL//QMeGphcDR
yA8uYfOQVKc3MO210Ne4xzzSnY51bjR9+DQJNcLmKJaRjhmfT1yK0ZEQayV4
0dk5H51kfvELekmITj1QQ5PY4q4ZrXZrW0hYyXfrDOUuwOvxnjbVMhIezXef
LfCxw/59Q+caKkioq8o5525hj13pk/vbi0g4YM75oeNve4yIf123L48E68GM
oCSZAxpu3M1330+C+pJzkTRzIYr49BnCvSQULV9kWRu2COUOIdMHd5JQKIlt
47Ic0W1ieJZmMwmRRTs7aW8csbb+ScrcQBI+fn/RJJU74aSqPqF7LQnDav/0
xvzFKHkQ4/jYi4TydV5OKu4SjJ3/6XQym4TKPAGd78FASa1BzGGQkB8WHWJh
ZOA4zb801Y6E1YNlV/NVTMxqc7Hl0kgoWXGuUhXCwvAGP09/SxKy7otLQmop
Z9ZsezSpgY1OYRfbXZ3xhV1/Sb9BA98lte2gi5yRzrAYko1oQLqY59phdMag
gi99UK0B16bLZzbtcMFyszD/40MaKPRo5DyRu6D7g7RjX/dpINZg2aXgEHiq
mmN+sksDvNv/skQFBJYlDSWcUWogIWfrVPBJAn+Zc2plJmXBVlkv7XcC13l7
v+dSFhoFJwrPEBgs2VLgQbnKxzRZXEqgjUE21tyuAdOD6Z5L1wlc5RWdPK6g
/p/QxM1tBB4XbQwPf6gBSUVi3G8KAtXl2ad9KVekdQYEKQncmS7qc6F8x75w
QtlJ4PK3C/e+bdPAYKRtXPczAm/4OdQJKbOHFwW8HCYwQtltW9+qgVWyDMYF
NYEm3VRBOeU1eQOmmDcEXgjQzxVRDmWX3iK1BB6GZU7hlFPjWYx37wjssn4a
NdaigUzfw6ZqA4HiI2xTD+U8m5dP04wEHhT6Ft+jXHKz4tjHjwS6vb48dJRy
ebYl/88JApnFU/kplK9vjvHPnCKwOnfu6h8py1xal/h9JvDswHO1H2W5YZlp
eppAxcMEyVLK/wH4F17i
       "]], LineBox[CompressedData["
1:eJwVz3tUjAkcxvGh0sq0q4vkNpfeSCMWGxvh98uwqytmaiVbaUoz283WMS41
VkijbWtDUjmVRJ3WFjmTNaTtqk3NOAnt2bKcmQbzvjNzMDsy1Wrf/eM53/P5
8+GK9gv2TWcwGKH0/m/FD6IZqxLyN93odoz17jBB1yAnZBfnO5j4G3zr200w
db/1JIdzBMYlwsyltCvaCth2nDzgylZHL24zQcpGaeoYuwzuSO3L3VtNMDgh
KX7Drgfl7I/9OqUJ7Ic1Xka2El5SVDO3yQTVD6rSKXYv5PZrfHdUmqDxet5w
yoq/4E3J/swl6SYQw0CZIUMLQeZDCb/wTZCm89YqGvXQPaV1rp5jAgdujtdz
vzfA3p1yT6g1QuHsPl71XjOkarmBjxVGEA2H/27T/x7W2IRTx08aIb07R7Tf
axyy+7bH54Uboel7ptA98F9Qm5PKvuQZoTormVy5i4E6/v07zh8NcKJqcuc/
hmn4TJZbl//UAIzBF9iSaYNNjEvue5sMsORA4uFwnh0urD1U0PujAUYtF76Z
dW8GLhZcFsRKDBCkSzp6Nv0TzLuWnXZviwHCRouWsVgOuF7ZJ4gjDEB2irL/
aJiFvMrfPGrtDLDC6ekifqwjPky2lDx5SYEDWOJGzJ/isRhl8u4+Cr42Ro15
RMzGu2o3oaaRgj87EqZF+ThhfGeheHUxBc2nu2I4Ficstl89J1pGQaKd9IVa
7YyuEqW4Mp6C+IysZma5CyZVur2VhVLwuXiZOiTOFYffB2fU+VHw0NlnlnTd
HOxxGPAc86DgbuOJiz42bnhL0JCQ9xkFWdN4O/qfuaGPwLtxxwQJDiOZ29IU
c9HV6TbBf02CrpZbXCVzR+jq/ZU3RELx0nm2yoh5KIw87yvsJqGoPLEnjjMf
5ckBZ4KaSYgqjlYzX83HEHmHL6eWhA9brlqrWhfgwbrI0YASErS6zYc75Aux
47nkuVVOwuWNqxao4hahS1W2dOYREhpOSZ3Ey1nIdxWIzyaTII+ID7axsLC9
NLZKFUPCmpHqermKjUq+CyNpJwml3hcbVMEc1JRWnAvfSsKxtoLSYCUHk/ky
c70fCaELIq4+8ORi2M0a1hUfEgLSevY45XGxvOi9Qw+XhKqFIs9+CxcDjyn8
o91I8OysKwnb44G3Oy8VzmTS/5Z38B61eqBKlL95zXQSEs22A708Ar/amz1j
ZEwPoqZ3nLyfCSwfySmTmfSQckI4GXSGQN+AsCghbalQMcQ8R6CZKeDwaJ+2
SAuLSgi0jtm2DBn10LjOOnGhgkDNxOSqL2hb26ee1l4jcJ0sei5F6aHoEbOg
q4dA/2xee4xeD+U1qZLcXgIDW+K91tKuOaDmb+sjUNV2+6wj7VtuReN9agIv
xdw83PJaDyNRLpLBJwTalPcen0/bSzuPr9ESuGvlLfnQSz2sVGSyrugI3Bjn
D9dprz81bN33isAAkWoil3aIV8UNPUlgGMs1Zy3tjGQO6+1bAtWFzgPndXqQ
bThuvWkmMHT76I1U2qccNY8PWAi0P3L3/Fbapddr8j98IPBd5ME0y6geLmfb
iu+ME+joFylS0b62c99m2SSB6x/577lKW+Fxf9GmjwRmbeDsPkq71bzEOjVF
4MyfbL+NoP0fRa9Ymg==
       "]], LineBox[CompressedData["
1:eJwVzXtUjAkYBvDu2iSq1cpUM/VhNJXbcSkn3lc5Vk0hNThhV9PNJaXL7EFR
EppDFC2FTmVEFqNsrDZTqZSmTKYottgYRd838500Ro1u++0fz3nO75/ncRbG
bY40MjAwCGTyfxccFZotjji9ekkE5WmvpKGhgxOwlbMH3PelvGh/QcNkY/Vx
DucQ7Kg1Z51hXFCbxTbliCHGPEk+3kZDzCrR/mF2Pqiuc6++VdDQMbo7d5B9
C6z4mVvOtdIwpfsDV8OuBPlEXYKsiYZieWE8xW6GQL8ppQIZDdJ74u6YBf+A
nrWNei2hIRqU+eoEFcx909LrL6Yhts9VVSEdgEFDIi9hPw0Wzhncfz0HwTdj
iZEqkIazM1p4xbu08OpI2aobC2kQdofUGLd+g/Qil2VJVjTEP80QxnG/g3+O
+9p6jQbKD1gGz/Ibh51Fi0XRbRooTt5HLtpqgGeUIbFKqQbSC8eCvqoN8dFG
qaozWwMGHb34+LAxVvSyY74mamBeUtTBEJ4pesyadhUFGviou7RlqswMu8O1
G9FLA/59e4+cjzfH62siRyUsDWz4mO3m5GSBtI5tu21SDWS9MO3Z3ak4w235
8Zt9alhg3eno++s05N0eKzorV4MF6MJ6tFboM6m0Gi1Xw8+a0GEXwQz0mdk6
4JSnhtd1EYah7tbY75mUmJqqhgeZDb9wdNZYxo+LW7JHDVGmol6FwgZvDnVz
q4LUEJ6Q/MDysi2eHL+/9JC3GhZGuykCwn7Ehs2dVivnq6HNxn2qyGsm3smp
YX22UUOVNP2Ku7EdVtd9U+RNUpBsyNvU+tYOjZbG8P0oCix6Dq+PrfgJWw54
Ldd2UdB3wzm3MGUWVgW/C4lrpCB3vr1JpcAet1nuHRj7k4Lsy1FNYZzZiJvy
s30lFITm7lRYfpqNXzqzgoMuUDCytkRfWM3Cncqt5anpFKj6fA7WnXLAmoU2
j1YnUnBt1WLW8zBHrB7ascctnIK7J0TW0R5O2F/aF3EhhIJTgnC+sc4Jpf1i
u5J1FCzrKb516jkbM4f1XYMrKMhzvXL3OZ+DttPrB37nUZBam5XHr+RgqeEE
lepAQSBLUCKf44ylimZXy+kUrIlt2m4tdsY7Jivk7UYUFDoI57TqnLFGIhv5
rCNhTv3Nixu2u6Drx5FOV5KEbI86Xnu1C7YJShM170iI0poom3kEvgyN51l0
kCAsH+KIzxGozWnL93xGQkx68Jh/DoFlz469N2csCq7osrxAYEpUwII3TSRk
6kRnsy8SeOQpt+sQY6mXfvRSAYHXrr6PrGokQf9ksvPGbQLD0h7+Bk+Z/3bL
rIYmAjkD53fx60i4LNm/+2Qzs2/22s+BsSRJ4bu+hUAlOnpqnpDw0C77e4uC
wD8sSohzjHtCbXd3vCLw0mju8o5aErgqe98PKgLTRjfwd9SQsKjisNP1PgKH
5nlneDBeeaJbH/mJwHVHHesmqkkI4BaUDZAEulZWBhQzTtjHcfryhUCBxLeg
X0ZCivcx/X0tgTEHZON/MT4x7cPLJB2BZkfnhosZ592TnB4ZIbA4Wubtzvha
mkn0398JjJRTZeOPSbgdFOmTMkbgimRTXhvjCpdGx9UTBDbLfigtYlytnaef
nCRw5NUwL4HxfznFZ7k=
       "]]},
     Annotation[#, "Charting`Private`Tag$48743#1"]& ]}, {}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*FractionBox[SubscriptBox[\\(v\\), \\(pfk\\)], SubscriptBox[\
\\(V\\), \\(pfk\\)]]\\)\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"F16bP [mM]\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Directive[
    GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{75, 10}, {80, 15}},
  ImageSize->400,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 9.999999795918367}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Prolog->{
    RGBColor[
     NCache[{
       Rational[223, 255], 
       Rational[72, 85], 
       Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
      0.7843137254901961}]], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  RotateLabel->False,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.6104387030008163`*^9, 3.610438752292946*^9}, {
   3.610438827072603*^9, 3.610438890564652*^9}, 3.6104389209825153`*^9, {
   3.6104389860723753`*^9, 3.6104390209531183`*^9}, 3.610439052401392*^9, 
   3.6104390865617847`*^9, {3.610439117161216*^9, 3.610439219118691*^9}, 
   3.6104416603031387`*^9, {3.610441714934103*^9, 3.6104417393365993`*^9}, 
   3.6106391727816353`*^9, 3.610640089844535*^9, {3.610640222143343*^9, 
   3.610640257316532*^9}, {3.61064030973536*^9, 3.610640317470282*^9}, 
   3.610640348322359*^9, 3.6106404518900337`*^9, 3.6106799158541813`*^9, 
   3.610692032851386*^9, {3.6106934749499607`*^9, 3.610693511227956*^9}, {
   3.6106935513457603`*^9, 3.610693596999235*^9}, 3.6108025298421373`*^9, 
   3.895303150373148*^9, {3.895303615409319*^9, 3.895303644493475*^9}},
 CellLabel->
  "Out[172]=",ExpressionUUID->"c6fb58de-6da8-4137-96d3-d3304765b887"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"plATP", "[", 
   RowBox[{"f26bpv_", ",", "options_"}], "]"}], ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"vpfknum", "/.", 
          RowBox[{"f16bp", "\[Rule]", "0"}]}], "/.", 
         RowBox[{"f6p", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0.025", ",", "0.05", ",", "0.1", ",", "0.2", ",", "0.5"}],
            "}"}]}]}], "/.", 
        RowBox[{"f26bp", "\[Rule]", 
         RowBox[{"{", "f26bpv", "}"}]}]}], "/.", 
       RowBox[{"atp", "\[Rule]", 
        RowBox[{"At", " ", "\[Phi]"}]}]}], "/.", "parameters"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Phi]", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*FractionBox[\(ATP\), SubscriptBox[\(A\), \(TOT\)]]\)\>\"", 
       ",", "\"\<\!\(\*FractionBox[SubscriptBox[\(v\), \(pfk\)], \
SubscriptBox[\(V\), \(pfk\)]]\)\>\""}], "}"}]}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontSize", "->", "12"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"StringJoin", "[", 
          RowBox[{"\"\<F26BP = \>\"", ",", 
           RowBox[{"ToString", "[", "f26bpv", "]"}], ",", "\"\< mM\>\""}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", "0.95"}], "}"}]}], "]"}]}], "}"}]}], ",", 
    "options"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.610439742771759*^9, 3.610439759503263*^9}, {
  3.6104398057387466`*^9, 3.610439936053617*^9}, {3.610440021109029*^9, 
  3.6104400437434673`*^9}, {3.6104401851273117`*^9, 3.610440212783502*^9}, {
  3.6104404440448093`*^9, 3.610440479500255*^9}, {3.610678365972159*^9, 
  3.6106783696162663`*^9}, {3.610678524275392*^9, 3.610678532976963*^9}, {
  3.610678570928772*^9, 3.610678595271739*^9}, {3.610678679085017*^9, 
  3.61067873958073*^9}, {3.610678771635849*^9, 3.610678774068671*^9}, {
  3.610679926807089*^9, 3.610679945150671*^9}, {3.610691871530252*^9, 
  3.6106918829898148`*^9}, {3.610717836769691*^9, 3.610717874141531*^9}, {
  3.895303356078706*^9, 3.8953033963111*^9}, {3.895303436896536*^9, 
  3.8953034531722116`*^9}, {3.8953036945052443`*^9, 3.895303757125061*^9}, {
  3.895303813174275*^9, 3.8953039177883472`*^9}},
 CellLabel->
  "In[245]:=",ExpressionUUID->"6288c271-fb90-47c5-ab9e-03550054989e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"plA", "=", 
   RowBox[{"plATP", "[", 
    RowBox[{"0.001", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "\"\<0.025\>\"", ",", "\"\<0.05\>\"", ",", "\"\<0.1\>\"", ",", 
              "\"\<0.2\>\"", ",", "\"\<0.5\>\""}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<Column\>\"", ",", "1"}], "}"}]}], ",", 
            RowBox[{"LegendLabel", "->", "\"\<F6P (mM)\>\""}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
               RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.85", ",", "0.7"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0.1", ",", "0.05"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.6", ",", "0.85"}], "}"}]}], "}"}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<f6p\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"0.5", ",", "0.8"}], "}"}]}], "]"}]}], "}"}]}]}], 
      "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plB", "=", 
   RowBox[{"plATP", "[", 
    RowBox[{"0.005", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plC", "=", 
   RowBox[{"plATP", "[", 
    RowBox[{"0.02", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6106800433537273`*^9, 3.610680057999667*^9}, {
   3.6106918860009203`*^9, 3.610691920224697*^9}, 3.610691971575665*^9, {
   3.610692079234229*^9, 3.61069208552737*^9}, {3.610692117971369*^9, 
   3.6106921186504087`*^9}, {3.610692173700033*^9, 3.610692316529476*^9}, {
   3.610717696307147*^9, 3.610717697019157*^9}, {3.6107177311143847`*^9, 
   3.610717758033578*^9}, {3.6107178768630466`*^9, 3.610717902856331*^9}, {
   3.8953031153021917`*^9, 3.8953031176109657`*^9}, {3.895303213568263*^9, 
   3.895303325093713*^9}, {3.8953034170946493`*^9, 3.895303539205658*^9}, {
   3.8953038025003853`*^9, 3.895303838208762*^9}},
 CellLabel->
  "In[246]:=",ExpressionUUID->"b090f9fc-e56a-496d-9614-db3e95ec8222"],

Cell[CellGroupData[{

Cell["F26bP relieves ATP inhibition and hardly activated PFK", "Subsubsection",
 CellChangeTimes->{{3.610678848031355*^9, 
  3.610678890012792*^9}},ExpressionUUID->"1c68f249-0edb-4043-9158-\
49b5e78e0d53"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"plA", ",", "plB", ",", "plC"}], "}"}], "}"}], ",", 
    RowBox[{"ImageSize", "->", "1200"}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellLabel->
  "In[256]:=",ExpressionUUID->"aa4b37d5-e34f-443b-9394-f5ad52322d62"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{}, {}, 
            TagBox[
             {Hue[0.55, 1, 0.7], AbsoluteThickness[1.6], Opacity[1.], 
              LineBox[CompressedData["
1:eJwVlXc81f8Xx0lJJSsNIjMNksbXtfKyd8MeyV6RJJFQKApZSUj2juxr3Y+V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               "]]},
             Annotation[#, "Charting`Private`Tag$67749#1"]& ], 
            TagBox[
             {Hue[0.06, 1, 0.9], AbsoluteThickness[1.6], Opacity[1.], 
              LineBox[CompressedData["
1:eJwVlnc81e0bx4lQiqxCJLPMPEVD41ORQuk5xx5ZIVRWSZMUSpKGTfbeZZY9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               "]]},
             Annotation[#, "Charting`Private`Tag$67749#2"]& ], 
            TagBox[
             {Hue[0.25, 1, 0.55], AbsoluteThickness[1.6], Opacity[1.], 
              LineBox[CompressedData["
1:eJwV13k4VO0bB3CSSEWWCiURioSEVPIlsucNbUqRkJQZSySyhlAhyZbsZMm+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               "]]},
             Annotation[#, "Charting`Private`Tag$67749#3"]& ], 
            TagBox[
             {Hue[0.11, 0.9, 0.85], AbsoluteThickness[1.6], Opacity[1.], 
              LineBox[CompressedData["
1:eJwV13k0Vt0XB3DRoBIpFJJE3hTypojwTUqGypsGFIqElKhURImIPI95HsoY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               "]]},
             Annotation[#, "Charting`Private`Tag$67749#4"]& ], 
            TagBox[
             {Hue[0.5, 1, 0.5], AbsoluteThickness[1.6], Opacity[1.], 
              LineBox[CompressedData["
1:eJwV13k4lGsYBnBZIlkilTVppaRyTkTLLUlCiy2RJJQikVQqhOhYkpLslcpe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               "]]},
             Annotation[#, "Charting`Private`Tag$67749#5"]& ]}, {}}, 
          InsetBox[
           
           TemplateBox[{
            "\"0.025\"", "\"0.05\"", "\"0.1\"", "\"0.2\"", "\"0.5\""},
            "LineLegend",
            DisplayFunction->(FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    StyleBox[
                    "\"F6P (mM)\"", {
                    FontFamily -> "Helvetica", FontSize -> 14}, Background -> 
                    Automatic, StripOnInput -> False]}, {
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.55, 1, 0.7]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.55, 1, 0.7]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.023999999999999994`] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.06, 1, 0.9]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.06, 1, 0.9]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.023999999999999994`] -> 
                    Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.25, 1, 0.55]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.25, 1, 0.55]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.023999999999999994`] -> 
                    Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.11, 0.9, 0.85]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.11, 0.9, 0.85]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.023999999999999994`] -> 
                    Baseline)], #4}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.5, 1, 0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.5, 1, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.023999999999999994`] -> 
                    Baseline)], #5}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"]}}, GridBoxAlignment -> {"Columns" -> {{Center}}},
                    AutoDelete -> False, 
                   GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Helvetica", FontSize -> 14}, Background -> 
               Automatic, StripOnInput -> False], TraditionalForm]& ),
            Editable->True,
            InterpretationFunction:>(RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> Hue[0.55, 1, 0.7]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> Hue[0.06, 1, 0.9]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> Hue[0.25, 1, 0.55]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> Hue[0.11, 0.9, 0.85]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> Hue[0.5, 1, 0.5]|>, 
                    "HueColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], 
                 ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"FontFamily", "\[Rule]", "\"Helvetica\""}], ",", 
                    RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}], ",", 
                 RowBox[{"LegendLabel", "\[Rule]", "\"F6P (mM)\""}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"\"Column\"", ",", "1"}], "}"}]}]}], "]"}]& )], 
           Scaled[{0.85, 0.7}], ImageScaled[{0.5, 0.5}],
           BaseStyle->{FontSize -> Larger},
           FormatType->StandardForm]},
         AspectRatio->1,
         Axes->{True, True},
         AxesLabel->{None, None},
         AxesOrigin->{0, 0},
         BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
         DisplayFunction->Identity,
         Epilog->{FontSize -> 12, 
           InsetBox[
            FormBox["\"F26BP = 0.001 mM\"", TraditionalForm], {0.2, 0.95}]},
         Frame->{{True, True}, {True, True}},
         FrameLabel->{{
            FormBox[
             TagBox[
             "\"\\!\\(\\*FractionBox[SubscriptBox[\\(v\\), \\(pfk\\)], \
SubscriptBox[\\(V\\), \\(pfk\\)]]\\)\"", HoldForm], TraditionalForm], None}, {
           
            FormBox[
             TagBox[
             "\"\\!\\(\\*FractionBox[\\(ATP\\), SubscriptBox[\\(A\\), \
\\(TOT\\)]]\\)\"", HoldForm], TraditionalForm], None}},
         FrameStyle->Directive[
           GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
         FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
         GridLines->{None, None},
         GridLinesStyle->Directive[
           GrayLevel[0.5, 0.4]],
         ImagePadding->{{75, 10}, {80, 15}},
         ImageSize->400,
         Method->{
          "DefaultBoundaryStyle" -> Automatic, 
           "DefaultGraphicsInteraction" -> {
            "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
             "Effects" -> {
              "Highlight" -> {"ratio" -> 2}, 
               "HighlightPoint" -> {"ratio" -> 2}, 
               "Droplines" -> {
                "freeformCursorMode" -> True, 
                 "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
           "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
           None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& )}},
         PlotRange->{{0., 0.9999999795918367}, {0., 1.}},
         PlotRangeClipping->True,
         PlotRangePadding->{{
            Scaled[0.02], 
            Scaled[0.02]}, {0, 0}},
         Prolog->{
           RGBColor[
            NCache[{
              Rational[223, 255], 
              Rational[72, 85], 
              Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
             0.7843137254901961}]], 
           RectangleBox[
            Scaled[{0, 0}], 
            Scaled[{1, 1}]]},
         RotateLabel->False,
         Ticks->{Automatic, Automatic}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{{}, {}, 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[1.6], 
                Hue[0.55, 1, 0.7]], 
               Line[CompressedData["
1:eJwVlXc81f8Xx0lJJSsNIjMNksbXtfKyd8MeyV6RJJFQKApZSUj2juxr3Y+V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                "]]}, "Charting`Private`Tag$67749#1"], 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[1.6], 
                Hue[0.06, 1, 0.9]], 
               Line[CompressedData["
1:eJwVlnc81e0bx4lQiqxCJLPMPEVD41ORQuk5xx5ZIVRWSZMUSpKGTfbeZZY9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                "]]}, "Charting`Private`Tag$67749#2"], 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[1.6], 
                Hue[0.25, 1, 0.55]], 
               Line[CompressedData["
1:eJwV13k4VO0bB3CSSEWWCiURioSEVPIlsucNbUqRkJQZSySyhlAhyZbsZMm+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                "]]}, "Charting`Private`Tag$67749#3"], 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[1.6], 
                Hue[0.11, 0.9, 0.85]], 
               Line[CompressedData["
1:eJwV13k0Vt0XB3DRoBIpFJJE3hTypojwTUqGypsGFIqElKhURImIPI95HsoY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                "]]}, "Charting`Private`Tag$67749#4"], 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[1.6], 
                Hue[0.5, 1, 0.5]], 
               Line[CompressedData["
1:eJwV13k4lGsYBnBZIlkilTVppaRyTkTLLUlCiy2RJJQikVQqhOhYkpLslcpe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                "]]}, "Charting`Private`Tag$67749#5"]}}, {}}, {
          DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
           AxesOrigin -> {0, 0}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, DisplayFunction -> Identity, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {0, 0}}, PlotRangeClipping -> True, 
           ImagePadding -> {{75, 10}, {80, 15}}, DisplayFunction -> Identity, 
           AspectRatio -> 1, Axes -> {True, True}, AxesLabel -> {None, None}, 
           AxesOrigin -> {0, 0}, 
           BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
           DisplayFunction :> Identity, Epilog -> {FontSize -> 12, 
             Text["F26BP = 0.001 mM", {0.2, 0.95}]}, 
           Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
              HoldForm[
              "\!\(\*FractionBox[SubscriptBox[\(v\), \(pfk\)], \
SubscriptBox[\(V\), \(pfk\)]]\)"], None}, {
              HoldForm[
              "\!\(\*FractionBox[\(ATP\), SubscriptBox[\(A\), \(TOT\)]]\)"], 
              None}}, FrameStyle -> Directive[
             GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
            FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImagePadding -> {{75, 10}, {80, 15}}, 
           ImageSize -> 400, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
             None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 (Identity[#]& )[
                  Part[#, 1]], 
                 (Identity[#]& )[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 (Identity[#]& )[
                  Part[#, 1]], 
                 (Identity[#]& )[
                  Part[#, 2]]}& )}}, 
           PlotRange -> {{0., 0.9999999795918367}, {0., 1.}}, 
           PlotRangeClipping -> True, PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {Automatic, Automatic}}, Prolog -> {
             RGBColor[{
               Rational[223, 255], 
               Rational[72, 85], 
               Rational[40, 51]}], 
             Rectangle[
              Scaled[{0, 0}], 
              Scaled[{1, 1}]]}, RotateLabel -> False, 
           Ticks -> {Automatic, Automatic}}], 
         Placed[
          Unevaluated[
           LineLegend[{
             Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
              Opacity[1.], 
              AbsoluteThickness[1.6], 
              Hue[0.55, 1, 0.7]], 
             Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
              Opacity[1.], 
              AbsoluteThickness[1.6], 
              Hue[0.06, 1, 0.9]], 
             Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
              Opacity[1.], 
              AbsoluteThickness[1.6], 
              Hue[0.25, 1, 0.55]], 
             Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
              Opacity[1.], 
              AbsoluteThickness[1.6], 
              Hue[0.11, 0.9, 0.85]], 
             Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
              Opacity[1.], 
              AbsoluteThickness[1.6], 
              Hue[0.5, 1, 0.5]]}, {"0.025", "0.05", "0.1", "0.2", "0.5"}, 
            LegendMarkers -> None, 
            LabelStyle -> {FontFamily -> "Helvetica", FontSize -> 14}, 
            LegendLabel -> "F6P (mM)", LegendLayout -> {"Column", 1}]], {0.85,
           0.7}, Identity]]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {215., -215.25}, {Center, Center}, {400., 410.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {Hue[0.55, 1, 0.7], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV1Hc8le8bB3BKEWW2SEZUZKaMND5F2SW0CCGkjj2yyp5FJCEJZSYre28y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           "]]},
         Annotation[#, "Charting`Private`Tag$67842#1"]& ], 
        TagBox[
         {Hue[0.06, 1, 0.9], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13c8le//B3AtpLKSoiSRKCub0qsiGaUhSUaJJAppoVTqnENW9opokJHs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           "]]},
         Annotation[#, "Charting`Private`Tag$67842#2"]& ], 
        TagBox[
         {Hue[0.25, 1, 0.55], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13c81V8YB3D6VUbDlllJJFFaROqDrBDJziijiYSSBlIRMgsh5NojIzt7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           "]]},
         Annotation[#, "Charting`Private`Tag$67842#3"]& ], 
        TagBox[
         {Hue[0.11, 0.9, 0.85], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13c81d8fB3AppWW1jDJKkyQ/I8SrhCKVHSUyQjIqkoai8JWsIiurRCh7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           "]]},
         Annotation[#, "Charting`Private`Tag$67842#4"]& ], 
        TagBox[
         {Hue[0.5, 1, 0.5], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13k41F0UB3ChUoqoiJQsaZO8Utr4lhYUImVpkaVUKiKVUpG0kCVLspPs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           "]]},
         Annotation[#, "Charting`Private`Tag$67842#5"]& ]}, {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
      DisplayFunction->Identity,
      Epilog->{FontSize -> 12, 
        InsetBox[
         FormBox["\"F26BP = 0.005 mM\"", TraditionalForm], {0.2, 0.95}]},
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
          "\"\\!\\(\\*FractionBox[SubscriptBox[\\(v\\), \\(pfk\\)], \
SubscriptBox[\\(V\\), \\(pfk\\)]]\\)\"", HoldForm], TraditionalForm], None}, {
        
         FormBox[
          TagBox[
          "\"\\!\\(\\*FractionBox[\\(ATP\\), SubscriptBox[\\(A\\), \
\\(TOT\\)]]\\)\"", HoldForm], TraditionalForm], None}},
      FrameStyle->Directive[
        GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{75, 10}, {80, 15}},
      ImageSize->400,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 0.9999999795918367}, {0., 1.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Prolog->{
        RGBColor[
         NCache[{
           Rational[223, 255], 
           Rational[72, 85], 
           Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
          0.7843137254901961}]], 
        RectangleBox[
         Scaled[{0, 0}], 
         Scaled[{1, 1}]]},
      RotateLabel->False,
      Ticks->{Automatic, Automatic}], {645., -215.25}, 
     ImageScaled[{0.5, 0.5}], {400, 400.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {Hue[0.55, 1, 0.7], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13c8lW0YB3CpJEmZUVSioaFNNH6SlJGyKg1lJr2yZYQkMiO8dY6RPSKR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           "]]},
         Annotation[#, "Charting`Private`Tag$67913#1"]& ], 
        TagBox[
         {Hue[0.06, 1, 0.9], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13dczd8fB/BISnuhIRWVtBAVwiuVNGQ0lBAaSkaEJEJD36QUJUUqLYnG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           "]]},
         Annotation[#, "Charting`Private`Tag$67913#2"]& ], 
        TagBox[
         {Hue[0.25, 1, 0.55], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13k4VV8XB3CkSaIkRSoKISSJQr6SZAyhIpmTVFJ5hQzJkMrQoEKSIsmc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           "]]},
         Annotation[#, "Charting`Private`Tag$67913#3"]& ], 
        TagBox[
         {Hue[0.11, 0.9, 0.85], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13k8VF0YB3BJJRUlLbaQpcgWUkp+RSrRolQoS6hoUSqlRVRIKL0lCaEs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           "]]},
         Annotation[#, "Charting`Private`Tag$67913#4"]& ], 
        TagBox[
         {Hue[0.5, 1, 0.5], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13dYjW0cB/AGSl6lhQYho5JKZqgvCk2KtJSkolBo2KRSaFNSibYR7aWl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           "]]},
         Annotation[#, "Charting`Private`Tag$67913#5"]& ]}, {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
      DisplayFunction->Identity,
      Epilog->{FontSize -> 12, 
        InsetBox[
         FormBox["\"F26BP = 0.02 mM\"", TraditionalForm], {0.2, 0.95}]},
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
          "\"\\!\\(\\*FractionBox[SubscriptBox[\\(v\\), \\(pfk\\)], \
SubscriptBox[\\(V\\), \\(pfk\\)]]\\)\"", HoldForm], TraditionalForm], None}, {
        
         FormBox[
          TagBox[
          "\"\\!\\(\\*FractionBox[\\(ATP\\), SubscriptBox[\\(A\\), \
\\(TOT\\)]]\\)\"", HoldForm], TraditionalForm], None}},
      FrameStyle->Directive[
        GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{75, 10}, {80, 15}},
      ImageSize->400,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 0.9999999795918367}, {0., 1.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Prolog->{
        RGBColor[
         NCache[{
           Rational[223, 255], 
           Rational[72, 85], 
           Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
          0.7843137254901961}]], 
        RectangleBox[
         Scaled[{0, 0}], 
         Scaled[{1, 1}]]},
      RotateLabel->False,
      Ticks->{Automatic, Automatic}], {1075., -215.25}, 
     ImageScaled[{0.5, 0.5}], {400, 400.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->1200,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.8953040397575903`*^9},
 CellLabel->
  "Out[256]=",ExpressionUUID->"3dc237de-9da2-4151-a3eb-fee5d285d790"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"plA", ",", "plC"}], "}"}], "}"}], ",", 
   RowBox[{"ImageSize", "->", "800"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/PFK_complex1.pdf\>\"", ",", "%"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.6104392415481358`*^9, 3.610439481863172*^9}, {
  3.610439661026023*^9, 3.6104397407578907`*^9}, {3.6104397709840593`*^9, 
  3.6104397940363903`*^9}, {3.6104400574868298`*^9, 3.610440057619022*^9}, {
  3.610440116849909*^9, 3.610440157587476*^9}, {3.610440642718431*^9, 
  3.610440658103236*^9}, {3.6106391987350273`*^9, 3.6106393240260553`*^9}, {
  3.610678393863962*^9, 3.61067840491958*^9}, {3.61067879322372*^9, 
  3.610678827174692*^9}, {3.610680062346306*^9, 3.610680068294919*^9}, {
  3.610692126620319*^9, 3.610692136166206*^9}, {3.895303334385552*^9, 
  3.895303342082108*^9}, {3.8953039444067583`*^9, 3.895303983485207*^9}, {
  3.895304042234008*^9, 3.895304048690905*^9}},
 CellLabel->
  "In[259]:=",ExpressionUUID->"96463ce2-6f3b-4bf1-abc2-fd733ea7d279"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{}, {}, 
            TagBox[
             {Hue[0.55, 1, 0.7], AbsoluteThickness[1.6], Opacity[1.], 
              LineBox[CompressedData["
1:eJwVlXc81f8Xx0lJJSsNIjMNksbXtfKyd8MeyV6RJJFQKApZSUj2juxr3Y+V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               "]]},
             Annotation[#, "Charting`Private`Tag$67749#1"]& ], 
            TagBox[
             {Hue[0.06, 1, 0.9], AbsoluteThickness[1.6], Opacity[1.], 
              LineBox[CompressedData["
1:eJwVlnc81e0bx4lQiqxCJLPMPEVD41ORQuk5xx5ZIVRWSZMUSpKGTfbeZZY9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               "]]},
             Annotation[#, "Charting`Private`Tag$67749#2"]& ], 
            TagBox[
             {Hue[0.25, 1, 0.55], AbsoluteThickness[1.6], Opacity[1.], 
              LineBox[CompressedData["
1:eJwV13k4VO0bB3CSSEWWCiURioSEVPIlsucNbUqRkJQZSySyhlAhyZbsZMm+
R5JEdoMZKksJWWbm5O0tkvSb31/n+vzxPNd9nvt7X+c5ErZkc/tVbGxsx9jZ
2P7/NLKfpjTOnNIMvBJA/FeUoLlaR9RlTEQF87/Zbtzw9cT+1ITkchFdfN1/
78/T06Ew7hoseypyEvUck5kKPHE4Y7fwMkbEDk68s19kPLIxonhX54HIDfB/
VpdWsqxAbKpwo/R5DxwF08HWuxJGfPkaDcmeaHCS6E6Kr0IVs1OVEL8F5/Gi
KNOWGkQWCuw2k/FDZeKK2Yaf9Ujb9E9ohEgw4hMzKY4nm+DTFd98+kUwis80
qU+1NuF0yKdVO8+HoNvOgvnq4Bus/+HqX5cciizTMPdk4WZ4DcR60cXDsa91
SjL4zVtY3B+pqmkMh8g3UipJrgUKujI/gi9F4ETq58vDUS2YKK92Fcu8hwsq
n46dPN0Ks0cfnExlImHh+ExNpe8d5I135om2RmL/vS+bava2gZvj+tepK1Ho
i3FcHr/bBuvaldJXJ6PhqqrzXlO9HZtkoxXOxj0E/avz9jvhHQjkLt8VLhIL
wcibunXzXZDTfxhW5hILvUc65Y/Qjb4Q8szH1lh8sOEc33G/G1Ic8gUKno+x
vCsx5ZpED1r+ZCkM9MVh7SeScur2XpA17kT9kY3HBmHO4GStXgj7XPomExiP
rzeUMjhte3F1UazslmICpG11fHZm9mL99zhV8fuJGDA/VvN2OwWV+zziDL4k
4rtAX4WlBgUXXSwWXA8l4Xj0dr2rlhQUM/hqm6eT8Iw2G7sqhgLz6TANp2PJ
mGQPjDvxh4KEEW+dypUUeKfIvx1+2QftbZZZo6dSEeqwbmS5vw+z5w5wchem
IrVUJqd8pg/b6bcuF+5NQxnN++ScYD/IV9Wk2YbTIPIiV+v55X40h2VTY7nS
IdElIlPg2Q/hXKFQ2f3p2O/vZWwS3o/GqX+nzCPSUXCV87V3YT8E7Ipzs9Uz
kOA5qVU43w+HO9stD9ll4J/aD0pf2AdQl/FgbU9UBuIXe1695R+A3edrTotT
GfgzvPj4sdIAKi/uljd+nAnNarJqoNMAzlqmF3+bz4LR1WCfO70DID6e5MkQ
zca+G2VfjT4OIPQit72FTjaWrJTnhiYHUH6ZLFoVm42T+56MGy8NgJd0JMTn
QA4cfK13Z+6gIvvbtzF5mxy8yo9cqJClQsM969BoWA7qvLXJj5SpcPJa903r
Qw7ihCeUanWoeBv0/twa32fQm+i9XHeZCivOB5XV2c+wKLKfOHaNin/vam28
2v0MyTX88RluVOx48Oxth3guRtbR2gcCqLgd76H0sCkXQUurFRWeUCEoKnvv
6FwuqqRjRc+nU5GfPDz5XTAPWpKK3NbPqBhM13ly2j4Poht4VZllVCg/51+z
jTsfJ8Ivex18R0WbwlubLqV8NOoHSit0UWFT6lXnZ5mPqU8hB1coVDyoGnP5
nJ8PxXc62cofqZA6+Kgjpj8f74V42BLGqHhRpyeju5yPeO6R1g9fqJhuLPyY
c7wAnY2FD5fmqPDXuaR21rMAv9h+hA0RVGxuEXq4NrUA/rJfBx9/p0Knw0fv
+rcCeKronipZoiKFali679FzPHwuZePKRYPq2T/rvtQ9h7NofNlpHho6P5Q4
xE48h4w4MbF9Aw2/xrZsW1AtxIJOTbSlAA3Rth2euRcLEd+o86FTiAaZST+K
5d1CXDv3PVNqCw0nZydD64cKMTocbHBnKw1z1xM/O7MX4Z2EzXSEGA1BhImG
uFwREHM+xkucBhE3tvhe8yJckkrNNpGgoeS/8vlAnyJ0zXEGcO2kQf/mFZP9
WUUoeijplydFw+gv0WcTnUUYa9D5rSxDw7q/gVb624tBc4p9/2c3DQlXz1yU
1yuGtaZg/0E5GqQG5G34ScWw6BqOtt5DQ6nmKtufj4vhaGd4mSxPg2be4OWP
L4uRqvs08epeGjoEC+0bJ4uRYbI+yFSBBnm8Lu9bU4LIuJdXtyvS4PZfgcpb
0RLw8PQkv2e5Ni+uslqhBGu+nHUIUKKBzTpQLf9oCTj2um4U3EeDntD16uTT
JTDfrzjxkOX7bafVo5xY66eKZP+w3O+nXRvoV4J1KkK7TynTIKoif+hGTAmk
z0VKJ7FsM7O5ziGnBH67zl/pZDknhV3D8kUJ1A6076OzzLCg1xt3l+CRuNa7
XyyrrB08ojlegpa4g84/WPZueN2g9LMEmg9MbcdYbnR/jp08pRg5ojpdzTKX
bHzjpu2lWK/yVtOfZdPRQG1u5VL06y9lqbIc++h609KxUnBHL5z9yKr3g8EZ
HYZlKWqMeBJcWJZY0W4ecy7FUt3zlB+s93cslz/WF1gKIY7wXCeWixy3tDQ/
LsXRKZ9vPazz+k9slX51XinkHseXSLN8uJ/emveyFD8vyUheZ513UNigQTKl
FL6uhb6ZrH68O9LUFjlZin22xFIHq1+ncuM73DeUQdB5XnWe1d/kC0EmDhJl
cL4baM2UpWFcwLnrrGoZPj1yDRph5YHse7TnyIUyRPsqBcew8lKlvPeEkmsZ
xOZ3tJ2VpmH56xaKZEgZKk/U9vOz8hVuzujjKixDX3jRihUrj71cQxZLjWW4
6djhT7Dyuvll0wB9oAwJ7UJhHttpyNyVQKMsl6G86Mm0FSvvL5ePfnhiUg4H
tXdjT1nzsbps7/lIm3IYbt36mMKaH6MrwsMBN8pBKUpQW9pIwyCFMWKfXI5M
TrtJOda8zeckfFaklwNOBg68nDRImzGn39yrwELmCdrff6kQ9dc/dCW9An76
WQzrb1RsLEy7x1NdgZuh3e2VDCqWuC0UzMYr0BBnGaQzTUVvY7X7qHol2BaS
POaGqfBWClxZnGS5nbQY1UxFN5+QkIJWNW5HHAjZGUnFmyPO9pRT1di03mk4
OIKKmmstVTeuVYM8Y2D6KZSKzFYvy7q4aoyW3GeE+FPh5T+SYsCoRgNl849I
FyokiRzZy0k1KM5a115oRsXN7oNI+K8WDT5SX2s3UsGrUDnZxv0Czu72vv3r
qch6oHT/97YXeNJCMZnlpoJisuv9xWMv4MW/2MXHTsWeDiF36bgXINVUdx+e
H8BYK5FTdqAOFbvIY5KUAei/zubt8q6HnoGXlW/UALZU8I+ys79CwD+imi7c
A6ga1+ns0WiC3FD+uaixPjQ5Pd1qSW9G2O281C9vKPghc4Sv0LkVAo8o8rOt
vVj1q2DjVul2PEwq6bG+1wO1vzZVFkWd2Lljcv3W5i50Bqt0t8j1YO93O2rC
tk6IR8/9ymP2wtyQ+0zZlXbMLYyNUpX6cOvPq4tF4++QNVvXzhvZD5Uk0/Q+
01bwij0jJiYGMDIVrW3Y9xb3r1Y6pLFyJ3cralHydjN+ahVMOPoPYlCp5mHV
pje4odxcsfnNEG7GiMxo9b3GWFHzPYrEB2jdk1LV9G/Eb6eBJ7LeHxGW4h56
xacBe7S5VhzqhmH2pO/0nQP10M+QuFK6ZRSK2sTtyaFa3BSzlvxsNQYfvZjj
PdXVkKefWjd4/BM4BgIeCVdVQpDvG3fz0ifkHucXmkkrx+pXT4p3Jn+GS9v6
BrbWUlxTqXu/1ngc4vdn42obi1FgaJvW8HMcbeVx7Uqaz/FjTnTjVNwX5PUm
GNHl81Bpoc8RqzuB2AeGnC+EcuBvEJJaMTWBExPq/mpOmZAYMRrKDJmEdaOA
sgZHOg4dCI4VUZ6Cp4N8ppnhU1ht7/nF3j+Fcy8K/gkwTcSP9gfjLoFf4SFG
saey7nUJqy/eMJeaRq5kRPg20xgIjlZmrGqeRuFrj9iDilHg9A08edB1BnYR
Y7W62yJQMU//9cp9Bmky3X/f80TAzuFsqp7nDBIr1ZS9f4Wj+R/FWQufGbRZ
D5t+pIUjWHLEnxQyg5vBa7h3xIRj9Tv1gszEGfC9vO5dwhOOVYLf2HmbWLZv
kaVyhIEt72LxuMAs2pa5ihw3haKFPkhK3TQLtaeWGpc4Q3FfyUzBSngWOVVm
j+1/hGBLjU4hVWwWv8+VxT6khkChdXfBu92zsFa5ru8ZFwKryX9zijRn8Zo7
7BpJNAS1EndTvJ1msXA2+teiXDDckoofCDTNosF+oyXZOQjVy0l3m5pnsaPg
8lF3myAsXwwNdGudBS2i0SHQIgh3d17w6OucxcOgB6b1B4OQ/JznQszgLJzT
5bY9XxOEtw328gKMWeiSPteTMwIh/GVrB7/wHEJCnfyvfA7Ayz1h3PykOYj/
Fio+uOgHtYEtXTEuc+jP+0gLmvBDye1nD4Xc55CQHj70sdcPGV0tosJeczim
WGPyMs8PYWTOveJBc9jjf1HhiJUfzMuDzPbGzeHm3KYIuWZffD3km2TYMIdI
jsKb4am3wW/kJh/ES0fvu+ZtHUHeSHvNt+4QPx27PiDR29UbSgcLZ+YF6cga
Msw6ZOMN093TOZdE6BCOFdChH/FGxJqLEtpSdFjIGBQLLd3C6jeGm9kO0TGx
mivfzeMWfh6WYPOzpyP31SL7Li8vhJQ3jKo60tFwpzhu0NELQnusXjKc6MjY
0f8s3tIL+0XjvS+40HFX/F8xvcNecFlc/0PDh45jFwxdzv+9iZmKxZnf0XRE
nW8g2UTcxPDe3v5b9XRk/nzzNKnAE6lz/L4cr+gYyKS08aZ6wjbPQubBa1Y9
jc9jomI8MSM16JXWQsercrHPVbc88XPrqFhrLx1sUR9ePjHwBD8P/YrQJB2r
qgqma6Y9oDfFtVy0gQFrio7mJmUPrM0yzFbfyIDWWH3vxl0e6Lx0z7RJgIGr
+p3qwts8YDHCm07dwkC2cYGr0RoP2Axs0luWYMCMJjZ2+OMN+DTtjDZUY7Du
nwbex+/eQEkKpCYuMlDh2LSyatod372/c126xIC8fRdnyqg71M48mxu5zICb
a+0LHao76vj4ygcdGWgTsBQpbnJHS8CodocbAzXFgcKcKe74aOtrXRbKwG87
elreaXes2VWXFFDEQFjAy7LSHjcYcpD9/pQwEG7bl57Q6ob7Y5K23uUM9Dtv
TA1/5Qb+hAjZGzUMFCsJloYXu2Hb2nM1V5oYyGG3KWaPdoPy3CLVlMbAhROJ
HF3mbrhQrMYvtsJaL2lhUTrmiqpzi7y9bEzwC3nyaQy5gnfNi/V3OJhYplIW
KL2uaLQ6wj3DzcT+1akHxJtcIcmj+7dCkImn2q0jmtmumLIzY5jIMuHVcE02
0tkVJNHrbbdPMhHmlrDDcI0rWt7ubVU8w8TQBIeNIpsrxF2J5nFLJhILLsvt
WHJBb6tbo4E1E+/Wko9LMF2g7HGrWsiJid6pLSbpNBcs9IRmP/dnwjNb9XBs
ngsCQtIDh/OZSLlzIGfXGRdsuMlldKmQiZjO2tFccxckOToLTBUzWd/XuG5l
UxeUGx/MJCqY2EkabLU55oIpfkrzqldMaJf3t0mpuMA4hY1btp8JMalsByNB
FwxFOfQWUpmYTV/77BSfC+wCOxOUh5i4uHmcdHWdC/zsEmQ1Rpg475Qens/h
ghI5JeN/vjJREJF2SHqGjM3V1pEev5k4rtP+gigmIzP37emlP0zoDjslCOWR
oZS0R9yfjUBlCKeiUQYZhr4LxWGcBDQb17p/jSXjtk4U5QkfgZLK9I4ZbzLG
exqEmnYSrP+jgIi1RmSQX0uN6MkQWD3UVnJAl4zlsojsjt0E3LcJ63pqkrEp
7rQadS+BKhuZNKn9ZBhYMc9MHyAw/Him4pgYGYXTYk94TQisW+TLe/wfCWFP
Q2xGTQnk6Z16fYggwc6cIV1kRqBz7/TK9xkSttXXlxw/Q2DDAXZqxhgJEVHn
W+7bErgQVn1hvoMEB90396zsCahJl2880ErC0V9yZvKOBMLY8hqjm0j4Zbv0
scOZwIHuO6sDaklwVEuc57lF4LzOlaTjuSTozrFVf/AhIH5dvVw5iwTxNMfb
+X4EIlKTs/akkUBbq85lFEygpUGIzTKBhGMjtG3hUQQi189Lp4eTsCNGc/xs
DIHr7SJRUqEkLOvlPNv9mOXecyV1QSRUlHgov0siIHtdYL30bRIkg4UMuHII
3NuOpi9kElbUb28YzGXVG5gZstqZhPeML305BQSOaz+cUHciIfpM+QW9UgIJ
O+auDNuRcH391p2bKwhohRAhxrYkGLwOmp6sIsCkFip3W5PwV87cPaSewBuG
ijzveRI+jNWqn3pFwEVa0L3jLAlVsRIrUk0EouVpGsmnSSCtfAtrbiVA3Px8
3MucBKPys6ax7QQMleqj7pwgQdqxUdCuiwBXSpphhikJw5SoFI5+1v5yZ7aK
GpNQE7pwuZ9KYDpSXcHdkITYw9aymUMEvPYdLR7TJ8E4W6Hi6CiBCcGEf//V
JUHmXNwtgc8E5ve7lCTqkLCKb0Vz/AuBAeOwfoujJLzw6moLnCFwWO6w9iot
EuL2qkaZ0Qloy43e/alJgut48kkJgkBhDGXPyhESTOJXi87PE3hrpLVHhOXd
JtfHGv8jMFRrF6yvQcJq9oGs6AUC5e/CVMMPk/Cp8rCTzRKBo+85j4weIqHe
KVNR6Q+Br626iXosx4uv+/H3L4HlqZcGTQdJ+B+4IfWr
               "]]},
             Annotation[#, "Charting`Private`Tag$67749#3"]& ], 
            TagBox[
             {Hue[0.11, 0.9, 0.85], AbsoluteThickness[1.6], Opacity[1.], 
              LineBox[CompressedData["
1:eJwV13k0Vt0XB3DRoBIpFJJE3hTypojwTUqGypsGFIqElKhURImIPI95HsoY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               "]]},
             Annotation[#, "Charting`Private`Tag$67749#4"]& ], 
            TagBox[
             {Hue[0.5, 1, 0.5], AbsoluteThickness[1.6], Opacity[1.], 
              LineBox[CompressedData["
1:eJwV13k4lGsYBnBZIlkilTVppaRyTkTLLUlCiy2RJJQikVQqhOhYkpLslcpe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               "]]},
             Annotation[#, "Charting`Private`Tag$67749#5"]& ]}, {}}, 
          InsetBox[
           
           TemplateBox[{
            "\"0.025\"", "\"0.05\"", "\"0.1\"", "\"0.2\"", "\"0.5\""},
            "LineLegend",
            DisplayFunction->(FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    StyleBox[
                    "\"F6P (mM)\"", {
                    FontFamily -> "Helvetica", FontSize -> 14}, Background -> 
                    Automatic, StripOnInput -> False]}, {
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.55, 1, 0.7]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.55, 1, 0.7]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.023999999999999994`] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.06, 1, 0.9]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.06, 1, 0.9]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.023999999999999994`] -> 
                    Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.25, 1, 0.55]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.25, 1, 0.55]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.023999999999999994`] -> 
                    Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.11, 0.9, 0.85]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.11, 0.9, 0.85]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.023999999999999994`] -> 
                    Baseline)], #4}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.5, 1, 0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.5, 1, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.023999999999999994`] -> 
                    Baseline)], #5}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"]}}, GridBoxAlignment -> {"Columns" -> {{Center}}},
                    AutoDelete -> False, 
                   GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Helvetica", FontSize -> 14}, Background -> 
               Automatic, StripOnInput -> False], TraditionalForm]& ),
            Editable->True,
            InterpretationFunction:>(RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> Hue[0.55, 1, 0.7]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> Hue[0.06, 1, 0.9]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> Hue[0.25, 1, 0.55]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> Hue[0.11, 0.9, 0.85]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> Hue[0.5, 1, 0.5]|>, 
                    "HueColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], 
                 ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"FontFamily", "\[Rule]", "\"Helvetica\""}], ",", 
                    RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}], ",", 
                 RowBox[{"LegendLabel", "\[Rule]", "\"F6P (mM)\""}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"\"Column\"", ",", "1"}], "}"}]}]}], "]"}]& )], 
           Scaled[{0.85, 0.7}], ImageScaled[{0.5, 0.5}],
           BaseStyle->{FontSize -> Larger},
           FormatType->StandardForm]},
         AspectRatio->1,
         Axes->{True, True},
         AxesLabel->{None, None},
         AxesOrigin->{0, 0},
         BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
         DisplayFunction->Identity,
         Epilog->{FontSize -> 12, 
           InsetBox[
            FormBox["\"F26BP = 0.001 mM\"", TraditionalForm], {0.2, 0.95}]},
         Frame->{{True, True}, {True, True}},
         FrameLabel->{{
            FormBox[
             TagBox[
             "\"\\!\\(\\*FractionBox[SubscriptBox[\\(v\\), \\(pfk\\)], \
SubscriptBox[\\(V\\), \\(pfk\\)]]\\)\"", HoldForm], TraditionalForm], None}, {
           
            FormBox[
             TagBox[
             "\"\\!\\(\\*FractionBox[\\(ATP\\), SubscriptBox[\\(A\\), \
\\(TOT\\)]]\\)\"", HoldForm], TraditionalForm], None}},
         FrameStyle->Directive[
           GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
         FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
         GridLines->{None, None},
         GridLinesStyle->Directive[
           GrayLevel[0.5, 0.4]],
         ImagePadding->{{75, 10}, {80, 15}},
         ImageSize->400,
         Method->{
          "DefaultBoundaryStyle" -> Automatic, 
           "DefaultGraphicsInteraction" -> {
            "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
             "Effects" -> {
              "Highlight" -> {"ratio" -> 2}, 
               "HighlightPoint" -> {"ratio" -> 2}, 
               "Droplines" -> {
                "freeformCursorMode" -> True, 
                 "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
           "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
           None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& )}},
         PlotRange->{{0., 0.9999999795918367}, {0., 1.}},
         PlotRangeClipping->True,
         PlotRangePadding->{{
            Scaled[0.02], 
            Scaled[0.02]}, {0, 0}},
         Prolog->{
           RGBColor[
            NCache[{
              Rational[223, 255], 
              Rational[72, 85], 
              Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
             0.7843137254901961}]], 
           RectangleBox[
            Scaled[{0, 0}], 
            Scaled[{1, 1}]]},
         RotateLabel->False,
         Ticks->{Automatic, Automatic}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{{}, {}, 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[1.6], 
                Hue[0.55, 1, 0.7]], 
               Line[CompressedData["
1:eJwVlXc81f8Xx0lJJSsNIjMNksbXtfKyd8MeyV6RJJFQKApZSUj2juxr3Y+V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                "]]}, "Charting`Private`Tag$67749#1"], 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[1.6], 
                Hue[0.06, 1, 0.9]], 
               Line[CompressedData["
1:eJwVlnc81e0bx4lQiqxCJLPMPEVD41ORQuk5xx5ZIVRWSZMUSpKGTfbeZZY9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                "]]}, "Charting`Private`Tag$67749#2"], 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[1.6], 
                Hue[0.25, 1, 0.55]], 
               Line[CompressedData["
1:eJwV13k4VO0bB3CSSEWWCiURioSEVPIlsucNbUqRkJQZSySyhlAhyZbsZMm+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                "]]}, "Charting`Private`Tag$67749#3"], 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[1.6], 
                Hue[0.11, 0.9, 0.85]], 
               Line[CompressedData["
1:eJwV13k0Vt0XB3DRoBIpFJJE3hTypojwTUqGypsGFIqElKhURImIPI95HsoY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                "]]}, "Charting`Private`Tag$67749#4"], 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[1.6], 
                Hue[0.5, 1, 0.5]], 
               Line[CompressedData["
1:eJwV13k4lGsYBnBZIlkilTVppaRyTkTLLUlCiy2RJJQikVQqhOhYkpLslcpe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                "]]}, "Charting`Private`Tag$67749#5"]}}, {}}, {
          DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
           AxesOrigin -> {0, 0}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, DisplayFunction -> Identity, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {0, 0}}, PlotRangeClipping -> True, 
           ImagePadding -> {{75, 10}, {80, 15}}, DisplayFunction -> Identity, 
           AspectRatio -> 1, Axes -> {True, True}, AxesLabel -> {None, None}, 
           AxesOrigin -> {0, 0}, 
           BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
           DisplayFunction :> Identity, Epilog -> {FontSize -> 12, 
             Text["F26BP = 0.001 mM", {0.2, 0.95}]}, 
           Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
              HoldForm[
              "\!\(\*FractionBox[SubscriptBox[\(v\), \(pfk\)], \
SubscriptBox[\(V\), \(pfk\)]]\)"], None}, {
              HoldForm[
              "\!\(\*FractionBox[\(ATP\), SubscriptBox[\(A\), \(TOT\)]]\)"], 
              None}}, FrameStyle -> Directive[
             GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
            FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImagePadding -> {{75, 10}, {80, 15}}, 
           ImageSize -> 400, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
             None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 (Identity[#]& )[
                  Part[#, 1]], 
                 (Identity[#]& )[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 (Identity[#]& )[
                  Part[#, 1]], 
                 (Identity[#]& )[
                  Part[#, 2]]}& )}}, 
           PlotRange -> {{0., 0.9999999795918367}, {0., 1.}}, 
           PlotRangeClipping -> True, PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {Automatic, Automatic}}, Prolog -> {
             RGBColor[{
               Rational[223, 255], 
               Rational[72, 85], 
               Rational[40, 51]}], 
             Rectangle[
              Scaled[{0, 0}], 
              Scaled[{1, 1}]]}, RotateLabel -> False, 
           Ticks -> {Automatic, Automatic}}], 
         Placed[
          Unevaluated[
           LineLegend[{
             Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
              Opacity[1.], 
              AbsoluteThickness[1.6], 
              Hue[0.55, 1, 0.7]], 
             Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
              Opacity[1.], 
              AbsoluteThickness[1.6], 
              Hue[0.06, 1, 0.9]], 
             Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
              Opacity[1.], 
              AbsoluteThickness[1.6], 
              Hue[0.25, 1, 0.55]], 
             Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
              Opacity[1.], 
              AbsoluteThickness[1.6], 
              Hue[0.11, 0.9, 0.85]], 
             Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
              Opacity[1.], 
              AbsoluteThickness[1.6], 
              Hue[0.5, 1, 0.5]]}, {"0.025", "0.05", "0.1", "0.2", "0.5"}, 
            LegendMarkers -> None, 
            LabelStyle -> {FontFamily -> "Helvetica", FontSize -> 14}, 
            LegendLabel -> "F6P (mM)", LegendLayout -> {"Column", 1}]], {0.85,
           0.7}, Identity]]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {213.33333333333334, -215.25}, {Center, Center}, {400.00000000000006, 410.},
     
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {Hue[0.55, 1, 0.7], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13c8lW0YB3CpJEmZUVSioaFNNH6SlJGyKg1lJr2yZYQkMiO8dY6RPSKR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           "]]},
         Annotation[#, "Charting`Private`Tag$67913#1"]& ], 
        TagBox[
         {Hue[0.06, 1, 0.9], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13dczd8fB/BISnuhIRWVtBAVwiuVNGQ0lBAaSkaEJEJD36QUJUUqLYnG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           "]]},
         Annotation[#, "Charting`Private`Tag$67913#2"]& ], 
        TagBox[
         {Hue[0.25, 1, 0.55], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13k4VV8XB3CkSaIkRSoKISSJQr6SZAyhIpmTVFJ5hQzJkMrQoEKSIsmc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           "]]},
         Annotation[#, "Charting`Private`Tag$67913#3"]& ], 
        TagBox[
         {Hue[0.11, 0.9, 0.85], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13k8VF0YB3BJJRUlLbaQpcgWUkp+RSrRolQoS6hoUSqlRVRIKL0lCaEs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           "]]},
         Annotation[#, "Charting`Private`Tag$67913#4"]& ], 
        TagBox[
         {Hue[0.5, 1, 0.5], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13dYjW0cB/AGSl6lhQYho5JKZqgvCk2KtJSkolBo2KRSaFNSibYR7aWl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           "]]},
         Annotation[#, "Charting`Private`Tag$67913#5"]& ]}, {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
      DisplayFunction->Identity,
      Epilog->{FontSize -> 12, 
        InsetBox[
         FormBox["\"F26BP = 0.02 mM\"", TraditionalForm], {0.2, 0.95}]},
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
          "\"\\!\\(\\*FractionBox[SubscriptBox[\\(v\\), \\(pfk\\)], \
SubscriptBox[\\(V\\), \\(pfk\\)]]\\)\"", HoldForm], TraditionalForm], None}, {
        
         FormBox[
          TagBox[
          "\"\\!\\(\\*FractionBox[\\(ATP\\), SubscriptBox[\\(A\\), \
\\(TOT\\)]]\\)\"", HoldForm], TraditionalForm], None}},
      FrameStyle->Directive[
        GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{75, 10}, {80, 15}},
      ImageSize->400,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 0.9999999795918367}, {0., 1.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Prolog->{
        RGBColor[
         NCache[{
           Rational[223, 255], 
           Rational[72, 85], 
           Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
          0.7843137254901961}]], 
        RectangleBox[
         Scaled[{0, 0}], 
         Scaled[{1, 1}]]},
      RotateLabel->False,
      Ticks->{Automatic, Automatic}], {640., -215.25}, 
     ImageScaled[{0.5, 0.5}], {400, 400.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->800,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.6106936109389143`*^9, {3.610717699451294*^9, 3.6107177599806232`*^9}, {
   3.610717863959421*^9, 3.610717904600564*^9}, {3.610717999051992*^9, 
   3.6107180160359583`*^9}, 3.610802541958837*^9, 3.895303151430996*^9, 
   3.89530325926294*^9, {3.89530329589692*^9, 3.895303399094184*^9}, {
   3.8953034301400747`*^9, 3.895303541209011*^9}, {3.895303620872938*^9, 
   3.895303645557366*^9}, {3.895303736074593*^9, 3.895303759453145*^9}, {
   3.8953038402782917`*^9, 3.895303920548134*^9}, 3.8953039843699913`*^9, {
   3.895304043326977*^9, 3.895304049085497*^9}},
 CellLabel->
  "Out[259]=",ExpressionUUID->"722ed864-9135-4764-9f2a-f84b32711b30"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/PFK_complex1.pdf\"\>"], "Output",
 CellChangeTimes->{
  3.6106936109389143`*^9, {3.610717699451294*^9, 3.6107177599806232`*^9}, {
   3.610717863959421*^9, 3.610717904600564*^9}, {3.610717999051992*^9, 
   3.6107180160359583`*^9}, 3.610802541958837*^9, 3.895303151430996*^9, 
   3.89530325926294*^9, {3.89530329589692*^9, 3.895303399094184*^9}, {
   3.8953034301400747`*^9, 3.895303541209011*^9}, {3.895303620872938*^9, 
   3.895303645557366*^9}, {3.895303736074593*^9, 3.895303759453145*^9}, {
   3.8953038402782917`*^9, 3.895303920548134*^9}, 3.8953039843699913`*^9, {
   3.895304043326977*^9, 3.895304049370728*^9}},
 CellLabel->
  "Out[260]=",ExpressionUUID->"8b443ea2-62df-4c4f-a9fa-5c9143248372"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
F26bP allows for lower F6P, reduces sensitivity to ATP, and increases \
sensitivity to F6P\
\>", "Subsubsection",
 CellChangeTimes->{{3.6106793391338787`*^9, 3.6106793479793873`*^9}, {
  3.610679378972949*^9, 3.6106793847946987`*^9}, {3.610679578121008*^9, 
  3.610679587363261*^9}},ExpressionUUID->"aa8aaaf6-854e-431c-8ab8-\
c77b2a00d290"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"vpfknum", "/.", 
            RowBox[{"f16bp", "\[Rule]", "0"}]}], "/.", 
           RowBox[{"f6p", "\[Rule]", 
            RowBox[{"{", "0.22", "}"}]}]}], "/.", 
          RowBox[{"f26bp", "\[Rule]", 
           RowBox[{"{", "0.001", "}"}]}]}], "/.", 
         RowBox[{"atp", "\[Rule]", 
          RowBox[{"At", " ", "\[Phi]"}]}]}], "/.", "parameters"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"vpfknum", "/.", 
            RowBox[{"f16bp", "\[Rule]", "0"}]}], "/.", 
           RowBox[{"f6p", "\[Rule]", 
            RowBox[{"{", "1.1", "}"}]}]}], "/.", 
          RowBox[{"f26bp", "\[Rule]", 
           RowBox[{"{", "0.001", "}"}]}]}], "/.", 
         RowBox[{"atp", "\[Rule]", 
          RowBox[{"At", " ", "\[Phi]"}]}]}], "/.", "parameters"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"vpfknum", "/.", 
            RowBox[{"f16bp", "\[Rule]", "0"}]}], "/.", 
           RowBox[{"f6p", "\[Rule]", 
            RowBox[{"{", "0.2", "}"}]}]}], "/.", 
          RowBox[{"f26bp", "\[Rule]", 
           RowBox[{"{", "0.02", "}"}]}]}], "/.", 
         RowBox[{"atp", "\[Rule]", 
          RowBox[{"At", " ", "\[Phi]"}]}]}], "/.", "parameters"}]}], "}"}], 
     "\[IndentingNewLine]", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Phi]", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*FractionBox[\(ATP\), SubscriptBox[\(A\), \(TOT\)]]\)\>\"", 
       ",", "\"\<\!\(\*FractionBox[SubscriptBox[\(v\), \(pfk\)], \
SubscriptBox[\(V\), \(pfk\)]]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"LineLegend", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<F6P=0.044 mM, F26bP=0.001 mM\>\"", ",", 
         "\"\<F6P=0.26 mM, F26bP=0.001 mM\>\"", ",", 
         "\"\<F6P=0.1 mM, F26bP=0.02 mM\>\""}], "}"}], ",", 
       RowBox[{"LegendLayout", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<Column\>\"", ",", "1"}], "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "}"}]}]}], "]"}]}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Dashed", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10", ",", "0.8"}], "}"}]}], "}"}], "]"}], ",", "Dashed", 
       ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10", ",", "0.2"}], "}"}]}], "}"}], "]"}], ",", "Red", ",",
        "Dashed", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.6", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.6", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.610440725159586*^9, 3.610440776867004*^9}, {
  3.6104408331533747`*^9, 3.6104409263615303`*^9}, {3.610440964603835*^9, 
  3.610441519759808*^9}, {3.610441556590413*^9, 3.610441616359044*^9}, {
  3.6104417783710012`*^9, 3.610441797414502*^9}, {3.61044183149691*^9, 
  3.6104419872486477`*^9}, {3.6104420380870037`*^9, 3.610442218401949*^9}, {
  3.61044234115704*^9, 3.6104425168983*^9}, {3.610678950922028*^9, 
  3.610679324187858*^9}, {3.610679364218862*^9, 3.6106793705788097`*^9}, {
  3.6106936991055117`*^9, 3.6106937008104897`*^9}, {3.6106937695172157`*^9, 
  3.610693812159553*^9}, {3.610717912620994*^9, 3.610717980234055*^9}, {
  3.610802553783861*^9, 3.610802594360985*^9}, {3.895304098560837*^9, 
  3.895304098825871*^9}},
 CellLabel->
  "In[261]:=",ExpressionUUID->"ce4c241c-8189-4835-b1fa-e3ffa7c0c7d2"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.55, 1, 0.7]], 
         LineBox[CompressedData["
1:eJwV1ndcTu8bB/DsJCUq2opUVDKa4kOKJhqUUkIp7YFvZFQaNHiaWpqKNLV3
TxttSnucJKlnZDVIfuf313m9/znndd3nuj7XLXrZ2cB6JQsLy38rWFj+/9S2
nuqifj17ZG1Y1sDmxaQjq4/zu4zyHcRJJ5fSeOIeDiRGxxfwqWM56Vzq1aTH
0GnrzX/GZwSpWD5uZdEEGFvNV4XxWUHIzJ4gZLLRcJy/pD7+Kq44rAxp1cyD
3I7DeT9FrmFdVfP7nh+vwTruk3JulxMOjeHTCoUiDO8NOB7Cdx3qliwJd50q
EJG4jSpudgNaPSseBNEroc35SrU6/iboukOMjqvVKGa0yjNFbiHHTd1I6TkV
j7M3S+rvugc9aT31IOt6JPGc9g/k84XOuYXwOdc38Gx72nCu3BfCbO+u6a1/
i3N+Yyt3mPnhbM1eaZ+Et2D/5Xq/It4feeWzbll17+DRHeFBE3mErim7G6w/
WqEfPmB3atdjFFX2RWbe7YS0zo4M/ubHYB+J4jAp7wTrKocvkzZP4Ecf6Jef
68TFsuXXNUYUlFfsWQqz7wKPFEXWJCoUvL1t/rJ67+HNWiDxiC8C32601QYz
PmD3ydCH+S4RsFFS7x3Z0Y33fs5fB5sj0MbuZHzDpBs7V0lnyt6MBFUt469n
TTea/j6X7X4fhZhgo03H/XrA/iNKXiQ4BuNCEezbv39E0b4bUZqfYiB292EO
u1AvLFwM511VYnHH812Q7cle5NI5yxqmYqHwpfnTzdheGEw9VLXTiEfgJgbP
bpU+RA/fPl60nABN4mZKxqV+HBM8/3zkbCK2NKjIePn2Y9pUcQ1rdiLK5Tm3
fU7vhzDt1pVsmSRQji4lW073w/magjjLUBJeaD5naDsMYLNV7ss0pRRYek/n
KpkP4uoD4fMqVimo3+7wIfPWICpSQtZ3PElB4jcn34bIQVgR9nYLkynYE5zl
M9M6iCILSWmdyFQoXR132ac4BJPzybmz356jqNyrPXppCMxBI7YU/jTo+l8+
br15GP4WrNaGx9PQtLFH7LvEMAquOPMXR6QhaLOu8hmDYXA4HfbzVExHeV5T
8/7nw2j06Tdde/cFRPetuyF3eAQX1oQUlaS9AE/4h1DT0yP4HnB007X2F3iz
3e7QmUsj2B7yorFF5CXet3qmJ/mO4M7TG3KhdS/xQirTc/LNCPZnca0VZH0F
UI9o+mqO4q1so2Wb3Cu8k+TanmU8CsvXHhX3zr8Ci+wls5dXRxFSPOpCvHqF
6H/isyK+o5iiZg+m62VCbIY2vK1qFAk9Wq/3hWehT+HAzZYtY5A3+bvhU0UW
2Neu5xPmH0PrQN7ViIks5Bjp3bLYPobF0a2C8/LZoO7NPJQhPQaj6c/+lX3Z
UKVt3+WgPoYN/7wvnBTOhbbGh7udLmOIvmZsIX0iF+66Fb9/3xjDzm5pSy6n
XIgrX87i9RzDkYzeK4NVudh4zl9TzG8MZRlRRSWyeTCVZ/V9HD0GuiGtUqc9
D+Liqx8PVI7h4Prew0fG83BS/rCvVO0YblfXVsvN5UFCYPGzfeMY1kk9pfII
v0bQX1X7lrYxiC4faxh1fI0HSxPjC8NjOPvyaYv7xnz0bd0fKLE0hnhzH92r
ovmwtBO4UvFvDOObHdtM5PORGXnbU30VAee7ah2HzfOxcdXmbgU2Ao8M6O/X
Zefj/tyuuYStBKqW1AbidAswlMkdEyZHYHW+jNljywI8MavZ43+AgLbNtiGv
6wUIfVTu46JAoLeLPmwdX4A4trAeKVUC39Kjib20AhyLbbbdd5KAuD5jqj6o
EHdbbA3SzQjw3z+pYpNcCG3K1PxxCwKbspOC2EoKoXDtwtE+SwK/WQ1l9ccL
sYeTZ9tnawKd1BL3EaUiLCypWYc5E2hkbGr0PlWE4NmP6V9cCZQL2vGKWxVh
wsnw6MHrBNI8BMvsnxThmUtMZ4EHgdty3ssLn4sgbFiee8qbrN9i4HT8nyL0
pJf9sXxAwCr4QDK4iqGuH6hu70fg9NTn4/6qxRhzyea3fURgZ5L2oy3hxcgz
52WuDiXQzsnNLXu0BFrBnUqDCQTqDztad50twWj7n7U3kwiU2jcVX7cvwW3l
5W/rUwikNnucr4gqgVFH+UWhNAIe94cTNOkl0C+9Y/LzFQHHbIXZmZWlWNvJ
03Y+i8DlwSfHnmwrRViZ2VBpNgE9RbWJnuOleFuatNYqj4AYM13qSmwpNmd/
F3MpIrBViMVzbV4pjHVZ1j0vJsCuc741o7EUSd0rFrtKCMynb3CenS3FrGTc
YcFyAq0WLoV3T5bhj4Eg1b6aQF3w2zWi5mWwaG4Ncq0hUFIuZtzgVobH26Q7
XKkEUnh7FtkSyqCqtp95qY7Af+3KiP5ZBpacaNqKJgIcskWf37KWo1ok70I7
6echcsF/BMvBP7D5dFQzgS5diX4LjXK8adca2/aWwJ4WbnfxqHLUbzQq/tpC
fn83hc/4VTmKnNQPhbcSMAncQH1YXQ4ndu0gpTYCflorN9Imy8FhbpB7s53A
aDMzPV+xAhoHhn/VdhK4KWGvN6FTAVmlp3XaXWT9AZM/eCwrED1e/ayDtPKJ
4aO3Hlbge9P9xLb3ZD+lmXx5FV+BAq2lnhMfCFxd0x0ylFeBBZdslUrS4Q3v
BtBfgXnB5Oy4bgK7d57wdqVXQNFBtmVNDwHqg1qJ1BWVWGnuL+9Amq5Wen3t
7kqwxVzikP1IwDflgIDSkUrU5D0LekSaf2Vu7TWDSoxb87oTpE/WpnG03a6E
T6HjM/9eAiPbRYuWH1diWOcW4wPp617xZnKplQgbEGgS6iOQjPCX4S2V0LzR
tPMFaaVEjtONo5VIDr9RNkm6ffnRr7kflXglwTYr1k/gT5WXmqlgFXTkvcxD
SYcJLU0FyVXhscvD5HrSknf/e1KlXgWN3/XJ30lXD32XZ5pUYcE10Up4gMBZ
Vaeh7Y5VKD7mMXuCNC3uq4+BdxXWN8frOJD2+WMl5RtZhbOeuncek95mNtZR
lFGFUYHSh9mkc8vNbn6pqoJi14r/3pI+wd8ryPe+CsrnDuuNkx66ZVCvPVmF
WGEXrgXSbv1t1+78rsLindC3bIME1itrbcrhqIbnm0BPftJJ0Q3Fo2LV+Oet
KCNBWmEB5lyK1fjoYT0hR7rVuGLVcZ1qsDO70xVJXylReHX9YjVOVSndPkT6
N2/+mXT3apjfVLBSJU25KTPfG1ANrsCrdiqkd318+Wx9fDWWbIzC5ElXye9U
P5RXjYTke4QMaaPIxGmHhmoosxub7yA9/ZM/NKGvGorjaht4SXsZRSl20qqh
NBE7u4b01kKukRUrapB3K3PzD7K+C8F/jCZ4ayDAHA0YJJ1i9bmlSboGdlsO
tFBJf1HtUMtQq4GBwoFPKaSlecrKgkxqcPSsxUfv/58PPUXOyakGWlpimeak
SxqDX5zxrYHPzyEbBdJqNy0jefJqsLjvYv4I+T8fntJmX2isQZhGhG4O6bZd
Bx8MDNaAuBb35TbprJkHpR2rqKjzMlTaQLq9d+EHlYOKR+yLi+1kP32rd9yb
z0fFClnT7iekFeKN0yP2UiEmHj3NSvr8w1bCT4UK3Z5f+2rJfr1z/ZjQfxpU
lAlzZdwkXau7J+K8GRUfaqdU+8l+1/277C0cQMVN2nLEXXJenL66V3GGUZG3
GPJThHRoz9QCyzMqVi+cyq0h5+1j9nvnT/lU7C+T0pkn5/GSRbr5yxEqlFhH
Xp0k59dXWyAm5isVpQe/u/WQ852uQOkO/EmFYti9akvSNI7bOo5stehfwA/n
/+dDjZ7yfoVa5IymGbuS+RG8/Rd3ZUgtlleWrV/9jkAOu92Z7Oha9LBVH3Ag
86lrYSQoIbUWFaVHpd6/IcDb9Wald1ktAh8YBTwl8yzZO35W43MtCo/keLM2
EigeP97aoVoHh49yY/5kfn7U9P4WcrIOl5cd1nSR+TqXU82ra1AHxZcXTvCR
VvRUvvTGpg42up8ln1eS+2LL3jlqWB36zve2pZYRKFPn354/VQcisNVWr4BA
Zfqse0REPaIz5FdcJPfHELtsjEFiPUw5NNPdnhNYcrOv3vSqHkfFdzf5phI4
jEnWkJp6lJXFeD1PJue7d/CZ33Q9NPvCdr1/RqCGtbn55tEGrJHyMJmKJPPX
7pnAeVoDRIPnDDaR+6/gq729xVwDLL9da2LzJfPcVqXiCksjzhZ2ia8m96Xf
1V5TJ+5G7BjvyvnhRUDzMlfsA9VGpO2V4Wm6Q6DjvN+2nOBGMOxY/JXJfTyk
6cizSqYJNNfXP60uE/i16zBntmMzpj+EavGQ94WVi5mbBMTfwdD5fd/iyBgU
/lkWG+a0IkNb6ue5e+R9zfdge9PuDogatOe6bxuDCGVmMYPRCeWV1jY3Toxi
Zn50pEfuPWInfj4rtRzB8+mKdxyPP6Aw/Nfyuwvk/VXoBXNiohtrz7wtVzMc
QvC1oqtJOz+SuUe99cZgEHNHMyds7/fitKaPpf6BAVzf31DIW9+HzjXyf58J
92M0pyGoS3QAfIEChvzTvfhj1x0ndXsQQcq7jVYVfMSeY+uWr1YMQfnC7gGZ
wB6cTBG1eb11BJKnfwiJqHXjP6GLYsSFUTgaasQLb/gAadrZDb16Y/AtPqoi
2NuFLZyzrA2/x5D5NoO+L6ATq2vicnfEk3P8JP9BR1w77A9W9K/XGccTnWm+
psUWZGpdTqqeG0ftp3l/Lae3+DXDv2ky6hOkm3q54wSbUWR4clWE+gRSeTtM
bLIbcF/TL7FwcgLqabr7Pt+vg+iwdl+q32dcY037ds2DChVF3wi+/ZMo2Eds
rGmvxAXhjsUVHybhoXh13/1DZfj1LmTcxfsLBKalDN7mFiF6tcV1g51TMKWk
7ZMtyMeWkaKUlQ1TcA/YGsLgzsOau95Gyq5fsXDLyK5dOhMsGRa545un4bid
tvrNrhdoovU6JfJMYySu/UMa7wsEy+nLXtg2jfcmkRGP177A1tLj2T1C0xgW
XkV4TaZDtlky843kNMLpvOen0tNx4fP39Jwj0zDdGHeeKpWOMtGAhNt20yBc
XWK8FNPgFpsbsrluGsG6VY3RbqkoWYoNqGuYhv5zi3em1qlYsvD3dmueBo9q
R+Iuk1QE7DC/8b51GsbXruQNHk5FfBabeVjvNOKedXJUrE9FY7W19Gb6ND67
X2LopKZg2yeBFq5tM6i1TtJMHE5G1Z6HrFxOMzCztGk77ZQEhe6tbWEuM9jZ
Mzi6yyoJeXdehHK7zyBbj7N2jWkSUtqa+Ld5zEB8WHliQCMJD53XyIj4zCD8
loT5uFASDAp89GWiZmC1dF2iOSERX1TuxmpVz0DnokWkvEsCuLTdpH04aLDv
uJ3ringk1XJuUOGiQdds4Lu7TDzklLO/fttCQ76g7YC/QDxOSU6lX+KjYcGB
z2NkPg6Bay1Ej+2kYZl6QNDodRxW12vxsqjQoKJb5mkgEYe5Q6Is96xpkGAN
N7cRiYVfQfWIvC0NeW1uOc6cseDec6GKbkeDdSZXUcC/GBzgf3rb3IWGnJQV
TZOjMXBZYP+l6knD+oo9kpbJMfhauPD1D4UGMcHUe8oSMRiS6fxwq5KGObHb
Zw2PRCNxhuvuqhoaGsjVtn9fNC5nGO4KqaXhOU/CP+Gd0fi6s9cjqYmGCWJQ
WpgtGnMCI0LNnTRMe7acK/74FFxsNBvuzzQEnJYY0HR7ihOT65ZyNtJBlcyK
as+PwvrnWmlKm+hYp1KTgRdRaL0UdKpuMx3mD9bQK+OiYDjMkdyzlY4I61/0
Qd8oWHbznFgSpYPi5Hok0zgKnnU7KFoKdDxi5GsH/otEXgJ2TljQEbLbbsdO
k0j8uP1j3aVLdExdOaxx/FQkFIxfzAxfoUPz6fJ/juqRqODkLOi1paNCPXNp
XC4STV4jx1rc6BBaZi7qs0Vi8PLdi/n+dIzLUwMO1URgrURFrFcOHV6n2l4J
7IuA1irne3/z6OTe7EsKl4xA8KjY5dsFdEhoBW3i3R4BruhAqeuldJxZbNdW
4YyA4HrTUps6Og6cm8/6Rw/H/pmFnlMf6egzYFe/nR0O81wFLqFlOhj/CZ7d
dDAcxaYLHJ0sDAjP7cjeJx0OjrXl7A9WMWBZ3l1ssTMc1AuHWb+ykpaweDfI
HQ4xNvV/hVsYOLrb9tKluTBMWunTdaUY2DJ1djCyIgxO/A5v7xgx4NG6ycP7
VBiaGmWa9xoz0O3INODUDIOIK7Nh/DwD+9g5jr88FobOZjeq5kUGvj+bPfPn
YBj237hVwm3HwN7OzjRxwTDMd/inZd1nQFR4s1kALRRefsneQ68YsF63/uKl
yFBs/G+d9qVsBtzn1tokUUIRa+u4eTKXgZx47eSpoFAU6CinMgsZiInRT4rw
CcUkV1fDyhoG9LIk3E1dQqGTwMIq9YEByqRfV6xeKPqeXO3M7mHAPvFnpL1W
KKy8W6P39zFgMnbfXEMjFPesoqVUh8n6tzVNbzkcirzdcjqnvzAQWMH1WlAm
FLwlFx/f+MPAv6eaEQMcoUh92Xju918GzjpOaahsCIVc7B6R+yxMHFiW70xZ
Fwqtu/O5D9cwMe85afWYJRR3jj/piuNkkvdxFu2O7xSMd1Rz1+1gotFWkPGr
jwLn2p3DJ3YxIYANbOM9FCzlB6a1SDLR8oOt/+N7Cniizin0yDCx7qxXwEAr
BZoXGMZTikwwP0lPa9VSkD0lFMehy4Sq1J9fTZkUPHzmZzlyiokl26cnvr+k
wMqALp6jz8S5HjMNyXQKBCsr8/SMmRj++E2tMImCwCdmTcGXmahP5ZrXiaLg
qnp90AVrJjzTPVxbwylQW9ytL23LRKfUop9xKAWLl38Ptjgysb20yz0kmAJb
hZhvbLeYiLlkIebxgAL1GZaSAU/y/X190nreFIgk2d55dY8JhUSdGun7FHxc
r7RO25cJUcN49w2eFGgMfxR89IQJMfU9YyfcKdgedmTcJIyJtb/dZp1dyfM4
kf5CMpIJ7Swvj1RnCgrzbux/E8tE77zNlJQDBWK+3Jrr0pm4k+zIXWhNwbLS
nY29L5mYvVmcK2dFQT/90/v0TCba4nwKSy5TQDEuMD/xmoniQt6fExcpcGAX
2MFbyITar1d7gizI8631mfpczESlqFnTIXMK/u02cPerZEKE869wpSkFA6Nl
SmdrmCjZstgfdJ6C4gjR5Z11TGSFiH+3NqHAaXn2YUMzEwfDbx1UPkeBdoHJ
qYh3TAjpfzXbf5YCcVvqFqs2Jh5P8Q3KG1Ew1PUkYdUHJpyFUwfNDCgo9Z+/
8qGHiUft3qb39CmIOHRRKrWPifueMtKZZyjQSZMtVBth4uGUbv2O0xTsMo26
tZlgwibA19/5FAUrOZePjH9igjK8KbpRj4Jyj7a33l+ZyNVcnULRpSBKRv6J
Po2J1bMO0WtIu47HG4kyyf/nJtPvq0OB7tPV/N++MfFs4PwVDtKSug6j1J9M
bJnYqJCiTcHqFd3PKfNkP/x1OHOU9FjRITvL30xoaqS8ntKioNIuda/cXyZu
BIyZxJF+KrLh179/TGQeuaxhQvp//S7NCQ==
          "]]}, Annotation[#, "Charting`Private`Tag$72182#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.06, 1, 0.9]], 
         LineBox[CompressedData["
1:eJwV2Hc81H8cB/BCpRJZDSWRpMwfolRekmSXlUgUImQkKZoKkdWQjESFkD0i
KZuyz7izyb477rS06/fpr3s8H4/vfe/zeX8/3/c4cXtP05McCxYsmFm4YMG/
T/2T05RKuoXGydVuW/iepGlw7RPxGl6rgh7JYsuU8EAoJ8U+LFyrDWOJl6u1
LaNh0EIrSFxrDve9H37Psp/C0vHr67trHbHy3VmrLXKFqN0nUlLz0AnLR+Qi
4myLobhpT95nMRcEli7aezOoBNyj158clvLAjs9d5b+KXmFQ4ea+iLU+sI/O
uk5vr0J00prKzUfPwSDwkJdNTTX0+TJ3v3noi7yixPPR+TV4wWrezhbzg5bx
ooTqgDpEZgtIm0hdQe6V2lvMT2+RLHww+NbaQLzPOJ7prdyGiy0Pag+XBWLN
avNtF2fbcDhohGPT0SCkbyw5Zm7aDp4vZ66+ehgMh2urvawXUXChK/rCjFgo
Vli8uvH4aAdM7vW5GktFQlN3+IFCWxdkDTZliDREQltck1W9phvcnKenJp2j
8IWTd435iW7YvfyTX2F+G37Lk54FsrshvPW2/JGYO5B1iXZPX0BDAHfhltC1
0Wi2CBl4/70H2w7cCSnwioaNpEy6n3ovOoI86f0N0Vj8afSusn8vJDlln8v7
3sdl/gEVsa+9qP+dIt/VEYO6XbyX9Kb6wPMpZrtYeBzuKXgaqqQMoPi/czG6
Y3Hg+jHlVt0zAFsvs69n1OPh0pvAzuIZRO4s38va6Xh0Mu40PPEehOl0yG7X
/Q/xV1jC005tCLGD/vuK/zxCyX/niw+nDWPvequUIYsksHn3zE9ShsGwVlvE
nZ2EiURs/vlrGBtm/Byy5ZLxa6VJbr/0CDxdVDcvGEiG743QZ33+IxBwzE1P
3fEEowaNR54LvccRq8e5cx9SoNbpl/hZchTsfvNlT0RSsdnB5WyU8iiCbblP
mu1LxTd968VLtUZR6OAp8iI6FZz8T9bH246C12NP0EW1NChzZhciZhR113ut
F19+BuVMnlVzf0dhsyiiuCT1GarXpNSn8Yzh403NlS6tz5BlpmSitXYMGyOe
1TWJpaNUw2z/VqUxXHpwTvFOdTrcnW/HVNiPQSmLf/F67kyIi/6VNKkYwzv5
uuMtipmQmF1r6t84huP5F15dscoEu9N/RUT3GCJeDHu9z8yEgckXFS/mGKYr
s/vTjJ5jdZf5TpVV43jUrZf/370sxP3hTZtyHsfyvwE2Bzbk4vqeov3nfo8j
1sXSVlYnF9eM5p8ILJ6AZJfscX6PXEi0bqpN5p2ARgbNof91Lsrau2ajxCbw
MiOmuEQ+DzHOApxvNCcwazZTbtCah2ubltVcuDYBi/QHTWdXFCC7gnu58fwE
Hh67bugkXoANa59F6PyewKiAe8uR7QXo95LoVeaahOdlrbY9xwpgI6anNMs/
iVDT2Y4l2QXIdD2UPyg7ide/tPoSDAthG01f3nR8EptNWNM1YUXYc/yPh3fV
JESuHlB3flyE0KIaueyGSazMTg5bVlIE2qnFc4Mtk/jBbSZvMloEatPePvG+
SbRXlpwd2lEMK1vN4u0fJ+GvGPDn20QxZIvWyCZvnEIrn5CQvGYJjLX1ly09
P4WaPe4nKRYlWBW4oknm0hRK3epf+LiVQFZJbl4nYApPGy5YvYopgXndu0an
sClcuDr4SHe2BA/1pzcYJ01Bgp221SG+FK3rLM69rZvC+dadiP38EnJ1P5c3
r5gGr3zxxDvuMmxr7Ylu5Z9GSoRi+M/1ZThqFfajSXgaFMMtvbb7y2DKoRlQ
IjoNmSahs5tjynBm9N0FU7lpDDew0wrUXuGb8/GCJINpHKhK5W3xL8cVmSNW
7YHTGNooXvwnshzvlFQoGiHT8Ln28Kji03IUqlZLZYRN4zHupd9rKoe8zcXg
M3en8fP1NS3r9a9xqO1NNyVpGrllR32nXr/GJzMxD+rLaawu4h9auLACDdLd
wSLMadiE/zQfX1WB4SyWxSHWNJ44TjTVy1agTX63/PUP05AVfvky7EgFVN6J
Cfd9nYaW7/H7wnkV2O3gf/YoFx2qDy3TohUqcfrozT8Z6+k4YZt2LH2oEqw5
sakkfToC9dfFxdErYRfcVmFvREea6u2uW58roVsteUziEB0zvP4G7suqIMSz
4McDCzp8K4x2KqkSPx07cOw4HeEbvwiVR1RB0bjJ3fwcHS9G9zW37a5Gh8af
XKFEOqi6AR8iDlTjV13DUo8kOuZz3qwyNK0GffOB9trHdKhd3HnirXM1YnSU
C1zT6CgVVJivvFsNrKhUiM2l46W2yMaC6WospWdtu1xFR3na3Nno6BpUiQ+H
B4/RMcAjH2eaVIM9azO3RE/Q8cvb7c3KzBpwuo7FJk3RsQeT3BEVNXgtsH9Z
HpOON7T+xCBGDfbZCfqVfKKjgruhwVezFhsq5L7ZczJQ7Zq4zmqmFojg4IQ4
A4V0Nzfb+Vr8N+X7YlaCgZRT6q8cFtRhvmG6PV6SgSAnmrWHUB3ucRhpzW1h
QNeeP/7G7jqIp4kbhMgz0GYVtCYnvA5Bt93CPHYxMKDrLswpV4/vb9XHxMwZ
aGnYdZJbrR7rQ9LGH1kw8EZnWfGKvfUokaLcWG/JQJL2M/M1FvUwOhz6WNCa
AXvN9/fkLtdDzX9Z0Ac7BqbVLASOtNTDNvblDnc3Br5I7eHLdm+A6ftSeAQw
oDGq1XDrQgPMu0NDR64zEJyoe/XUjQawjEqcTQIZWCVkzt4U14A7qxOm5G8y
oLrQrS2+tgHLNNZK9IYzcKE/Nipk3Vtk2QgPMR8w8CvqM5/ju7eYk97WIZTN
AMf35yvXbW5EUum2g5WdDKxr0foEhUY4rK5/1NbFgMrj3m7HnY1wXFr3c7Cb
gZN6SxJyjBqxP9fn/VcaA2/j7Ddr+TbCdnaRz8YBBqLU16q7NDRidbDGuf3j
DKy/FOxQ4tKEFY2nU8Y/kfX9Pf7CLKcZvK68HE9WMmFoVHl9f2kzkOTz2Jef
CYcEsYNq1c3ouRkdpC/AxG21oSkRajMMDlttmBNkgu55dO3o72bo+is9UVrN
xMMRi0teRi1Y3HHJ+74oEwur9bUiZlrwWOHyUupWJtaszOS9Ot+C+8f9zaO3
MSFvu7Tfa0Erhg7c/GIiw4T1j4az5kKtGD7UvKtJlokipf2p63a34nBEzWSx
AhNOT8GdGdaKBycPSZzezkRzoEpr/TbSp6i+87DTZEKdr4njzvY2fL8bRFm9
l4n0uBNqRzXbcPZN2OU24hs5kclsizYksRMKd+8j1/dMe68JaAPX8Zw0Xh1y
vUzialdaG75Va4reMWBCi349b7FWO/RzEpsEDzPhJ9/a6HagHW6hp8xfEOed
XTvRbthO+jQT1SOWTGz4k7s2wbId0lpGS+KPMPFdYPC6gns79JrsGMJHyfW7
1SyOxLYj4mP+KrYdE2K3md8zWO3g9D0xv9WFiTcnrmYUfGrHh483P+YQ2yoL
Wr361g67TPopZVcSX6p6aTMHBZU1sXXqbiSeord82asokKqTPLDPnQmBTOlP
KqDA/Vxi9q4zTCyqPTlTEUWB9/Wf3M0XmEi5/z3hbTQFLQXyg5p+TGg7RxhQ
4ihIUM5VKSa+vqw4c/QpBSGJjz0e+jPx5xCXy6JSCnJe+QufvMTEt8EnE/oj
FIRlmjgPX2WC+XV4qFuxA7JuUc1+wUy8cI6q1lftgI9t7tJp4ms0jbSKXR1Q
/Wj82uImE6tKEt0zdDowa701VCGExNf36K9LNh24YvijbCCUifjP1LWSIR1w
Gt5aIxrBhO6HFnPv4Q7cbA/6b/c9JgRPXN4xNd4BrbwnlXHEQ+2y620YHdB1
ONY6T+yTFza2/0sH6jVjnHKjmUjy1PNeu7wTOy2db4vEMDE/WxtVqdqJqv3j
P3piSTwYrxp5IzsxdLbm6ddEJjweHNzkeq8Too82LNZ+xISa9tjFuthOyBbK
fYwibkxcJnfpaSf22687JZXExIdDVlH00k70X+VtN0pmQqNk3qx2rBPSF7a+
CH7CRO+N/wb9dnZB81DFj8dpTDxRrNverdEF3g9bJ4aJTw8eiVTU7kILxcpW
9BkTC9SuYcq4CzKjsb9jiKUYrY/NHbtwR9P7U2A62d+h004KUV0I70/pM8hk
glf0GXt8nFy/V9g/OJsJzcM3BsfoXViS1atdSOwdZdc0yuqCoXp83jAxdeGa
ZyPfurD4o4ubWg4TjyZDbAd4ujHzOc9rlFg+z7WlU6UbPQtym6XymDhO13nV
sbMb4THO+UbEdyU2ZVA0uvFF0WuHD/F8dH9gm243dqtWylUSv/Ez3N1k0w3L
lX4lZvlMGO2Tf14dSPp87QxLlwImrlxaFlcV2o1W8b2ut4jziieDKyO7kc99
aONzYiHpJPs3sd14/GbVeSbxAM9KkbKsbmz8s4biXEjiRf0Qkt/VDetBlvbB
IrJ+vlbfvF7ihXdiXInbdTMdc4e6EbgxLTyIWOWVvWb2dDeU79g7lRH/Sur8
mv6rG0d+PKeIFTMR7lLslCxJRZ3Djnu9xAzN7JDl26jYPRrJ8YH4wJrUTF8F
KrbGyizhfsEER0M0y1CdCv+ks+0qxH6SPr7fD1KxvaLbMZSY+tMt1tGCChHx
r1cTiVU6HcrarKkw5KUo5hPPBZj9ST1JhXXqmBmN2GlYKdj0Irl/GjN5QwkT
tS+2pb++RsWBSnU3BWKJSIlG6WAqyOFoAvHgbgHev7epyPiz6KAdsbrQMkXX
GCrCZPm8PYhjmQtNuxOomJmzl7lMbB7/4f7zNCryDwifiCMuOEMvWZVFxce+
kME0Yj69970B+VQ8XXxmrpC48Wu76JFyKjrG63ubifda5KVydVCR5nnv1Xfi
R7LpDZ40KmSZJTOcpSSenMn0vgEqLkonFK0gLi2IksufokJOrIJ7I/GqWzcP
rp+l4vxHvvvSxGdPXD1z8yMVka9Qqkgsv9Kz+NhvKqJkrGtAHD7lRHvLQYPs
IbPnOsSMN7bflblp2OKku82IWDfm8LqkFTToyGpqmhGnuhvvWSZIw3/ye2eP
EHPs17E7t4aGuFqT/2yJj6/XCBgRpUFD+AKPA/GbT9ufGmyiQUiw7Ioz8fom
uboX0jQYXBENcSP2f7J5SlyeBt/xZ9KexDQ/0aURyjSEJdse9yZWMRGW+baD
hsX9OgrniO9KrzBy0KDhU+jJ++eJ5/5yebbuo2HVmYq7fsTGtF+3d+rRMC1u
teUicVbO54IUYxpKf6qaXSJeGjzTxWdOwxuZY6suEzsdG5/3tyL7z27z+uda
lYE1k7Y0aOrdtf9nCZ4udRNHGmwfpDP/ff/aWJNNuQv5vd/CPP88VFZzZYsn
DQdzBmv8iXfdfZV814cG1WwOwX/riXUprP7tR/bXePO7L/G85vPxU1dpUEz1
PO9DXJ7CTDgfSINHd3nVGeLr3LJmwaHk904y8jz+xf/06WX3I2kw4fih/S9e
vO1ZVU/v0bBDZfbyv3h2Kc9eKIiloeBY3dF/8Y5/IKdYlUjWV35j6N/zkLLL
eTT0jAaWaUmHOfFMNctiNosGUUN57YPEBVIKK37l09D4M9Jaj1iDlXtxbTkN
xqf4fHcTc5nOKUlX0RD0WuHiduLGYkWGaj25/w/1zfLEhy/nHzFvp2FjLf+p
Df+e7/sPfA7d5HnVDCxYRTyqrdRwpo8GpfA7Gv/OqwdP4faocRqkm4vTf5Dz
reL1aSaRTkNF5KbuOeIfncopWSwatAvPp00SBycUCTR+o+HillY1CrHh38/v
en7TkPio5WsdsYDD9oApjh6k1GfblP17X7a9YHOt6MHbKW7hJ8TFL0uaId6D
3jw23In9Rb/dMJbqQe1cmdS/91kzYMeuYzI9EMw1LzhE3Kz7MsN/ew/WD02V
KBGP08qCi/V6cDRN6dJHkj8yd/3cU2vcgy7fNaHvib2Sdn3pMOvB6vB89Xbi
X07lDnPHepCzZzYsi1ho/rWmjHcPor+snDxO3Gf15+vO8z34JrZmjRFx8muN
XN1LPai2zWHtIJYNqhB1Cu6B6dGzoXzE2kJVP5Lje3DHvN6nlORHH6XaolU1
ZH0fzUS/k/zqpLIx+c7bHsQ/3e45SHxE9VIYT2sPNsnvt6gi3qWuYs/R24P7
PG8HbxJzaKXwsVg92LBIf5iPOMok0LVOpBeCidwJy0m+v2Y2YqG5sRdLOue3
0Uk98LbYvffV5l5MTZ80ric+bPV5db5iL673Rx+8Srz+hGPdQ51e9Jxs3TlD
6k+ml/ZGH+9eHAujPs4n9emhd/Jy9vleuJU/cAghjvD5Ne9yuRf0pF8ltsRe
F4pa7EJ6kfbk7Boy4EDtmuRFg0e9CBM5+uJoLnkfo7ioEo29uPguxpJB6ulw
Tm0YRbwPzebSBUWkHrfPcs0obenD0KRX+hXiStn9htGyfdjQIKKsS5ycWcdj
qdaHh7p7F/VlMGGfVh8xYNgHszMP4r+R+j6Z+DZq6nwf4m0afMVJ/Z8Nb773
u6UP6h1LLcWfkve7ieezbWcfpKNHcwZJf9G6zMi8sqcPEXYasXHEOSEtQjfG
+vAgZrXYSmKvwNb73N/7oG/k/eMr6U8+X2x/ICjZD7Ogfe0FpJ/56dqVsNW/
H3IxdKWuOFIvVI/dkb/aD5a1IlcIcdbCyWDlwH4cn1Hx3kVsG/v1zJ7IfkCc
X/Ix6Z+q6kR0TZ70o+LD3gHnB0zc3Hji84XGfhSr+twcJf2XIHXW8K3IANaV
n14aHkXq92NfrRaxAWBKX0OZuPb0X7UOyQHU1J7h6YtkwpeTf9OA/ADuV4r7
SBH3Kqp8Z2sNwGBduXtZOOnnwvxTV7sN4G30HKuV9Isye5f8cXo1APMnhfoZ
N0g/kfl8S0/lAA6oCnaqE6sIHTLRqx8gef/7YNN1JnZPxabIUAawZ2u2/0wA
yc8R2wzmJgfwTYLSuOUaOV+9RrF+AoO4u/rRo2DS7748E60U7jIIGape65gP
6QeeiDvnrx6CY/voWX5Hcv9YXqn69UOA7duMMAcmNkb+HO8TH8LFVcecFxH/
8Ou255Idgq1b34WvJ5jINgm1tdQcAsuKe66b9P+CCz9Y/D41hGsm9Ysukflg
2K5SW69sCJ8Vev3dTJk4L2on8d5mGFUDgsebNch5OaR4eODEMByLk9W3ERvf
WHiL5jSMD6ek7t/cQ/Ir/emHFq9h+LO132nuJvm4aLqyLHAYzw++35K9kwlF
Q2+76KxhFN9IjXRXYWLaP+jhgV/DMNNR8Q8j85nsjMVymtEI9i6L+yVP5r1S
c8OKW4dGsKn/ymlrMg/ue611VsNsBHoME5UgMi9aRyr0px4ZQUr2ucYeXiZC
FZc+93EYAX9G0pILy8l59inXF/AbgSF15aUYLnL+f0vcMkoZQZio0pdD8wwI
8s1x1/4YgXHLbEw6mV87Xt+6qfd7BPc84oNLqQzcPb15cdvfERwP0WtvIPOu
QKM1Zx/XezQJenqNk/lYIKjuN5v3PZo38vQLtzOw8mf8x3Wb3sPwXqSA1VsG
eKb2D5w1eI+ObNe3tqUMcFUk5G56+B4aCpsfmMcw4KbyqnepwSi2vry0SVOL
ged69slv5kexOZV15dQIHV+YIisnY8agZu3FSjxHR7HZAc5o7XEUvYize8ya
xlXdoKSiyXGMbvD55G0zDfFB/Z6nQROwueeyemfpFNTVAqPXKk3imcx/32/N
TMJmQ9v3hZ2TqOATWy8hPIkvjRGjXgFTWCebXL6TbwKxXLY+ppLTkDK0oSct
GIfgUPETjtppXN4m7bLh/SgWXQ4w33mGjmT7rn0i999jQYZt7qgAA7wOVsof
TUfgHZ8bIVDNwG+Z/PnY8UG8lgnh5vdgoicg1uScZj/49b1lr/PO4LfUqv5T
JO8OyLV3+pXPYKJs/YBCBhVJTP7LnBUz2FT1w8rwMRX2GWZSEVUzGDTaGeke
RwVdknYhuX4G4cwu6TehVMyvGxJtaJ8h83NQZKwrFfzLZpyFJmbwrHrEaLsc
FTqTS37lrJiF50ZLwy0vupH3CJLjtrPYErLhagqtC5/8Py05cWIWH//6RG+j
dEHV8hlz0GEWabKbvxY3duEVH18h7dQsXoQ8yBl43YX6a0N7m7xnMVTLJeOa
0oV++8t2BcGz4NTp9r3pTeaaLa/ir+XMYuXReM9+gS7ocXpe+Z03ix15c2/4
VpC5aVjC3r9wFsKD8il6S7rAH3trq0/pLMkL7jtaf3Zi/VLrUufqWdgEe1SI
THRCifmt25g6i+7SyvlqMucdy1XlF/0ziyUJoZU2jp14Yf2Nt30BC89VdSR7
bTvBu7iM5wYnC2Ki2bY2Vp2otNnDTedmwYLHwe68cScklmn/LRJkgRFQVf93
RycmHU1mDbey8DFOof0oXyc8RE6/u2TOglJN6pxhFZlj6+QaFCxZMLZPT31W
3gGxM+zaUSti8zfOS0s70N7gXalrxwKnR8Oa0ZwOKJ3zKxFyZUFdpc98+mEH
vrYFp2ZdZcGzq/Oonn8HrgU9DhjIZOGPTMdSJ/UOrDi/RP9ENgvJjo2D42Ru
jz/lLjCZy4LhN755F+UOFBrsfMouInYMmg+W7cAkP6WWo4KFFqt7BjxiHTB4
tIB7aycLacLe77UXdaAnyqk9u5uF9d95D0pzdMAxoDlWqYeFLzydywX+UnDF
MXbr7kESj3D5c9++UZC3TdHg4BQLDp/UV/PPUrCqxC7y3E8W7BUF+L2pFDxN
rzv84zcLGn1ShWWdFCjGy4hdXcCGZ0Rd1lIKBXqXv+aGLGLDZYlLelkTBZf2
RVES+NjYPb6v5VQVBaNtb4SqN7Ex3sElNZ9NgWeV5KCOFBuNkU/PpDyn4FfB
rdQmaTaCv8yJWGVQIBxzWLVbjo3LgbSb3SkU6NqwLKfV2ODYKN4p8pCC7GnR
BF5DNgIOxLjRwv79TxJ0fMiYDYZl5mxBKAWOprObc0zYeD6Y5RBzk4L15eV5
RpZs9MWGyZ67QcGtqKP14fZs1DT77Lh7kQIn7Zowm5NsLK/rPp7tR4HW920m
sqfYeOz67Ur7eQq+2//ob3JnY/sdtUR5HwpOqcZ9WObHRsr5ryf13SnQZi4o
6bvIBl2/UzPVjQKx5FOXMq+w4XcjWoDblQLq0h1L9APZkMiSSphwomD/IHV9
aBTZb+V9rQUnKNh4V2P0yF02Dix6RY23I/HQSXsmfZ+NXYy99ntsKSjKO6f0
Np6NB2HX7eKPUiARKKS7JI2N2hVpHwsPU/Bnx6UVtHSyf0rl3kgLCnpnxzrS
nrMRuWhtiJc5BbctC4/p5LMRf2LvD0NTCk7zrNu0qoiNa7bMzQdMSHyrrk9P
vGBj3aVgXb1DFPzdZno2qJyNsylbvU8aU9A3/HKHRQUbr29/u3DViIIX0eJ/
JKvZqHDW8X1sSIHHn7mQ2gY2wiY6zH7rU6BfeMQ4upGN0rd1ymrEm09VCjq2
sPFJMHmpnx4FA5SoR5yd5Pksto4R0qWgNPirQ2c3G6qh/YYeByiI3mW39WkP
GwnyId/adCjwmqtnefezkagsE7eT2CBVvkhriI2I+xHyz/dTIGUd4yfwno3m
Fb6lksQcfH80RsfYUF+ToZqmTUHZhZZ3AXQ2xOK+8FbtoyBGbnuUyQwbZ7rC
T1kTnxl9aC7OZmOzgmvxTy0KDB9wiXz4wMaGnzpfUoilDU8PV35m46Fp35bD
xFwLu1Juf2VjWqTXkI94pHiX6/EfbCzgnHdo30tBuetTBcXfbPAEvz8dR/xA
bPmXv3/ZuM/Uc3Yl/h+2fa6y
          "]]}, Annotation[#, "Charting`Private`Tag$72182#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          Hue[0.25, 1, 0.55]], 
         LineBox[CompressedData["
1:eJwV13k8VF0YB3BJJRUlLbaQpcgWUkp+RSrRolQoS6hoUSqlRVRIKL0lCaEs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          "]]}, Annotation[#, "Charting`Private`Tag$72182#3"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 0}}, PlotRangeClipping -> True, 
     ImagePadding -> {{75, 10}, {80, 15}}, DisplayFunction -> Identity, 
     AspectRatio -> 1, Axes -> {True, True}, AxesLabel -> {None, None}, 
     AxesOrigin -> {0, 0}, 
     BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
     DisplayFunction :> Identity, Epilog -> {
       Dashing[{Small, Small}], 
       LineBox[{{0, 0.8}, {10, 0.8}}], 
       Dashing[{Small, Small}], 
       LineBox[{{0, 0.2}, {10, 0.2}}], 
       RGBColor[1, 0, 0], 
       Dashing[{Small, Small}], 
       LineBox[{{0.6, 0}, {0.6, 1}}]}, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox[
         "\"\\!\\(\\*FractionBox[SubscriptBox[\\(v\\), \\(pfk\\)], \
SubscriptBox[\\(V\\), \\(pfk\\)]]\\)\"", HoldForm], TraditionalForm], None}, {
       
        FormBox[
         TagBox[
         "\"\\!\\(\\*FractionBox[\\(ATP\\), SubscriptBox[\\(A\\), \\(TOT\\)]]\
\\)\"", HoldForm], TraditionalForm], None}}, FrameStyle -> Directive[
       GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImagePadding -> {{75, 10}, {80, 15}}, ImageSize -> 
     400, Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 0.9999999795918367}, {0., 1.}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {Automatic, Automatic}}, Prolog -> {
       RGBColor[
        NCache[{
          Rational[223, 255], 
          Rational[72, 85], 
          Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
         0.7843137254901961}]], 
       RectangleBox[
        Scaled[{0, 0}], 
        Scaled[{1, 1}]]}, RotateLabel -> False, 
     Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"F6P=0.044 mM, F26bP=0.001 mM\"", "\"F6P=0.26 mM, F26bP=0.001 mM\"", 
       "\"F6P=0.1 mM, F26bP=0.02 mM\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.55, 1, 0.7]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.55, 1, 0.7]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.038000000000000006`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.06, 1, 0.9]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.06, 1, 0.9]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.038000000000000006`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.25, 1, 0.55]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.25, 1, 0.55]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.038000000000000006`] -> 
                    Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Helvetica", FontSize -> 12}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.55, 1, 0.7]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.06, 1, 0.9]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.25, 1, 0.55]|>, 
                    "HueColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"FontFamily", "\[Rule]", "\"Helvetica\""}], ",", 
                 RowBox[{"FontSize", "\[Rule]", "12"}]}], "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"\"Column\"", ",", "1"}], "}"}]}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.610440881603855*^9, 3.61044092680304*^9}, {
   3.610440965511895*^9, 3.610440996381521*^9}, {3.610441032139903*^9, 
   3.6104415202357616`*^9}, {3.610441558447526*^9, 3.610441616706769*^9}, 
   3.6104416761396103`*^9, {3.6104417655106363`*^9, 3.610441797879064*^9}, {
   3.610441831969211*^9, 3.6104419876617937`*^9}, {3.610442038793054*^9, 
   3.610442218841879*^9}, {3.6104423419608603`*^9, 3.610442517349468*^9}, 
   3.610600534998691*^9, 3.6106404545601482`*^9, {3.610678955574491*^9, 
   3.6106790117082872`*^9}, {3.6106790450876017`*^9, 3.610679228147265*^9}, {
   3.610679262244659*^9, 3.610679324750491*^9}, {3.610679364749713*^9, 
   3.610679371057025*^9}, 3.610679589294177*^9, 3.610679958450539*^9, 
   3.610692483872857*^9, {3.610693687976095*^9, 3.610693701374193*^9}, {
   3.610693770825165*^9, 3.61069381253309*^9}, 3.610717777786059*^9, {
   3.6107179318299427`*^9, 3.610717980830243*^9}, {3.610802547023198*^9, 
   3.610802594813374*^9}, 3.895303151644862*^9, {3.895303625455866*^9, 
   3.895303645771038*^9}, 3.8953041009647913`*^9},
 CellLabel->
  "Out[261]=",ExpressionUUID->"b2ec2088-8135-413d-8167-c90962eaf1d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"vpfknum", "/.", 
          RowBox[{"atp", "\[Rule]", "3"}]}], "/.", 
         RowBox[{"f16bp", "\[Rule]", "0"}]}], "/.", 
        RowBox[{"f26bp", "\[Rule]", "0.0001"}]}], ",", "\[IndentingNewLine]", 
       
       RowBox[{
        RowBox[{
         RowBox[{"vpfknum", "/.", 
          RowBox[{"atp", "\[Rule]", "3"}]}], "/.", 
         RowBox[{"f16bp", "\[Rule]", "0"}]}], "/.", 
        RowBox[{"f26bp", "\[Rule]", "0.001"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"vpfknum", "/.", 
          RowBox[{"atp", "\[Rule]", "3"}]}], "/.", 
         RowBox[{"f16bp", "\[Rule]", "0"}]}], "/.", 
        RowBox[{"f26bp", "\[Rule]", "0.02"}]}]}], "}"}], 
     "\[IndentingNewLine]", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"f6p", ",", "0", ",", "0.7"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.2"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<F6P [mM]\>\"", ",", 
       "\"\<\!\(\*FractionBox[SubscriptBox[\(v\), \(pfk\)], \
SubscriptBox[\(V\), \(pfk\)]]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"Placed", "[", 
      RowBox[{
       RowBox[{"LineLegend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "\"\<F26bP=0.000125 mM, ATP=3 mM\>\"", ",", 
           "\"\<F26bP=0.001 mM, ATP=3 mM\>\"", ",", 
           "\"\<F26bP=0.02 mM, ATP=3 mM\>\""}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Column\>\"", ",", "1"}], "}"}]}], ",", 
         RowBox[{"LabelStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "}"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.35", ",", "0.875"}], "}"}]}], "]"}]}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.47", ",", "0.22"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.19", ",", "0.78"}], "}"}]}], "}"}], "]"}], ",", 
       "Dashed", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10", ",", "0.8"}], "}"}]}], "}"}], "]"}], ",", "Dashed", 
       ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10", ",", "0.2"}], "}"}]}], "}"}], "]"}], ",", "Red", ",",
        "Dashed", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"5", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/PFK_complex2.pdf\>\"", ",", "%"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.610679398299478*^9, 3.61067956198202*^9}, {
  3.6106796177195377`*^9, 3.610679669461746*^9}, {3.610679743812923*^9, 
  3.6106797622592583`*^9}, {3.610693951532164*^9, 3.610693953438447*^9}, {
  3.610718049792903*^9, 3.610718104152526*^9}, {3.6108026148994093`*^9, 
  3.610802691177451*^9}, {3.895303998223854*^9, 3.895304002853643*^9}, {
  3.895304105427821*^9, 3.895304192908154*^9}},
 CellLabel->
  "In[280]:=",ExpressionUUID->"0f2825d9-ce70-4bb0-bde6-df09079e4ec7"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      TagBox[
       {Hue[0.55, 1, 0.7], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[CompressedData["
1:eJwVkWk81IsChuUqnSwlSU3SMiJLixziWN5QCEVCWY7U2BLZanJkOY6EcpJu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         "]]},
       Annotation[#, "Charting`Private`Tag$77705#1"]& ], 
      TagBox[
       {Hue[0.06, 1, 0.9], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[CompressedData["
1:eJwVkmk4lQkDhg9ppKzR4qhMlmQpayHxRFnGSBgkqSQkMeKgIiSypVFdqLGk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         "]]},
       Annotation[#, "Charting`Private`Tag$77705#2"]& ], 
      TagBox[
       {Hue[0.25, 1, 0.55], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[CompressedData["
1:eJwV1nk81IkbB3Ck7aDo2nIkQpHKtYWSD8JYIishUkooVK6EiixC2rUkdt3r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         "]]},
       Annotation[#, "Charting`Private`Tag$77705#3"]& ]}, {}}, InsetBox[
     TemplateBox[{
      "\"F26bP=0.000125 mM, ATP=3 mM\"", "\"F26bP=0.001 mM, ATP=3 mM\"", 
       "\"F26bP=0.02 mM, ATP=3 mM\""},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.55, 1, 0.7]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.55, 1, 0.7]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.038000000000000006`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.06, 1, 0.9]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.06, 1, 0.9]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.038000000000000006`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.25, 1, 0.55]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 16, FontColor -> GrayLevel[0], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    Hue[0.25, 1, 0.55]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.038000000000000006`] -> 
                    Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Helvetica", FontSize -> 12}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.55, 1, 0.7]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.06, 1, 0.9]|>, 
                    "HueColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
                   RowBox[{"FontColor", "\[Rule]", 
                    
                    TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> Hue[0.25, 1, 0.55]|>, 
                    "HueColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"FontFamily", "\[Rule]", "\"Helvetica\""}], ",", 
                 RowBox[{"FontSize", "\[Rule]", "12"}]}], "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"\"Column\"", ",", "1"}], "}"}]}]}], "]"}]& )], 
     Scaled[{0.35, 0.875}], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->1,
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
   DisplayFunction->Identity,
   Epilog->{
     ArrowBox[{{0.47, 0.22}, {0.19, 0.78}}], 
     Dashing[{Small, Small}], 
     LineBox[{{0, 0.8}, {10, 0.8}}], 
     Dashing[{Small, Small}], 
     LineBox[{{0, 0.2}, {10, 0.2}}], 
     RGBColor[1, 0, 0], 
     Dashing[{Small, Small}], 
     LineBox[{{5, 0}, {5, 1}}]},
   Frame->{{True, True}, {True, True}},
   FrameLabel->{{
      FormBox[
       TagBox[
       "\"\\!\\(\\*FractionBox[SubscriptBox[\\(v\\), \\(pfk\\)], \
SubscriptBox[\\(V\\), \\(pfk\\)]]\\)\"", HoldForm], TraditionalForm], None}, {
     
      FormBox[
       TagBox["\"F6P [mM]\"", HoldForm], TraditionalForm], None}},
   FrameStyle->Directive[
     GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->{{75, 10}, {80, 15}},
   ImageSize->400,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{0., 0.6999999857142857}, {0., 1.2}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Prolog->{
     RGBColor[
      NCache[{
        Rational[223, 255], 
        Rational[72, 85], 
        Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
       0.7843137254901961}]], 
     RectangleBox[
      Scaled[{0, 0}], 
      Scaled[{1, 1}]]},
   RotateLabel->False,
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           Hue[0.55, 1, 0.7]], 
          Line[CompressedData["
1:eJwVkWk81IsChuUqnSwlSU3SMiJLixziWN5QCEVCWY7U2BLZanJkOY6EcpJu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           "]]}, "Charting`Private`Tag$77705#1"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           Hue[0.06, 1, 0.9]], 
          Line[CompressedData["
1:eJwVkmk4lQkDhg9ppKzR4qhMlmQpayHxRFnGSBgkqSQkMeKgIiSypVFdqLGk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           "]]}, "Charting`Private`Tag$77705#2"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           Hue[0.25, 1, 0.55]], 
          Line[CompressedData["
1:eJwV1nk81IkbB3Ck7aDo2nIkQpHKtYWSD8JYIishUkooVK6EiixC2rUkdt3r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           "]]}, "Charting`Private`Tag$77705#3"]}}, {}}, {
     DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
      AxesOrigin -> {0, 0}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, DisplayFunction -> Identity, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}}, PlotRangeClipping -> True, 
      ImagePadding -> {{75, 10}, {80, 15}}, DisplayFunction -> Identity, 
      AspectRatio -> 1, Axes -> {True, True}, AxesLabel -> {None, None}, 
      AxesOrigin -> {0, 0}, 
      BaseStyle -> {FontSize -> 16, FontColor -> GrayLevel[0]}, 
      DisplayFunction :> Identity, Epilog -> {
        Arrow[{{0.47, 0.22}, {0.19, 0.78}}], 
        Dashing[{Small, Small}], 
        Line[{{0, 0.8}, {10, 0.8}}], 
        Dashing[{Small, Small}], 
        Line[{{0, 0.2}, {10, 0.2}}], 
        RGBColor[1, 0, 0], 
        Dashing[{Small, Small}], 
        Line[{{5, 0}, {5, 1}}]}, Frame -> {{True, True}, {True, True}}, 
      FrameLabel -> {{
         HoldForm[
         "\!\(\*FractionBox[SubscriptBox[\(v\), \(pfk\)], SubscriptBox[\(V\), \
\(pfk\)]]\)"], None}, {
         HoldForm["F6P [mM]"], None}}, FrameStyle -> Directive[
        GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"], 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], ImagePadding -> {{75, 10}, {80, 15}}, ImageSize -> 
      400, Method -> {
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, 
      PlotRange -> {{0., 0.6999999857142857}, {0., 1.2}}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {Automatic, Automatic}}, Prolog -> {
        RGBColor[{
          Rational[223, 255], 
          Rational[72, 85], 
          Rational[40, 51]}], 
        Rectangle[
         Scaled[{0, 0}], 
         Scaled[{1, 1}]]}, RotateLabel -> False, 
      Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         Hue[0.55, 1, 0.7]], 
        Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         Hue[0.06, 1, 0.9]], 
        Directive[FontSize -> 16, FontColor -> GrayLevel[0], 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         Hue[0.25, 1, 0.55]]}, {
       "F26bP=0.000125 mM, ATP=3 mM", "F26bP=0.001 mM, ATP=3 mM", 
        "F26bP=0.02 mM, ATP=3 mM"}, LegendMarkers -> None, 
       LabelStyle -> {FontFamily -> "Helvetica", FontSize -> 12}, 
       LegendLayout -> {"Column", 1}]], {0.35, 0.875}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.610679433062402*^9, {3.610679478504167*^9, 3.610679670083871*^9}, {
   3.610679746884036*^9, 3.6106797626287117`*^9}, 3.6106798144881897`*^9, 
   3.6106799611038933`*^9, {3.610693948418879*^9, 3.610693954554427*^9}, 
   3.61071778073829*^9, 3.6107179885717583`*^9, {3.610718075230266*^9, 
   3.6107181044485683`*^9}, {3.610802604662862*^9, 3.610802691626975*^9}, 
   3.8953031517169323`*^9, {3.89530362710491*^9, 3.895303645842222*^9}, 
   3.89530400333598*^9, 3.895304106060645*^9, {3.895304148323073*^9, 
   3.895304193332411*^9}},
 CellLabel->
  "Out[280]=",ExpressionUUID->"6c1429ff-f7dc-484f-bdfb-2f8804d2dad7"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/PFK_complex2.pdf\"\>"], "Output",
 CellChangeTimes->{
  3.610679433062402*^9, {3.610679478504167*^9, 3.610679670083871*^9}, {
   3.610679746884036*^9, 3.6106797626287117`*^9}, 3.6106798144881897`*^9, 
   3.6106799611038933`*^9, {3.610693948418879*^9, 3.610693954554427*^9}, 
   3.61071778073829*^9, 3.6107179885717583`*^9, {3.610718075230266*^9, 
   3.6107181044485683`*^9}, {3.610802604662862*^9, 3.610802691626975*^9}, 
   3.8953031517169323`*^9, {3.89530362710491*^9, 3.895303645842222*^9}, 
   3.89530400333598*^9, 3.895304106060645*^9, {3.895304148323073*^9, 
   3.895304193552609*^9}},
 CellLabel->
  "Out[281]=",ExpressionUUID->"23aeed30-ad64-4c75-b47a-8e0980c76ac1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Conclusion: 
The role of F26bP regulation of PFK is to:
1. accelerate glycosis by lowering [F6P] and hereby relieving inhibition of \
enzymes upstream of PFK,
2. a consequence of this is that flux control shifts to glucose transporter + \
HK + PGI (most of the flux control was already within this block due to lack \
of inhibition of PFK),
3. reduce ATP inhibition of PFK, allowing for (transiently) higher ATP \
concentrations. 
We assumed conservation of adenine nucleotides, AK equilibrium, and that \
F16bP influence of PFK can be neglected.

So, when glucose increases, PFK2 is activated via RAS/cAMP/PKA signaling such \
that F6P +ATP => ADP+ F26bP: F6P decreases and F26bP increases. Still, PFK is \
activated even though F6P is a substrate. The affinity of PFK increases as \
well as its apparent Hill coefficient, so F6P becomes more homeostatic. At \
lower F6P, the enzymes upstream of PFK can work faster. This in combination \
with the higher sensitivity of PFK for F6P shifts flux control to enzymes \
upstream of PFK. Accompanying these effects is that PFK becomes less \
sensitive to ATP inhibition, which could be transiently advantageous if \
anabolic processes are activated in a delayed manner.

A lot of this is speculation as the full dynamic model of glycolysis was not \
considered here. However, obtaining a full kinetic understanding of \
glycolysis -- one that is completely validated by both enzyme kinetics, \
specific enzyme activity, metabolomics and flux measurements -- is certainly \
doable but remains to be done. Only then can we truly assess the functional \
role of this magnificently regulated PFK.

A \[OpenCurlyDoubleQuote]dangerous\[CloseCurlyDoubleQuote] consequence of \
shifting control to supply in yeast is that lower and upper glycolysis can \
run out of balance causing the accumulation of F16bP. This is the trade off \
of glucose sensitivity.

How does glucose signaling contribute to flux control of upper glycolysis?\
\>", "Subsubsection",
 CellChangeTimes->{{3.6106804305561333`*^9, 3.6106805353872137`*^9}, {
  3.610680612642375*^9, 3.610680820861058*^9}, {3.6106808546524267`*^9, 
  3.61068140046422*^9}, {3.610685507164193*^9, 3.610685507231127*^9}, {
  3.610685689621847*^9, 
  3.610685706124872*^9}},ExpressionUUID->"166dfc01-f397-4a9a-b39d-\
435b83b3415b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"atp", "+", " ", 
             RowBox[{
              FractionBox["1", "2"], "adp"}]}], 
            RowBox[{"atp", "+", "adp", "+", "amp"}]], "/.", "relation"}], "/.",
           "parameters"}], ",", "vpfknum"}], "}"}], "/.", 
       RowBox[{"f16bp", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"f6p", "\[Rule]", "0.15"}]}], "/.", 
     RowBox[{"f26bp", "\[Rule]", "0.02"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"atp", ",", "0", ",", 
     RowBox[{"At", "/.", "parameters"}]}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<EC\>\"", ",", 
      "\"\<\!\(\*FractionBox[SubscriptBox[\(v\), \(pfk\)], \
SubscriptBox[\(V\), \(PFK\)]]\)\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/frankbruggeman/Library/CloudStorage/Dropbox/from enzyme \
kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/PFK_complex3.pdf\>\"", ",", "%"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.610694848318142*^9, 3.610695119691073*^9}, {
  3.610695151410562*^9, 3.610695152553851*^9}, {3.610695189417493*^9, 
  3.610695189577395*^9}, {3.610695220730516*^9, 3.610695278943397*^9}, {
  3.8953040145255013`*^9, 3.895304017743572*^9}},
 CellLabel->
  "In[254]:=",ExpressionUUID->"54a72d0d-3f07-4188-932b-638a0eaca1b0"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {Hue[0.6, 0.5, 0.9], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
      Opacity[0.3]], LineBox[CompressedData["
1:eJwV13c81V8YB3AqaZGUtsrOKlIU8SFEImXEj0pDaKFUyigqRFlJpCUjopRE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       "]]},
     Annotation[#, "Charting`Private`Tag$70028#1"]& ], {}}, {}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 16, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*FractionBox[SubscriptBox[\\(v\\), \\(pfk\\)], SubscriptBox[\
\\(V\\), \\(PFK\\)]]\\)\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"EC\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Directive[
    GrayLevel[0], 18, Thickness -> 0.0025, PlotTheme -> "Marketing"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{75, 10}, {80, 15}},
  ImageSize->400,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{0, 1}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Prolog->{
    RGBColor[
     NCache[{
       Rational[223, 255], 
       Rational[72, 85], 
       Rational[40, 51]}, {0.8745098039215686, 0.8470588235294118, 
      0.7843137254901961}]], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  RotateLabel->False,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.610694973087064*^9, 3.610694991847006*^9}, {
   3.6106950268709087`*^9, 3.610695120011104*^9}, 3.610695156485291*^9, 
   3.610695191155514*^9, {3.610695223251606*^9, 3.610695280316574*^9}, 
   3.6107177870550547`*^9, 3.6108027070735807`*^9, 3.895303151795273*^9, {
   3.8953036316900787`*^9, 3.895303645901822*^9}, 3.895304018306449*^9},
 CellLabel->
  "Out[254]=",ExpressionUUID->"8e3a461c-0f5a-43c1-85ce-4a0949321192"],

Cell[BoxData["\<\"/Users/frankbruggeman/Library/CloudStorage/Dropbox/from \
enzyme kinetics to models of metabolic networks course material/course \
syllabus/syllabus/figures/PFK_complex3.pdf\"\>"], "Output",
 CellChangeTimes->{{3.610694973087064*^9, 3.610694991847006*^9}, {
   3.6106950268709087`*^9, 3.610695120011104*^9}, 3.610695156485291*^9, 
   3.610695191155514*^9, {3.610695223251606*^9, 3.610695280316574*^9}, 
   3.6107177870550547`*^9, 3.6108027070735807`*^9, 3.895303151795273*^9, {
   3.8953036316900787`*^9, 3.895303645901822*^9}, 3.895304018493581*^9},
 CellLabel->
  "Out[255]=",ExpressionUUID->"36e911af-4000-4b19-873c-408134a0f8bc"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1416, 944},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"13.2 for Mac OS X ARM (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"4b5c6b1b-1d24-4586-888b-9b486cb4a4b0"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 3651, 95, 98, "Input",ExpressionUUID->"57b5339f-eb9e-4680-85c2-ef87faa235a4"],
Cell[4211, 117, 263, 6, 35, "Text",ExpressionUUID->"a8131784-628e-43fa-8d0f-cf5dfbaa9746"],
Cell[CellGroupData[{
Cell[4499, 127, 1375, 35, 175, "Input",ExpressionUUID->"963de64c-2295-4f65-9d47-6dcf741ea616"],
Cell[5877, 164, 2649, 74, 106, "Output",ExpressionUUID->"164410ba-1083-4f25-b478-30387da24850"],
Cell[8529, 240, 1397, 30, 34, "Output",ExpressionUUID->"839d9b86-fdad-4898-8960-bfd418d61c29"],
Cell[9929, 272, 1531, 39, 55, "Output",ExpressionUUID->"e760bd4b-1a10-4e71-8f86-a1668508ad0d"]
}, Open  ]],
Cell[11475, 314, 972, 26, 120, "Text",ExpressionUUID->"04b8e26f-56ca-4093-8644-63bc032d0704"],
Cell[12450, 342, 374, 10, 30, "Input",ExpressionUUID->"bb0a1e5f-f2ab-4b49-b512-4f73de9a1a48"],
Cell[12827, 354, 537, 10, 58, "Text",ExpressionUUID->"fa745040-7be1-4dfe-ac43-9b6203d48ab7"],
Cell[CellGroupData[{
Cell[13389, 368, 1345, 35, 73, "Input",ExpressionUUID->"2defc8bf-f292-452b-9ed0-367ce7b4cded"],
Cell[14737, 405, 34546, 653, 427, "Output",ExpressionUUID->"a297f391-e3d4-4c74-8fdf-a8cdcaaf95a3"]
}, Open  ]],
Cell[49298, 1061, 156, 3, 35, "Text",ExpressionUUID->"3f4f34ad-e1da-446e-bf67-4fe97f87aa62"],
Cell[49457, 1066, 3732, 91, 410, "Input",ExpressionUUID->"0c9a0ab9-bf4a-43f1-94ce-0366c5419292"],
Cell[CellGroupData[{
Cell[53214, 1161, 484, 12, 30, "Input",ExpressionUUID->"ad5c91b4-46c5-4ad8-aa07-0a2558833f91"],
Cell[53701, 1175, 3154, 82, 72, "Output",ExpressionUUID->"fb1a1024-406f-4d6b-acc7-1c222e431ef6"]
}, Open  ]],
Cell[56870, 1260, 318, 7, 35, "Text",ExpressionUUID->"c35ee253-ac26-4a35-8582-217cec0c7fc4"],
Cell[CellGroupData[{
Cell[57213, 1271, 1581, 37, 82, "Input",ExpressionUUID->"bc857e87-179a-4ebb-b6e0-dadb01894ccc"],
Cell[58797, 1310, 244805, 4126, 427, "Output",ExpressionUUID->"c6fb58de-6da8-4137-96d3-d3304765b887"]
}, Open  ]],
Cell[303617, 5439, 2538, 58, 83, "Input",ExpressionUUID->"6288c271-fb90-47c5-ab9e-03550054989e"],
Cell[306158, 5499, 2609, 62, 136, "Input",ExpressionUUID->"b090f9fc-e56a-496d-9614-db3e95ec8222"],
Cell[CellGroupData[{
Cell[308792, 5565, 205, 3, 45, "Subsubsection",ExpressionUUID->"1c68f249-0edb-4043-9158-49b5e78e0d53"],
Cell[CellGroupData[{
Cell[309022, 5572, 365, 10, 73, "Input",ExpressionUUID->"aa4b37d5-e34f-443b-9394-f5ad52322d62"],
Cell[309390, 5584, 188682, 3295, 437, "Output",ExpressionUUID->"3dc237de-9da2-4151-a3eb-fee5d285d790"]
}, Open  ]],
Cell[CellGroupData[{
Cell[498109, 8884, 1283, 24, 115, "Input",ExpressionUUID->"96463ce2-6f3b-4bf1-abc2-fd733ea7d279"],
Cell[499395, 8910, 143437, 2515, 444, "Output",ExpressionUUID->"722ed864-9135-4764-9f2a-f84b32711b30"],
Cell[642835, 11427, 876, 13, 56, "Output",ExpressionUUID->"8b443ea2-62df-4c4f-a9fa-5c9143248372"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[643760, 11446, 350, 7, 45, "Subsubsection",ExpressionUUID->"aa8aaaf6-854e-431c-8ab8-c77b2a00d290"],
Cell[CellGroupData[{
Cell[644135, 11457, 4514, 113, 239, "Input",ExpressionUUID->"ce4c241c-8189-4835-b1fa-e3ffa7c0c7d2"],
Cell[648652, 11572, 40143, 729, 429, "Output",ExpressionUUID->"b2ec2088-8135-413d-8167-c90962eaf1d3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[688832, 12306, 4114, 107, 322, "Input",ExpressionUUID->"0f2825d9-ce70-4bb0-bde6-df09079e4ec7"],
Cell[692949, 12415, 31538, 629, 427, "Output",ExpressionUUID->"6c1429ff-f7dc-484f-bdfb-2f8804d2dad7"],
Cell[724490, 13046, 849, 13, 104, "Output",ExpressionUUID->"23aeed30-ad64-4c75-b47a-8e0980c76ac1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[725388, 13065, 2326, 42, 591, "Subsubsection",ExpressionUUID->"166dfc01-f397-4a9a-b39d-435b83b3415b"],
Cell[CellGroupData[{
Cell[727739, 13111, 1792, 48, 168, "Input",ExpressionUUID->"54a72d0d-3f07-4188-932b-638a0eaca1b0"],
Cell[729534, 13161, 11362, 208, 427, "Output",ExpressionUUID->"8e3a461c-0f5a-43c1-85ce-4a0949321192"],
Cell[740899, 13371, 651, 9, 56, "Output",ExpressionUUID->"36e911af-4000-4b19-873c-408134a0f8bc"]
}, Open  ]]
}, Open  ]]
}
]
*)

